@@ -598,16 +598,7 @@ jj currently does not support partial clones. To use jj with this repository, tr
                     err,
                     "Specify patterns in `(positive | ...) & ~(negative | ...)` form.",
                 ),
-                GitRefExpansionError::InvalidBranchPattern(pattern) => {
-                    if pattern.as_exact().is_some_and(|s| s.contains('*')) {
-                        user_error_with_hint(
-                            "Branch names may not include `*`.",
-                            "Prefix the pattern with `glob:` to expand `*` as a glob",
-                        )
-                    } else {
-                        user_error(err)
-                    }
-                }
+                GitRefExpansionError::InvalidBranchPattern(_) => user_error(err),
             }
         }
     }
@@ -811,7 +802,10 @@ fn bookmark_name_parse_error_hint(err: &BookmarkNameParseError) -> Option<String
     use revset::ExpressionKind;
     match revset::parse_program(&err.input).map(|node| node.kind) {
         Ok(ExpressionKind::RemoteSymbol(symbol)) => Some(format!(
-            "Looks like remote bookmark. Run `jj bookmark track {symbol}` to track it."
+            "Looks like remote bookmark. Run `jj bookmark track {name} --remote={remote}` to \
+             track it.",
+            name = symbol.name.as_symbol(),
+            remote = symbol.remote.as_symbol()
         )),
         _ => Some(REVSET_SYMBOL_HINT.to_owned()),
     }
@@ -921,8 +915,17 @@ fn revset_resolution_error_hints(err: &RevsetResolutionError) -> Vec<String> {
             name: _,
             candidates,
         } => format_similarity_hint(candidates).into_iter().collect(),
-        RevsetResolutionError::DivergentChangeId { symbol, targets } => vec![
-            multiple_targets_hint(targets),
+        RevsetResolutionError::DivergentChangeId {
+            symbol,
+            visible_targets,
+        } => vec![
+            format!(
+                "Use change offset to select single revision: {}",
+                visible_targets
+                    .iter()
+                    .map(|(offset, _)| format!("{symbol}/{offset}"))
+                    .join(", ")
+            ),
             format!("Use `change_id({symbol})` to select all revisions"),
             "To abandon unneeded revisions, run `jj abandon <commit_id>`".to_owned(),
         ],
@@ -932,7 +935,7 @@ fn revset_resolution_error_hints(err: &RevsetResolutionError) -> Vec<String> {
             targets,
         } => vec![
             multiple_targets_hint(targets),
-            format!("Use `bookmarks(exact:{symbol})` to select all revisions"),
+            format!("Use `bookmarks({symbol})` to select all revisions"),
             format!(
                 "To set which revision the bookmark points to, run `jj bookmark set {symbol} -r \
                  <REVISION>`"
