@@ -52,8 +52,8 @@ use crate::ui::Ui;
 ///
 /// Example: To run `cargo test` with the changes from revision `xyz` applied:
 ///
-/// `jj bisect --range v1.0..main -- bash -c "jj duplicate -r xyz -B @ && cargo
-/// test"`
+/// `jj bisect run --range v1.0..main -- bash -c "jj duplicate -r xyz -B @ &&
+/// cargo test"`
 #[derive(clap::Args, Clone, Debug)]
 pub(crate) struct BisectRunArgs {
     /// Range of revisions to bisect
@@ -61,14 +61,10 @@ pub(crate) struct BisectRunArgs {
     /// This is typically a range like `v1.0..main`. The heads of the range are
     /// assumed to be bad. Ancestors of the range that are not also in the range
     /// are assumed to be good.
-    #[arg(
-        long,
-        short,
-        value_name = "REVSETS",
-        required = true,
-        add = ArgValueCompleter::new(complete::revset_expression_all),
-    )]
+    #[arg(long, short, value_name = "REVSETS", required = true)]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     range: Vec<RevisionArg>,
+
     /// Deprecated. Use positional arguments instead.
     #[arg(
         long = "command",
@@ -117,7 +113,7 @@ pub(crate) fn cmd_bisect_run(
         writeln!(
             ui.warning_default(),
             "`--command` is deprecated; use positional arguments instead: `jj bisect run \
-             --range=... -- {command}"
+             --range=... -- {command}`"
         )?;
     } else if args.command.is_none() {
         return Err(cli_error("Command argument is required"));
