@@ -32,12 +32,13 @@ use crate::ui::Ui;
 pub struct BookmarkCreateArgs {
     /// The bookmark's target revision
     #[arg(
-        long, short,
+        long,
+        short,
         default_value = "@",
         visible_alias = "to",
-        value_name = "REVSET",
-        add = ArgValueCompleter::new(complete::revset_expression_all),
+        value_name = "REVSET"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     revision: RevisionArg,
 
     /// The bookmarks to create
@@ -70,7 +71,7 @@ pub fn cmd_bookmark_create(
                 ),
                 format!(
                     "Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark \
-                     untrack 'glob:{name}@*'` to disassociate them.",
+                     untrack {name}` to disassociate them.",
                     name = name.as_symbol()
                 ),
             ));
@@ -82,12 +83,14 @@ pub fn cmd_bookmark_create(
 
     let mut tx = workspace_command.start_transaction();
     let remote_settings = tx.settings().remote_settings()?;
+    let remote_auto_track_matchers =
+        revset_util::parse_remote_auto_track_bookmarks_map(ui, &remote_settings)?;
     let readonly_repo = tx.base_repo().clone();
     for name in bookmark_names {
         tx.repo_mut()
             .set_local_bookmark_target(name, RefTarget::normal(target_commit.id().clone()));
-        for (remote_name, settings) in &remote_settings {
-            if !settings.auto_track_bookmarks.is_match(name.as_str()) {
+        for (remote_name, matcher) in &remote_auto_track_matchers {
+            if !matcher.is_match(name.as_str()) {
                 continue;
             }
             let Some(view) = readonly_repo.view().get_remote_view(remote_name) else {
