@@ -36,10 +36,8 @@ use crate::ui::Ui;
 #[derive(clap::Args, Clone, Debug)]
 pub struct BookmarkRenameArgs {
     /// The old name of the bookmark
-    #[arg(
-        value_parser = revset_util::parse_bookmark_name,
-        add = ArgValueCandidates::new(complete::local_bookmarks),
-    )]
+    #[arg(value_parser = revset_util::parse_bookmark_name)]
+    #[arg(add = ArgValueCandidates::new(complete::local_bookmarks))]
     old: RefNameBuf,
 
     /// The new name of the bookmark
@@ -119,8 +117,10 @@ pub fn cmd_bookmark_rename(
             )?;
             writeln!(
                 ui.hint_default(),
-                "To track the existing remote bookmark, run `jj bookmark track \
-                 {new_remote_bookmark}`",
+                "To track the existing remote bookmark, run `jj bookmark track {name} \
+                 --remote={remote}`",
+                name = new_remote_bookmark.name.as_symbol(),
+                remote = new_remote_bookmark.remote.as_symbol()
             )?;
             continue;
         }
@@ -162,9 +162,8 @@ pub fn cmd_bookmark_rename(
         )?;
         writeln!(
             ui.hint_default(),
-            "Run `jj bookmark untrack 'glob:{new_bookmark}@*'` to disassociate them.",
-            // TODO: use .as_symbol() if pattern parser is ported to revset
-            new_bookmark = new_bookmark.as_str()
+            "Run `jj bookmark untrack {new_bookmark}` to disassociate them.",
+            new_bookmark = new_bookmark.as_symbol()
         )?;
     }
 
