@@ -37,46 +37,49 @@ use crate::ui::Ui;
 /// When called without path arguments or `--interactive`, `jj commit` is
 /// equivalent to `jj describe` followed by `jj new`.
 ///
-/// Otherwise, this command is very similar to `jj split`. Differences include:
+/// When using `--interactive` or path arguments, the selected changes stay in
+/// the current commit while the remaining changes are moved to a new
+/// working-copy commit on top. This is very similar to `jj split`. Differences
+/// include:
 ///
 /// * `jj commit` is not interactive by default (it selects all changes).
 ///
 /// * `jj commit` doesn't have a `-r` option. It always acts on the working-copy
 ///   commit (@).
 ///
-/// * `jj split` (without `-d/-A/-B`) will move bookmarks forward from the old
-///   change to the child change. `jj commit` doesn't move bookmarks forward.
+/// * `jj split` (without `-o`/`-A`/`-B`) will move bookmarks forward from the
+///   old change to the child change. `jj commit` doesn't move bookmarks
+///   forward.
 ///
 /// * `jj split` allows you to move the selected changes to a different
-///   destination with `-d/-A/-B`.
+///   destination with `-o`/`-A`/`-B`.
 #[derive(clap::Args, Clone, Debug)]
 pub(crate) struct CommitArgs {
-    /// Interactively choose which changes to include in the first commit
+    /// Interactively choose which changes to include in the current commit
     #[arg(short, long)]
     interactive: bool,
+
     /// Specify diff editor to be used (implies --interactive)
-    #[arg(
-        long,
-        value_name = "NAME",
-        add = ArgValueCandidates::new(complete::diff_editors),
-    )]
+    #[arg(long, value_name = "NAME")]
+    #[arg(add = ArgValueCandidates::new(complete::diff_editors))]
     tool: Option<String>,
+
     /// The change description to use (don't open editor)
     #[arg(long = "message", short, value_name = "MESSAGE")]
     message_paragraphs: Vec<String>,
+
     /// Open an editor to edit the change description
     ///
     /// Forces an editor to open when using `--message` to allow the
     /// message to be edited afterwards.
     #[arg(long)]
     editor: bool,
-    /// Put these paths in the first commit
-    #[arg(
-        value_name = "FILESETS",
-        value_hint = clap::ValueHint::AnyPath,
-        add = ArgValueCompleter::new(complete::modified_files),
-    )]
+
+    /// Put these paths in the current commit
+    #[arg(value_name = "FILESETS", value_hint = clap::ValueHint::AnyPath)]
+    #[arg(add = ArgValueCompleter::new(complete::modified_files))]
     paths: Vec<String>,
+
     // TODO: Delete in jj 0.40.0+
     /// Reset the author to the configured user
     ///
@@ -88,6 +91,7 @@ pub(crate) struct CommitArgs {
     /// $ JJ_USER='Foo Bar' JJ_EMAIL=foo@bar.com jj commit --reset-author
     #[arg(long, hide = true)]
     reset_author: bool,
+
     // TODO: Delete in jj 0.40.0+
     /// Set author to the provided string
     ///
