@@ -37,19 +37,23 @@ pub struct ConfigListArgs {
     /// An optional name of a specific config option to look up.
     #[arg(add = ArgValueCandidates::new(complete::config_keys))]
     pub name: Option<ConfigNamePathBuf>,
+
     /// Whether to explicitly include built-in default values in the list.
     #[arg(long, conflicts_with = "config_level")]
     pub include_defaults: bool,
+
     /// Allow printing overridden values.
     #[arg(long)]
     pub include_overridden: bool,
+
     #[command(flatten)]
     pub level: ConfigLevelArgs,
+
     /// Render each variable using the given template
     ///
     /// The following keywords are available in the template expression:
     ///
-    /// * `name: String`: Config name.
+    /// * `name: String`: Config name, in [TOML's "dotted key" format].
     /// * `value: ConfigValue`: Value to be formatted in TOML syntax.
     /// * `overridden: Boolean`: True if the value is shadowed by other.
     /// * `source: String`: Source of the value.
@@ -61,13 +65,12 @@ pub struct ConfigListArgs {
     ///
     /// See [`jj help -k templates`] for more information.
     ///
+    /// [TOML's "dotted key" format]: https://toml.io/en/v1.0.0#keys
+    ///
     /// [`jj help -k templates`]:
     ///     https://docs.jj-vcs.dev/latest/templates/
-    #[arg(
-        long, short = 'T',
-        verbatim_doc_comment,
-        add = ArgValueCandidates::new(complete::template_aliases)
-    )]
+    #[arg(long, short = 'T', verbatim_doc_comment)]
+    #[arg(add = ArgValueCandidates::new(complete::template_aliases))]
     template: Option<String>,
 }
 
