@@ -33,8 +33,10 @@ use crate::ui::Ui;
 /// Update a config file to set the given option to a given value.
 #[derive(clap::Args, Clone, Debug)]
 pub struct ConfigSetArgs {
-    #[arg(required = true, add = ArgValueCandidates::new(complete::leaf_config_keys))]
+    #[arg(required = true)]
+    #[arg(add = ArgValueCandidates::new(complete::leaf_config_keys))]
     name: ConfigNamePathBuf,
+
     /// New value to set
     ///
     /// The value should be specified as a TOML expression. If string value
@@ -49,6 +51,7 @@ pub struct ConfigSetArgs {
     /// edit` to edit the TOML file directly.
     #[arg(required = true, value_parser = parse_value_or_bare_string)]
     value: ConfigValue,
+
     #[command(flatten)]
     level: ConfigLevelArgs,
 }
