@@ -27,8 +27,10 @@ use crate::ui::Ui;
 /// Update a config file to unset the given option.
 #[derive(clap::Args, Clone, Debug)]
 pub struct ConfigUnsetArgs {
-    #[arg(required = true, add = ArgValueCandidates::new(complete::leaf_config_keys))]
+    #[arg(required = true)]
+    #[arg(add = ArgValueCandidates::new(complete::leaf_config_keys))]
     name: ConfigNamePathBuf,
+
     #[command(flatten)]
     level: ConfigLevelArgs,
 }
