@@ -19,6 +19,7 @@ use std::num::NonZeroU32;
 use std::path::Path;
 
 use itertools::Itertools as _;
+use jj_lib::file_util;
 use jj_lib::git;
 use jj_lib::git::FetchTagsOverride;
 use jj_lib::git::GitFetch;
@@ -42,6 +43,7 @@ use crate::command_error::user_error_with_message;
 use crate::commands::git::FetchTagsMode;
 use crate::commands::git::maybe_add_gitignore;
 use crate::git_util::absolute_git_url;
+use crate::git_util::load_git_import_options;
 use crate::git_util::print_git_import_stats;
 use crate::git_util::with_remote_git_callbacks;
 use crate::revset_util::parse_union_name_patterns;
@@ -55,15 +57,18 @@ pub struct GitCloneArgs {
     /// Local path will be resolved to absolute form.
     #[arg(value_hint = clap::ValueHint::Url)]
     source: String,
+
     /// Specifies the target directory for the Jujutsu repository clone.
     /// If not provided, defaults to a directory named after the last component
     /// of the source URL. The full directory path will be created if it
     /// doesn't exist.
     #[arg(value_hint = clap::ValueHint::DirPath)]
     destination: Option<String>,
+
     /// Name of the newly created remote
     #[arg(long = "remote", default_value = "origin")]
     remote_name: RemoteNameBuf,
+
     /// Colocate the Jujutsu repo with the git repo
     ///
     /// Specifies that the `jj` repo should also be a valid `git` repo, allowing
@@ -79,6 +84,7 @@ pub struct GitCloneArgs {
     ///     https://docs.jj-vcs.dev/latest/config/#default-colocation
     #[arg(long)]
     colocate: bool,
+
     /// Disable colocation of the Jujutsu repo with the git repo
     ///
     /// Prevent Git tools that are unaware of `jj` and regular Git commands from
@@ -92,26 +98,35 @@ pub struct GitCloneArgs {
     ///     https://docs.jj-vcs.dev/latest/git-compatibility/#colocated-jujutsugit-repos
     #[arg(long, conflicts_with = "colocate")]
     no_colocate: bool,
+
     /// Create a shallow clone of the given depth
     #[arg(long)]
     depth: Option<NonZeroU32>,
+
     /// Configure when to fetch tags
     ///
     /// Unless otherwise specified, the initial clone will fetch all tags,
     /// while all subsequent fetches will only fetch included tags.
     #[arg(long, value_enum)]
     fetch_tags: Option<FetchTagsMode>,
+
     /// Name of the branch to fetch and use as the parent of the working-copy
     /// change
     ///
     /// If not present, all branches are fetched and the repository's default
     /// branch is used as parent of the working-copy change.
     ///
-    /// By default, the specified name matches exactly. Use `glob:` prefix to
-    /// expand `*` as a glob, e.g. `--branch 'glob:push-*'`. Other wildcard
-    /// characters such as `?` are *not* supported. Can be repeated to specify
-    /// multiple branches, in which case the first exact branch name is used as
-    /// the working-copy parent.
+    /// By default, the specified pattern matches branch names with glob syntax,
+    /// but only `*` is expanded. Other wildcard characters such as `?` are
+    /// *not* supported. Patterns can be repeated or combined with [logical
+    /// operators] to specify multiple branches, but only union and negative
+    /// intersection are supported. If there are multiple matching branches, the
+    /// first exact branch name is used as the working-copy parent.
+    ///
+    /// Examples: `push-*`, `(push-* | foo/*) ~ foo/unwanted`
+    ///
+    /// [logical operators]:
+    ///     https://docs.jj-vcs.dev/latest/revsets/#string-patterns
     #[arg(long, short, alias = "bookmark")]
     branch: Option<Vec<String>>,
 }
@@ -124,14 +139,6 @@ fn clone_destination_for_source(source: &str) -> Option<&str> {
         .map(|(_, name)| name)
 }
 
-fn is_empty_dir(path: &Path) -> bool {
-    if let Ok(mut entries) = path.read_dir() {
-        entries.next().is_none()
-    } else {
-        false
-    }
-}
-
 pub fn cmd_git_clone(
     ui: &mut Ui,
     command: &CommandHelper,
@@ -150,7 +157,7 @@ pub fn cmd_git_clone(
     let wc_path = command.cwd().join(wc_path_str);
 
     let wc_path_existed = wc_path.exists();
-    if wc_path_existed && !is_empty_dir(&wc_path) {
+    if wc_path_existed && !file_util::is_empty_dir(&wc_path)? {
         return Err(user_error(
             "Destination path exists and is not an empty directory",
         ));
@@ -202,9 +209,13 @@ pub fn cmd_git_clone(
     })();
     if clone_result.is_err() {
         let clean_up_dirs = || -> io::Result<()> {
-            fs::remove_dir_all(canonical_wc_path.join(".jj"))?;
-            if colocate {
-                fs::remove_dir_all(canonical_wc_path.join(".git"))?;
+            let sub_dirs = [Some(".jj"), colocate.then_some(".git")];
+            for &name in sub_dirs.iter().flatten() {
+                let dir = canonical_wc_path.join(name);
+                fs::remove_dir_all(&dir).or_else(|err| match err.kind() {
+                    io::ErrorKind::NotFound => Ok(()),
+                    _ => Err(err),
+                })?;
             }
             if !wc_path_existed {
                 fs::remove_dir(&canonical_wc_path)?;
@@ -286,6 +297,7 @@ fn configure_remote(
         tx.repo_mut(),
         remote_name,
         source,
+        None,
         fetch_tags.as_fetch_tags(),
         bookmark_expr,
     )?;
@@ -318,10 +330,13 @@ fn fetch_new_remote(
     )?;
     let settings = workspace_command.settings();
     let git_settings = GitSettings::from_settings(settings)?;
+    let remote_settings = settings.remote_settings()?;
+    let subprocess_options = git_settings.to_subprocess_options();
+    let import_options = load_git_import_options(ui, &git_settings, &remote_settings)?;
     let should_track_default = settings.get_bool("git.track-default-bookmark-on-clone")?;
     let mut tx = workspace_command.start_transaction();
     let (default_branch, import_stats) = {
-        let mut git_fetch = GitFetch::new(tx.repo_mut(), &git_settings)?;
+        let mut git_fetch = GitFetch::new(tx.repo_mut(), subprocess_options, &import_options)?;
 
         let fetch_refspecs = expand_fetch_refspecs(remote_name, bookmark_expr.clone())?;
 
