@@ -79,6 +79,15 @@ use crate::ui::Ui;
 /// bookmarks. Use `--all` to push all bookmarks. Use `--change` to generate
 /// bookmark names based on the change IDs of specific commits.
 ///
+/// When pushing a bookmark, the command pushes all commits in the range from
+/// the remote's current position up to and including the bookmark's target
+/// commit. Any descendant commits beyond the bookmark are not pushed.
+///
+/// If the local bookmark has changed from the last fetch, push will update the
+/// remote bookmark to the new position after passing safety checks. This is
+/// similar to `git push --force-with-lease` - the remote is updated only if its
+/// current state matches what Jujutsu last fetched.
+///
 /// Unlike in Git, the remote to push to is not derived from the tracked remote
 /// bookmarks. Use `--remote` to select the remote Git repository by name. There
 /// is no option to push to multiple remotes.
@@ -102,25 +111,26 @@ pub struct GitPushArgs {
     ///
     /// This defaults to the `git.push` setting. If that is not configured, and
     /// if there are multiple remotes, the remote named "origin" will be used.
-    #[arg(long, add = ArgValueCandidates::new(complete::git_remotes))]
+    #[arg(long)]
+    #[arg(add = ArgValueCandidates::new(complete::git_remotes))]
     remote: Option<RemoteNameBuf>,
+
     /// Push only this bookmark, or bookmarks matching a pattern (can be
     /// repeated)
     ///
-    /// By default, the specified name matches exactly. Use `glob:` prefix to
-    /// select bookmarks by [wildcard pattern].
+    /// By default, the specified pattern matches bookmark names with glob
+    /// syntax. You can also use other [string pattern syntax].
     ///
-    /// [wildcard pattern]:
-    ///     https://docs.jj-vcs.dev/latest/revsets#string-patterns
-    #[arg(
-        long, short,
-        alias = "branch",
-        add = ArgValueCandidates::new(complete::local_bookmarks),
-    )]
+    /// [string pattern syntax]:
+    ///     https://docs.jj-vcs.dev/latest/revsets/#string-patterns
+    #[arg(long, short, alias = "branch")]
+    #[arg(add = ArgValueCandidates::new(complete::local_bookmarks))]
     bookmark: Vec<String>,
+
     /// Push all bookmarks (including new bookmarks)
     #[arg(long)]
     all: bool,
+
     /// Push all tracked bookmarks
     ///
     /// This usually means that the bookmark was already pushed to or fetched
@@ -130,6 +140,7 @@ pub struct GitPushArgs {
     ///     https://docs.jj-vcs.dev/latest/bookmarks#remotes-and-tracked-bookmarks
     #[arg(long)]
     tracked: bool,
+
     /// Push all deleted bookmarks
     ///
     /// Only tracked bookmarks can be successfully deleted on the remote. A
@@ -137,15 +148,18 @@ pub struct GitPushArgs {
     /// correspond to missing local bookmarks.
     #[arg(long, conflicts_with = "specific")]
     deleted: bool,
+
     // TODO: Delete in jj 0.42.0+
     /// Allow pushing new bookmarks
     ///
     /// Newly-created remote bookmarks will be tracked automatically.
     #[arg(long, short = 'N', hide = true, conflicts_with = "what")]
     allow_new: bool,
+
     /// Allow pushing commits with empty descriptions
     #[arg(long)]
     allow_empty_description: bool,
+
     /// Allow pushing commits that are private
     ///
     /// The set of private commits can be configured by the
@@ -153,43 +167,35 @@ pub struct GitPushArgs {
     /// commits are eligible to be pushed.
     #[arg(long)]
     allow_private: bool,
+
     /// Push bookmarks pointing to these commits (can be repeated)
-    #[arg(
-        long,
-        short,
-        value_name = "REVSETS",
-        // While `-r` will often be used with mutable revisions, immutable
-        // revisions can be useful as parts of revsets or to push
-        // special-purpose branches.
-        add = ArgValueCompleter::new(complete::revset_expression_all),
-    )]
+    #[arg(long, short, value_name = "REVSETS")]
+    // While `-r` will often be used with mutable revisions, immutable revisions
+    // can be useful as parts of revsets or to push special-purpose branches.
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     revisions: Vec<RevisionArg>,
+
     /// Push this commit by creating a bookmark (can be repeated)
     ///
     /// The created bookmark will be tracked automatically. Use the
     /// `templates.git_push_bookmark` setting to customize the generated
     /// bookmark name. The default is `"push-" ++ change_id.short()`.
-    #[arg(
-        long,
-        short,
-        value_name = "REVSETS",
-        // I'm guessing that `git push -c` is almost exclusively used with
-        // recently created mutable revisions, even though it can in theory
-        // be used with immutable ones as well. We can change it if the guess
-        // turns out to be wrong.
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
-    )]
+    #[arg(long, short, value_name = "REVSETS")]
+    // I'm guessing that `git push -c` is almost exclusively used with recently
+    // created mutable revisions, even though it can in theory be used with
+    // immutable ones as well. We can change it if the guess turns out to be
+    // wrong.
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     change: Vec<RevisionArg>,
+
     /// Specify a new bookmark name and a revision to push under that name, e.g.
     /// '--named myfeature=@'
     ///
     /// Automatically tracks the bookmark if it is new.
-    #[arg(
-        long,
-        value_name = "NAME=REVISION",
-        add = ArgValueCompleter::new(complete::branch_name_equals_any_revision)
-    )]
+    #[arg(long, value_name = "NAME=REVISION")]
+    #[arg(add = ArgValueCompleter::new(complete::branch_name_equals_any_revision))]
     named: Vec<String>,
+
     /// Only display what will change on the remote
     #[arg(long)]
     dry_run: bool,
@@ -453,56 +459,70 @@ pub fn cmd_git_push(
     };
     let git_settings = GitSettings::from_settings(tx.settings())?;
     let push_stats = with_remote_git_callbacks(ui, |cb| {
-        git::push_branches(tx.repo_mut(), &git_settings, remote, &targets, cb)
+        git::push_branches(
+            tx.repo_mut(),
+            git_settings.to_subprocess_options(),
+            remote,
+            &targets,
+            cb,
+        )
     })?;
-    process_push_stats(&push_stats)?;
-    tx.finish(ui, tx_description)?;
-    Ok(())
+    print_stats(ui, &push_stats)?;
+    // TODO: On partial success, locally-created --change/--named bookmarks will
+    // be committed. It's probably better to remove failed local bookmarks.
+    if push_stats.all_ok() || !push_stats.pushed.is_empty() {
+        tx.finish(ui, tx_description)?;
+    }
+    if push_stats.all_ok() {
+        Ok(())
+    } else {
+        Err(user_error("Failed to push some bookmarks"))
+    }
 }
 
-fn process_push_stats(push_stats: &GitPushStats) -> Result<(), CommandError> {
-    if !push_stats.all_ok() {
-        let mut error = user_error("Failed to push some bookmarks");
-        if !push_stats.rejected.is_empty() {
-            error.add_formatted_hint_with(|formatter| {
-                writeln!(
-                    formatter,
-                    "The following references unexpectedly moved on the remote:"
-                )?;
-                for (reference, reason) in &push_stats.rejected {
-                    write!(formatter, "  ")?;
-                    write!(formatter.labeled("git_ref"), "{}", reference.as_symbol())?;
-                    if let Some(r) = reason {
-                        write!(formatter, " (reason: {r})")?;
-                    }
-                    writeln!(formatter)?;
-                }
-                Ok(())
-            });
-            error.add_hint(
-                "Try fetching from the remote, then make the bookmark point to where you want it \
-                 to be, and push again.",
-            );
+fn print_stats(ui: &Ui, stats: &GitPushStats) -> io::Result<()> {
+    if !stats.rejected.is_empty() {
+        writeln!(
+            ui.warning_default(),
+            "The following references unexpectedly moved on the remote:"
+        )?;
+        let mut formatter = ui.stderr_formatter();
+        for (reference, reason) in &stats.rejected {
+            write!(formatter, "  ")?;
+            write!(formatter.labeled("git_ref"), "{}", reference.as_symbol())?;
+            if let Some(r) = reason {
+                write!(formatter, " (reason: {r})")?;
+            }
+            writeln!(formatter)?;
         }
-        if !push_stats.remote_rejected.is_empty() {
-            error.add_formatted_hint_with(|formatter| {
-                writeln!(formatter, "The remote rejected the following updates:")?;
-                for (reference, reason) in &push_stats.remote_rejected {
-                    write!(formatter, "  ")?;
-                    write!(formatter.labeled("git_ref"), "{}", reference.as_symbol())?;
-                    if let Some(r) = reason {
-                        write!(formatter, " (reason: {r})")?;
-                    }
-                    writeln!(formatter)?;
-                }
-                Ok(())
-            });
-            error.add_hint("Try checking if you have permission to push to all the bookmarks.");
-        }
-        Err(error)
-    } else {
-        Ok(())
+        drop(formatter);
+        writeln!(
+            ui.hint_default(),
+            "Try fetching from the remote, then make the bookmark point to where you want it to \
+             be, and push again.",
+        )?;
     }
+    if !stats.remote_rejected.is_empty() {
+        writeln!(
+            ui.warning_default(),
+            "The remote rejected the following updates:"
+        )?;
+        let mut formatter = ui.stderr_formatter();
+        for (reference, reason) in &stats.remote_rejected {
+            write!(formatter, "  ")?;
+            write!(formatter.labeled("git_ref"), "{}", reference.as_symbol())?;
+            if let Some(r) = reason {
+                write!(formatter, " (reason: {r})")?;
+            }
+            writeln!(formatter)?;
+        }
+        drop(formatter);
+        writeln!(
+            ui.hint_default(),
+            "Try checking if you have permission to push to all the bookmarks."
+        )?;
+    }
+    Ok(())
 }
 
 /// Validates that the commits that will be pushed are ready (have authorship
@@ -792,7 +812,9 @@ fn classify_bookmark_update(
         BookmarkPushAction::RemoteUntracked => Err(RejectedBookmarkUpdateReason {
             message: format!("Non-tracking remote bookmark {remote_symbol} exists"),
             hint: Some(format!(
-                "Run `jj bookmark track {remote_symbol}` to import the remote bookmark."
+                "Run `jj bookmark track {name} --remote={remote}` to import the remote bookmark.",
+                name = remote_symbol.name.as_symbol(),
+                remote = remote_symbol.remote.as_symbol()
             )),
         }),
         // TODO: deprecate --allow-new and make classify_bookmark_push_action()
@@ -801,7 +823,9 @@ fn classify_bookmark_update(
             Err(RejectedBookmarkUpdateReason {
                 message: format!("Refusing to create new remote bookmark {remote_symbol}"),
                 hint: Some(format!(
-                    "Run `jj bookmark track {remote_symbol}` and try again."
+                    "Run `jj bookmark track {name} --remote={remote}` and try again.",
+                    name = remote_symbol.name.as_symbol(),
+                    remote = remote_symbol.remote.as_symbol()
                 )),
             })
         }
@@ -835,7 +859,7 @@ fn ensure_new_bookmark_name(repo: &dyn Repo, name: &RefName) -> Result<(), Comma
             format!("Tracked remote bookmarks exist for deleted bookmark: {symbol}"),
             format!(
                 "Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark untrack \
-                 'glob:{symbol}@*'` to disassociate them."
+                 {symbol}` to disassociate them."
             ),
         ));
     }
@@ -895,7 +919,7 @@ fn create_change_bookmarks(
 
     let all_commits: Vec<_> = tx
         .base_workspace_helper()
-        .resolve_some_revsets_default_single(ui, changes)?
+        .resolve_some_revsets(ui, changes)?
         .iter()
         .map(|id| tx.repo().store().get_commit(id))
         .try_collect()?;
