@@ -20,6 +20,8 @@ use jj_lib::backend::CommitId;
 use jj_lib::commit::Commit;
 use jj_lib::matchers::Matcher;
 use jj_lib::merge::Diff;
+use jj_lib::merge::Merge;
+use jj_lib::merged_tree::MergedTree;
 use jj_lib::object_id::ObjectId as _;
 use jj_lib::rewrite::CommitWithSelection;
 use jj_lib::rewrite::EmptyBehavior;
@@ -51,100 +53,151 @@ use crate::ui::Ui;
 /// Split a revision in two
 ///
 /// Starts a [diff editor] on the changes in the revision. Edit the right side
-/// of the diff until it has the content you want in the new revision. Once
-/// you close the editor, your edited content will replace the previous
-/// revision. The remaining changes will be put in a new revision on top.
+/// of the diff until it has the content you want in the first commit. Once you
+/// close the editor, your revision will be split into two commits.
 ///
 /// [diff editor]:
 ///     https://docs.jj-vcs.dev/latest/config/#editing-diffs
 ///
+/// By default, the selected changes stay in the original commit, and the
+/// remaining changes go into a new child commit:
+///
+/// ```text
+/// L                 L'
+/// |                 |
+/// K (split)   =>    K" (remaining)
+/// |                 |
+/// J                 K' (selected)
+///                   |
+///                   J
+/// ```
+///
+/// With `--parallel/-p`, the two parts become sibling commits instead of
+/// parent and child:
+///
+/// ```text
+///                   L'
+/// L                / \
+/// |               K'  |  (selected)
+/// K (split)  =>   |   K" (remaining)
+/// |                \ /
+/// J                 J
+/// ```
+///
+/// With `-o`, `-A`, or `-B`, the selected changes are extracted into a new
+/// commit at the specified location, while the remaining changes stay in place:
+///
+/// ```text
+/// M                 M'
+/// |                 |
+/// L                 L'
+/// |                 |
+/// K (split)   =>    K' (remaining, stays here)
+/// |                 |
+/// J                 J'
+///                   |
+///                   K" (selected, inserted before J with -B J)
+/// ```
+///
 /// If the change you split had a description, you will be asked to enter a
 /// change description for each commit. If the change did not have a
-/// description, the remaining changes will not get a description, and you will
-/// be asked for a description only for the selected changes.
+/// description, the second commit will not get a description, and you will be
+/// asked for a description only for the first commit.
 ///
 /// Splitting an empty commit is not supported because the same effect can be
 /// achieved with `jj new`.
 #[derive(clap::Args, Clone, Debug)]
+#[command(verbatim_doc_comment)]
 pub(crate) struct SplitArgs {
     /// Interactively choose which parts to split
     ///
     /// This is the default if no filesets are provided.
     #[arg(long, short)]
     interactive: bool,
+
     /// Specify diff editor to be used (implies --interactive)
-    #[arg(
-        long,
-        value_name = "NAME",
-        add = ArgValueCandidates::new(complete::diff_editors),
-    )]
+    #[arg(long, value_name = "NAME")]
+    #[arg(add = ArgValueCandidates::new(complete::diff_editors))]
     tool: Option<String>,
+
     /// The revision to split
-    #[arg(
-        long, short,
-        default_value = "@",
-        value_name = "REVSET",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
-    )]
+    #[arg(long, short, default_value = "@", value_name = "REVSET")]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     revision: RevisionArg,
-    /// The revision(s) to base the new revision onto (can be repeated to create
-    /// a merge commit)
+
+    /// The revision(s) to rebase the selected changes onto (can be repeated to
+    /// create a merge commit)
+    ///
+    /// Extracts the selected changes into a new commit based on the given
+    /// revision(s). The remaining changes stay in the original commit's
+    /// location.
     #[arg(
         long,
-        alias = "destination",
+        visible_alias = "destination",
         short,
-        short_alias = 'd',
+        visible_short_alias = 'd',
         conflicts_with = "parallel",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_all),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     onto: Option<Vec<RevisionArg>>,
+
     /// The revision(s) to insert after (can be repeated to create a merge
     /// commit)
+    ///
+    /// Extracts the selected changes into a new commit inserted after the
+    /// given revision(s). The remaining changes stay in the original commit's
+    /// location.
     #[arg(
         long,
         short = 'A',
         visible_alias = "after",
         conflicts_with = "onto",
         conflicts_with = "parallel",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_all),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     insert_after: Option<Vec<RevisionArg>>,
+
     /// The revision(s) to insert before (can be repeated to create a merge
     /// commit)
+    ///
+    /// Extracts the selected changes into a new commit inserted before the
+    /// given revision(s). The remaining changes stay in the original commit's
+    /// location.
     #[arg(
         long,
         short = 'B',
         visible_alias = "before",
         conflicts_with = "onto",
         conflicts_with = "parallel",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     insert_before: Option<Vec<RevisionArg>>,
+
     /// The change description to use (don't open editor)
     ///
-    /// The description is used for the commit with the selected changes. The
-    /// source commit description is kept unchanged.
+    /// Sets the description for the first commit (the one containing the
+    /// selected changes). The second commit keeps the original description.
     #[arg(long = "message", short, value_name = "MESSAGE")]
     message_paragraphs: Vec<String>,
+
     /// Open an editor to edit the change description
     ///
     /// Forces an editor to open when using `--message` to allow the
     /// message to be edited afterwards.
     #[arg(long)]
     editor: bool,
+
     /// Split the revision into two parallel revisions instead of a parent and
     /// child
     #[arg(long, short)]
     parallel: bool,
+
     /// Files matching any of these filesets are put in the selected changes
-    #[arg(
-        value_name = "FILESETS",
-        value_hint = clap::ValueHint::AnyPath,
-        add = ArgValueCompleter::new(complete::modified_revision_files),
-    )]
+    #[arg(value_name = "FILESETS", value_hint = clap::ValueHint::AnyPath)]
+    #[arg(add = ArgValueCompleter::new(complete::modified_revision_files))]
     paths: Vec<String>,
 }
 
@@ -287,9 +340,19 @@ pub(crate) fn cmd_split(
             // Merge the original commit tree with its parent using the tree
             // containing the user selected changes as the base for the merge.
             // This results in a tree with the changes the user didn't select.
-            target_tree
-                .merge(target.selected_tree.clone(), target.parent_tree.clone())
-                .block_on()?
+            let selected_diff = target.diff_with_labels(
+                "parents of split revision",
+                "selected changes for split",
+                "split revision",
+            )?;
+            MergedTree::merge(Merge::from_diffs(
+                (
+                    target_tree,
+                    format!("split revision ({})", target.commit.conflict_label()),
+                ),
+                [selected_diff.invert()],
+            ))
+            .block_on()?
         } else {
             target_tree
         };
