@@ -51,6 +51,9 @@ use crate::ui::Ui;
 
 /// Move changes from a revision into another revision
 ///
+/// Without any options, moves the changes from the working-copy revision to the
+/// parent revision.
+///
 /// With the `-r` option, moves the changes from the specified revision to the
 /// parent revision. Fails if there are several parent revisions (i.e., the
 /// given revision is a merge).
@@ -71,6 +74,9 @@ use crate::ui::Ui;
 /// If a working-copy commit gets abandoned, it will be given a new, empty
 /// commit. This is true in general; it is not specific to this command.
 ///
+/// The name "squash" comes from the idea of combining (squashing) the changes
+/// from multiple revisions together.
+///
 /// EXPERIMENTAL FEATURES
 ///
 /// An alternative squashing UI is available via the `-o`, `-A`, and `-B`
@@ -81,45 +87,38 @@ use crate::ui::Ui;
 pub(crate) struct SquashArgs {
     /// Revision to squash into its parent (default: @). Incompatible with the
     /// experimental `-o`/`-A`/`-B` options.
-    #[arg(
-        long,
-        short,
-        value_name = "REVSET",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
-    )]
+    #[arg(long, short, value_name = "REVSET")]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     revision: Option<RevisionArg>,
 
     /// Revision(s) to squash from (default: @)
-    #[arg(
-        long, short,
-        conflicts_with = "revision",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
-    )]
+    #[arg(long, short, conflicts_with = "revision", value_name = "REVSETS")]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     from: Vec<RevisionArg>,
 
     /// Revision to squash into (default: @)
     #[arg(
-        long, short = 't',
+        long,
+        short = 't',
         conflicts_with = "revision",
         visible_alias = "to",
-        value_name = "REVSET",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
+        value_name = "REVSET"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     into: Option<RevisionArg>,
 
     /// (Experimental) The revision(s) to use as parent for the new commit (can
     /// be repeated to create a merge commit)
     #[arg(
         long,
-        alias = "destination",
+        visible_alias = "destination",
         short,
-        short_alias = 'd',
+        visible_short_alias = 'd',
         conflicts_with = "into",
         conflicts_with = "revision",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_all),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     onto: Option<Vec<RevisionArg>>,
 
     /// (Experimental) The revision(s) to insert the new commit after (can be
@@ -131,9 +130,9 @@ pub(crate) struct SquashArgs {
         conflicts_with = "onto",
         conflicts_with = "into",
         conflicts_with = "revision",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_all),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_all))]
     insert_after: Option<Vec<RevisionArg>>,
 
     /// (Experimental) The revision(s) to insert the new commit before (can be
@@ -145,9 +144,9 @@ pub(crate) struct SquashArgs {
         conflicts_with = "onto",
         conflicts_with = "into",
         conflicts_with = "revision",
-        value_name = "REVSETS",
-        add = ArgValueCompleter::new(complete::revset_expression_mutable),
+        value_name = "REVSETS"
     )]
+    #[arg(add = ArgValueCompleter::new(complete::revset_expression_mutable))]
     insert_before: Option<Vec<RevisionArg>>,
 
     /// The description to use for squashed revision (don't open editor)
@@ -171,19 +170,13 @@ pub(crate) struct SquashArgs {
     interactive: bool,
 
     /// Specify diff editor to be used (implies --interactive)
-    #[arg(
-        long,
-        value_name = "NAME",
-        add = ArgValueCandidates::new(complete::diff_editors),
-    )]
+    #[arg(long, value_name = "NAME")]
+    #[arg(add = ArgValueCandidates::new(complete::diff_editors))]
     tool: Option<String>,
 
     /// Move only changes to these paths (instead of all paths)
-    #[arg(
-        value_name = "FILESETS",
-        value_hint = clap::ValueHint::AnyPath,
-        add = ArgValueCompleter::new(complete::squash_revision_files),
-    )]
+    #[arg(value_name = "FILESETS", value_hint = clap::ValueHint::AnyPath)]
+    #[arg(add = ArgValueCompleter::new(complete::squash_revision_files))]
     paths: Vec<String>,
 
     /// The source revision will not be abandoned
