@@ -113,7 +113,11 @@ pub fn tracked_bookmarks() -> Vec<CompletionCandidate> {
         Ok(String::from_utf8_lossy(&output.stdout)
             .lines()
             .map(split_help_text)
-            .map(|(name, help)| CompletionCandidate::new(name).help(help))
+            .filter_map(|(symbol, help)| Some((symbol.split_once('@')?, help)))
+            // There may be multiple remote bookmarks to untrack. Just pick the
+            // first one for help text.
+            .dedup_by(|((name1, _), _), ((name2, _), _)| name1 == name2)
+            .map(|((name, _remote), help)| CompletionCandidate::new(name).help(help))
             .collect())
     })
 }
@@ -177,9 +181,13 @@ pub fn untracked_bookmarks() -> Vec<CompletionCandidate> {
             .retain(|(bookmark, _help)| !already_tracked_bookmarks.contains(&bookmark.as_str()));
 
         Ok(possible_bookmarks_to_track
-            .into_iter()
-            .map(|(bookmark, help)| {
-                CompletionCandidate::new(bookmark).help(Some(help.to_string().into()))
+            .iter()
+            .filter_map(|(symbol, help)| Some((symbol.split_once('@')?, help)))
+            // There may be multiple remote bookmarks to track. Just pick the
+            // first one for help text.
+            .dedup_by(|((name1, _), _), ((name2, _), _)| name1 == name2)
+            .map(|((name, _remote), help)| {
+                CompletionCandidate::new(name).help(Some(help.to_string().into()))
             })
             .collect())
     })
@@ -382,7 +390,16 @@ fn revisions(match_prefix: &str, revset_filter: Option<&str>) -> Vec<CompletionC
             .arg("--revisions")
             .arg(revisions)
             .arg("--template")
-            .arg(r#"change_id.shortest() ++ " " ++ if(description, description.first_line(), "(no description set)") ++ "\n""#)
+            .arg(
+                r#"
+                join(" ",
+                    separate("/",
+                        change_id.shortest(),
+                        if(hidden || divergent, change_offset),
+                    ),
+                    if(description, description.first_line(), "(no description set)"),
+                ) ++ "\n""#,
+            )
             .output()
             .map_err(user_error)?;
         let stdout = String::from_utf8_lossy(&output.stdout);
@@ -1061,12 +1078,12 @@ fn get_jj_command() -> Result<(JjBuilder, UserSettings), CommandError> {
     // No config migration for completion. Simply ignore deprecated variables.
     let mut config_env = ConfigEnv::from_environment();
     let maybe_cwd_workspace_loader = DefaultWorkspaceLoaderFactory.create(find_workspace_dir(&cwd));
-    let _ = config_env.reload_user_config(&mut raw_config);
+    config_env.reload_user_config(&mut raw_config).ok();
     if let Ok(loader) = &maybe_cwd_workspace_loader {
         config_env.reset_repo_path(loader.repo_path());
-        let _ = config_env.reload_repo_config(&mut raw_config);
+        config_env.reload_repo_config(&mut raw_config).ok();
         config_env.reset_workspace_path(loader.workspace_root());
-        let _ = config_env.reload_workspace_config(&mut raw_config);
+        config_env.reload_workspace_config(&mut raw_config).ok();
     }
     let mut config = config_env.resolve_config(&raw_config)?;
     // skip 2 because of the clap_complete prelude: jj -- jj <actual args...>
@@ -1084,9 +1101,9 @@ fn get_jj_command() -> Result<(JjBuilder, UserSettings), CommandError> {
         // Try to update repo-specific config on a best-effort basis.
         if let Ok(loader) = DefaultWorkspaceLoaderFactory.create(&cwd.join(&repository)) {
             config_env.reset_repo_path(loader.repo_path());
-            let _ = config_env.reload_repo_config(&mut raw_config);
+            config_env.reload_repo_config(&mut raw_config).ok();
             config_env.reset_workspace_path(loader.workspace_root());
-            let _ = config_env.reload_workspace_config(&mut raw_config);
+            config_env.reload_workspace_config(&mut raw_config).ok();
             if let Ok(new_config) = config_env.resolve_config(&raw_config) {
                 config = new_config;
             }
@@ -1340,7 +1357,7 @@ mod tests {
     #[test]
     fn test_config_keys() {
         // Just make sure the schema is parsed without failure.
-        let _ = config_keys();
+        config_keys();
     }
 
     #[test]
