@@ -35,6 +35,7 @@ use jj_lib::backend::CopyRecord;
 use jj_lib::backend::TreeValue;
 use jj_lib::commit::Commit;
 use jj_lib::config::ConfigGetError;
+use jj_lib::conflict_labels::ConflictLabels;
 use jj_lib::conflicts::ConflictMarkerStyle;
 use jj_lib::conflicts::ConflictMaterializeOptions;
 use jj_lib::conflicts::MaterializedTreeDiffEntry;
@@ -106,9 +107,11 @@ pub struct DiffFormatArgs {
     /// For each path, show only whether it was modified, added, or deleted
     #[arg(long, short)]
     pub summary: bool,
+
     /// Show a histogram of the changes
     #[arg(long)]
     pub stat: bool,
+
     /// For each path, show only its type before and after
     ///
     /// The diff is shown as two letters. The first letter indicates the type
@@ -118,27 +121,30 @@ pub struct DiffFormatArgs {
     /// Git submodule.
     #[arg(long)]
     pub types: bool,
+
     /// For each path, show only its path
     ///
     /// Typically useful for shell commands like:
     ///    `jj diff -r @- --name-only | xargs perl -pi -e's/OLD/NEW/g`
     #[arg(long)]
     pub name_only: bool,
+
     /// Show a Git-format diff
     #[arg(long)]
     pub git: bool,
+
     /// Show a word-level diff with changes indicated only by color
     #[arg(long)]
     pub color_words: bool,
+
     /// Generate diff by external command
     ///
     /// A builtin format can also be specified as `:<name>`. For example,
     /// `--tool=:git` is equivalent to `--git`.
-    #[arg(
-        long,
-        add = ArgValueCandidates::new(crate::complete::diff_formatters),
-    )]
+    #[arg(long)]
+    #[arg(add = ArgValueCandidates::new(crate::complete::diff_formatters))]
     pub tool: Option<String>,
+
     /// Number of lines of context to show
     #[arg(long)]
     context: Option<usize>,
@@ -147,6 +153,7 @@ pub struct DiffFormatArgs {
     /// Ignore whitespace when comparing lines.
     #[arg(long)] // short = 'w'
     ignore_all_space: bool,
+
     /// Ignore changes in amount of whitespace when comparing lines.
     #[arg(long, conflicts_with = "ignore_all_space")] // short = 'b'
     ignore_space_change: bool,
@@ -467,6 +474,7 @@ impl<'a> DiffRenderer<'a> {
                 .before
                 .diff_stream_with_copies(trees.after, matcher, copy_records)
         };
+        let conflict_labels = trees.map(|tree| tree.labels());
 
         let store = self.repo.store();
         let path_converter = self.path_converter;
@@ -497,6 +505,7 @@ impl<'a> DiffRenderer<'a> {
                         formatter,
                         store,
                         tree_diff,
+                        conflict_labels,
                         options,
                         self.conflict_marker_style,
                     )
@@ -508,6 +517,7 @@ impl<'a> DiffRenderer<'a> {
                         formatter,
                         store,
                         tree_diff,
+                        conflict_labels,
                         path_converter,
                         options,
                         self.conflict_marker_style,
@@ -523,6 +533,7 @@ impl<'a> DiffRenderer<'a> {
                                 formatter,
                                 store,
                                 tree_diff,
+                                conflict_labels,
                                 path_converter,
                                 tool,
                                 self.conflict_marker_style,
@@ -587,6 +598,7 @@ impl<'a> DiffRenderer<'a> {
                     show_color_words_diff_hunks(
                         formatter,
                         descriptions,
+                        Diff::new(&ConflictLabels::unlabeled(), &ConflictLabels::unlabeled()),
                         options,
                         &materialize_options,
                     )?;
@@ -756,6 +768,7 @@ impl ColorWordsDiffOptions {
 fn show_color_words_diff_hunks<T: AsRef<[u8]>>(
     formatter: &mut dyn Formatter,
     contents: Diff<&Merge<T>>,
+    conflict_labels: Diff<&ConflictLabels>,
     options: &ColorWordsDiffOptions,
     materialize_options: &ConflictMaterializeOptions,
 ) -> io::Result<()> {
@@ -769,8 +782,9 @@ fn show_color_words_diff_hunks<T: AsRef<[u8]>>(
     }
     match options.conflict {
         ConflictDiffMethod::Materialize => {
-            let contents =
-                contents.map(|side| materialize_merge_result_to_bytes(side, materialize_options));
+            let contents = contents.zip(conflict_labels).map(|(side, labels)| {
+                materialize_merge_result_to_bytes(side, labels, materialize_options)
+            });
             show_color_words_resolved_hunks(
                 formatter,
                 contents.as_ref().map(BStr::new),
@@ -802,7 +816,7 @@ fn show_color_words_conflict_hunks(
 ) -> io::Result<DiffLineNumber> {
     let num_lefts = contents.before.as_slice().len();
     let line_diff = diff_by_line(
-        contents.before.iter().chain(contents.after.iter()),
+        itertools::chain(contents.before, contents.after),
         &options.line_diff.compare_mode,
     );
     // Matching entries shouldn't appear consecutively in diff of two inputs.
@@ -912,7 +926,7 @@ fn show_color_words_unresolved_hunk(
         let contents = Diff::new(left_content, right_content);
         let labels = match positive {
             true => labels,
-            false => Diff::new(labels.after, labels.before),
+            false => labels.invert(),
         };
         // Individual hunk pair may be largely the same, so diff it again.
         let new_line_number =
@@ -1018,15 +1032,18 @@ fn show_color_words_context_lines(
     let show = |formatter: &mut dyn Formatter,
                 [left_lines, right_lines]: [&[&[u8]]; 2],
                 mut line_number: DiffLineNumber| {
+        // Whether or not left/right lines differ in whitespace, they are
+        // "context" lines.
+        let mut formatter = formatter.labeled("context");
         if left_lines == right_lines {
             for line in left_lines {
                 show_color_words_line_number(
-                    formatter,
+                    *formatter,
                     Diff::new(Some(line_number.left), Some(line_number.right)),
                     labels,
                 )?;
                 show_color_words_inline_hunks(
-                    formatter,
+                    *formatter,
                     &[(DiffLineHunkSide::Both, line.as_ref())],
                     labels,
                 )?;
@@ -1038,7 +1055,7 @@ fn show_color_words_context_lines(
             let left = left_lines.concat();
             let right = right_lines.concat();
             show_color_words_diff_lines(
-                formatter,
+                *formatter,
                 Diff::new(&left, &right).map(BStr::new),
                 line_number,
                 labels,
@@ -1240,22 +1257,49 @@ fn diff_content(
         path,
         value,
         |content| content,
-        |contents| materialize_merge_result_to_bytes(&contents, materialize_options),
+        |contents, labels| {
+            materialize_merge_result_to_bytes(&contents, &labels, materialize_options)
+        },
     )
 }
 
+#[derive(PartialEq, Eq, Debug)]
+struct DiffContentAsMerge {
+    file_content: Merge<BString>,
+    conflict_labels: ConflictLabels,
+}
+
+impl DiffContentAsMerge {
+    pub fn is_empty(&self) -> bool {
+        self.file_content
+            .as_resolved()
+            .is_some_and(|c| c.is_empty())
+    }
+}
+
 fn diff_content_as_merge(
     path: &RepoPath,
     value: MaterializedTreeValue,
-) -> BackendResult<FileContent<Merge<BString>>> {
-    diff_content_with(path, value, Merge::resolved, |contents| contents)
+) -> BackendResult<FileContent<DiffContentAsMerge>> {
+    diff_content_with(
+        path,
+        value,
+        |contents| DiffContentAsMerge {
+            file_content: Merge::resolved(contents),
+            conflict_labels: ConflictLabels::unlabeled(),
+        },
+        |contents, labels| DiffContentAsMerge {
+            file_content: contents,
+            conflict_labels: labels,
+        },
+    )
 }
 
 fn diff_content_with<T>(
     path: &RepoPath,
     value: MaterializedTreeValue,
     map_resolved: impl FnOnce(BString) -> T,
-    map_conflict: impl FnOnce(Merge<BString>) -> T,
+    map_conflict: impl FnOnce(Merge<BString>, ConflictLabels) -> T,
 ) -> BackendResult<FileContent<T>> {
     match value {
         MaterializedTreeValue::Absent => Ok(FileContent {
@@ -1281,11 +1325,11 @@ fn diff_content_with<T>(
         // TODO: are we sure this is never binary?
         MaterializedTreeValue::FileConflict(file) => Ok(FileContent {
             is_binary: false,
-            contents: map_conflict(file.contents),
+            contents: map_conflict(file.contents, file.labels),
         }),
-        MaterializedTreeValue::OtherConflict { id } => Ok(FileContent {
+        MaterializedTreeValue::OtherConflict { id, labels } => Ok(FileContent {
             is_binary: false,
-            contents: map_resolved(id.describe().into()),
+            contents: map_resolved(id.describe(&labels).into()),
         }),
         MaterializedTreeValue::Tree(id) => {
             panic!("Unexpected tree with id {id:?} in diff at path {path:?}");
@@ -1319,6 +1363,7 @@ pub async fn show_color_words_diff(
     formatter: &mut dyn Formatter,
     store: &Store,
     tree_diff: BoxStream<'_, CopiesTreeDiffEntry>,
+    conflict_labels: Diff<&ConflictLabels>,
     path_converter: &RepoPathUiConverter,
     options: &ColorWordsDiffOptions,
     marker_style: ConflictMarkerStyle,
@@ -1329,7 +1374,7 @@ pub async fn show_color_words_diff(
         merge: store.merge_options().clone(),
     };
     let empty_content = || Merge::resolved(BString::default());
-    let mut diff_stream = materialized_diff_stream(store, tree_diff);
+    let mut diff_stream = materialized_diff_stream(store, tree_diff, conflict_labels);
     while let Some(MaterializedTreeDiffEntry { path, values }) = diff_stream.next().await {
         let left_path = path.source();
         let right_path = path.target();
@@ -1366,14 +1411,18 @@ pub async fn show_color_words_diff(
                 "Added {description} {right_ui_path}:"
             )?;
             let right_content = diff_content_as_merge(right_path, right_value)?;
-            if right_content.is_empty() {
+            if right_content.contents.is_empty() {
                 writeln!(formatter.labeled("empty"), "    (empty)")?;
             } else if right_content.is_binary {
                 writeln!(formatter.labeled("binary"), "    (binary)")?;
             } else {
                 show_color_words_diff_hunks(
                     formatter,
-                    Diff::new(&empty_content(), &right_content.contents),
+                    Diff::new(&empty_content(), &right_content.contents.file_content),
+                    Diff::new(
+                        &ConflictLabels::unlabeled(),
+                        &right_content.contents.conflict_labels,
+                    ),
                     options,
                     &materialize_options,
                 )?;
@@ -1440,7 +1489,14 @@ pub async fn show_color_words_diff(
             } else if left_content.contents != right_content.contents {
                 show_color_words_diff_hunks(
                     formatter,
-                    Diff::new(&left_content.contents, &right_content.contents),
+                    Diff::new(
+                        &left_content.contents.file_content,
+                        &right_content.contents.file_content,
+                    ),
+                    Diff::new(
+                        &left_content.contents.conflict_labels,
+                        &right_content.contents.conflict_labels,
+                    ),
                     options,
                     &materialize_options,
                 )?;
@@ -1452,14 +1508,18 @@ pub async fn show_color_words_diff(
                 "Removed {description} {right_ui_path}:"
             )?;
             let left_content = diff_content_as_merge(left_path, left_value)?;
-            if left_content.is_empty() {
+            if left_content.contents.is_empty() {
                 writeln!(formatter.labeled("empty"), "    (empty)")?;
             } else if left_content.is_binary {
                 writeln!(formatter.labeled("binary"), "    (binary)")?;
             } else {
                 show_color_words_diff_hunks(
                     formatter,
-                    Diff::new(&left_content.contents, &empty_content()),
+                    Diff::new(&left_content.contents.file_content, &empty_content()),
+                    Diff::new(
+                        &left_content.contents.conflict_labels,
+                        &ConflictLabels::unlabeled(),
+                    ),
                     options,
                     &materialize_options,
                 )?;
@@ -1475,6 +1535,7 @@ pub async fn show_file_by_file_diff(
     formatter: &mut dyn Formatter,
     store: &Store,
     tree_diff: BoxStream<'_, CopiesTreeDiffEntry>,
+    conflict_labels: Diff<&ConflictLabels>,
     path_converter: &RepoPathUiConverter,
     tool: &ExternalMergeTool,
     marker_style: ConflictMarkerStyle,
@@ -1499,7 +1560,7 @@ pub async fn show_file_by_file_diff(
     let temp_dir = new_utf8_temp_dir("jj-diff-")?;
     let left_wc_dir = temp_dir.path().join("left");
     let right_wc_dir = temp_dir.path().join("right");
-    let mut diff_stream = materialized_diff_stream(store, tree_diff);
+    let mut diff_stream = materialized_diff_stream(store, tree_diff, conflict_labels);
     while let Some(MaterializedTreeDiffEntry { path, values }) = diff_stream.next().await {
         let Diff {
             before: left_value,
@@ -1641,6 +1702,7 @@ pub async fn show_git_diff(
     formatter: &mut dyn Formatter,
     store: &Store,
     tree_diff: BoxStream<'_, CopiesTreeDiffEntry>,
+    conflict_labels: Diff<&ConflictLabels>,
     options: &UnifiedDiffOptions,
     marker_style: ConflictMarkerStyle,
 ) -> Result<(), DiffRenderError> {
@@ -1649,7 +1711,7 @@ pub async fn show_git_diff(
         marker_len: None,
         merge: store.merge_options().clone(),
     };
-    let mut diff_stream = materialized_diff_stream(store, tree_diff);
+    let mut diff_stream = materialized_diff_stream(store, tree_diff, conflict_labels);
     while let Some(MaterializedTreeDiffEntry { path, values }) = diff_stream.next().await {
         let left_path = path.source();
         let right_path = path.target();
@@ -1754,6 +1816,7 @@ fn show_git_diff_texts<T: AsRef<[u8]>>(
         Some(text) => Cow::Borrowed(BStr::new(text)),
         None => Cow::Owned(materialize_merge_result_to_bytes(
             content,
+            &ConflictLabels::unlabeled(),
             materialize_options,
         )),
     });
@@ -1770,12 +1833,11 @@ pub async fn show_diff_summary(
         let values = values?;
         let status = diff_status(&path, &values);
         let (label, sigil) = (status.label(), status.char());
-        let path = if path.copy_operation().is_some() {
-            path_converter.format_copied_path(path.source(), path.target())
-        } else {
-            path_converter.format_file_path(path.target())
+        let ui_path = match path.to_diff() {
+            Some(paths) => path_converter.format_copied_path(paths),
+            None => path_converter.format_file_path(path.target()),
         };
-        writeln!(formatter.labeled(label), "{sigil} {path}")?;
+        writeln!(formatter.labeled(label), "{sigil} {ui_path}")?;
     }
     Ok(())
 }
@@ -1837,25 +1899,28 @@ impl DiffStats {
             marker_len: None,
             merge: store.merge_options().clone(),
         };
-        let entries = materialized_diff_stream(store, tree_diff)
-            .map(|MaterializedTreeDiffEntry { path, values }| {
-                let values = values?;
-                let status =
-                    diff_status_inner(&path, values.before.is_present(), values.after.is_present());
-                let left_content =
-                    diff_content(path.source(), values.before, &materialize_options)?;
-                let right_content =
-                    diff_content(path.target(), values.after, &materialize_options)?;
-                let stat = get_diff_stat_entry(
-                    path,
-                    status,
-                    Diff::new(&left_content, &right_content),
-                    options,
-                );
-                BackendResult::Ok(stat)
-            })
-            .try_collect()
-            .await?;
+        let conflict_labels = ConflictLabels::unlabeled();
+        let entries = materialized_diff_stream(
+            store,
+            tree_diff,
+            Diff::new(&conflict_labels, &conflict_labels),
+        )
+        .map(|MaterializedTreeDiffEntry { path, values }| {
+            let values = values?;
+            let status =
+                diff_status_inner(&path, values.before.is_present(), values.after.is_present());
+            let left_content = diff_content(path.source(), values.before, &materialize_options)?;
+            let right_content = diff_content(path.target(), values.after, &materialize_options)?;
+            let stat = get_diff_stat_entry(
+                path,
+                status,
+                Diff::new(&left_content, &right_content),
+                options,
+            );
+            BackendResult::Ok(stat)
+        })
+        .try_collect()
+        .await?;
         Ok(Self { entries })
     }
 
@@ -1968,12 +2033,9 @@ pub fn show_diff_stats(
     let ui_paths = stats
         .entries()
         .iter()
-        .map(|stat| {
-            if stat.path.copy_operation().is_some() {
-                path_converter.format_copied_path(stat.path.source(), stat.path.target())
-            } else {
-                path_converter.format_file_path(stat.path.target())
-            }
+        .map(|stat| match stat.path.to_diff() {
+            Some(paths) => path_converter.format_copied_path(paths),
+            None => path_converter.format_file_path(stat.path.target()),
         })
         .collect_vec();
 
@@ -2054,7 +2116,7 @@ pub fn show_diff_stats(
             //
             // Fractional space after scaling is given to whichever of adds/removes is
             // smaller, to show at least one tick for small (but nonzero) counts.
-            let bar_length = bar_length.max((added > 0) as usize + (removed > 0) as usize);
+            let bar_length = bar_length.max(usize::from(added > 0) + usize::from(removed > 0));
             let (bar_added, bar_removed) = if added < removed {
                 let len = (added as f64 * factor).ceil() as usize;
                 (len, bar_length - len)
@@ -2108,12 +2170,15 @@ pub async fn show_types(
 ) -> Result<(), DiffRenderError> {
     while let Some(CopiesTreeDiffEntry { path, values }) = tree_diff.next().await {
         let values = values?;
+        let ui_path = match path.to_diff() {
+            Some(paths) => path_converter.format_copied_path(paths),
+            None => path_converter.format_file_path(path.target()),
+        };
         writeln!(
             formatter.labeled("modified"),
-            "{}{} {}",
-            diff_summary_char(&values.before),
-            diff_summary_char(&values.after),
-            path_converter.format_copied_path(path.source(), path.target())
+            "{before}{after} {ui_path}",
+            before = diff_summary_char(&values.before),
+            after = diff_summary_char(&values.after)
         )?;
     }
     Ok(())
