@@ -16,13 +16,10 @@
 
 use std::error;
 use std::io;
-use std::io::Read as _;
 use std::io::Write as _;
 use std::iter;
 use std::mem;
 use std::path::Path;
-use std::path::PathBuf;
-use std::process::Stdio;
 use std::time::Duration;
 use std::time::Instant;
 
@@ -34,13 +31,16 @@ use jj_lib::fmt_util::binary_prefix;
 use jj_lib::git;
 use jj_lib::git::FailedRefExportReason;
 use jj_lib::git::GitExportStats;
+use jj_lib::git::GitImportOptions;
 use jj_lib::git::GitImportStats;
 use jj_lib::git::GitRefKind;
+use jj_lib::git::GitSettings;
 use jj_lib::op_store::RefTarget;
 use jj_lib::op_store::RemoteRef;
 use jj_lib::ref_name::RemoteRefSymbol;
 use jj_lib::repo::ReadonlyRepo;
 use jj_lib::repo::Repo;
+use jj_lib::settings::RemoteSettingsMap;
 use jj_lib::workspace::Workspace;
 use unicode_width::UnicodeWidthStr as _;
 
@@ -50,6 +50,7 @@ use crate::command_error::cli_error;
 use crate::command_error::user_error;
 use crate::formatter::Formatter;
 use crate::formatter::FormatterExt as _;
+use crate::revset_util::parse_remote_auto_track_bookmarks_map;
 use crate::ui::ProgressOutput;
 use crate::ui::Ui;
 
@@ -88,83 +89,6 @@ pub fn absolute_git_url(cwd: &Path, source: &str) -> Result<String, CommandError
     Ok(String::from_utf8(url.to_bstring().into()).unwrap_or_else(|_| source.to_owned()))
 }
 
-fn terminal_get_username(ui: &Ui, url: &str) -> Option<String> {
-    ui.prompt(&format!("Username for {url}")).ok()
-}
-
-fn terminal_get_pw(ui: &Ui, url: &str) -> Option<String> {
-    ui.prompt_password(&format!("Passphrase for {url}")).ok()
-}
-
-fn pinentry_get_pw(url: &str) -> Option<String> {
-    // https://www.gnupg.org/documentation/manuals/assuan/Server-responses.html#Server-responses
-    fn decode_assuan_data(encoded: &str) -> Option<String> {
-        let encoded = encoded.as_bytes();
-        let mut decoded = Vec::with_capacity(encoded.len());
-        let mut i = 0;
-        while i < encoded.len() {
-            if encoded[i] != b'%' {
-                decoded.push(encoded[i]);
-                i += 1;
-                continue;
-            }
-            i += 1;
-            let byte = u8::from_str_radix(str::from_utf8(encoded.get(i..i + 2)?).ok()?, 16).ok()?;
-            decoded.push(byte);
-            i += 2;
-        }
-        String::from_utf8(decoded).ok()
-    }
-
-    let mut pinentry = std::process::Command::new("pinentry")
-        .stdin(Stdio::piped())
-        .stdout(Stdio::piped())
-        .spawn()
-        .ok()?;
-    let mut interact = || -> std::io::Result<_> {
-        #[rustfmt::skip]
-        let req = format!(
-            "SETTITLE jj passphrase\n\
-             SETDESC Enter passphrase for {url}\n\
-             SETPROMPT Passphrase:\n\
-             GETPIN\n"
-        );
-        pinentry.stdin.take().unwrap().write_all(req.as_bytes())?;
-        let mut out = String::new();
-        pinentry.stdout.take().unwrap().read_to_string(&mut out)?;
-        Ok(out)
-    };
-    let maybe_out = interact();
-    _ = pinentry.wait();
-    for line in maybe_out.ok()?.split('\n') {
-        if !line.starts_with("D ") {
-            continue;
-        }
-        let (_, encoded) = line.split_at(2);
-        return decode_assuan_data(encoded);
-    }
-    None
-}
-
-#[tracing::instrument]
-fn get_ssh_keys(_username: &str) -> Vec<PathBuf> {
-    let mut paths = vec![];
-    if let Ok(home_dir) = etcetera::home_dir() {
-        let ssh_dir = home_dir.join(".ssh");
-        for filename in ["id_ed25519_sk", "id_ed25519", "id_rsa"] {
-            let key_path = ssh_dir.join(filename);
-            if key_path.is_file() {
-                tracing::info!(path = ?key_path, "found ssh key");
-                paths.push(key_path);
-            }
-        }
-    }
-    if paths.is_empty() {
-        tracing::info!("no ssh key found");
-    }
-    paths
-}
-
 // Based on Git's implementation: https://github.com/git/git/blob/43072b4ca132437f21975ac6acc6b72dc22fd398/sideband.c#L178
 pub struct GitSidebandProgressMessageWriter {
     display_prefix: &'static [u8],
@@ -255,31 +179,34 @@ pub fn with_remote_git_callbacks<T>(ui: &Ui, f: impl FnOnce(git::RemoteCallbacks
     if let Some(mut output) = ui.progress_output() {
         let mut progress = Progress::new(Instant::now());
         progress_callback = move |x: &git::Progress| {
-            _ = progress.update(Instant::now(), x, &mut output);
+            progress.update(Instant::now(), x, &mut output).ok();
         };
         callbacks.progress = Some(&mut progress_callback);
     }
 
     let mut sideband_progress_writer = GitSidebandProgressMessageWriter::new(ui);
     let mut sideband_progress_callback = |progress_message: &[u8]| {
-        _ = sideband_progress_writer.write(ui, progress_message);
+        sideband_progress_writer.write(ui, progress_message).ok();
     };
     callbacks.sideband_progress = Some(&mut sideband_progress_callback);
 
-    let mut get_ssh_keys = get_ssh_keys; // Coerce to unit fn type
-    callbacks.get_ssh_keys = Some(&mut get_ssh_keys);
-    let mut get_pw =
-        |url: &str, _username: &str| pinentry_get_pw(url).or_else(|| terminal_get_pw(ui, url));
-    callbacks.get_password = Some(&mut get_pw);
-    let mut get_user_pw =
-        |url: &str| Some((terminal_get_username(ui, url)?, terminal_get_pw(ui, url)?));
-    callbacks.get_username_password = Some(&mut get_user_pw);
-
     let result = f(callbacks);
-    _ = sideband_progress_writer.flush(ui);
+    sideband_progress_writer.flush(ui).ok();
     result
 }
 
+pub fn load_git_import_options(
+    ui: &Ui,
+    git_settings: &GitSettings,
+    remote_settings: &RemoteSettingsMap,
+) -> Result<GitImportOptions, CommandError> {
+    Ok(GitImportOptions {
+        auto_local_bookmark: git_settings.auto_local_bookmark,
+        abandon_unreachable_commits: git_settings.abandon_unreachable_commits,
+        remote_auto_track_bookmarks: parse_remote_auto_track_bookmarks_map(ui, remote_settings)?,
+    })
+}
+
 pub fn print_git_import_stats(
     ui: &Ui,
     repo: &dyn Repo,
@@ -387,7 +314,7 @@ impl Progress {
             let guard = CleanupGuard::new(move || {
                 drop(guard);
             });
-            _ = write!(output, "{}", crossterm::cursor::Hide);
+            write!(output, "{}", crossterm::cursor::Hide).ok();
             self.guard = Some(guard);
         }
 
@@ -714,7 +641,7 @@ mod tests {
         assert_snapshot!(update(Duration::from_millis(10), 0.12), @"");
         assert_snapshot!(update(Duration::from_millis(10), 0.13), @"");
         // We get an update now that we go over the threshold
-        assert_snapshot!(update(Duration::from_millis(100), 0.30), @" 30% [█████▍            ][K");
+        assert_snapshot!(update(Duration::from_millis(100), 0.30), @"\r 30% [█████▍            ]\u{1b}[K");
         // Even though we went over by quite a bit, the new threshold is relative to the
         // previous output, so we don't get an update here
         assert_snapshot!(update(Duration::from_millis(30), 0.40), @"");
