@@ -178,7 +178,12 @@ fn read_file_contents(
             // Since scm_record doesn't support diffs of conflicts, file
             // conflicts are compared in materialized form. The UI would look
             // scary, but it can at least allow squashing resolved hunks.
-            let buf = materialize_merge_result_to_bytes(&file.contents, materialize_options).into();
+            let buf = materialize_merge_result_to_bytes(
+                &file.contents,
+                &file.labels,
+                materialize_options,
+            )
+            .into();
             // TODO: Render the ID somehow?
             let contents = buf_to_file_contents(None, buf);
             Ok(FileInfo {
@@ -186,10 +191,10 @@ fn read_file_contents(
                 contents,
             })
         }
-        MaterializedTreeValue::OtherConflict { id } => {
+        MaterializedTreeValue::OtherConflict { id, labels } => {
             // TODO: Non-file conflict shouldn't be rendered as a normal file
             // TODO: Render the ID somehow?
-            let contents = buf_to_file_contents(None, id.describe().into_bytes());
+            let contents = buf_to_file_contents(None, id.describe(&labels).into_bytes());
             Ok(FileInfo {
                 file_mode: mode::NORMAL,
                 contents,
@@ -262,6 +267,7 @@ fn make_diff_sections(
 
 async fn make_diff_files(
     store: &Arc<Store>,
+    trees: Diff<&MergedTree>,
     tree_diff: BoxStream<'_, CopiesTreeDiffEntry>,
     marker_style: ConflictMarkerStyle,
 ) -> Result<(Vec<RepoPathBuf>, Vec<scm_record::File<'static>>), BuiltinToolError> {
@@ -270,7 +276,8 @@ async fn make_diff_files(
         marker_len: None,
         merge: store.merge_options().clone(),
     };
-    let mut diff_stream = materialized_diff_stream(store, tree_diff);
+    let conflict_labels = trees.map(MergedTree::labels);
+    let mut diff_stream = materialized_diff_stream(store, tree_diff, conflict_labels);
     let mut changed_files = Vec::new();
     let mut files = Vec::new();
     while let Some(entry) = diff_stream.next().await {
@@ -548,7 +555,7 @@ pub fn edit_diff_builtin(
         .before
         .diff_stream_with_copies(trees.after, matcher, &copy_records);
     let (changed_files, files) =
-        make_diff_files(&store, tree_diff, conflict_marker_style).block_on()?;
+        make_diff_files(&store, trees, tree_diff, conflict_marker_style).block_on()?;
     let mut input = scm_record::helpers::CrosstermInput;
     let recorder = scm_record::Recorder::new(
         scm_record::RecordState {
@@ -727,6 +734,7 @@ mod tests {
     use std::collections::BTreeSet;
 
     use jj_lib::backend::FileId;
+    use jj_lib::conflict_labels::ConflictLabels;
     use jj_lib::conflicts::extract_as_single_hunk;
     use jj_lib::matchers::EverythingMatcher;
     use jj_lib::matchers::FilesMatcher;
@@ -761,9 +769,14 @@ mod tests {
     ) -> (Vec<RepoPathBuf>, Vec<scm_record::File<'static>>) {
         let copy_records = CopyRecords::default();
         let tree_diff = left_tree.diff_stream_with_copies(right_tree, matcher, &copy_records);
-        make_diff_files(store, tree_diff, ConflictMarkerStyle::Diff)
-            .block_on()
-            .unwrap()
+        make_diff_files(
+            store,
+            Diff::new(left_tree, right_tree),
+            tree_diff,
+            ConflictMarkerStyle::Diff,
+        )
+        .block_on()
+        .unwrap()
     }
 
     fn apply_diff(
@@ -962,7 +975,7 @@ mod tests {
             "executable_file",
         ]
         "#);
-        insta::assert_debug_snapshot!(files, @r###"
+        insta::assert_debug_snapshot!(files, @r#"
         [
             File {
                 old_path: None,
@@ -987,7 +1000,7 @@ mod tests {
                 ],
             },
         ]
-        "###);
+        "#);
         let no_changes_tree = apply_diff(store, &left_tree, &right_tree, &changed_files, &files);
         assert_tree_eq!(left_tree, no_changes_tree, "no-changes tree was different");
 
@@ -1316,7 +1329,7 @@ mod tests {
             "file_with_content",
         ]
         "#);
-        insta::assert_debug_snapshot!(files, @r###"
+        insta::assert_debug_snapshot!(files, @r#"
         [
             File {
                 old_path: None,
@@ -1341,7 +1354,7 @@ mod tests {
                 ],
             },
         ]
-        "###);
+        "#);
         let no_changes_tree = apply_diff(store, &left_tree, &right_tree, &changed_files, &files);
         assert_tree_eq!(left_tree, no_changes_tree, "no-changes tree was different");
 
@@ -1472,7 +1485,7 @@ mod tests {
             "file_with_content",
         ]
         "#);
-        insta::assert_debug_snapshot!(files, @r###"
+        insta::assert_debug_snapshot!(files, @r#"
         [
             File {
                 old_path: None,
@@ -1493,7 +1506,7 @@ mod tests {
                 ],
             },
         ]
-        "###);
+        "#);
         let no_changes_tree = apply_diff(store, &left_tree, &right_tree, &changed_files, &files);
         assert_tree_eq!(left_tree, no_changes_tree, "no-changes tree was different");
 
@@ -1526,6 +1539,7 @@ mod tests {
                     base.id().clone(),
                     right.id().clone(),
                 ]),
+                ConflictLabels::from_vec(vec!["left".into(), "base".into(), "right".into()]),
             )
         };
         let right_tree = testutils::create_tree(&test_repo.repo, &[(file_path, "resolved\n")]);
@@ -1550,12 +1564,17 @@ mod tests {
                             SectionChangedLine {
                                 is_checked: false,
                                 change_type: Removed,
-                                line: "<<<<<<< Conflict 1 of 1\n",
+                                line: "<<<<<<< conflict 1 of 1\n",
                             },
                             SectionChangedLine {
                                 is_checked: false,
                                 change_type: Removed,
-                                line: "%%%%%%% Changes from base to side #1\n",
+                                line: "%%%%%%% diff from: base\n",
+                            },
+                            SectionChangedLine {
+                                is_checked: false,
+                                change_type: Removed,
+                                line: "\\\\\\\\\\\\\\        to: left\n",
                             },
                             SectionChangedLine {
                                 is_checked: false,
@@ -1565,7 +1584,7 @@ mod tests {
                             SectionChangedLine {
                                 is_checked: false,
                                 change_type: Removed,
-                                line: "+++++++ Contents of side #2\n",
+                                line: "+++++++ right\n",
                             },
                             SectionChangedLine {
                                 is_checked: false,
@@ -1575,7 +1594,7 @@ mod tests {
                             SectionChangedLine {
                                 is_checked: false,
                                 change_type: Removed,
-                                line: ">>>>>>> Conflict 1 of 1 ends\n",
+                                line: ">>>>>>> conflict 1 of 1 ends\n",
                             },
                             SectionChangedLine {
                                 is_checked: false,
@@ -1589,7 +1608,18 @@ mod tests {
         ]
         "#);
         let no_changes_tree = apply_diff(store, &left_tree, &right_tree, &changed_files, &files);
-        assert_tree_eq!(left_tree, no_changes_tree, "no-changes tree was different");
+        // TODO: we should ensure that `jj diffedit` preserves labels when restoring a
+        // conflict. It also should work when restoring conflicts of differing arities.
+        let left_tree_without_labels = MergedTree::new(
+            left_tree.store().clone(),
+            left_tree.tree_ids().clone(),
+            ConflictLabels::unlabeled(),
+        );
+        assert_tree_eq!(
+            left_tree_without_labels,
+            no_changes_tree,
+            "no-changes tree was different"
+        );
 
         let mut files = files;
         for file in &mut files {
