@@ -28,14 +28,16 @@ use tempfile::TempDir;
 
 use super::command_output::CommandOutput;
 use super::command_output::CommandOutputString;
+use super::fake_bisector_path;
 use super::fake_diff_editor_path;
 use super::fake_editor_path;
 use super::to_toml_value;
 
 pub struct TestEnvironment {
-    _temp_dir: TempDir,
+    _env_dir: TempDir,
     env_root: PathBuf,
     home_dir: PathBuf,
+    tmp_dir: PathBuf,
     config_path: PathBuf,
     env_vars: HashMap<OsString, OsString>,
     paths_to_normalize: Vec<(PathBuf, String)>,
@@ -47,10 +49,12 @@ impl Default for TestEnvironment {
     fn default() -> Self {
         testutils::hermetic_git();
 
-        let tmp_dir = testutils::new_temp_dir();
-        let env_root = dunce::canonicalize(tmp_dir.path()).unwrap();
+        let env_dir = testutils::new_temp_dir();
+        let env_root = dunce::canonicalize(env_dir.path()).unwrap();
         let home_dir = env_root.join("home");
         std::fs::create_dir(&home_dir).unwrap();
+        let tmp_dir = env_root.join("tmp");
+        std::fs::create_dir(&tmp_dir).unwrap();
         let config_dir = env_root.join("config");
         std::fs::create_dir(&config_dir).unwrap();
         let env_vars = HashMap::new();
@@ -58,9 +62,10 @@ impl Default for TestEnvironment {
             .into_iter()
             .collect();
         let env = Self {
-            _temp_dir: tmp_dir,
+            _env_dir: env_dir,
             env_root,
             home_dir,
+            tmp_dir,
             config_path: config_dir,
             env_vars,
             paths_to_normalize,
@@ -128,9 +133,27 @@ impl TestEnvironment {
         // executables like `git` from the PATH.
         cmd.env("PATH", std::env::var_os("PATH").unwrap_or_default());
         cmd.env("HOME", &self.home_dir);
+        if !cfg!(windows) {
+            // Override TMPDIR so editor-* files won't be left in global /tmp.
+            // https://doc.rust-lang.org/stable/std/env/fn.temp_dir.html
+            cmd.env("TMPDIR", &self.tmp_dir);
+        } else {
+            // On Windows, "/tmp" mounted in Git Bash appears to be leaked to
+            // other Git Bash processes running concurrently, so the TEMP path
+            // has to be stable.
+            cmd.env("TEMP", std::env::temp_dir());
+        }
         // Prevent git.subprocess from reading outside git config
         cmd.env("GIT_CONFIG_SYSTEM", "/dev/null");
         cmd.env("GIT_CONFIG_GLOBAL", "/dev/null");
+        for (i, (key, value)) in testutils::HERMETIC_GIT_CONFIGS.iter().enumerate() {
+            cmd.env(format!("GIT_CONFIG_KEY_{i}"), key);
+            cmd.env(format!("GIT_CONFIG_VALUE_{i}"), value);
+        }
+        cmd.env(
+            "GIT_CONFIG_COUNT",
+            testutils::HERMETIC_GIT_CONFIGS.len().to_string(),
+        );
         cmd.env("JJ_CONFIG", &self.config_path);
         cmd.env("JJ_USER", "Test User");
         cmd.env("JJ_EMAIL", "test.user@example.com");
@@ -153,14 +176,6 @@ impl TestEnvironment {
             cmd.env(key, value);
         }
 
-        if cfg!(windows) {
-            // Windows uses `TEMP` to create temporary directories, which we need for some
-            // tests.
-            if let Ok(tmp_var) = std::env::var("TEMP") {
-                cmd.env("TEMP", tmp_var);
-            }
-        }
-
         cmd
     }
 
@@ -222,9 +237,20 @@ impl TestEnvironment {
             .push((path.into(), replacement.into()));
     }
 
+    /// Sets up echo as a merge tool.
+    ///
+    /// Windows machines may not have the echo executable installed.
+    pub fn set_up_fake_echo_merge_tool(&self) {
+        let echo_path = assert_cmd::cargo::cargo_bin!("fake-echo");
+        assert!(echo_path.is_file());
+        let echo_path = to_toml_value(echo_path.to_str().unwrap());
+        self.add_config(formatdoc!("merge-tools.fake-echo.program = {echo_path}"));
+    }
+
     /// Sets up the fake bisection test command to read a script from the
     /// returned path
     pub fn set_up_fake_bisector(&mut self) -> PathBuf {
+        self.add_paths_to_normalize(fake_bisector_path(), "$FAKE_BISECTOR_PATH");
         let bisection_script = self.env_root().join("bisection_script");
         std::fs::write(&bisection_script, "").unwrap();
         self.add_env_var("BISECTION_SCRIPT", &bisection_script);
@@ -270,7 +296,7 @@ impl TestEnvironment {
         for (path, replacement) in &self.paths_to_normalize {
             let path = path.display().to_string();
             // Platform-native $TEST_ENV
-            let regex = Regex::new(&format!(r"{}(\S+)", regex::escape(&path))).unwrap();
+            let regex = Regex::new(&format!(r"{}((:?[/\\]\S+)?)", regex::escape(&path))).unwrap();
             normalized = regex
                 .replace_all(&normalized, |caps: &Captures| {
                     format!("{}{}", replacement, caps[1].replace('\\', "/"))
