@@ -126,31 +126,31 @@ fn test_absorb_simple() {
        index 0000000000..e69de29bb2
     [EOF]
     ");
-    insta::assert_snapshot!(get_evolog(&work_dir, "subject(glob:1)"), @r"
+    insta::assert_snapshot!(get_evolog(&work_dir, "subject(1)"), @r"
     ○    kkmpptxz 5810eb0f 1
     ├─╮
-    │ ○  yqosqzyt hidden 39b42898 (no description set)
-    │ ○  yqosqzyt hidden 977269ac (empty) (no description set)
-    ○    kkmpptxz hidden bd7d4016 1
+    │ ○  yqosqzyt/0 39b42898 (hidden) (no description set)
+    │ ○  yqosqzyt/1 977269ac (hidden) (empty) (no description set)
+    ○    kkmpptxz/1 bd7d4016 (hidden) 1
     ├─╮
-    │ ○  mzvwutvl hidden 0b307741 (no description set)
-    │ ○  mzvwutvl hidden f2709b4e (empty) (no description set)
-    ○  kkmpptxz hidden 1553c5e8 1
-    ○  kkmpptxz hidden eb943711 (empty) 1
+    │ ○  mzvwutvl/0 0b307741 (hidden) (no description set)
+    │ ○  mzvwutvl/1 f2709b4e (hidden) (empty) (no description set)
+    ○  kkmpptxz/2 1553c5e8 (hidden) 1
+    ○  kkmpptxz/3 eb943711 (hidden) (empty) 1
     [EOF]
     ");
-    insta::assert_snapshot!(get_evolog(&work_dir, "subject(glob:2)"), @r"
+    insta::assert_snapshot!(get_evolog(&work_dir, "subject(2)"), @r"
     ○    zsuskuln dd109863 2
     ├─╮
-    │ ○  vruxwmqv hidden 761492a8 (no description set)
-    │ ○  vruxwmqv hidden 48c7d8fa (empty) (no description set)
-    ○  zsuskuln hidden 8edd60a2 2
-    ○    zsuskuln hidden 95568809 2
+    │ ○  vruxwmqv/0 761492a8 (hidden) (no description set)
+    │ ○  vruxwmqv/1 48c7d8fa (hidden) (empty) (no description set)
+    ○  zsuskuln/1 8edd60a2 (hidden) 2
+    ○    zsuskuln/2 95568809 (hidden) 2
     ├─╮
-    │ ○  mzvwutvl hidden 0b307741 (no description set)
-    │ ○  mzvwutvl hidden f2709b4e (empty) (no description set)
-    ○  zsuskuln hidden 36fad385 2
-    ○  zsuskuln hidden 561fbce9 (empty) 2
+    │ ○  mzvwutvl/0 0b307741 (hidden) (no description set)
+    │ ○  mzvwutvl/1 f2709b4e (hidden) (empty) (no description set)
+    ○  zsuskuln/3 36fad385 (hidden) 2
+    ○  zsuskuln/4 561fbce9 (hidden) (empty) 2
     [EOF]
     ");
 }
@@ -173,15 +173,15 @@ fn test_absorb_replace_single_line_hunk() {
     work_dir.run_jj(["new"]).success();
     work_dir.write_file("file1", "2a\n1A\n2b\n");
     let output = work_dir.run_jj(["absorb"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Absorbed changes into 1 revisions:
-      qpvuntsm 19034586 (conflict) 1
+      qpvuntsm b00f5b08 (conflict) 1
     Rebased 1 descendant commits.
-    Working copy  (@) now at: mzvwutvl f9c426f2 (empty) (no description set)
-    Parent commit (@-)      : kkmpptxz a5f84679 2
+    Working copy  (@) now at: mzvwutvl 9655ef4d (empty) (no description set)
+    Parent commit (@-)      : kkmpptxz a6531d0a 2
     New conflicts appeared in 1 commits:
-      qpvuntsm 19034586 (conflict) 1
+      qpvuntsm b00f5b08 (conflict) 1
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
       jj new qpvuntsm
@@ -189,45 +189,47 @@ fn test_absorb_replace_single_line_hunk() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
-    insta::assert_snapshot!(get_diffs(&work_dir, "mutable()"), @r"
-    @  mzvwutvl f9c426f2 (empty) (no description set)
-    ○  kkmpptxz a5f84679 2
+    insta::assert_snapshot!(get_diffs(&work_dir, "mutable()"), @r#"
+    @  mzvwutvl 9655ef4d (empty) (no description set)
+    ○  kkmpptxz a6531d0a 2
     │  diff --git a/file1 b/file1
     │  index 0000000000..2f87e8e465 100644
     │  --- a/file1
     │  +++ b/file1
-    │  @@ -1,10 +1,3 @@
-    │  -<<<<<<< Conflict 1 of 1
-    │  -%%%%%%% Changes from base to side #1
+    │  @@ -1,11 +1,3 @@
+    │  -<<<<<<< conflict 1 of 1
+    │  -%%%%%%% diff from: kkmpptxz 9d700628 "2" (parents of absorbed revision)
+    │  -\\\\\\\        to: qpvuntsm aa6cb9bc "1" (absorb destination)
     │  --2a
     │  - 1a
     │  --2b
-    │  -+++++++ Contents of side #2
+    │  -+++++++ absorbed changes (from zsuskuln 5d926f12)
     │   2a
     │   1A
     │   2b
-    │  ->>>>>>> Conflict 1 of 1 ends
-    ×  qpvuntsm 19034586 (conflict) 1
+    │  ->>>>>>> conflict 1 of 1 ends
+    ×  qpvuntsm b00f5b08 (conflict) 1
     │  diff --git a/file1 b/file1
     ~  new file mode 100644
        index 0000000000..0000000000
        --- /dev/null
        +++ b/file1
-       @@ -0,0 +1,10 @@
-       +<<<<<<< Conflict 1 of 1
-       +%%%%%%% Changes from base to side #1
+       @@ -0,0 +1,11 @@
+       +<<<<<<< conflict 1 of 1
+       +%%%%%%% diff from: kkmpptxz 9d700628 "2" (parents of absorbed revision)
+       +\\\\\\\        to: qpvuntsm aa6cb9bc "1" (absorb destination)
        +-2a
        + 1a
        +-2b
-       ++++++++ Contents of side #2
+       ++++++++ absorbed changes (from zsuskuln 5d926f12)
        +2a
        +1A
        +2b
-       +>>>>>>> Conflict 1 of 1 ends
+       +>>>>>>> conflict 1 of 1 ends
     [EOF]
-    ");
+    "#);
 }
 
 #[test]
@@ -242,10 +244,10 @@ fn test_absorb_merge() {
     work_dir.run_jj(["new", "-m1"]).success();
     work_dir.write_file("file1", "1a\n1b\n0a\n");
 
-    work_dir.run_jj(["new", "-m2", "subject(glob:0)"]).success();
+    work_dir.run_jj(["new", "-m2", "subject(0)"]).success();
     work_dir.write_file("file1", "0a\n2a\n2b\n");
 
-    let output = work_dir.run_jj(["new", "-m3", "subject(glob:1)", "subject(glob:2)"]);
+    let output = work_dir.run_jj(["new", "-m3", "subject(1)", "subject(2)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Working copy  (@) now at: mzvwutvl 42875bf7 (empty) 3
@@ -338,10 +340,10 @@ fn test_absorb_discardable_merge_with_descendant() {
     work_dir.run_jj(["new", "-m1"]).success();
     work_dir.write_file("file1", "1a\n1b\n0a\n");
 
-    work_dir.run_jj(["new", "-m2", "subject(glob:0)"]).success();
+    work_dir.run_jj(["new", "-m2", "subject(0)"]).success();
     work_dir.write_file("file1", "0a\n2a\n2b\n");
 
-    let output = work_dir.run_jj(["new", "subject(glob:1)", "subject(glob:2)"]);
+    let output = work_dir.run_jj(["new", "subject(1)", "subject(2)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Working copy  (@) now at: mzvwutvl ad00b91a (empty) (no description set)
@@ -420,17 +422,17 @@ fn test_absorb_conflict() {
 
     work_dir.run_jj(["new", "root()"]).success();
     work_dir.write_file("file1", "2a\n2b\n");
-    let output = work_dir.run_jj(["rebase", "-r@", "-dsubject(glob:1)"]);
-    insta::assert_snapshot!(output, @r###"
+    let output = work_dir.run_jj(["rebase", "-r@", "-dsubject(1)"]);
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 commits to destination
-    Working copy  (@) now at: kkmpptxz 01e6cd99 (conflict) (no description set)
+    Working copy  (@) now at: kkmpptxz 4ab5d3e5 (conflict) (no description set)
     Parent commit (@-)      : qpvuntsm e35bcaff 1
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file1    2-sided conflict
     New conflicts appeared in 1 commits:
-      kkmpptxz 01e6cd99 (conflict) (no description set)
+      kkmpptxz 4ab5d3e5 (conflict) (no description set)
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
       jj new kkmpptxz
@@ -438,19 +440,20 @@ fn test_absorb_conflict() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
     let conflict_content = work_dir.read_file("file1");
-    insta::assert_snapshot!(conflict_content, @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    insta::assert_snapshot!(conflict_content, @r#"
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: zzzzzzzz 00000000 (parents of rebased revision)
+    \\\\\\\        to: qpvuntsm e35bcaff "1" (rebase destination)
     +1a
     +1b
-    +++++++ Contents of side #2
+    +++++++ kkmpptxz e05db987 (rebased revision)
     2a
     2b
-    >>>>>>> Conflict 1 of 1 ends
-    ");
+    >>>>>>> conflict 1 of 1 ends
+    "#);
 
     // Cannot absorb from conflict
     let output = work_dir.run_jj(["absorb"]);
@@ -547,17 +550,17 @@ fn test_absorb_deleted_file_with_multiple_hunks() {
     work_dir.remove_file("file1");
     work_dir.remove_file("file2");
     let output = work_dir.run_jj(["absorb"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Absorbed changes into 2 revisions:
-      kkmpptxz 9210e16d (conflict) 2
-      qpvuntsm a52f61f7 (conflict) 1
+      kkmpptxz af86b290 (conflict) 2
+      qpvuntsm 536f8cbe (conflict) 1
     Rebased 1 descendant commits.
-    Working copy  (@) now at: zsuskuln f8744d38 (no description set)
-    Parent commit (@-)      : kkmpptxz 9210e16d (conflict) 2
+    Working copy  (@) now at: zsuskuln 3058e6b0 (no description set)
+    Parent commit (@-)      : kkmpptxz af86b290 (conflict) 2
     New conflicts appeared in 2 commits:
-      kkmpptxz 9210e16d (conflict) 2
-      qpvuntsm a52f61f7 (conflict) 1
+      kkmpptxz af86b290 (conflict) 2
+      qpvuntsm 536f8cbe (conflict) 1
     Hint: To resolve the conflicts, start by creating a commit on top of
     the first conflicted commit:
       jj new qpvuntsm
@@ -567,78 +570,84 @@ fn test_absorb_deleted_file_with_multiple_hunks() {
     Remaining changes:
     D file2
     [EOF]
-    "###);
+    ");
 
-    insta::assert_snapshot!(get_diffs(&work_dir, "mutable()"), @r"
-    @  zsuskuln f8744d38 (no description set)
+    insta::assert_snapshot!(get_diffs(&work_dir, "mutable()"), @r#"
+    @  zsuskuln 3058e6b0 (no description set)
     │  diff --git a/file2 b/file2
     │  deleted file mode 100644
     │  index 0000000000..0000000000
     │  --- a/file2
     │  +++ /dev/null
-    │  @@ -1,7 +0,0 @@
-    │  -<<<<<<< Conflict 1 of 1
-    │  -%%%%%%% Changes from base to side #1
+    │  @@ -1,8 +0,0 @@
+    │  -<<<<<<< conflict 1 of 1
+    │  -%%%%%%% diff from: kkmpptxz 33662096 "2" (parents of absorbed revision)
+    │  -\\\\\\\        to: kkmpptxz 33662096 "2" (absorb destination)
     │  --1a
     │  - 1b
-    │  -+++++++ Contents of side #2
+    │  -+++++++ absorbed changes (from zsuskuln d6492c8f)
     │  -1a
-    │  ->>>>>>> Conflict 1 of 1 ends
-    ×  kkmpptxz 9210e16d (conflict) 2
+    │  ->>>>>>> conflict 1 of 1 ends
+    ×  kkmpptxz af86b290 (conflict) 2
     │  diff --git a/file1 b/file1
     │  deleted file mode 100644
     │  index 0000000000..0000000000
     │  --- a/file1
     │  +++ /dev/null
-    │  @@ -1,6 +0,0 @@
-    │  -<<<<<<< Conflict 1 of 1
-    │  -%%%%%%% Changes from base to side #1
+    │  @@ -1,7 +0,0 @@
+    │  -<<<<<<< conflict 1 of 1
+    │  -%%%%%%% diff from: kkmpptxz 33662096 "2" (parents of absorbed revision)
+    │  -\\\\\\\        to: qpvuntsm 66b2ce5b "1" (absorb destination)
     │  - 1a
     │  -+1b
-    │  -+++++++ Contents of side #2
-    │  ->>>>>>> Conflict 1 of 1 ends
+    │  -+++++++ absorbed changes (from zsuskuln d6492c8f)
+    │  ->>>>>>> conflict 1 of 1 ends
     │  diff --git a/file2 b/file2
     │  --- a/file2
     │  +++ b/file2
-    │  @@ -1,7 +1,7 @@
-    │   <<<<<<< Conflict 1 of 1
-    │   %%%%%%% Changes from base to side #1
+    │  @@ -1,8 +1,8 @@
+    │   <<<<<<< conflict 1 of 1
+    │   %%%%%%% diff from: kkmpptxz 33662096 "2" (parents of absorbed revision)
+    │  -\\\\\\\        to: qpvuntsm 66b2ce5b "1" (absorb destination)
     │  - 1a
     │  --1b
+    │  +\\\\\\\        to: kkmpptxz 33662096 "2" (absorb destination)
     │  +-1a
     │  + 1b
-    │   +++++++ Contents of side #2
+    │   +++++++ absorbed changes (from zsuskuln d6492c8f)
     │  -1b
     │  +1a
-    │   >>>>>>> Conflict 1 of 1 ends
-    ×  qpvuntsm a52f61f7 (conflict) 1
+    │   >>>>>>> conflict 1 of 1 ends
+    ×  qpvuntsm 536f8cbe (conflict) 1
     │  diff --git a/file1 b/file1
     ~  new file mode 100644
        index 0000000000..0000000000
        --- /dev/null
        +++ b/file1
-       @@ -0,0 +1,6 @@
-       +<<<<<<< Conflict 1 of 1
-       +%%%%%%% Changes from base to side #1
+       @@ -0,0 +1,7 @@
+       +<<<<<<< conflict 1 of 1
+       +%%%%%%% diff from: kkmpptxz 33662096 "2" (parents of absorbed revision)
+       +\\\\\\\        to: qpvuntsm 66b2ce5b "1" (absorb destination)
        + 1a
        ++1b
-       ++++++++ Contents of side #2
-       +>>>>>>> Conflict 1 of 1 ends
+       ++++++++ absorbed changes (from zsuskuln d6492c8f)
+       +>>>>>>> conflict 1 of 1 ends
        diff --git a/file2 b/file2
        new file mode 100644
        index 0000000000..0000000000
        --- /dev/null
        +++ b/file2
-       @@ -0,0 +1,7 @@
-       +<<<<<<< Conflict 1 of 1
-       +%%%%%%% Changes from base to side #1
+       @@ -0,0 +1,8 @@
+       +<<<<<<< conflict 1 of 1
+       +%%%%%%% diff from: kkmpptxz 33662096 "2" (parents of absorbed revision)
+       +\\\\\\\        to: qpvuntsm 66b2ce5b "1" (absorb destination)
        + 1a
        +-1b
-       ++++++++ Contents of side #2
+       ++++++++ absorbed changes (from zsuskuln d6492c8f)
        +1b
-       +>>>>>>> Conflict 1 of 1 ends
+       +>>>>>>> conflict 1 of 1 ends
     [EOF]
-    ");
+    "#);
 }
 
 #[test]
