@@ -138,6 +138,8 @@ fn test_commit_with_empty_description_from_editor() {
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor0")).unwrap(),
         @r#"
+
+
     JJ: Change ID: qpvuntsm
     JJ:
     JJ: Lines starting with "JJ:" (like this one) will be removed.
@@ -294,7 +296,7 @@ fn test_commit_with_default_description() {
     let mut test_env = TestEnvironment::default();
     let edit_script = test_env.set_up_fake_editor();
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
-    test_env.add_config(r#"ui.default-description = "\n\nTESTED=TODO""#);
+    test_env.add_config(r#"template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'"#);
     let work_dir = test_env.work_dir("repo");
 
     work_dir.write_file("file1", "foo\n");
@@ -302,17 +304,16 @@ fn test_commit_with_default_description() {
     std::fs::write(edit_script, ["dump editor"].join("\0")).unwrap();
     work_dir.run_jj(["commit"]).success();
 
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  cba559ac1a48
     ○  7276dfff8027 TESTED=TODO
     ◆  000000000000
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
+
+
     TESTED=TODO
 
     JJ: Change ID: qpvuntsm
@@ -361,6 +362,7 @@ fn test_commit_with_description_template() {
     work_dir.run_jj(["commit", "file1"]).success();
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
+
     JJ: Author: Test User <test.user@example.com> (2001-02-03 08:05:08)
     JJ: Committer: Test User <test.user@example.com> (2001-02-03 08:05:08)
 
@@ -381,6 +383,7 @@ fn test_commit_with_description_template() {
         .success();
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
+
     JJ: Author: Another User <another.user@example.com> (2001-02-03 08:05:08)
     JJ: Committer: Test User <test.user@example.com> (2001-02-03 08:05:09)
 
@@ -394,6 +397,7 @@ fn test_commit_with_description_template() {
     work_dir.run_jj(["commit", "--reset-author"]).success();
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
+
     JJ: Author: Test User <test.user@example.com> (2001-02-03 08:05:10)
     JJ: Committer: Test User <test.user@example.com> (2001-02-03 08:05:10)
 
@@ -647,6 +651,7 @@ fn test_commit_with_editor_and_empty_message() {
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
 
+
     Trailer: value
 
     JJ: Change ID: qpvuntsm
@@ -673,6 +678,8 @@ fn test_commit_with_editor_without_message() {
     // Verify editor was opened
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
+
+
     JJ: Change ID: qpvuntsm
     JJ: This commit contains the following changes:
     JJ:     A file1
