@@ -136,14 +136,14 @@ fn test_bookmark_names() {
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
     let work_dir = test_env.work_dir("repo");
 
-    test_env.run_jj_in(".", ["git", "init", "origin"]).success();
+    test_env
+        .run_jj_in(".", ["git", "init", "--colocate", "origin"])
+        .success();
     let origin_dir = test_env.work_dir("origin");
-    let origin_git_repo_path = origin_dir
-        .root()
-        .join(".jj")
-        .join("repo")
-        .join("store")
-        .join("git");
+    test_env
+        .run_jj_in(".", ["git", "init", "--colocate", "upstream"])
+        .success();
+    let _upstream_dir = test_env.work_dir("upstream");
 
     work_dir
         .run_jj(["bookmark", "create", "-r@", "aaa-local"])
@@ -154,13 +154,10 @@ fn test_bookmark_names() {
 
     // add various remote branches
     work_dir
-        .run_jj([
-            "git",
-            "remote",
-            "add",
-            "origin",
-            origin_git_repo_path.to_str().unwrap(),
-        ])
+        .run_jj(["git", "remote", "add", "origin", "../origin"])
+        .success();
+    work_dir
+        .run_jj(["git", "remote", "add", "upstream", "../upstream"])
         .success();
     work_dir
         .run_jj(["bookmark", "create", "-r@", "aaa-tracked"])
@@ -174,8 +171,18 @@ fn test_bookmark_names() {
     work_dir
         .run_jj(["desc", "-r", "bbb-tracked", "-m", "x"])
         .success();
+
     work_dir
-        .run_jj(["git", "push", "--allow-new", "--bookmark", "glob:*-tracked"])
+        .run_jj(["bookmark", "track", "--remote=origin", "*-tracked"])
+        .success();
+    work_dir
+        .run_jj(["bookmark", "track", "--remote=upstream", "aaa-tracked"])
+        .success();
+    work_dir
+        .run_jj(["git", "push", "--remote=origin", "--tracked"])
+        .success();
+    work_dir
+        .run_jj(["git", "push", "--remote=upstream", "--tracked"])
         .success();
 
     origin_dir
@@ -190,8 +197,20 @@ fn test_bookmark_names() {
     origin_dir
         .run_jj(["desc", "-r", "bbb-untracked", "-m", "x"])
         .success();
-    origin_dir.run_jj(["git", "export"]).success();
-    work_dir.run_jj(["git", "fetch"]).success();
+    work_dir.run_jj(["git", "fetch", "--all-remotes"]).success();
+
+    insta::assert_snapshot!(work_dir.run_jj(["bookmark", "list", "--all"]), @r"
+    aaa-local: qpvuntsm fe38a82d (empty) x
+    aaa-tracked: qpvuntsm fe38a82d (empty) x
+      @origin: qpvuntsm fe38a82d (empty) x
+      @upstream: qpvuntsm fe38a82d (empty) x
+    aaa-untracked@origin: rlvkpnrz 434ae005 (empty) x
+    bbb-local: qpvuntsm fe38a82d (empty) x
+    bbb-tracked: qpvuntsm fe38a82d (empty) x
+      @origin: qpvuntsm fe38a82d (empty) x
+    bbb-untracked@origin: rlvkpnrz 434ae005 (empty) x
+    [EOF]
+    ");
 
     // Every shell hook is a little different, e.g. the zsh hooks add some
     // additional environment variables. But this is irrelevant for the purpose
@@ -264,14 +283,30 @@ fn test_bookmark_names() {
 
     let output = work_dir.complete_fish(["bookmark", "track", "a"]);
     insta::assert_snapshot!(output, @r"
-    aaa-local@origin	 x
-    aaa-untracked@origin	 x
+    aaa-local	 x
+    aaa-untracked	 x
     [EOF]
     ");
 
     let output = work_dir.complete_fish(["bookmark", "untrack", "a"]);
     insta::assert_snapshot!(output, @r"
-    aaa-tracked@origin	x
+    aaa-tracked	x
+    [EOF]
+    ");
+
+    // TODO: Make it so this only lists untracked remotes
+    let output = work_dir.complete_fish(["bookmark", "track", "a", "--remote", ""]);
+    insta::assert_snapshot!(output, @"
+    origin
+    upstream
+    [EOF]
+    ");
+
+    // TODO: Make it so this only lists tracked remotes
+    let output = work_dir.complete_fish(["bookmark", "untrack", "a", "--remote", ""]);
+    insta::assert_snapshot!(output, @"
+    origin
+    upstream
     [EOF]
     ");
 
@@ -434,6 +469,42 @@ fn test_completions_are_generated() {
     ");
 }
 
+#[test]
+fn test_bad_complete_env() {
+    let mut test_env = TestEnvironment::default();
+
+    test_env.add_env_var("COMPLETE", "badshell");
+    let output = test_env.run_jj_in(".", [""; 0]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    error: unknown shell `badshell`, expected one of `bash`, `elvish`, `fish`, `powershell`, `zsh`[EOF]
+    [exit status: 2]
+    ");
+
+    // Empty value of COMPLETE is ignored as is the value of "0".  This could
+    // change if `clap` changes the way it interprets an empty COMPLETE env var.
+    //
+    // In other words, jj runs normally instead of returning completions. We get
+    // an error because the default jj command needs to be run in a jj repo.
+    test_env.add_env_var("COMPLETE", "");
+    let output = test_env.run_jj_in(".", [""; 0]);
+    insta::assert_snapshot!(output, @r#"
+    ------- stderr -------
+    Hint: Use `jj -h` for a list of available commands.
+    Run `jj config set --user ui.default-command log` to disable this message.
+    Error: There is no jj repo in "."
+    [EOF]
+    [exit status: 1]
+    "#);
+    // Same thing (normal execution) happens for a sub-command and "0"
+    test_env.add_env_var("COMPLETE", "0");
+    let output = test_env.run_jj_in(".", ["config", "list", "user.name"]);
+    insta::assert_snapshot!(output, @r#"
+    user.name = "Test User"
+    [EOF]
+    "#);
+}
+
 #[test_case(Shell::Bash; "bash")]
 #[test_case(Shell::Zsh; "zsh")]
 #[test_case(Shell::Fish; "fish")]
@@ -790,14 +861,16 @@ fn test_revisions() {
     );
 
     work_dir.write_file("file", "A");
-    work_dir
-        .run_jj(["b", "c", "-r@", "mutable_bookmark"])
-        .success();
     work_dir.run_jj(["describe", "-m", "mutable 1"]).success();
+    work_dir.run_jj(["describe", "-m", "mutable 2"]).success();
+    // Create divergent change
+    work_dir
+        .run_jj(["b", "c", "-r=at_operation(@-, @)", "mutable_bookmark"])
+        .success();
 
     work_dir.run_jj(["new", "immutable_bookmark"]).success();
     work_dir.write_file("file", "B");
-    work_dir.run_jj(["describe", "-m", "mutable 2"]).success();
+    work_dir.run_jj(["describe", "-m", "mutable 3"]).success();
     work_dir.run_jj(["new", "@", "mutable_bookmark"]).success();
     work_dir
         .run_jj(["b", "c", "-r@", "conflicted_bookmark"])
@@ -821,10 +894,11 @@ fn test_revisions() {
     conflicted_bookmark	conflicted
     immutable_bookmark	immutable
     mutable_bookmark	mutable 1
-    u	working_copy
-    l	conflicted
-    k	mutable 2
-    y	mutable 1
+    x	working_copy
+    k	conflicted
+    w	mutable 3
+    y/0	mutable 2
+    y/1	mutable 1
     q	immutable
     r	remote_commit
     z	(no description set)
@@ -840,10 +914,11 @@ fn test_revisions() {
     ..conflicted_bookmark	conflicted
     ..immutable_bookmark	immutable
     ..mutable_bookmark	mutable 1
-    ..u	working_copy
-    ..l	conflicted
-    ..k	mutable 2
-    ..y	mutable 1
+    ..x	working_copy
+    ..k	conflicted
+    ..w	mutable 3
+    ..y/0	mutable 2
+    ..y/1	mutable 1
     ..q	immutable
     ..r	remote_commit
     ..z	(no description set)
@@ -858,10 +933,11 @@ fn test_revisions() {
     insta::assert_snapshot!(output, @r"
     conflicted_bookmark	conflicted
     mutable_bookmark	mutable 1
-    u	working_copy
-    l	conflicted
-    k	mutable 2
-    y	mutable 1
+    x	working_copy
+    k	conflicted
+    w	mutable 3
+    y/0	mutable 2
+    y/1	mutable 1
     r	remote_commit
     alias_with_newline	    roots(
     siblings	@-+ ~@
@@ -873,10 +949,11 @@ fn test_revisions() {
     insta::assert_snapshot!(output, @r"
     y::conflicted_bookmark	conflicted
     y::mutable_bookmark	mutable 1
-    y::u	working_copy
-    y::l	conflicted
-    y::k	mutable 2
-    y::y	mutable 1
+    y::x	working_copy
+    y::k	conflicted
+    y::w	mutable 3
+    y::y/0	mutable 2
+    y::y/1	mutable 1
     y::r	remote_commit
     y::alias_with_newline	    roots(
     y::siblings	@-+ ~@
@@ -894,7 +971,7 @@ fn test_revisions() {
     let output = work_dir.complete_fish(["resolve", "-r", ""]);
     insta::assert_snapshot!(output, @r"
     conflicted_bookmark	conflicted
-    l	conflicted
+    k	conflicted
     alias_with_newline	    roots(
     siblings	@-+ ~@
     [EOF]
@@ -907,10 +984,11 @@ fn test_revisions() {
     conflicted_bookmark	conflicted
     immutable_bookmark	immutable
     mutable_bookmark	mutable 1
-    u	working_copy
-    l	conflicted
-    k	mutable 2
-    y	mutable 1
+    x	working_copy
+    k	conflicted
+    w	mutable 3
+    y/0	mutable 2
+    y/1	mutable 1
     q	immutable
     r	remote_commit
     z	(no description set)
@@ -934,10 +1012,11 @@ fn test_revisions() {
     a=conflicted_bookmark	conflicted
     a=immutable_bookmark	immutable
     a=mutable_bookmark	mutable 1
-    a=u	working_copy
-    a=l	conflicted
-    a=k	mutable 2
-    a=y	mutable 1
+    a=x	working_copy
+    a=k	conflicted
+    a=w	mutable 3
+    a=y/0	mutable 2
+    a=y/1	mutable 1
     a=q	immutable
     a=r	remote_commit
     a=z	(no description set)
@@ -1357,7 +1436,7 @@ fn test_files() {
     │  M f_modified
     │  M f_not_yet_copied
     │  R {f_not_yet_renamed => f_renamed}
-    │ ×  royxmykx test.user@example.com 2001-02-03 08:05:14 conflicted a24d7569 conflict
+    │ ×  royxmykx test.user@example.com 2001-02-03 08:05:14 conflicted b58ba5ab (conflict)
     ├─╯  conflicted
     │    A f_added_2
     │    A f_dir/dir_file_1
@@ -1543,12 +1622,12 @@ fn test_files() {
     insta::assert_snapshot!(
         output.normalize_stdout_with(|s| s.replace(std::path::MAIN_SEPARATOR, "→")),
         @r"
-        f_dir→dir_file_1	Added
-        f_dir→dir_file_2	Added
-        f_dir→dir_file_3	Added
-        f_dir→f_renamed_3	Renamed
-        [EOF]
-        ");
+    f_dir→dir_file_1	Added
+    f_dir→dir_file_2	Added
+    f_dir→dir_file_3	Added
+    f_dir→f_renamed_3	Renamed
+    [EOF]
+    ");
 
     let output = work_dir.complete_fish(["diff", "--from", "root()", "--to", "@-", "f_"]);
     insta::assert_snapshot!(output, @r"
