@@ -60,6 +60,13 @@ fn test_config_list_nonexistent() {
     Warning: No matching config key for nonexistent-test-key
     [EOF]
     ");
+
+    let output = test_env.run_jj_in(".", ["config", "list", "--repo"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Warning: No config to list
+    [EOF]
+    ");
 }
 
 #[test]
@@ -440,12 +447,12 @@ fn test_config_layer_override_default() {
         "--config",
         &format!("{config_key}={value}", value = to_toml_value("command-arg")),
     ]);
-    insta::assert_snapshot!(output, @r##"
+    insta::assert_snapshot!(output, @r#"
     # merge-tools.vimdiff.program = "user"
     # merge-tools.vimdiff.program = "repo"
     merge-tools.vimdiff.program = "command-arg"
     [EOF]
-    "##);
+    "#);
 
     let output = work_dir.run_jj([
         "config",
@@ -529,14 +536,14 @@ fn test_config_layer_override_env() {
         "--config",
         &format!("{config_key}={value}", value = to_toml_value("command-arg")),
     ]);
-    insta::assert_snapshot!(output, @r##"
+    insta::assert_snapshot!(output, @r#"
     # ui.editor = "env-base"
     # ui.editor = "user"
     # ui.editor = "repo"
     # ui.editor = "env-override"
     ui.editor = "command-arg"
     [EOF]
-    "##);
+    "#);
 }
 
 #[test]
@@ -1099,7 +1106,8 @@ fn test_config_edit_invalid_config() {
     let output = work_dir.run_jj(["config", "get", "test"]);
     insta::assert_snapshot!(output, @r"
     success
-    [EOF]"
+    [EOF]
+    "
     );
 
     // Test the restore previous config
@@ -1128,7 +1136,8 @@ fn test_config_edit_invalid_config() {
     let output = work_dir.run_jj(["config", "get", "test"]);
     insta::assert_snapshot!(output, @r"
     success
-    [EOF]"
+    [EOF]
+    "
     );
 }
 
@@ -1142,6 +1151,9 @@ fn test_config_path() {
     let repo_config_path = work_dir
         .root()
         .join(PathBuf::from_iter([".jj", "repo", "config.toml"]));
+    let ws_config_path = work_dir
+        .root()
+        .join(PathBuf::from_iter([".jj", "workspace-config.toml"]));
     test_env.set_config_path(&user_config_path);
     let work_dir = test_env.work_dir("repo");
 
@@ -1169,6 +1181,22 @@ fn test_config_path() {
     [EOF]
     [exit status: 1]
     ");
+
+    insta::assert_snapshot!(work_dir.run_jj(["config", "path", "--workspace"]), @r"
+    $TEST_ENV/repo/.jj/workspace-config.toml
+    [EOF]
+    ");
+    assert!(
+        !ws_config_path.exists(),
+        "jj config path shouldn't create new file"
+    );
+
+    insta::assert_snapshot!(test_env.run_jj_in(".", ["config", "path", "--workspace"]), @r"
+    ------- stderr -------
+    Error: No workspace config path found
+    [EOF]
+    [exit status: 1]
+    ");
 }
 
 #[test]
@@ -1746,13 +1774,52 @@ fn test_config_author_change_warning() {
         })
         .success();
 
-    let output = work_dir.run_jj(["log"]);
+    let output = work_dir.run_jj(["show"]);
     insta::assert_snapshot!(output, @r"
-    @  qpvuntsm Foo 2001-02-03 08:05:09 c2090b51
-    │  (empty) (no description set)
-    ◆  zzzzzzzz root() 00000000
+    Commit ID: c2090b51d7ecd861e83a677fdf5e9d855efd14fa
+    Change ID: qpvuntsmwlqtpsluzzsnyyzlmlwvmlnu
+    Author   : Test User <Foo> (2001-02-03 08:05:07)
+    Committer: Test User <Foo> (2001-02-03 08:05:09)
+
+        (no description set)
+
     [EOF]
     ");
+
+    let output = work_dir.run_jj(["config", "set", "--repo", "user.name", "'Bar'"]);
+    insta::assert_snapshot!(output, @r#"
+    ------- stderr -------
+    Warning: This setting will only impact future commits.
+    The author of the working copy will stay "Test User <Foo>".
+    To change the working copy author, use "jj metaedit --update-author"
+    [EOF]
+    "#);
+
+    // test_env.run_jj*() resets state for every invocation
+    // for this test, both user.name and user.email are needed
+    work_dir
+        .run_jj_with(|cmd| {
+            cmd.args(["metaedit", "--update-author"])
+                .env_remove("JJ_EMAIL")
+                .env_remove("JJ_USER")
+        })
+        .success();
+
+    let output = work_dir.run_jj(["show"]);
+    insta::assert_snapshot!(output, @r"
+    Commit ID: cab1afa907c193ca2db14f6bc971fde030e3970a
+    Change ID: qpvuntsmwlqtpsluzzsnyyzlmlwvmlnu
+    Author   : Bar <Foo> (2001-02-03 08:05:07)
+    Committer: Bar <Foo> (2001-02-03 08:05:12)
+
+        (no description set)
+
+    [EOF]
+    ");
+
+    // no warnings if no change
+    let output = work_dir.run_jj(["config", "set", "--repo", "user.name", "'Bar'"]);
+    insta::assert_snapshot!(output, @"");
 }
 
 #[test]
