@@ -34,14 +34,14 @@ fn test_evolog_with_or_without_diff() {
     insta::assert_snapshot!(output, @r"
     @  rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     │  my description
-    │  -- operation ae9fa2e2ea1c snapshot working copy
-    ×  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    │  -- operation 29abe568fb5a snapshot working copy
+    ×  rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     │  my description
-    │  -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    │  -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    ○  rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     │  my description
     │  -- operation 826347115e2d snapshot working copy
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    ○  rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
        (empty) my description
        -- operation e0f8e58b3800 new empty commit
     [EOF]
@@ -52,14 +52,14 @@ fn test_evolog_with_or_without_diff() {
     insta::assert_snapshot!(output, @r"
     [1m[38;5;2m@[0m  [1m[38;5;13mr[38;5;8mlvkpnrz[39m [38;5;3mtest.user@example.com[39m [38;5;14m2001-02-03 08:05:10[39m [38;5;12m3[38;5;8m3c10ace[39m[0m
     │  [1mmy description[0m
-    │  [38;5;8m--[39m operation [38;5;4mae9fa2e2ea1c[39m snapshot working copy
-    [1m[38;5;1m×[0m  [1m[39mr[0m[38;5;8mlvkpnrz[39m hidden [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:09[39m [1m[38;5;4m1[0m[38;5;8md598134[39m [38;5;1mconflict[39m
+    │  [38;5;8m--[39m operation [38;5;4m29abe568fb5a[39m snapshot working copy
+    [1m[38;5;1m×[0m  [1m[39mr[0m[38;5;8mlvkpnrz[1m[39m/1[0m [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:09[39m [1m[38;5;4m9[0m[38;5;8m84f03b9[39m (hidden) [38;5;1m(conflict)[39m
     │  my description
-    │  [38;5;8m--[39m operation [38;5;4mb5bfb716eb6f[39m rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    ○  [1m[39mr[0m[38;5;8mlvkpnrz[39m hidden [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:09[39m [1m[38;5;4m5[0m[38;5;8m1e08f95[39m
+    │  [38;5;8m--[39m operation [38;5;4m863adc9ab542[39m rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    ○  [1m[39mr[0m[38;5;8mlvkpnrz[1m[39m/2[0m [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:09[39m [1m[38;5;4m5[0m[38;5;8m1e08f95[39m (hidden)
     │  my description
     │  [38;5;8m--[39m operation [38;5;4m826347115e2d[39m snapshot working copy
-    ○  [1m[39mr[0m[38;5;8mlvkpnrz[39m hidden [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:08[39m [1m[38;5;4mb[0m[38;5;8m955b72e[39m
+    ○  [1m[39mr[0m[38;5;8mlvkpnrz[1m[39m/3[0m [38;5;3mtest.user@example.com[39m [38;5;6m2001-02-03 08:05:08[39m [1m[38;5;4mb[0m[38;5;8m955b72e[39m (hidden)
        [38;5;2m(empty)[39m my description
        [38;5;8m--[39m operation [38;5;4me0f8e58b3800[39m new empty commit
     [EOF]
@@ -68,22 +68,23 @@ fn test_evolog_with_or_without_diff() {
     // There should be no diff caused by the rebase because it was a pure rebase
     // (even even though it resulted in a conflict).
     let output = work_dir.run_jj(["evolog", "-p"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @r#"
     @  rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     │  my description
-    │  -- operation ae9fa2e2ea1c snapshot working copy
+    │  -- operation 29abe568fb5a snapshot working copy
     │  Resolved conflict in file1:
-    │     1     : <<<<<<< Conflict 1 of 1
-    │     2     : %%%%%%% Changes from base to side #1
-    │     3     : -foo
-    │     4     : +++++++ Contents of side #2
-    │     5     : foo
-    │     6     : bar
-    │     7    1: >>>>>>> Conflict 1 of 1 endsresolved
-    ×  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    │     1     : <<<<<<< conflict 1 of 1
+    │     2     : %%%%%%% diff from: qpvuntsm c664a51b (parents of rebased revision)
+    │     3     : \\\\\\\        to: zzzzzzzz 00000000 (rebase destination)
+    │     4     : -foo
+    │     5     : +++++++ rlvkpnrz 51e08f95 "my description" (rebased revision)
+    │     6     : foo
+    │     7     : bar
+    │     8    1: >>>>>>> conflict 1 of 1 endsresolved
+    ×  rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     │  my description
-    │  -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    │  -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    ○  rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     │  my description
     │  -- operation 826347115e2d snapshot working copy
     │  Modified regular file file1:
@@ -91,33 +92,33 @@ fn test_evolog_with_or_without_diff() {
     │          2: bar
     │  Added regular file file2:
     │          1: foo
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    ○  rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
        (empty) my description
        -- operation e0f8e58b3800 new empty commit
        Modified commit description:
                1: my description
     [EOF]
-    ");
+    "#);
 
     // Multiple starting revisions
     let output = work_dir.run_jj(["evolog", "-r.."]);
     insta::assert_snapshot!(output, @r"
     @  rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     │  my description
-    │  -- operation ae9fa2e2ea1c snapshot working copy
-    ×  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    │  -- operation 29abe568fb5a snapshot working copy
+    ×  rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     │  my description
-    │  -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    │  -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    ○  rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     │  my description
     │  -- operation 826347115e2d snapshot working copy
-    ○  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    ○  rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
        (empty) my description
        -- operation e0f8e58b3800 new empty commit
     ○  qpvuntsm test.user@example.com 2001-02-03 08:05:08 c664a51b
     │  (no description set)
     │  -- operation ca1226de0084 snapshot working copy
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -128,10 +129,10 @@ fn test_evolog_with_or_without_diff() {
     insta::assert_snapshot!(output, @r"
     @  rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     │  my description
-    │  -- operation ae9fa2e2ea1c snapshot working copy
-    ×  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    │  -- operation 29abe568fb5a snapshot working copy
+    ×  rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     │  my description
-    │  -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    │  -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
     [EOF]
     ");
 
@@ -140,14 +141,14 @@ fn test_evolog_with_or_without_diff() {
     insta::assert_snapshot!(output, @r"
     rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     my description
-    -- operation ae9fa2e2ea1c snapshot working copy
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    -- operation 29abe568fb5a snapshot working copy
+    rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     my description
-    -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     my description
     -- operation 826347115e2d snapshot working copy
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
     (empty) my description
     -- operation e0f8e58b3800 new empty commit
     [EOF]
@@ -155,27 +156,28 @@ fn test_evolog_with_or_without_diff() {
 
     // Test `--git` format, and that it implies `-p`
     let output = work_dir.run_jj(["evolog", "--no-graph", "--git"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @r#"
     rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     my description
-    -- operation ae9fa2e2ea1c snapshot working copy
+    -- operation 29abe568fb5a snapshot working copy
     diff --git a/file1 b/file1
     index 0000000000..2ab19ae607 100644
     --- a/file1
     +++ b/file1
-    @@ -1,7 +1,1 @@
-    -<<<<<<< Conflict 1 of 1
-    -%%%%%%% Changes from base to side #1
+    @@ -1,8 +1,1 @@
+    -<<<<<<< conflict 1 of 1
+    -%%%%%%% diff from: qpvuntsm c664a51b (parents of rebased revision)
+    -\\\\\\\        to: zzzzzzzz 00000000 (rebase destination)
     --foo
-    -+++++++ Contents of side #2
+    -+++++++ rlvkpnrz 51e08f95 "my description" (rebased revision)
     -foo
     -bar
-    ->>>>>>> Conflict 1 of 1 ends
+    ->>>>>>> conflict 1 of 1 ends
     +resolved
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     my description
-    -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     my description
     -- operation 826347115e2d snapshot working copy
     diff --git a/file1 b/file1
@@ -192,7 +194,7 @@ fn test_evolog_with_or_without_diff() {
     +++ b/file2
     @@ -0,0 +1,1 @@
     +foo
-    rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
     (empty) my description
     -- operation e0f8e58b3800 new empty commit
     diff --git a/JJ-COMMIT-DESCRIPTION b/JJ-COMMIT-DESCRIPTION
@@ -201,7 +203,7 @@ fn test_evolog_with_or_without_diff() {
     @@ -0,0 +1,1 @@
     +my description
     [EOF]
-    ");
+    "#);
 }
 
 #[test]
@@ -293,14 +295,14 @@ fn test_evolog_with_custom_symbols() {
     insta::assert_snapshot!(output, @r"
     $  rlvkpnrz test.user@example.com 2001-02-03 08:05:10 33c10ace
     │  my description
-    │  -- operation a51c9c093002 snapshot working copy
-    ┝  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 1d598134 conflict
+    │  -- operation 9989311c94df snapshot working copy
+    ┝  rlvkpnrz/1 test.user@example.com 2001-02-03 08:05:09 984f03b9 (hidden) (conflict)
     │  my description
-    │  -- operation b5bfb716eb6f rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
-    ┝  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:09 51e08f95
+    │  -- operation 863adc9ab542 rebase commit 51e08f95160c897080d035d330aead3ee6ed5588
+    ┝  rlvkpnrz/2 test.user@example.com 2001-02-03 08:05:09 51e08f95 (hidden)
     │  my description
     │  -- operation 826347115e2d snapshot working copy
-    ┝  rlvkpnrz hidden test.user@example.com 2001-02-03 08:05:08 b955b72e
+    ┝  rlvkpnrz/3 test.user@example.com 2001-02-03 08:05:08 b955b72e (hidden)
        (empty) my description
        -- operation e0f8e58b3800 new empty commit
     [EOF]
@@ -328,7 +330,7 @@ fn test_evolog_word_wrap() {
     @  qpvuntsm test.user@example.com 2001-02-03 08:05:08 68a50538
     │  (empty) first
     │  -- operation 75545f7ff2df describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -340,8 +342,8 @@ fn test_evolog_word_wrap() {
     │  -- operation 75545f7ff2df describe
     │  commit
     │  e8849ae12c709f2321908879bc724fdb2ab8a781
-    ○  qpvuntsm hidden test.user@example.com
-       2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/1 test.user@example.com
+       2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add
        workspace 'default'
@@ -351,7 +353,7 @@ fn test_evolog_word_wrap() {
     qpvuntsm test.user@example.com 2001-02-03 08:05:08 68a50538
     (empty) first
     -- operation 75545f7ff2df describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
-    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    qpvuntsm/1 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
     (empty) (no description set)
     -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -363,8 +365,8 @@ fn test_evolog_word_wrap() {
     -- operation 75545f7ff2df describe
     commit
     e8849ae12c709f2321908879bc724fdb2ab8a781
-    qpvuntsm hidden test.user@example.com
-    2001-02-03 08:05:07 e8849ae1
+    qpvuntsm/1 test.user@example.com
+    2001-02-03 08:05:07 e8849ae1 (hidden)
     (empty) (no description set)
     -- operation 8f47435a3990 add workspace
     'default'
@@ -407,60 +409,60 @@ fn test_evolog_squash() {
         .run_jj([
             "squash",
             "-msquashed 3",
-            "--from=subject(glob:fourth)|subject(glob:fifth)",
-            "--into=subject(glob:squash*)",
+            "--from=subject(fourth)|subject(fifth)",
+            "--into=subject(squash*)",
         ])
         .success();
 
-    let output = work_dir.run_jj(["evolog", "-p", "-rsubject(glob:squash*)"]);
+    let output = work_dir.run_jj(["evolog", "-p", "-rsubject(squash*)"]);
     insta::assert_snapshot!(output, @r"
     ○      qpvuntsm test.user@example.com 2001-02-03 08:05:15 5f3281c6
     ├─┬─╮  squashed 3
-    │ │ │  -- operation 3049d8383eb2 squash commits into 5ec0619af5cb4f7707a556a71a6f96af0bc294d2
+    │ │ │  -- operation 69ecc16188a1 squash commits into 5ec0619af5cb4f7707a556a71a6f96af0bc294d2
     │ │ │  Modified commit description:
-    │ │ │     1     : <<<<<<< Conflict 1 of 1
-    │ │ │     2     : +++++++ Contents of side #1
+    │ │ │     1     : <<<<<<< conflict 1 of 1
+    │ │ │     2     : +++++++ side #1
     │ │ │     3    1: squashed 2
-    │ │ │     4     : %%%%%%% Changes from base #1 to side #2
+    │ │ │     4     : %%%%%%% diff from base #1 to side #2
     │ │ │     5     : +fourth
-    │ │ │     6    1: %%%%%%% Changes from base #2 to side #3
+    │ │ │     6    1: %%%%%%% diff from base #2 to side #3
     │ │ │     7     : +fifth
-    │ │ │     8     : >>>>>>> Conflict 1 of 1 ends
-    │ │ ○  vruxwmqv hidden test.user@example.com 2001-02-03 08:05:15 770795d0
+    │ │ │     8     : >>>>>>> conflict 1 of 1 ends
+    │ │ ○  vruxwmqv/0 test.user@example.com 2001-02-03 08:05:15 770795d0 (hidden)
     │ │ │  fifth
-    │ │ │  -- operation 904e204f4bb0 snapshot working copy
+    │ │ │  -- operation b22b0aceb94e snapshot working copy
     │ │ │  Added regular file file5:
     │ │ │          1: foo5
-    │ │ ○  vruxwmqv hidden test.user@example.com 2001-02-03 08:05:14 2e0123d1
+    │ │ ○  vruxwmqv/1 test.user@example.com 2001-02-03 08:05:14 2e0123d1 (hidden)
     │ │    (empty) fifth
     │ │    -- operation fc852ed87801 new empty commit
     │ │    Modified commit description:
     │ │            1: fifth
-    │ ○  yqosqzyt hidden test.user@example.com 2001-02-03 08:05:14 ea8161b6
+    │ ○  yqosqzyt/0 test.user@example.com 2001-02-03 08:05:14 ea8161b6 (hidden)
     │ │  fourth
     │ │  -- operation 3b09d55dfa6e snapshot working copy
     │ │  Added regular file file4:
     │ │          1: foo4
-    │ ○  yqosqzyt hidden test.user@example.com 2001-02-03 08:05:13 1de5fdb6
+    │ ○  yqosqzyt/1 test.user@example.com 2001-02-03 08:05:13 1de5fdb6 (hidden)
     │    (empty) fourth
     │    -- operation 9404a551035a new empty commit
     │    Modified commit description:
     │            1: fourth
-    ○    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:12 5ec0619a
+    ○    qpvuntsm/1 test.user@example.com 2001-02-03 08:05:12 5ec0619a (hidden)
     ├─╮  squashed 2
     │ │  -- operation fa9796d12627 squash commits into 690858846504af0e42fde980fdacf9851559ebb8
     │ │  Modified commit description:
-    │ │     1     : <<<<<<< Conflict 1 of 1
-    │ │     2     : +++++++ Contents of side #1
+    │ │     1     : <<<<<<< conflict 1 of 1
+    │ │     2     : +++++++ side #1
     │ │     3    1: squashed 1
-    │ │     4    1: %%%%%%% Changes from base to side #2
+    │ │     4    1: %%%%%%% diff from base to side #2
     │ │     5     : +third
-    │ │     6     : >>>>>>> Conflict 1 of 1 ends
+    │ │     6     : >>>>>>> conflict 1 of 1 ends
     │ │  Removed regular file file2:
     │ │     1     : foo2
     │ │  Removed regular file file3:
     │ │     1     : foo3
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:12 cce957f1
+    │ ○  zsuskuln/3 test.user@example.com 2001-02-03 08:05:12 cce957f1 (hidden)
     │ │  third
     │ │  -- operation de96267cd621 snapshot working copy
     │ │  Modified regular file file1:
@@ -471,47 +473,47 @@ fn test_evolog_squash() {
     │ │          1: foo2
     │ │  Added regular file file3:
     │ │          1: foo3
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:11 3a2a4253
+    │ ○  zsuskuln/4 test.user@example.com 2001-02-03 08:05:11 3a2a4253 (hidden)
     │ │  (empty) third
     │ │  -- operation 4611a6121e8a describe commit ebec10f449ad7ab92c7293efab5e3db2d8e9fea1
     │ │  Modified commit description:
     │ │          1: third
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:10 ebec10f4
+    │ ○  zsuskuln/5 test.user@example.com 2001-02-03 08:05:10 ebec10f4 (hidden)
     │    (empty) (no description set)
     │    -- operation 65c81703100d squash commits into 5878cbe03cdf599c9353e5a1a52a01f4c5e0e0fa
-    ○    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:10 69085884
+    ○    qpvuntsm/2 test.user@example.com 2001-02-03 08:05:10 69085884 (hidden)
     ├─╮  squashed 1
     │ │  -- operation 65c81703100d squash commits into 5878cbe03cdf599c9353e5a1a52a01f4c5e0e0fa
     │ │  Modified commit description:
-    │ │     1     : <<<<<<< Conflict 1 of 1
-    │ │     2     : %%%%%%% Changes from base to side #1
+    │ │     1     : <<<<<<< conflict 1 of 1
+    │ │     2     : %%%%%%% diff from base to side #1
     │ │     3     : +first
-    │ │     4     : +++++++ Contents of side #2
+    │ │     4     : +++++++ side #2
     │ │     5     : second
-    │ │     6     : >>>>>>> Conflict 1 of 1 ends
+    │ │     6     : >>>>>>> conflict 1 of 1 ends
     │ │          1: squashed 1
-    │ ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:10 a3759c9d
+    │ ○  kkmpptxz/0 test.user@example.com 2001-02-03 08:05:10 a3759c9d (hidden)
     │ │  second
     │ │  -- operation a7b202f56742 snapshot working copy
     │ │  Modified regular file file1:
     │ │     1    1: foo
     │ │          2: bar
-    │ ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:09 a5b2f625
+    │ ○  kkmpptxz/1 test.user@example.com 2001-02-03 08:05:09 a5b2f625 (hidden)
     │    (empty) second
     │    -- operation 26f649a0cdfa new empty commit
     │    Modified commit description:
     │            1: second
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 5878cbe0
+    ○  qpvuntsm/3 test.user@example.com 2001-02-03 08:05:09 5878cbe0 (hidden)
     │  first
     │  -- operation af15122a5868 snapshot working copy
     │  Added regular file file1:
     │          1: foo
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 68a50538
+    ○  qpvuntsm/4 test.user@example.com 2001-02-03 08:05:08 68a50538 (hidden)
     │  (empty) first
     │  -- operation 75545f7ff2df describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
     │  Modified commit description:
     │          1: first
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/5 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -533,18 +535,18 @@ fn test_evolog_abandoned_op() {
     @  qpvuntsm test.user@example.com 2001-02-03 08:05:09 e1869e5d
     │  file2
     │  -- operation 043c31d6dd84 describe commit 32cabcfa05c604a36074d74ae59964e4e5eb18e9
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 32cabcfa
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:09 32cabcfa (hidden)
     │  file1
     │  -- operation baef907e5b55 snapshot working copy
     │  A file2
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 cb5ebdc6
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:08 cb5ebdc6 (hidden)
     │  file1
     │  -- operation c4cf439c43a8 describe commit 093c3c9624b6cfe22b310586f5638792aa80e6d7
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 093c3c96
+    ○  qpvuntsm/3 test.user@example.com 2001-02-03 08:05:08 093c3c96 (hidden)
     │  (no description set)
     │  -- operation f41b80dc73b6 snapshot working copy
     │  A file1
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/4 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -559,7 +561,7 @@ fn test_evolog_abandoned_op() {
     @  qpvuntsm test.user@example.com 2001-02-03 08:05:09 e1869e5d
     │  file2
     │  -- operation ab2192a635be describe commit 32cabcfa05c604a36074d74ae59964e4e5eb18e9
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 32cabcfa
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:09 32cabcfa (hidden)
        file1
        A file1
        A file2
@@ -621,13 +623,13 @@ fn test_evolog_reversed_no_graph() {
     work_dir.run_jj(["describe", "-m", "c"]).success();
     let output = work_dir.run_jj(["evolog", "--reversed", "--no-graph"]);
     insta::assert_snapshot!(output, @r"
-    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    qpvuntsm/3 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
     (empty) (no description set)
     -- operation 8f47435a3990 add workspace 'default'
-    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 b86e28cd
+    qpvuntsm/2 test.user@example.com 2001-02-03 08:05:08 b86e28cd (hidden)
     (empty) a
     -- operation ab34d1de4875 describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
-    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 9f43967b
+    qpvuntsm/1 test.user@example.com 2001-02-03 08:05:09 9f43967b (hidden)
     (empty) b
     -- operation 3851e9877d51 describe commit b86e28cd6862624ad77e1aaf31e34b2c7545bebd
     qpvuntsm test.user@example.com 2001-02-03 08:05:10 b28cda4b
@@ -638,7 +640,7 @@ fn test_evolog_reversed_no_graph() {
 
     let output = work_dir.run_jj(["evolog", "--limit=2", "--reversed", "--no-graph"]);
     insta::assert_snapshot!(output, @r"
-    qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 9f43967b
+    qpvuntsm/1 test.user@example.com 2001-02-03 08:05:09 9f43967b (hidden)
     (empty) b
     -- operation 3851e9877d51 describe commit b86e28cd6862624ad77e1aaf31e34b2c7545bebd
     qpvuntsm test.user@example.com 2001-02-03 08:05:10 b28cda4b
@@ -658,57 +660,161 @@ fn test_evolog_reverse_with_graph() {
     work_dir.run_jj(["describe", "-m", "b"]).success();
     work_dir.run_jj(["describe", "-m", "c"]).success();
     work_dir
-        .run_jj(["new", "-r", "subject(glob:c)", "-m", "d"])
+        .run_jj(["new", "-r", "subject(c)", "-m", "d"])
         .success();
     work_dir
-        .run_jj(["new", "-r", "subject(glob:c)", "-m", "e"])
+        .run_jj(["new", "-r", "subject(c)", "-m", "e"])
         .success();
     work_dir
         .run_jj([
             "squash",
-            "--from=subject(glob:d)|subject(glob:e)",
-            "--to=subject(glob:c)",
+            "--from=subject(d)|subject(e)",
+            "--to=subject(c)",
             "-m",
             "c+d+e",
         ])
         .success();
-    let output = work_dir.run_jj(["evolog", "-r", "subject(glob:c+d+e)", "--reversed"]);
+    let output = work_dir.run_jj(["evolog", "-r", "subject(c+d+e)", "--reversed"]);
     insta::assert_snapshot!(output, @r"
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/4 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
     │  (empty) (no description set)
     │  -- operation 8f47435a3990 add workspace 'default'
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 b86e28cd
+    ○  qpvuntsm/3 test.user@example.com 2001-02-03 08:05:08 b86e28cd (hidden)
     │  (empty) a
     │  -- operation ab34d1de4875 describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:09 9f43967b
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:09 9f43967b (hidden)
     │  (empty) b
     │  -- operation 3851e9877d51 describe commit b86e28cd6862624ad77e1aaf31e34b2c7545bebd
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:10 b28cda4b
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:10 b28cda4b (hidden)
     │  (empty) c
     │  -- operation 5f4c7b5cb177 describe commit 9f43967b1cdbce4ab322cb7b4636fc0362c38373
-    │ ○  mzvwutvl hidden test.user@example.com 2001-02-03 08:05:11 6a4ff8aa
+    │ ○  mzvwutvl/0 test.user@example.com 2001-02-03 08:05:11 6a4ff8aa (hidden)
     ├─╯  (empty) d
-    │    -- operation d7ad62552658 new empty commit
-    │ ○  royxmykx hidden test.user@example.com 2001-02-03 08:05:12 7dea2d1d
+    │    -- operation bc5f758ddd39 new empty commit
+    │ ○  royxmykx/0 test.user@example.com 2001-02-03 08:05:12 7dea2d1d (hidden)
     ├─╯  (empty) e
-    │    -- operation e5c6f290120f new empty commit
+    │    -- operation 984a0df6c274 new empty commit
     ○  qpvuntsm test.user@example.com 2001-02-03 08:05:13 78fdd026
        (empty) c+d+e
-       -- operation b391c05c22de squash commits into b28cda4b118fc50495ca34a24f030abc078d032e
+       -- operation 77d2222953aa squash commits into b28cda4b118fc50495ca34a24f030abc078d032e
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["evolog", "-rsubject(glob:c+d+e)", "--limit=3", "--reversed"]);
+    let output = work_dir.run_jj(["evolog", "-rsubject(c+d+e)", "--limit=3", "--reversed"]);
     insta::assert_snapshot!(output, @r"
-    ○  mzvwutvl hidden test.user@example.com 2001-02-03 08:05:11 6a4ff8aa
+    ○  mzvwutvl/0 test.user@example.com 2001-02-03 08:05:11 6a4ff8aa (hidden)
     │  (empty) d
-    │  -- operation d7ad62552658 new empty commit
-    │ ○  royxmykx hidden test.user@example.com 2001-02-03 08:05:12 7dea2d1d
+    │  -- operation bc5f758ddd39 new empty commit
+    │ ○  royxmykx/0 test.user@example.com 2001-02-03 08:05:12 7dea2d1d (hidden)
     ├─╯  (empty) e
-    │    -- operation e5c6f290120f new empty commit
+    │    -- operation 984a0df6c274 new empty commit
     ○  qpvuntsm test.user@example.com 2001-02-03 08:05:13 78fdd026
        (empty) c+d+e
-       -- operation b391c05c22de squash commits into b28cda4b118fc50495ca34a24f030abc078d032e
+       -- operation 77d2222953aa squash commits into b28cda4b118fc50495ca34a24f030abc078d032e
+    [EOF]
+    ");
+}
+
+#[test]
+fn test_evolog_template_predecessors_and_inter_diff() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let work_dir = test_env.work_dir("repo");
+
+    // Base change "c".
+    work_dir.run_jj(["describe", "-m", "c"]).success();
+
+    // Two sibling changes to be squashed into "c".
+    work_dir
+        .run_jj(["new", "-r", "subject(c)", "-m", "d"])
+        .success();
+    work_dir.write_file("file1", "d\n");
+    work_dir.write_file("file2", "d\n");
+
+    // Test inter_diff with fileset argument before squash.
+    let output = work_dir
+        .run_jj([
+            "evolog",
+            "-r@",
+            r#"-T=builtin_evolog_compact ++ self.inter_diff("file1").git()"#,
+        ])
+        .success();
+    insta::assert_snapshot!(output, @"
+    @  kkmpptxz test.user@example.com 2001-02-03 08:05:10 c6106cde
+    │  d
+    │  -- operation 744c65238a20 snapshot working copy
+    │  diff --git a/file1 b/file1
+    │  new file mode 100644
+    │  index 0000000000..4bcfe98e64
+    │  --- /dev/null
+    │  +++ b/file1
+    │  @@ -0,0 +1,1 @@
+    │  +d
+    ○  kkmpptxz/1 test.user@example.com 2001-02-03 08:05:09 780d27be (hidden)
+       (empty) d
+       -- operation 653d54836a8e new empty commit
+    [EOF]
+    ");
+
+    work_dir
+        .run_jj(["new", "-r", "subject(c)", "-m", "e"])
+        .success();
+    work_dir.write_file("file3", "e\n");
+
+    // Squash both changes into "c". This should record multiple predecessors
+    // for the rewritten commit (previous version of "c" + squashed commits).
+    work_dir
+        .run_jj([
+            "squash",
+            "--from=subject(d)|subject(e)",
+            "--to=subject(c)",
+            "-m",
+            "c+d+e",
+        ])
+        .success();
+
+    // The rewritten commit has multiple predecessors. `inter_diff()` should be
+    // empty because it's computed against predecessor trees rebased onto the
+    // destination parents.
+    let output = work_dir
+        .run_jj([
+            "evolog",
+            "-rsubject(c+d+e)",
+            r#"-T=builtin_evolog_compact ++ separate("\n", "predecessors: " ++ predecessors.map(|c| c.commit_id().shortest(8)).join(","), inter_diff.summary())"#,
+        ])
+        .success();
+    insta::assert_snapshot!(output, @"
+    ○      qpvuntsm test.user@example.com 2001-02-03 08:05:12 92850c35
+    ├─┬─╮  c+d+e
+    │ │ │  -- operation ab5c35eec35c squash commits into e3ce68f48b53d16111a1310c7f417a39c2934931
+    │ │ │  predecessors: e3ce68f4,c6106cde,870e49d7
+    │ │ ○  mzvwutvl/0 test.user@example.com 2001-02-03 08:05:12 870e49d7 (hidden)
+    │ │ │  e
+    │ │ │  -- operation 1838e74a7014 snapshot working copy
+    │ │ │  predecessors: 3345e308
+    │ │ │  A file3
+    │ │ ○  mzvwutvl/1 test.user@example.com 2001-02-03 08:05:11 3345e308 (hidden)
+    │ │    (empty) e
+    │ │    -- operation 460508b07632 new empty commit
+    │ │    predecessors:
+    │ ○  kkmpptxz/0 test.user@example.com 2001-02-03 08:05:10 c6106cde (hidden)
+    │ │  d
+    │ │  -- operation 744c65238a20 snapshot working copy
+    │ │  predecessors: 780d27be
+    │ │  A file1
+    │ │  A file2
+    │ ○  kkmpptxz/1 test.user@example.com 2001-02-03 08:05:09 780d27be (hidden)
+    │    (empty) d
+    │    -- operation 653d54836a8e new empty commit
+    │    predecessors:
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:08 e3ce68f4 (hidden)
+    │  (empty) c
+    │  -- operation 12d7ec2266d5 describe commit e8849ae12c709f2321908879bc724fdb2ab8a781
+    │  predecessors: e8849ae1
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
+       (empty) (no description set)
+       -- operation 8f47435a3990 add workspace 'default'
+       predecessors:
     [EOF]
     ");
 }
