@@ -16,6 +16,9 @@ use std::fs::OpenOptions;
 use std::io::Write as _;
 use std::path::Path;
 
+use jj_lib::file_util::check_symlink_support;
+use jj_lib::file_util::symlink_file;
+
 use crate::common::TestEnvironment;
 
 fn append_to_file(file_path: &Path, contents: &str) {
@@ -50,6 +53,41 @@ fn test_annotate_linear() {
     ");
 }
 
+#[test]
+fn test_annotate_non_file() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let work_dir = test_env.work_dir("repo");
+
+    let output = work_dir.run_jj(["file", "annotate", "non-existent.txt"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Error: No such path: non-existent.txt
+    [EOF]
+    [exit status: 1]
+    ");
+
+    work_dir.write_file("dir/file.txt", "");
+    let output = work_dir.run_jj(["file", "annotate", "dir"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Error: Path exists but is not a regular file: dir
+    [EOF]
+    [exit status: 1]
+    ");
+
+    if check_symlink_support().unwrap() {
+        symlink_file("target", work_dir.root().join("symlink")).unwrap();
+        let output = work_dir.run_jj(["file", "annotate", "symlink"]);
+        insta::assert_snapshot!(output, @"
+        ------- stderr -------
+        Error: Path exists but is not a regular file: symlink
+        [EOF]
+        [exit status: 1]
+        ");
+    }
+}
+
 #[test]
 fn test_annotate_merge() {
     let test_env = TestEnvironment::default();
@@ -136,16 +174,17 @@ fn test_annotate_conflicted() {
     work_dir.run_jj(["new"]).success();
 
     let output = work_dir.run_jj(["file", "annotate", "file.txt"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @r#"
     qpvuntsm test.use 2001-02-03 08:05:08    1: line1
-    yostqsxw test.use 2001-02-03 08:05:15    2: <<<<<<< Conflict 1 of 1
-    yostqsxw test.use 2001-02-03 08:05:15    3: %%%%%%% Changes from base to side #1
-    yostqsxw test.use 2001-02-03 08:05:15    4: +new text from new commit 1
-    yostqsxw test.use 2001-02-03 08:05:15    5: +++++++ Contents of side #2
-    royxmykx test.use 2001-02-03 08:05:13    6: new text from new commit 2
-    yostqsxw test.use 2001-02-03 08:05:15    7: >>>>>>> Conflict 1 of 1 ends
+    yostqsxw test.use 2001-02-03 08:05:15    2: <<<<<<< conflict 1 of 1
+    yostqsxw test.use 2001-02-03 08:05:15    3: %%%%%%% diff from: qpvuntsm a5daff01 "initial"
+    yostqsxw test.use 2001-02-03 08:05:15    4: \\\\\\\        to: zsuskuln 30cd4478 "commit1"
+    yostqsxw test.use 2001-02-03 08:05:15    5: +new text from new commit 1
+    yostqsxw test.use 2001-02-03 08:05:15    6: +++++++ royxmykx ad312256 "commit2"
+    royxmykx test.use 2001-02-03 08:05:13    7: new text from new commit 2
+    yostqsxw test.use 2001-02-03 08:05:15    8: >>>>>>> conflict 1 of 1 ends
     [EOF]
-    ");
+    "#);
 }
 
 #[test]
@@ -246,6 +285,7 @@ fn test_annotate_with_template() {
 
     let output = work_dir.run_jj(["file", "annotate", "file.txt", "-T", template]);
     insta::assert_snapshot!(output, @r"
+
     qpvuntsm initial
     2001-02-03 08:05:08 Test User <test.user@example.com>
        2 ->   1: initial 2
