@@ -18,7 +18,7 @@ use std::path::PathBuf;
 
 use indoc::formatdoc;
 use indoc::indoc;
-use jj_lib::file_util::try_symlink;
+use jj_lib::file_util::symlink_file;
 
 use crate::common::TestEnvironment;
 use crate::common::to_toml_value;
@@ -456,9 +456,15 @@ fn test_config_filesets() {
     [EOF]
     ");
     let output = work_dir.run_jj(["file", "show", "b1", "-r", "@"]);
-    insta::assert_snapshot!(output, @"1b[EOF]");
+    insta::assert_snapshot!(output, @r"
+
+    1b[EOF]
+    ");
     let output = work_dir.run_jj(["file", "show", "b2", "-r", "@"]);
-    insta::assert_snapshot!(output, @"2b[EOF]");
+    insta::assert_snapshot!(output, @r"
+
+    2b[EOF]
+    ");
 }
 
 #[test]
@@ -583,15 +589,15 @@ fn test_relative_tool_path_from_subdirectory() {
     ");
 
     let output = work_dir.run_jj(["file", "show", "test.txt", "-r", "@"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     HELLO WORLD
     [EOF]
-    "###);
+    ");
     let output = work_dir.run_jj(["file", "show", "subdir/nested.txt", "-r", "@"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     NESTED CONTENT
     [EOF]
-    "###);
+    ");
 
     // Reset so the fix tools should have an effect again
     work_dir.run_jj(["op", "restore", &setup_opid]).success();
@@ -608,15 +614,15 @@ fn test_relative_tool_path_from_subdirectory() {
     ");
 
     let output = work_dir.run_jj(["file", "show", "test.txt", "-r", "@"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     HELLO WORLD
     [EOF]
-    "###);
+    ");
     let output = work_dir.run_jj(["file", "show", "subdir/nested.txt", "-r", "@"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     NESTED CONTENT
     [EOF]
-    "###);
+    ");
 }
 
 #[test]
@@ -1006,7 +1012,10 @@ fn test_fix_cyclic() {
     [EOF]
     ");
     let output = work_dir.run_jj(["file", "show", "file", "-r", "@"]);
-    insta::assert_snapshot!(output, @"tnetnoc[EOF]");
+    insta::assert_snapshot!(output, @r"
+
+    tnetnoc[EOF]
+    ");
 
     let output = work_dir.run_jj(["fix"]);
     insta::assert_snapshot!(output, @r"
@@ -1018,7 +1027,10 @@ fn test_fix_cyclic() {
     [EOF]
     ");
     let output = work_dir.run_jj(["file", "show", "file", "-r", "@"]);
-    insta::assert_snapshot!(output, @"content[EOF]");
+    insta::assert_snapshot!(output, @r"
+
+    content[EOF]
+    ");
 }
 
 #[test]
@@ -1248,7 +1260,7 @@ fn test_fix_file_types() {
     let work_dir = test_env.work_dir("repo");
     work_dir.write_file("file", "content");
     work_dir.create_dir("dir");
-    try_symlink("file", work_dir.root().join("link")).unwrap();
+    symlink_file("file", work_dir.root().join("link")).unwrap();
 
     let output = work_dir.run_jj(["fix", "-s", "@"]);
     insta::assert_snapshot!(output, @r"
@@ -1286,7 +1298,7 @@ fn test_fix_executable() {
     [EOF]
     ");
     let output = work_dir.run_jj(["file", "show", "file", "-r", "@"]);
-    insta::assert_snapshot!(output, @r"CONTENT[EOF]");
+    insta::assert_snapshot!(output, @"CONTENT[EOF]");
     let executable = std::fs::metadata(&path).unwrap().permissions().mode() & 0o111;
     assert_eq!(executable, 0o111);
 }
@@ -1395,7 +1407,7 @@ fn test_fix_both_sides_of_conflict() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Fixed 3 commits of 3 checked.
-    Working copy  (@) now at: mzvwutvl e1acdc6e (conflict) (empty) (no description set)
+    Working copy  (@) now at: mzvwutvl ad547b24 (conflict) (empty) (no description set)
     Parent commit (@-)      : qpvuntsm 0eae0dae a | (no description set)
     Parent commit (@-)      : kkmpptxz eb61ba8d b | (no description set)
     Added 0 files, modified 1 files, removed 0 files
@@ -1415,12 +1427,13 @@ fn test_fix_both_sides_of_conflict() {
     ");
     let output = work_dir.run_jj(["file", "show", "file", "-r", "@"]);
     insta::assert_snapshot!(output, @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: zzzzzzzz 00000000
+    \\\\\\\        to: qpvuntsm c8346c1c
     +CONTENT A
-    +++++++ Contents of side #2
+    +++++++ kkmpptxz 7c4518cb
     CONTENT B
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     [EOF]
     ");
 }
