@@ -43,7 +43,7 @@ fn set_up_git_repo_with_file(git_repo: &gix::Repository, filename: &str) {
 fn test_git_clone() {
     let test_env = TestEnvironment::default();
     let root_dir = test_env.work_dir("");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let git_repo_path = test_env.env_root().join("source");
     let git_repo = git::init(git_repo_path);
 
@@ -93,6 +93,27 @@ fn test_git_clone() {
     "#);
     assert!(!test_env.env_root().join("failed").exists());
 
+    // Failed initialization of the workspace should clean up the destination
+    // directory
+    let output = root_dir.run_jj([
+        "git",
+        "clone",
+        "--config=fsmonitor.backend=invalid",
+        "source",
+        "failed-init",
+    ]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Internal error: Failed to access the repository
+    Caused by:
+    1: Failed to read the tree state settings
+    2: Invalid type or value for fsmonitor.backend
+    3: Unknown fsmonitor kind: invalid
+    [EOF]
+    [exit status: 255]
+    ");
+    assert!(!test_env.env_root().join("failed-init").exists());
+
     // Failed clone shouldn't remove the existing destination directory
     let failed_dir = root_dir.create_dir("failed");
     let output = root_dir.run_jj(["git", "clone", "bad", "failed"]);
@@ -152,7 +173,7 @@ fn test_git_clone() {
     Fetching into new repo in "$TEST_ENV/nested/path/to/repo"
     bookmark: main@origin [new] tracked
     Setting the revset alias `trunk()` to `main@origin`
-    Working copy  (@) now at: uuzqqzqu c871b515 (empty) (no description set)
+    Working copy  (@) now at: vzqnnsmr fea36bca (empty) (no description set)
     Parent commit (@-)      : qomsplrm ebeb70d8 main | message
     Added 1 files, modified 0 files, removed 0 files
     [EOF]
@@ -183,11 +204,46 @@ fn test_git_clone_bad_source() {
     "#);
 }
 
+#[test]
+fn test_git_clone_choose_dest_path() {
+    let test_env = TestEnvironment::default();
+    let root_dir = test_env.work_dir("");
+    let git_repo_path = test_env.env_root().join("source.git");
+    git::init(git_repo_path);
+
+    // Windows drive letters prevent this case from triggering
+    if cfg!(unix) {
+        let output = root_dir.run_jj(["git", "clone", "/"]);
+        insta::assert_snapshot!(output, @"
+        ------- stderr -------
+        Error: No destination specified and wasn't able to guess it
+        [EOF]
+        [exit status: 1]
+        ");
+
+        let output = root_dir.run_jj(["git", "clone", "/.git"]);
+        insta::assert_snapshot!(output, @"
+        ------- stderr -------
+        Error: No destination specified and wasn't able to guess it
+        [EOF]
+        [exit status: 1]
+        ");
+    }
+
+    let output = root_dir.run_jj(["git", "clone", "source.git"]);
+    insta::assert_snapshot!(output, @r#"
+    ------- stderr -------
+    Fetching into new repo in "$TEST_ENV/source"
+    Nothing changed.
+    [EOF]
+    "#);
+}
+
 #[test]
 fn test_git_clone_colocate() {
     let test_env = TestEnvironment::default();
     let root_dir = test_env.work_dir("");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let git_repo_path = test_env.env_root().join("source");
     let git_repo = git::init(git_repo_path);
 
@@ -561,8 +617,8 @@ fn test_git_clone_remote_default_bookmark() {
         )
         .unwrap();
 
-    // All fetched bookmarks will be imported if auto-track-bookmarks = 'glob:*'
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    // All fetched bookmarks will be imported if auto-track-bookmarks = '*'
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let output = root_dir.run_jj(["git", "clone", "source", "clone1"]);
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
@@ -591,8 +647,8 @@ fn test_git_clone_remote_default_bookmark() {
     [EOF]
     "#);
 
-    // Only the default bookmark will be imported if auto-track-bookmarks = ''
-    test_env.add_config("remotes.origin.auto-track-bookmarks = ''");
+    // Only the default bookmark will be imported if auto-track-bookmarks = '~*'
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '~*'");
     let output = root_dir.run_jj(["git", "clone", "source", "clone2"]);
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
@@ -681,7 +737,7 @@ fn test_git_clone_remote_default_bookmark() {
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
     Warning: Deprecated CLI-provided config: `git.auto-local-bookmark` is deprecated; use `remotes.<name>.auto-track-bookmarks` instead.
-    Example: jj config set --user remotes.origin.auto-track-bookmarks 'glob:*'
+    Example: jj config set --user remotes.origin.auto-track-bookmarks '*'
     For details, see: https://docs.jj-vcs.dev/latest/config/#automatic-tracking-of-bookmarks
     Fetching into new repo in "$TEST_ENV/clone5"
     bookmark: feature1@origin [new] tracked
@@ -805,7 +861,7 @@ fn test_git_clone_at_operation() {
 fn test_git_clone_with_remote_name() {
     let test_env = TestEnvironment::default();
     let root_dir = test_env.work_dir("");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let git_repo_path = test_env.env_root().join("source");
     let git_repo = git::init(git_repo_path);
     set_up_non_empty_git_repo(&git_repo);
@@ -991,7 +1047,7 @@ fn test_git_clone_conditional_config() {
 fn test_git_clone_with_depth() {
     let test_env = TestEnvironment::default();
     let root_dir = test_env.work_dir("");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let clone_dir = test_env.work_dir("clone");
     let git_repo_path = test_env.env_root().join("source");
     let git_repo = git::init(git_repo_path);
@@ -1176,11 +1232,11 @@ fn test_git_clone_no_git_executable_with_path() {
 fn test_git_clone_branch() {
     let test_env = TestEnvironment::default();
     let root_dir = test_env.work_dir("");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let git_repo_path = test_env.env_root().join("source");
     let git_repo = git::init(&git_repo_path);
     set_up_non_empty_git_repo(&git_repo);
-    let _ = git::add_commit(
+    git::add_commit(
         &git_repo,
         "refs/heads/feature1",
         "file",
@@ -1208,7 +1264,7 @@ fn test_git_clone_branch() {
         "clone",
         "source",
         "clone_no_such_branch",
-        "--branch=(nonexistent1 | glob:nonexistent*) & ~nonexistent2",
+        "--branch=(nonexistent1 | nonexistent*) & ~nonexistent2",
     ]);
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
@@ -1247,7 +1303,7 @@ fn test_git_clone_branch() {
     ");
 
     // Clone all branches explicitly, the default branch should be checked out
-    let output = root_dir.run_jj(["git", "clone", "source", "clone_all", "--branch=glob:*"]);
+    let output = root_dir.run_jj(["git", "clone", "source", "clone_all", "--branch=*"]);
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
     Fetching into new repo in "$TEST_ENV/clone_all"
@@ -1287,6 +1343,26 @@ fn test_git_clone_branch() {
     Nothing changed.
     [EOF]
     ");
+
+    // Clone all branches individually, first exact match becomes wc parent
+    let output = root_dir.run_jj([
+        "git",
+        "clone",
+        "source",
+        "clone_each",
+        "--branch=feature1",
+        "--branch=main",
+    ]);
+    insta::assert_snapshot!(output, @r#"
+    ------- stderr -------
+    Fetching into new repo in "$TEST_ENV/clone_each"
+    bookmark: feature1@origin [new] tracked
+    bookmark: main@origin     [new] tracked
+    Working copy  (@) now at: nuwvvtmy 38b11a7f (empty) (no description set)
+    Parent commit (@-)      : yxwyzxtq 14835edf feature1 | feature1 message
+    Added 1 files, modified 0 files, removed 0 files
+    [EOF]
+    "#);
 }
 
 #[test]
@@ -1296,7 +1372,7 @@ fn test_git_clone_auto_track_bookmarks() {
     test_env.add_config(
         "
         [remotes.origin]
-        auto-track-bookmarks = 'glob:mine/*'
+        auto-track-bookmarks = 'mine/*'
         ",
     );
 
