@@ -41,7 +41,7 @@ fn test_resolution_of_git_tracking_bookmarks() {
         .success();
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm 384a1421 (empty) new_message
-      @git (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden a7f9930b (empty) old_message
+      @git (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 a7f9930b (hidden) (empty) old_message
     [EOF]
     ");
 
@@ -58,7 +58,7 @@ fn test_resolution_of_git_tracking_bookmarks() {
     a7f9930bb6d54ba39e6c254135b9bfe32041fea4 old_message
     [EOF]
     ");
-    insta::assert_snapshot!(query(r#"remote_bookmarks(exact:"main", exact:"git")"#), @r"
+    insta::assert_snapshot!(query(r#"remote_bookmarks("main", "git")"#), @r"
     a7f9930bb6d54ba39e6c254135b9bfe32041fea4 old_message
     [EOF]
     ");
@@ -331,7 +331,7 @@ fn test_git_import_export_stats_color() {
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
     [1m[38;5;3mWarning: [39mFailed to export some bookmarks:[0m
-      [38;5;5m"un:exportable"@git[39m: Failed to set: A reference must be a valid tag name as well: A ref must not contain invalid bytes or ascii control characters: ":"
+      [38;5;5m"un:exportable"@git[39m: Failed to set: The ref name or path is not a valid ref name: A reference must be a valid tag name as well: A ref must not contain invalid bytes or ascii control characters: ":"
     [1m[38;5;6mHint: [0m[39mGit doesn't allow a branch/tag name that looks like a parent directory of[39m
     [39manother (e.g. `foo` and `foo/bar`). Try to rename the bookmarks/tags that failed[39m
     [39mto export or their "parent" bookmarks/tags.[39m
