@@ -54,12 +54,22 @@ fn get_log_output(work_dir: &TestWorkDir) -> CommandOutput {
     separate(" ",
       commit_id.short(),
       bookmarks,
-      if(git_head, "git_head()"),
       description,
     )"#;
     work_dir.run_jj(["log", "-T", template, "-r=all()"])
 }
 
+#[must_use]
+fn get_colocation_status(work_dir: &TestWorkDir) -> CommandOutput {
+    work_dir.run_jj([
+        "git",
+        "colocation",
+        "status",
+        "--ignore-working-copy",
+        "--quiet", // suppress hint
+    ])
+}
+
 fn read_git_target(work_dir: &TestWorkDir) -> String {
     String::from_utf8(work_dir.read_file(".jj/repo/store/git_target").into()).unwrap()
 }
@@ -88,7 +98,21 @@ fn test_git_init_internal() {
 }
 
 #[test]
-fn test_git_init_internal_ignore_working_copy() {
+fn test_git_init_internal_preexisting_git_repo() {
+    let test_env = TestEnvironment::default();
+    test_env.work_dir("").create_dir_all("repo/.git");
+    let output = test_env.run_jj_in(".", ["git", "init", "repo"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Error: Did not create a jj repo because there is an existing Git repo in this directory.
+    Hint: To create a repo backed by the existing Git repo, run `jj git init --colocate` instead.
+    [EOF]
+    [exit status: 1]
+    ");
+}
+
+#[test]
+fn test_git_init_ignore_working_copy() {
     let test_env = TestEnvironment::default();
     let work_dir = test_env.work_dir("").create_dir("repo");
     work_dir.write_file("file1", "");
@@ -103,7 +127,7 @@ fn test_git_init_internal_ignore_working_copy() {
 }
 
 #[test]
-fn test_git_init_internal_at_operation() {
+fn test_git_init_at_operation() {
     let test_env = TestEnvironment::default();
     let work_dir = test_env.work_dir("").create_dir("repo");
 
@@ -165,10 +189,15 @@ fn test_git_init_external(bare: bool) {
     insta::allow_duplicates! {
         insta::assert_snapshot!(get_log_output(&work_dir), @r"
         @  ed6b513890ae
-        ○  e80a42cccd06 my-bookmark git_head() My commit message
+        ○  e80a42cccd06 my-bookmark My commit message
         ◆  000000000000
         [EOF]
         ");
+        insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+        Workspace is currently not colocated with Git.
+        Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+        [EOF]
+        ");
     }
 }
 
@@ -278,6 +307,7 @@ fn test_git_init_external_import_trunk_upstream_takes_precedence() {
         "refs/remotes/origin/trunk",
     );
 
+    // also accepts full .git path
     let output = test_env.run_jj_in(
         ".",
         [
@@ -285,7 +315,7 @@ fn test_git_init_external_import_trunk_upstream_takes_precedence() {
             "init",
             "repo",
             "--git-repo",
-            git_repo_path.to_str().unwrap(),
+            git_repo_path.join(".git").to_str().unwrap(),
         ],
     );
     insta::allow_duplicates! {
@@ -312,52 +342,6 @@ fn test_git_init_external_import_trunk_upstream_takes_precedence() {
     }
 }
 
-#[test]
-fn test_git_init_external_ignore_working_copy() {
-    let test_env = TestEnvironment::default();
-    let git_repo_path = test_env.env_root().join("git-repo");
-    init_git_repo(&git_repo_path, false);
-    let work_dir = test_env.work_dir("").create_dir("repo");
-    work_dir.write_file("file1", "");
-
-    // No snapshot should be taken
-    let output = work_dir.run_jj([
-        "git",
-        "init",
-        "--ignore-working-copy",
-        "--git-repo",
-        git_repo_path.to_str().unwrap(),
-    ]);
-    insta::assert_snapshot!(output, @r"
-    ------- stderr -------
-    Error: --ignore-working-copy is not respected
-    [EOF]
-    [exit status: 2]
-    ");
-}
-
-#[test]
-fn test_git_init_external_at_operation() {
-    let test_env = TestEnvironment::default();
-    let git_repo_path = test_env.env_root().join("git-repo");
-    init_git_repo(&git_repo_path, false);
-    let work_dir = test_env.work_dir("").create_dir("repo");
-
-    let output = work_dir.run_jj([
-        "git",
-        "init",
-        "--at-op=@-",
-        "--git-repo",
-        git_repo_path.to_str().unwrap(),
-    ]);
-    insta::assert_snapshot!(output, @r"
-    ------- stderr -------
-    Error: --at-op is not respected
-    [EOF]
-    [exit status: 2]
-    ");
-}
-
 #[test]
 fn test_git_init_external_non_existent_directory() {
     let test_env = TestEnvironment::default();
@@ -421,20 +405,30 @@ fn test_git_init_colocated_via_git_repo_path() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[test]
@@ -459,20 +453,30 @@ fn test_git_init_colocated_via_git_repo_path_gitlink() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     jj_work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[cfg(unix)]
@@ -497,20 +501,30 @@ fn test_git_init_colocated_via_git_repo_path_symlink_directory() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     jj_work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[cfg(unix)]
@@ -539,20 +553,30 @@ fn test_git_init_colocated_via_git_repo_path_symlink_directory_without_bare_conf
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     jj_work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[cfg(unix)]
@@ -584,26 +608,36 @@ fn test_git_init_colocated_via_git_repo_path_symlink_gitlink() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     jj_work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&jj_work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&jj_work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[test]
 fn test_git_init_colocated_via_git_repo_path_imported_refs() {
     let test_env = TestEnvironment::default();
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
 
     // Set up remote refs
     test_env.run_jj_in(".", ["git", "init", "remote"]).success();
@@ -632,7 +666,7 @@ fn test_git_init_colocated_via_git_repo_path_imported_refs() {
             .unwrap();
     };
 
-    // With remotes.origin.auto-track-bookmarks = 'glob:*'
+    // With remotes.origin.auto-track-bookmarks = '*'
     let local_dir = test_env.work_dir("local1");
     set_up_local_repo(local_dir.root());
     let output = local_dir.run_jj(["git", "init", "--git-repo=."]);
@@ -652,8 +686,8 @@ fn test_git_init_colocated_via_git_repo_path_imported_refs() {
     [EOF]
     ");
 
-    // With remotes.origin.auto-track-bookmarks = ''
-    test_env.add_config("remotes.origin.auto-track-bookmarks = ''");
+    // With remotes.origin.auto-track-bookmarks = '~*'
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '~*'");
     let local_dir = test_env.work_dir("local2");
     set_up_local_repo(local_dir.root());
     let output = local_dir.run_jj(["git", "init", "--git-repo=."]);
@@ -663,7 +697,7 @@ fn test_git_init_colocated_via_git_repo_path_imported_refs() {
     Hint: The following remote bookmarks aren't associated with the existing local bookmarks:
       local-remote@origin
     Hint: Run the following command to keep local bookmarks updated on future pulls:
-      jj bookmark track local-remote@origin
+      jj bookmark track local-remote --remote=origin
     Initialized repo in "."
     [EOF]
     "#);
@@ -728,7 +762,7 @@ fn test_git_init_colocated_dirty_working_copy() {
     │  C {some-file => new-staged-file}
     │  M some-file
     │  C {some-file => unstaged-file}
-    ○  nntyzxmz someone@example.org 1970-01-01 11:00:00 my-bookmark git_head() e80a42cc
+    ○  nntyzxmz someone@example.org 1970-01-01 11:00:00 my-bookmark e80a42cc
     │  My commit message
     │  A some-file
     ◆  zzzzzzzz root() 00000000
@@ -781,37 +815,6 @@ fn test_git_init_colocated_dirty_working_copy() {
     "#);
 }
 
-#[test]
-fn test_git_init_colocated_ignore_working_copy() {
-    let test_env = TestEnvironment::default();
-    let work_dir = test_env.work_dir("repo");
-    init_git_repo(work_dir.root(), false);
-    work_dir.write_file("file1", "");
-
-    let output = work_dir.run_jj(["git", "init", "--ignore-working-copy", "--colocate"]);
-    insta::assert_snapshot!(output, @r"
-    ------- stderr -------
-    Error: --ignore-working-copy is not respected
-    [EOF]
-    [exit status: 2]
-    ");
-}
-
-#[test]
-fn test_git_init_colocated_at_operation() {
-    let test_env = TestEnvironment::default();
-    let work_dir = test_env.work_dir("repo");
-    init_git_repo(work_dir.root(), false);
-
-    let output = work_dir.run_jj(["git", "init", "--at-op=@-", "--colocate"]);
-    insta::assert_snapshot!(output, @r"
-    ------- stderr -------
-    Error: --at-op is not respected
-    [EOF]
-    [exit status: 2]
-    ");
-}
-
 #[test]
 fn test_git_init_external_but_git_dir_exists() {
     let test_env = TestEnvironment::default();
@@ -841,6 +844,11 @@ fn test_git_init_external_but_git_dir_exists() {
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently not colocated with Git.
+    Last imported/exported Git HEAD: (none)
+    [EOF]
+    ");
 }
 
 #[test]
@@ -861,20 +869,30 @@ fn test_git_init_colocated_via_flag_git_dir_exists() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[test]
@@ -897,20 +915,30 @@ fn test_git_init_colocated_via_config_git_dir_exists() {
     // Check that the Git repo's HEAD got checked out
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  f3fe58bc88cc
-    ○  e80a42cccd06 my-bookmark git_head() My commit message
+    ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: e80a42cccd069007c7a2bb427ac7f1d10b408633
+    [EOF]
+    ");
 
     // Check that the Git repo's HEAD moves
     work_dir.run_jj(["new"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
-    @  0c77f9e21b55
-    ○  f3fe58bc88cc git_head()
+    @  bacc067e7740
+    ○  f3fe58bc88cc
     ○  e80a42cccd06 my-bookmark My commit message
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: f3fe58bc88ccfb820b930a21297d8e48bf76ac2a
+    [EOF]
+    ");
 }
 
 #[test]
@@ -947,6 +975,11 @@ fn test_git_init_colocated_via_flag_git_dir_not_exists() {
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: (none)
+    [EOF]
+    ");
 
     // Create the default bookmark (create both in case we change the default)
     work_dir
@@ -960,6 +993,11 @@ fn test_git_init_colocated_via_flag_git_dir_not_exists() {
     ◆  000000000000
     [EOF]
     ");
+    insta::assert_snapshot!(get_colocation_status(&work_dir), @r"
+    Workspace is currently colocated with Git.
+    Last imported/exported Git HEAD: (none)
+    [EOF]
+    ");
 }
 
 #[test]
