@@ -53,7 +53,7 @@ fn set_up(test_env: &TestEnvironment) {
             [
                 "git",
                 "clone",
-                "--config=remotes.origin.auto-track-bookmarks='glob:*'",
+                "--config=remotes.origin.auto-track-bookmarks='*'",
                 origin_git_repo_path.to_str().unwrap(),
                 "local",
             ],
@@ -87,7 +87,7 @@ fn test_git_push_nothing() {
 fn test_git_push_current_bookmark() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "none()""#);
     // Update some bookmarks. `bookmark1` is not a current bookmark, but
@@ -106,7 +106,7 @@ fn test_git_push_current_bookmark() {
     // Check the setup
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     bookmark1: qpvuntsm e5ce6d9a (empty) modified bookmark1 commit
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 9b2e76de (empty) description 1
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 9b2e76de (hidden) (empty) description 1
     bookmark2: yostqsxw 88ca14a7 (empty) foo
       @origin (behind by 1 commits): zsuskuln 38a20473 (empty) description 2
     my-bookmark: yostqsxw 88ca14a7 (empty) foo
@@ -133,7 +133,7 @@ fn test_git_push_current_bookmark() {
     ");
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     bookmark1: qpvuntsm e5ce6d9a (empty) modified bookmark1 commit
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 9b2e76de (empty) description 1
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 9b2e76de (hidden) (empty) description 1
     bookmark2: yostqsxw 88ca14a7 (empty) foo
       @origin: yostqsxw 88ca14a7 (empty) foo
     my-bookmark: yostqsxw 88ca14a7 (empty) foo
@@ -276,7 +276,7 @@ fn test_git_push_other_remote_has_bookmark() {
     //
     // TODO: Saner test?
     work_dir
-        .run_jj(["bookmark", "track", "bookmark1@other"])
+        .run_jj(["bookmark", "track", "bookmark1", "--remote=other"])
         .success();
     let output = work_dir.run_jj(["git", "push", "--remote=other"]);
     insta::assert_snapshot!(output, @r"
@@ -313,28 +313,28 @@ fn test_git_push_forward_unexpectedly_moved() {
 
     // Pushing should fail
     let output = work_dir.run_jj(["git", "push"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Move forward bookmark bookmark1 from 9b2e76de3920 to 624f94a35f00
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
 
     // The ref name should be colorized
     let output = work_dir.run_jj(["git", "push", "--color=always"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Move forward bookmark bookmark1 from 9b2e76de3920 to 624f94a35f00
-    [1m[38;5;1mError: [39mFailed to push some bookmarks[0m
-    [1m[38;5;6mHint: [0m[39mThe following references unexpectedly moved on the remote:[39m
-    [39m  [38;5;2mrefs/heads/bookmark1[39m (reason: stale info)[39m
+    [1m[38;5;3mWarning: [39mThe following references unexpectedly moved on the remote:[0m
+      [38;5;2mrefs/heads/bookmark1[39m (reason: stale info)
     [1m[38;5;6mHint: [0m[39mTry fetching from the remote, then make the bookmark point to where you want it to be, and push again.[39m
+    [1m[38;5;1mError: [39mFailed to push some bookmarks[0m
     [EOF]
     [exit status: 1]
     ");
@@ -379,28 +379,28 @@ fn test_git_push_sideways_unexpectedly_moved() {
     ");
 
     let output = work_dir.run_jj(["git", "push"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Move sideways bookmark bookmark1 from 9b2e76de3920 to 827b8a385853
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
 
     // The ref name should be colorized
     let output = work_dir.run_jj(["git", "push", "--color=always"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Move sideways bookmark bookmark1 from 9b2e76de3920 to 827b8a385853
-    [1m[38;5;1mError: [39mFailed to push some bookmarks[0m
-    [1m[38;5;6mHint: [0m[39mThe following references unexpectedly moved on the remote:[39m
-    [39m  [38;5;2mrefs/heads/bookmark1[39m (reason: stale info)[39m
+    [1m[38;5;3mWarning: [39mThe following references unexpectedly moved on the remote:[0m
+      [38;5;2mrefs/heads/bookmark1[39m (reason: stale info)
     [1m[38;5;6mHint: [0m[39mTry fetching from the remote, then make the bookmark point to where you want it to be, and push again.[39m
+    [1m[38;5;1mError: [39mFailed to push some bookmarks[0m
     [EOF]
     [exit status: 1]
     ");
@@ -445,14 +445,14 @@ fn test_git_push_deletion_unexpectedly_moved() {
     ");
 
     let output = work_dir.run_jj(["git", "push", "--bookmark", "bookmark1"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -494,14 +494,14 @@ fn test_git_push_unexpectedly_deleted() {
 
     // Pushing a moved bookmark fails if deleted on remote
     let output = work_dir.run_jj(["git", "push"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Move sideways bookmark bookmark1 from 9b2e76de3920 to 09919fb051bf
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -520,14 +520,14 @@ fn test_git_push_unexpectedly_deleted() {
     // git does not allow to push a deleted bookmark if we expect it to exist even
     // though it was already deleted
     let output = work_dir.run_jj(["git", "push", "-bbookmark1"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -537,7 +537,7 @@ fn test_git_push_unexpectedly_deleted() {
 fn test_git_push_creation_unexpectedly_already_exists() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
 
     // Forget bookmark1 locally
@@ -562,14 +562,14 @@ fn test_git_push_creation_unexpectedly_already_exists() {
     ");
 
     let output = work_dir.run_jj(["git", "push"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Add bookmark bookmark1 to a43cb8011c85
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/bookmark1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -581,7 +581,7 @@ fn test_git_push_locally_created_and_rewritten() {
     set_up(&test_env);
     let work_dir = test_env.work_dir("local");
     // Ensure that remote bookmarks aren't tracked automatically
-    test_env.add_config("remotes.origin.auto-track-bookmarks = ''");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '~*'");
 
     // Push locally-created bookmark
     work_dir.run_jj(["new", "root()", "-mlocal 1"]).success();
@@ -592,7 +592,7 @@ fn test_git_push_locally_created_and_rewritten() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Refusing to create new remote bookmark my@origin
-    Hint: Run `jj bookmark track my@origin` and try again.
+    Hint: Run `jj bookmark track my --remote=origin` and try again.
     Nothing changed.
     [EOF]
     ");
@@ -615,7 +615,7 @@ fn test_git_push_locally_created_and_rewritten() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Deprecated CLI-provided config: `git.push-new-bookmarks` is deprecated; use `remotes.<name>.auto-track-bookmarks` instead.
-    Example: jj config set --user remotes.origin.auto-track-bookmarks 'glob:*'
+    Example: jj config set --user remotes.origin.auto-track-bookmarks '*'
     For details, see: https://docs.jj-vcs.dev/latest/config/#automatic-tracking-of-bookmarks
     Changes to push to origin:
       Add bookmark my to e0cba5e497ee
@@ -624,7 +624,7 @@ fn test_git_push_locally_created_and_rewritten() {
     ");
     // Absent-tracked bookmark can be pushed without --allow-new
     work_dir
-        .run_jj(["bookmark", "track", "my@origin"])
+        .run_jj(["bookmark", "track", "my", "--remote=origin"])
         .success();
     let output = work_dir.run_jj(["git", "push"]);
     insta::assert_snapshot!(output, @r"
@@ -643,7 +643,7 @@ fn test_git_push_locally_created_and_rewritten() {
     bookmark2: zsuskuln 38a20473 (empty) description 2
       @origin: zsuskuln 38a20473 (empty) description 2
     my: vruxwmqv 9ebc3217 (empty) local 2
-      @origin (ahead by 1 commits, behind by 1 commits): vruxwmqv hidden e0cba5e4 (empty) local 1
+      @origin (ahead by 1 commits, behind by 1 commits): vruxwmqv/1 e0cba5e4 (hidden) (empty) local 1
     [EOF]
     ");
     let output = work_dir.run_jj(["git", "push"]);
@@ -659,7 +659,8 @@ fn test_git_push_locally_created_and_rewritten() {
 fn test_git_push_multiple() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
+    let origin_dir = test_env.work_dir("origin");
     let work_dir = test_env.work_dir("local");
     work_dir
         .run_jj(["bookmark", "delete", "bookmark1"])
@@ -671,23 +672,34 @@ fn test_git_push_multiple() {
         .run_jj(["bookmark", "create", "-r@", "my-bookmark"])
         .success();
     work_dir.run_jj(["describe", "-m", "foo"]).success();
+    // Make conflicting changes on bookmark3
+    work_dir
+        .run_jj(["bookmark", "set", "bookmark3", "-rbookmark2"])
+        .success();
+    origin_dir
+        .run_jj(["bookmark", "set", "bookmark3", "-rbookmark1"])
+        .success();
+    origin_dir.run_jj(["git", "export"]).success();
     // Check the setup
-    insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
+    insta::assert_snapshot!(get_bookmark_output(&work_dir), @"
     bookmark1 (deleted)
       @origin: qpvuntsm 9b2e76de (empty) description 1
     bookmark2: yqosqzyt 352fa187 (empty) foo
       @origin (ahead by 1 commits, behind by 1 commits): zsuskuln 38a20473 (empty) description 2
+    bookmark3: yqosqzyt 352fa187 (empty) foo
+      @origin (not created yet)
     my-bookmark: yqosqzyt 352fa187 (empty) foo
       @origin (not created yet)
     [EOF]
     ");
     // First dry-run
     let output = work_dir.run_jj(["git", "push", "--all", "--deleted", "--dry-run"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
       Move sideways bookmark bookmark2 from 38a204733702 to 352fa1879f75
+      Add bookmark bookmark3 to 352fa1879f75
       Add bookmark my-bookmark to 352fa1879f75
     Dry-run requested, not pushing.
     [EOF]
@@ -709,7 +721,7 @@ fn test_git_push_multiple() {
         "-b=bookmark1",
         "-b=my-bookmark",
         "-b=bookmark1",
-        "-b=glob:my-*",
+        "-b=my-*",
         "--dry-run",
     ]);
     insta::assert_snapshot!(output, @r"
@@ -721,12 +733,13 @@ fn test_git_push_multiple() {
     [EOF]
     ");
     // Dry run with glob pattern
-    let output = work_dir.run_jj(["git", "push", "-b=glob:'bookmark?'", "--dry-run"]);
-    insta::assert_snapshot!(output, @r"
+    let output = work_dir.run_jj(["git", "push", "-b='bookmark?'", "--dry-run"]);
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
       Move sideways bookmark bookmark2 from 38a204733702 to 352fa1879f75
+      Add bookmark bookmark3 to 352fa1879f75
     Dry-run requested, not pushing.
     [EOF]
     ");
@@ -739,7 +752,7 @@ fn test_git_push_multiple() {
     Nothing changed.
     [EOF]
     ");
-    let output = work_dir.run_jj(["git", "push", "-b=foo", "-b=glob:'?bookmark'"]);
+    let output = work_dir.run_jj(["git", "push", "-b=foo", "-b='?bookmark'"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: No matching bookmarks for names: foo
@@ -749,46 +762,64 @@ fn test_git_push_multiple() {
 
     // --deleted is required to push deleted bookmarks even with --all
     let output = work_dir.run_jj(["git", "push", "--all", "--dry-run"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Warning: Refusing to push deleted bookmark bookmark1
     Hint: Push deleted bookmarks with --deleted or forget the bookmark to suppress this warning.
     Changes to push to origin:
       Move sideways bookmark bookmark2 from 38a204733702 to 352fa1879f75
+      Add bookmark bookmark3 to 352fa1879f75
       Add bookmark my-bookmark to 352fa1879f75
     Dry-run requested, not pushing.
     [EOF]
     ");
     let output = work_dir.run_jj(["git", "push", "--all", "--deleted", "--dry-run"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
       Move sideways bookmark bookmark2 from 38a204733702 to 352fa1879f75
+      Add bookmark bookmark3 to 352fa1879f75
       Add bookmark my-bookmark to 352fa1879f75
     Dry-run requested, not pushing.
     [EOF]
     ");
 
+    // All pushed bookmarks should be committed to the operation. Therefore, the
+    // subsequent "git import" should be noop.
     let output = work_dir.run_jj(["git", "push", "--all", "--deleted"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Delete bookmark bookmark1 from 9b2e76de3920
       Move sideways bookmark bookmark2 from 38a204733702 to 352fa1879f75
+      Add bookmark bookmark3 to 352fa1879f75
       Add bookmark my-bookmark to 352fa1879f75
+    Warning: The following references unexpectedly moved on the remote:
+      refs/heads/bookmark3 (reason: stale info)
+    Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
+    [EOF]
+    [exit status: 1]
+    ");
+    let output = work_dir.run_jj(["git", "import"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Nothing changed.
     [EOF]
     ");
-    insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
+    insta::assert_snapshot!(get_bookmark_output(&work_dir), @"
     bookmark2: yqosqzyt 352fa187 (empty) foo
       @origin: yqosqzyt 352fa187 (empty) foo
+    bookmark3: yqosqzyt 352fa187 (empty) foo
+      @origin (not created yet)
     my-bookmark: yqosqzyt 352fa187 (empty) foo
       @origin: yqosqzyt 352fa187 (empty) foo
     [EOF]
     ");
     let output = work_dir.run_jj(["log", "-rall()"]);
-    insta::assert_snapshot!(output, @r"
-    @  yqosqzyt test.user@example.com 2001-02-03 08:05:17 bookmark2 my-bookmark 352fa187
+    insta::assert_snapshot!(output, @"
+    @  yqosqzyt test.user@example.com 2001-02-03 08:05:17 bookmark2 bookmark3* my-bookmark 352fa187
     │  (empty) foo
     │ ○  zsuskuln test.user@example.com 2001-02-03 08:05:10 38a20473
     ├─╯  (empty) description 2
@@ -902,21 +933,6 @@ fn test_git_push_changes() {
     [EOF]
     ");
 
-    // Try again with the deprecated config
-    let output = work_dir.run_jj([
-        "git",
-        "push",
-        "--config=git.push-bookmark-prefix=test-",
-        "--change=@",
-    ]);
-    insta::assert_snapshot!(output, @r#"
-    ------- stderr -------
-    Warning: Deprecated CLI-provided config: git.push-bookmark-prefix is updated to templates.git_push_bookmark = '"test-" ++ change_id.short()'
-    Bookmark test-yostqsxwqrlt@origin already matches test-yostqsxwqrlt
-    Nothing changed.
-    [EOF]
-    "#);
-
     // Bad `git_push_bookmark` templates
     let output = work_dir.run_jj([
         "git",
@@ -1102,7 +1118,7 @@ fn test_git_push_changes_with_name_deleted_tracked() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Error: Tracked remote bookmarks exist for deleted bookmark: b1
-    Hint: Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark untrack 'glob:b1@*'` to disassociate them.
+    Hint: Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark untrack b1` to disassociate them.
     [EOF]
     [exit status: 1]
     ");
@@ -1110,7 +1126,7 @@ fn test_git_push_changes_with_name_deleted_tracked() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Error: Tracked remote bookmarks exist for deleted bookmark: b1
-    Hint: Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark untrack 'glob:b1@*'` to disassociate them.
+    Hint: Use `jj bookmark set` to recreate the local bookmark. Run `jj bookmark untrack b1` to disassociate them.
     [EOF]
     [exit status: 1]
     ");
@@ -1118,7 +1134,7 @@ fn test_git_push_changes_with_name_deleted_tracked() {
     // OK to push to a different remote once the bookmark is no longer tracked on
     // `origin`
     work_dir
-        .run_jj(["bookmark", "untrack", "b1@origin"])
+        .run_jj(["bookmark", "untrack", "b1", "--remote=origin"])
         .success();
     let output = work_dir
         .run_jj(["bookmark", "list", "--all", "b1"])
@@ -1165,9 +1181,7 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
     work_dir
         .run_jj(["git", "push", "--named", "b1=@"])
         .success();
-    work_dir
-        .run_jj(["bookmark", "untrack", "b1@origin"])
-        .success();
+    work_dir.run_jj(["bookmark", "untrack", "b1"]).success();
     work_dir.run_jj(["bookmark", "delete", "b1"]).success();
 
     let output = work_dir
@@ -1196,7 +1210,7 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Error: Non-tracking remote bookmark b1@origin exists
-    Hint: Run `jj bookmark track b1@origin` to import the remote bookmark.
+    Hint: Run `jj bookmark track b1 --remote=origin` to import the remote bookmark.
     [EOF]
     [exit status: 1]
     ");
@@ -1205,7 +1219,7 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Error: Non-tracking remote bookmark b1@origin exists
-    Hint: Run `jj bookmark track b1@origin` to import the remote bookmark.
+    Hint: Run `jj bookmark track b1 --remote=origin` to import the remote bookmark.
     [EOF]
     [exit status: 1]
     ");
@@ -1227,14 +1241,14 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
     // Make sure push still errors if we try to push a bookmark with the same name
     // to a different location.
     let output = work_dir.run_jj(["git", "push", "--named", "b1=@-"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Add bookmark b1 to aa9ad64cb4ce
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/b1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -1247,14 +1261,14 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
     [EOF]
     ");
     let output = work_dir.run_jj(["git", "push", "--named", "b1=@+"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     ------- stderr -------
     Changes to push to origin:
       Add bookmark b1 to 9a0f76645905
-    Error: Failed to push some bookmarks
-    Hint: The following references unexpectedly moved on the remote:
+    Warning: The following references unexpectedly moved on the remote:
       refs/heads/b1 (reason: stale info)
     Hint: Try fetching from the remote, then make the bookmark point to where you want it to be, and push again.
+    Error: Failed to push some bookmarks
     [EOF]
     [exit status: 1]
     ");
@@ -1274,7 +1288,7 @@ fn test_git_push_changes_with_name_untracked_or_forgotten() {
 fn test_git_push_revisions() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     work_dir.run_jj(["describe", "-m", "foo"]).success();
     work_dir.write_file("file", "contents");
@@ -1381,7 +1395,7 @@ fn test_git_push_mixed() {
     ------- stderr -------
     Creating bookmark push-yqosqzytrlsw for revision yqosqzytrlsw
     Error: Refusing to create new remote bookmark bookmark-1@origin
-    Hint: Run `jj bookmark track bookmark-1@origin` and try again.
+    Hint: Run `jj bookmark track bookmark-1 --remote=origin` and try again.
     [EOF]
     [exit status: 1]
     ");
@@ -1439,8 +1453,8 @@ fn test_git_push_conflict() {
     let output = work_dir.run_jj(["git", "push", "--all"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Error: Won't push commit d1b152bb0916 since it has conflicts
-    Hint: Rejected commit: yostqsxw d1b152bb my-bookmark | (conflict) third
+    Error: Won't push commit 0ae07d1968ee since it has conflicts
+    Hint: Rejected commit: yostqsxw 0ae07d19 my-bookmark | (conflict) third
     [EOF]
     [exit status: 1]
     ");
@@ -1450,7 +1464,7 @@ fn test_git_push_conflict() {
 fn test_git_push_no_description() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     work_dir
         .run_jj(["bookmark", "create", "-r@", "my-bookmark"])
@@ -1479,7 +1493,7 @@ fn test_git_push_no_description() {
 fn test_git_push_no_description_in_immutable() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     work_dir
         .run_jj(["bookmark", "create", "-r@", "imm"])
@@ -1515,7 +1529,7 @@ fn test_git_push_no_description_in_immutable() {
 fn test_git_push_missing_author() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     let run_without_var = |var: &str, args: &[&str]| {
         work_dir
@@ -1548,7 +1562,7 @@ fn test_git_push_missing_author() {
 fn test_git_push_missing_author_in_immutable() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     let run_without_var = |var: &str, args: &[&str]| {
         work_dir
@@ -1590,7 +1604,7 @@ fn test_git_push_missing_author_in_immutable() {
 fn test_git_push_missing_committer() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     let run_without_var = |var: &str, args: &[&str]| {
         work_dir
@@ -1640,7 +1654,7 @@ fn test_git_push_missing_committer() {
 fn test_git_push_missing_committer_in_immutable() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let work_dir = test_env.work_dir("local");
     let run_without_var = |var: &str, args: &[&str]| {
         work_dir
@@ -1719,7 +1733,7 @@ fn test_git_push_conflicting_bookmarks() {
     let test_env = TestEnvironment::default();
     set_up(&test_env);
     let work_dir = test_env.work_dir("local");
-    test_env.add_config("remotes.origin.auto-track-bookmarks = 'glob:*'");
+    test_env.add_config("remotes.origin.auto-track-bookmarks = '*'");
     let git_repo = {
         let mut git_repo_path = work_dir.root().to_owned();
         git_repo_path.extend([".jj", "repo", "store", "git"]);
@@ -1814,7 +1828,7 @@ fn test_git_push_deleted_untracked() {
         .run_jj(["bookmark", "delete", "bookmark1"])
         .success();
     work_dir
-        .run_jj(["bookmark", "untrack", "bookmark1@origin"])
+        .run_jj(["bookmark", "untrack", "bookmark1"])
         .success();
     let output = work_dir.run_jj(["git", "push", "--deleted"]);
     insta::assert_snapshot!(output, @r"
@@ -1849,7 +1863,7 @@ fn test_git_push_tracked_vs_all() {
         .run_jj(["bookmark", "delete", "bookmark2"])
         .success();
     work_dir
-        .run_jj(["bookmark", "untrack", "bookmark1@origin"])
+        .run_jj(["bookmark", "untrack", "bookmark1"])
         .success();
     work_dir
         .run_jj(["bookmark", "create", "-r@", "bookmark3"])
@@ -1885,7 +1899,7 @@ fn test_git_push_tracked_vs_all() {
 
     // Untrack the last remaining tracked bookmark.
     work_dir
-        .run_jj(["bookmark", "untrack", "bookmark2@origin"])
+        .run_jj(["bookmark", "untrack", "bookmark2"])
         .success();
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     bookmark1: vruxwmqv d7607a25 (empty) moved bookmark1
@@ -1917,13 +1931,13 @@ fn test_git_push_tracked_vs_all() {
     // - Whatever we do should be consistent with what `jj bookmark list` does; it
     //   currently does *not* list bookmarks like bookmark2 as "about to be
     //   deleted", as can be seen above.
-    // - We could consider showing some hint on `jj bookmark untrack
-    //   bookmark2@origin` instead of showing an error here.
+    // - We could consider showing some hint on `jj bookmark untrack bookmark2
+    //   --remote=origin` instead of showing an error here.
     let output = work_dir.run_jj(["git", "push", "--all"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Non-tracking remote bookmark bookmark1@origin exists
-    Hint: Run `jj bookmark track bookmark1@origin` to import the remote bookmark.
+    Hint: Run `jj bookmark track bookmark1 --remote=origin` to import the remote bookmark.
     Changes to push to origin:
       Add bookmark bookmark3 to 0004a65e1d28
     [EOF]
@@ -1943,13 +1957,13 @@ fn test_git_push_moved_forward_untracked() {
         .run_jj(["bookmark", "set", "bookmark1", "-r@"])
         .success();
     work_dir
-        .run_jj(["bookmark", "untrack", "bookmark1@origin"])
+        .run_jj(["bookmark", "untrack", "bookmark1"])
         .success();
     let output = work_dir.run_jj(["git", "push"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Non-tracking remote bookmark bookmark1@origin exists
-    Hint: Run `jj bookmark track bookmark1@origin` to import the remote bookmark.
+    Hint: Run `jj bookmark track bookmark1 --remote=origin` to import the remote bookmark.
     Nothing changed.
     [EOF]
     ");
@@ -1968,13 +1982,13 @@ fn test_git_push_moved_sideways_untracked() {
         .run_jj(["bookmark", "set", "--allow-backwards", "bookmark1", "-r@"])
         .success();
     work_dir
-        .run_jj(["bookmark", "untrack", "bookmark1@origin"])
+        .run_jj(["bookmark", "untrack", "bookmark1"])
         .success();
     let output = work_dir.run_jj(["git", "push"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Non-tracking remote bookmark bookmark1@origin exists
-    Hint: Run `jj bookmark track bookmark1@origin` to import the remote bookmark.
+    Hint: Run `jj bookmark track bookmark1 --remote=origin` to import the remote bookmark.
     Nothing changed.
     [EOF]
     ");
@@ -2135,7 +2149,7 @@ fn test_git_push_sign_on_push() {
         "bookmark",
         "create",
         "bookmark3",
-        "-rsubject(glob:'commit which should not be signed 1')",
+        "-rsubject('commit which should not be signed 1')",
     ]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
@@ -2153,7 +2167,7 @@ fn test_git_push_sign_on_push() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: Refusing to create new remote bookmark bookmark3@origin
-    Hint: Run `jj bookmark track bookmark3@origin` and try again.
+    Hint: Run `jj bookmark track bookmark3 --remote=origin` and try again.
     Changes to push to origin:
       Move forward bookmark bookmark2 from d45e2adce0ad to 48ea83e9499c
     [EOF]
@@ -2229,15 +2243,15 @@ fn test_git_push_rejected_by_remote() {
     let mut settings = insta::Settings::clone_current();
     settings.add_filter(r"\s*\n", "\n");
     settings.bind(|| {
-        insta::assert_snapshot!(output, @r"
+        insta::assert_snapshot!(output, @"
         ------- stderr -------
         Changes to push to origin:
           Move forward bookmark bookmark1 from 9b2e76de3920 to 0fc4cf312e83
         remote: error: hook declined to update refs/heads/bookmark1
-        Error: Failed to push some bookmarks
-        Hint: The remote rejected the following updates:
+        Warning: The remote rejected the following updates:
           refs/heads/bookmark1 (reason: hook declined)
         Hint: Try checking if you have permission to push to all the bookmarks.
+        Error: Failed to push some bookmarks
         [EOF]
         [exit status: 1]
         ");
