@@ -189,14 +189,15 @@ fn test_interdiff_conflicting() {
     index 0000000000..24c5735c3e 100644
     --- a/file
     +++ b/file
-    @@ -1,7 +1,1 @@
-    -<<<<<<< Conflict 1 of 1
-    -%%%%%%% Changes from base to side #1
+    @@ -1,8 +1,1 @@
+    -<<<<<<< conflict 1 of 1
+    -%%%%%%% diff from: qpvuntsm d0c049cd (original parents)
+    -\\\\\\\        to: zsuskuln 0b2c304e (new parents)
     --foo
     -+abc
-    -+++++++ Contents of side #2
+    -+++++++ rlvkpnrz b23f92c3 (original revision)
     -bar
-    ->>>>>>> Conflict 1 of 1 ends
+    ->>>>>>> conflict 1 of 1 ends
     +def
     [EOF]
     ");
