@@ -99,7 +99,7 @@ fn test_log_with_diff_stats() {
 
     let template = r#"
     self.diff().files().map(
-        |f| f.status() ++ " " ++ f.source().path() ++ " " ++ f.target().path()
+        |f| f.status_char() ++ " " ++ f.status() ++ " " ++ f.source().path() ++ " " ++ f.target().path()
     ).join("\n")
     ++ "\n" ++
     self.diff().stat().files().map(
@@ -109,21 +109,21 @@ fn test_log_with_diff_stats() {
 
     let output = work_dir.run_jj(["log", "-T", template]);
     insta::assert_snapshot!(output, @r"
-    @  modified file1 file1
-    │  modified file2 file2
-    │  modified file3 file3
-    │  removed file4 file4
-    │  renamed file5 file6
+    @  M modified file1 file1
+    │  M modified file2 file2
+    │  M modified file3 file3
+    │  D removed file4 file4
+    │  R renamed file5 file6
     │  M modified 1 0 file1
     │  M modified 0 1 file2
     │  M modified 1 1 file3
     │  D removed 0 1 file4
     │  R renamed 0 0 file6
-    ○  added file1 file1
-    │  added file2 file2
-    │  added file3 file3
-    │  added file4 file4
-    │  added file5 file5
+    ○  A added file1 file1
+    │  A added file2 file2
+    │  A added file3 file3
+    │  A added file4 file4
+    │  A added file5 file5
     │  A added 1 0 file1
     │  A added 2 0 file2
     │  A added 1 0 file3
@@ -237,14 +237,13 @@ fn test_log_with_or_without_diff() {
     │  1 file changed, 1 insertion(+), 0 deletions(-)
     │  Added regular file file1:
     │          1: foo
-    ◆
-       0 files changed, 0 insertions(+), 0 deletions(-)
+    ◆  0 files changed, 0 insertions(+), 0 deletions(-)
     [EOF]
     ");
 
     // `--stat` is short format, which should be printed first
     let output = work_dir.run_jj(["log", "-T", "description", "--git", "--stat"]);
-    insta::assert_snapshot!(output, @r"
+    insta::assert_snapshot!(output, @"
     @  a new commit
     │  file1 | 1 +
     │  1 file changed, 1 insertion(+), 0 deletions(-)
@@ -265,8 +264,7 @@ fn test_log_with_or_without_diff() {
     │  +++ b/file1
     │  @@ -0,0 +1,1 @@
     │  +foo
-    ◆
-       0 files changed, 0 insertions(+), 0 deletions(-)
+    ◆  0 files changed, 0 insertions(+), 0 deletions(-)
     [EOF]
     ");
 
@@ -480,9 +478,7 @@ fn test_log_shortest_accessors() {
     }
     // Create 2^3 duplicates of the chain
     for _ in 0..3 {
-        work_dir
-            .run_jj(["duplicate", "subject(glob:commit*)"])
-            .success();
+        work_dir.run_jj(["duplicate", "subject(commit*)"]).success();
     }
 
     insta::assert_snapshot!(
@@ -669,9 +665,7 @@ fn test_log_prefix_highlight_styled() {
     }
     // Create 2^3 duplicates of the chain
     for _ in 0..3 {
-        work_dir
-            .run_jj(["duplicate", "subject(glob:commit*)"])
-            .success();
+        work_dir.run_jj(["duplicate", "subject(commit*)"]).success();
     }
 
     insta::assert_snapshot!(
@@ -787,13 +781,9 @@ fn test_log_prefix_highlight_counts_hidden_commits() {
     // Create 2^7 hidden commits
     work_dir.run_jj(["new", "root()", "-m", "extra"]).success();
     for _ in 0..7 {
-        work_dir
-            .run_jj(["duplicate", "subject(glob:extra)"])
-            .success();
+        work_dir.run_jj(["duplicate", "subject(extra)"]).success();
     }
-    work_dir
-        .run_jj(["abandon", "subject(glob:extra)"])
-        .success();
+    work_dir.run_jj(["abandon", "subject(extra)"]).success();
 
     // The unique prefixes became longer.
     insta::assert_snapshot!(work_dir.run_jj(["log", "-T", prefix_format]), @r"
@@ -919,11 +909,11 @@ fn test_log_filtered_by_path() {
 
     // The output filtered to a non-existent file should display a warning.
     let output = work_dir.run_jj(["log", "-r", "@-", "-T", "description", "nonexistent"]);
-    insta::assert_snapshot!(output, @r#"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: No matching entries for paths: nonexistent
     [EOF]
-    "#);
+    ");
 
     // The output filtered to a non-existent file should display a warning.
     // The warning should be displayed at the beginning of the output.
@@ -1029,12 +1019,10 @@ fn test_log_limit() {
     work_dir.write_file("a", "");
     work_dir.run_jj(["new", "-m", "b"]).success();
     work_dir.write_file("b", "");
-    work_dir
-        .run_jj(["new", "-m", "c", "subject(glob:a)"])
-        .success();
+    work_dir.run_jj(["new", "-m", "c", "subject(a)"]).success();
     work_dir.write_file("c", "");
     work_dir
-        .run_jj(["new", "-m", "d", "subject(glob:c)", "subject(glob:b)"])
+        .run_jj(["new", "-m", "d", "subject(c)", "subject(b)"])
         .success();
 
     let output = work_dir.run_jj(["log", "-T", "description", "--limit=3"]);
@@ -1134,7 +1122,7 @@ fn test_log_warn_path_might_be_revset() {
     // been added to the working copy, yet.
     let sub_dir = work_dir.create_dir_all("dir");
     let output = sub_dir.run_jj(["log", "."]);
-    insta::assert_snapshot!(output, @"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: No matching entries for paths: .
     [EOF]
@@ -1160,7 +1148,7 @@ fn test_log_warn_path_might_be_revset() {
 
     // If an explicit revision is provided, then suppress the warning.
     let output = work_dir.run_jj(["log", "@", "-r", "@", "-T", "description"]);
-    insta::assert_snapshot!(output, @"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Warning: No matching entries for paths: @
     [EOF]
@@ -1323,7 +1311,7 @@ fn test_graph_styles() {
         .run_jj(["new", "-m", "side bookmark\nwith\nlong\ndescription"])
         .success();
     work_dir
-        .run_jj(["new", "-m", "merge", "subject(glob:'main bookmark 1')", "@"])
+        .run_jj(["new", "-m", "merge", "subject('main bookmark 1')", "@"])
         .success();
 
     // Default (curved) style
@@ -1593,7 +1581,7 @@ fn test_elided() {
         .success();
     work_dir.run_jj(["new", "-m", "side bookmark 2"]).success();
     work_dir
-        .run_jj(["new", "-m", "merge", "subject(glob:'main bookmark 2')", "@"])
+        .run_jj(["new", "-m", "merge", "subject('main bookmark 2')", "@"])
         .success();
 
     let get_log = |revs: &str| work_dir.run_jj(["log", "-T", r#"description ++ "\n""#, "-r", revs]);
@@ -1619,7 +1607,7 @@ fn test_elided() {
     // Elide some commits from each side of the merge. It's unclear that a revision
     // was skipped on the left side.
     test_env.add_config("ui.log-synthetic-elided-nodes = false");
-    insta::assert_snapshot!(get_log("@ | @- | subject(glob:initial)"), @r"
+    insta::assert_snapshot!(get_log("@ | @- | subject(initial)"), @r"
     @    merge
     ├─╮
     │ ○  side bookmark 2
@@ -1647,7 +1635,7 @@ fn test_elided() {
 
     // Elide some commits from each side of the merge
     test_env.add_config("ui.log-synthetic-elided-nodes = true");
-    insta::assert_snapshot!(get_log("@ | @- | subject(glob:initial)"), @r"
+    insta::assert_snapshot!(get_log("@ | @- | subject(initial)"), @r"
     @    merge
     ├─╮
     │ ○  side bookmark 2
@@ -1693,7 +1681,7 @@ fn test_log_with_custom_symbols() {
         .success();
     work_dir.run_jj(["new", "-m", "side bookmark 2"]).success();
     work_dir
-        .run_jj(["new", "-m", "merge", "subject(glob:'main bookmark 2')", "@"])
+        .run_jj(["new", "-m", "merge", "subject('main bookmark 2')", "@"])
         .success();
 
     let get_log = |revs: &str| work_dir.run_jj(["log", "-T", r#"description ++ "\n""#, "-r", revs]);
@@ -1705,7 +1693,7 @@ fn test_log_with_custom_symbols() {
         templates.log_node = 'if(self, if(current_working_copy, "$", if(root, "┴", "┝")), "🮀")'
         "###,
     );
-    insta::assert_snapshot!(get_log("@ | @- | subject(glob:initial) | root()"), @r"
+    insta::assert_snapshot!(get_log("@ | @- | subject(initial) | root()"), @r"
     $    merge
     ├─╮
     │ ┝  side bookmark 2
@@ -1729,7 +1717,7 @@ fn test_log_with_custom_symbols() {
         templates.log_node = 'if(self, if(current_working_copy, "$", if(root, "^", "*")), ":")'
         "###,
     );
-    insta::assert_snapshot!(get_log("@ | @- | subject(glob:initial) | root()"), @r"
+    insta::assert_snapshot!(get_log("@ | @- | subject(initial) | root()"), @r"
     $    merge
     |\
     | *  side bookmark 2
@@ -1800,9 +1788,7 @@ fn test_log_anonymize() {
         .run_jj_in(".", ["git", "clone", origin_git_repo, "local"])
         .success();
     let work_dir = test_env.work_dir("local");
-    work_dir
-        .run_jj(["bookmark", "track", "b1@origin", "b2@origin"])
-        .success();
+    work_dir.run_jj(["bookmark", "track", "b1 | b2"]).success();
     work_dir.run_jj(["new", "b1"]).success();
     work_dir.run_jj(["bookmark", "move", "b1", "-t@"]).success();
 
@@ -1846,4 +1832,17 @@ fn test_log_count() {
     2
     [EOF]
     ");
+
+    // count the number of revisions directly
+    // inexact revset size estimates (jj-lib testing-only) require 10+ revisions
+    for i in 0..10 {
+        work_dir
+            .run_jj(["commit", "-m", &format!("extra {i}")])
+            .success();
+    }
+    let output = work_dir.run_jj(["log", "--count"]);
+    insta::assert_snapshot!(output, @r"
+    14
+    [EOF]
+    ");
 }
