@@ -15,6 +15,7 @@
 use crate::common::CommandOutput;
 use crate::common::TestEnvironment;
 use crate::common::TestWorkDir;
+use crate::common::create_commit;
 use crate::common::create_commit_with_files;
 
 #[test]
@@ -166,6 +167,46 @@ fn test_new_merge() {
     ");
 }
 
+#[test]
+fn test_new_merge_parents_order() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let work_dir = test_env.work_dir("repo");
+
+    create_commit(&work_dir, "1", &[]);
+    create_commit(&work_dir, "2", &[]);
+    create_commit(&work_dir, "3", &[]);
+    create_commit(&work_dir, "4", &[]);
+    create_commit(&work_dir, "5", &[]);
+
+    // The order of positional and -r/-o args should be preserved
+    work_dir
+        .run_jj([
+            "new",
+            "-osubject(2)",
+            "subject(3)",
+            "-rsubject(1)",
+            "-dsubject(5)",
+            "subject(4)",
+        ])
+        .success();
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
+    @          2034dc93c6ddad404d1aa677ab99b0621d8e109d
+    ├─┬─┬─┬─╮
+    │ │ │ │ ○  de5bab19f679c52a021c343b8942ca875ec6aae7 4
+    │ │ │ ○ │  de3c6b2c8e065351203063817ef0794df1adb2f9 5
+    │ │ │ ├─╯
+    │ │ ○ │  1783ad0eb5c21d958b2e1bf8caab9b019f3d16e9 1
+    │ │ ├─╯
+    │ ○ │  fb047eea4c2bec04e2fd3cd21eca0193d5720341 3
+    │ ├─╯
+    ○ │  36b1b4840ac943a08e7f953df4eadc53e825f2a6 2
+    ├─╯
+    ◆  0000000000000000000000000000000000000000
+    [EOF]
+    ");
+}
+
 #[test]
 fn test_new_merge_conflicts() {
     let test_env = TestEnvironment::default();
@@ -180,7 +221,7 @@ fn test_new_merge_conflicts() {
     let output = work_dir.run_jj(["new", "2|3"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Working copy  (@) now at: vruxwmqv 0361ec6a (conflict) (empty) (no description set)
+    Working copy  (@) now at: vruxwmqv d85cd009 (conflict) (empty) (no description set)
     Parent commit (@-)      : royxmykx 1b282e07 3 | 3
     Parent commit (@-)      : zsuskuln 7ac709e5 2 | 2
     Added 0 files, modified 1 files, removed 0 files
@@ -188,17 +229,18 @@ fn test_new_merge_conflicts() {
     file    2-sided conflict
     [EOF]
     ");
-    insta::assert_snapshot!(work_dir.read_file("file"), @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    insta::assert_snapshot!(work_dir.read_file("file"), @r#"
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: rlvkpnrz a93ed0a5 "1"
+    \\\\\\\        to: royxmykx 1b282e07 "3"
     -1a
     +3a 1a
-    +++++++ Contents of side #2
+    +++++++ zsuskuln 7ac709e5 "2"
     1a 2a
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     1b
     2c
-    ");
+    "#);
 
     // reset working copy
     work_dir.run_jj(["new", "root()"]).success();
@@ -251,7 +293,7 @@ fn test_new_merge_same_change() {
     let output = work_dir.run_jj(["new", "2|3", "--config=merge.same-change=keep"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Working copy  (@) now at: znkkpsqq 453a144b (conflict) (empty) (no description set)
+    Working copy  (@) now at: znkkpsqq af8f7324 (conflict) (empty) (no description set)
     Parent commit (@-)      : royxmykx 1b9fe696 3 | 3
     Parent commit (@-)      : zsuskuln 829e1e90 2 | 2
     Added 1 files, modified 0 files, removed 0 files
@@ -259,15 +301,16 @@ fn test_new_merge_same_change() {
     file    2-sided conflict
     [EOF]
     ");
-    insta::assert_snapshot!(work_dir.read_file("file"), @r"
+    insta::assert_snapshot!(work_dir.read_file("file"), @r#"
     a
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: rlvkpnrz 2adf972b "1"
+    \\\\\\\        to: royxmykx 1b9fe696 "3"
     +b
-    +++++++ Contents of side #2
+    +++++++ zsuskuln 829e1e90 "2"
     b
-    >>>>>>> Conflict 1 of 1 ends
-    ");
+    >>>>>>> conflict 1 of 1 ends
+    "#);
 }
 
 #[test]
@@ -345,9 +388,11 @@ fn test_new_insert_after() {
     let output = work_dir.run_jj(["new", "--after", "B", "D"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    error: the argument '--insert-after <REVSETS>' cannot be used with '[REVSETS]...'
+    error: the argument '--insert-after <REVSETS>' cannot be used with:
+      [REVSETS]...
+      -o <REVSETS>
 
-    Usage: jj new --insert-after <REVSETS> [REVSETS]...
+    Usage: jj new --insert-after <REVSETS> <REVSETS>...
 
     For more information, try '--help'.
     [EOF]
@@ -452,9 +497,11 @@ fn test_new_insert_before() {
     let output = work_dir.run_jj(["new", "--before", "B", "D"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    error: the argument '--insert-before <REVSETS>' cannot be used with '[REVSETS]...'
+    error: the argument '--insert-before <REVSETS>' cannot be used with:
+      [REVSETS]...
+      -o <REVSETS>
 
-    Usage: jj new --insert-before <REVSETS> [REVSETS]...
+    Usage: jj new --insert-before <REVSETS> <REVSETS>...
 
     For more information, try '--help'.
     [EOF]
@@ -728,6 +775,60 @@ fn test_new_insert_after_before_no_loop() {
     ");
 }
 
+#[test]
+fn test_new_insert_after_empty_before() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let work_dir = test_env.work_dir("repo");
+    setup_before_insertion(&work_dir);
+    let template = r#"commit_id.short() ++ " " ++ if(description, description, "root")"#;
+    let output = work_dir.run_jj(["log", "-T", template]);
+    insta::assert_snapshot!(output, @r"
+    @    a8176a8a5348 F
+    ├─╮
+    │ ○  56a33cd09d90 E
+    ○ │  521674f591a6 D
+    ├─╯
+    │ ○  d32ebe56a293 C
+    │ ○  bb98b0102ef5 B
+    │ ○  515354d01f1b A
+    ├─╯
+    ◆  000000000000 root
+    [EOF]
+    ");
+
+    let output = work_dir.run_jj(["new", "-mG", "--insert-before=none()"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Error: No revisions found to use as parent
+    [EOF]
+    [exit status: 1]
+    ");
+
+    let output = work_dir.run_jj(["new", "-mG", "--insert-before=none()", "--insert-after=B"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Working copy  (@) now at: nkmrtpmo d7088f92 (empty) G
+    Parent commit (@-)      : kkmpptxz bb98b010 B | (empty) B
+    [EOF]
+    ");
+    insta::assert_snapshot!(get_short_log_output(&work_dir), @r"
+    @  G
+    │ ○  C
+    ├─╯
+    ○  B
+    ○  A
+    │ ○    F
+    │ ├─╮
+    │ │ ○  E
+    ├───╯
+    │ ○  D
+    ├─╯
+    ◆  root
+    [EOF]
+    ");
+}
+
 #[test]
 fn test_new_conflicting_bookmarks() {
     let test_env = TestEnvironment::default();
@@ -740,13 +841,7 @@ fn test_new_conflicting_bookmarks() {
         .run_jj(["bookmark", "create", "-r@", "foo"])
         .success();
     work_dir
-        .run_jj([
-            "--at-op=@-",
-            "bookmark",
-            "create",
-            "foo",
-            "-rsubject(glob:one)",
-        ])
+        .run_jj(["--at-op=@-", "bookmark", "create", "foo", "-rsubject(one)"])
         .success();
 
     // Trigger resolution of divergent operations
@@ -757,7 +852,7 @@ fn test_new_conflicting_bookmarks() {
     ------- stderr -------
     Error: Name `foo` is conflicted
     Hint: Use commit ID to select single revision from: 96948328bc42, 401ea16fc3fe
-    Hint: Use `bookmarks(exact:foo)` to select all revisions
+    Hint: Use `bookmarks(foo)` to select all revisions
     Hint: To set which revision the bookmark points to, run `jj bookmark set foo -r <REVISION>`
     [EOF]
     [exit status: 1]
@@ -782,7 +877,7 @@ fn test_new_conflicting_change_ids() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Error: Change ID `qpvuntsm` is divergent
-    Hint: Use commit ID to select single revision from: 401ea16fc3fe, 2f175dfc5e0e
+    Hint: Use change offset to select single revision: qpvuntsm/0, qpvuntsm/1
     Hint: Use `change_id(qpvuntsm)` to select all revisions
     Hint: To abandon unneeded revisions, run `jj abandon <commit_id>`
     [EOF]
@@ -859,10 +954,7 @@ fn setup_before_insertion(work_dir: &TestWorkDir) {
     work_dir
         .run_jj(["bookmark", "create", "-r@", "E"])
         .success();
-    // Any number of -r's is ignored
-    work_dir
-        .run_jj(["new", "-m", "F", "-r", "D", "-r", "E"])
-        .success();
+    work_dir.run_jj(["new", "-m", "F", "D", "E"]).success();
     work_dir
         .run_jj(["bookmark", "create", "-r@", "F"])
         .success();
