@@ -112,7 +112,7 @@ fn test_git_push_revert() {
     //    remote-tracking  | AA      |   AA   | AA
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     let pre_push_opid = work_dir.current_operation_id();
@@ -139,7 +139,7 @@ fn test_git_push_revert() {
     //    remote-tracking  | AA      |   AA   | BB
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     test_env.advance_test_rng_seed_to_multiple_of(100_000);
@@ -156,10 +156,10 @@ fn test_git_push_revert() {
     // become a no-op.
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main (conflicted):
-      - qpvuntsm hidden 3a44d6c5 (empty) AA
-      + qpvuntsm?? 1e742089 (empty) CC
-      + qpvuntsm?? d9a9f6a0 (empty) BB
-      @origin (behind by 1 commits): qpvuntsm?? d9a9f6a0 (empty) BB
+      - qpvuntsm/2 3a44d6c5 (hidden) (empty) AA
+      + qpvuntsm/0 1e742089 (divergent) (empty) CC
+      + qpvuntsm/1 d9a9f6a0 (divergent) (empty) BB
+      @origin (behind by 1 commits): qpvuntsm/1 d9a9f6a0 (divergent) (empty) BB
     [EOF]
     ");
 }
@@ -194,7 +194,7 @@ fn test_git_push_revert_with_import() {
     //    remote-tracking  | AA      |   AA   | AA
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     let pre_push_opid = work_dir.current_operation_id();
@@ -221,7 +221,7 @@ fn test_git_push_revert_with_import() {
     //    remote-tracking  | AA      |   AA   | BB
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
 
@@ -247,7 +247,7 @@ fn test_git_push_revert_with_import() {
     // was essentially a no-op.
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm 1e742089 (empty) CC
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden d9a9f6a0 (empty) BB
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 d9a9f6a0 (hidden) (empty) BB
     [EOF]
     ");
 }
@@ -283,7 +283,7 @@ fn test_git_push_revert_colocated() {
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
       @git: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     let pre_push_opid = work_dir.current_operation_id();
@@ -320,7 +320,7 @@ fn test_git_push_revert_colocated() {
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
       @git: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     test_env.advance_test_rng_seed_to_multiple_of(100_000);
@@ -330,11 +330,11 @@ fn test_git_push_revert_colocated() {
     // same result in a seemingly different way?
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main (conflicted):
-      - qpvuntsm hidden 3a44d6c5 (empty) AA
-      + qpvuntsm?? 1e742089 (empty) CC
-      + qpvuntsm?? d9a9f6a0 (empty) BB
-      @git (behind by 1 commits): qpvuntsm?? 1e742089 (empty) CC
-      @origin (behind by 1 commits): qpvuntsm?? d9a9f6a0 (empty) BB
+      - qpvuntsm/2 3a44d6c5 (hidden) (empty) AA
+      + qpvuntsm/0 1e742089 (divergent) (empty) CC
+      + qpvuntsm/1 d9a9f6a0 (divergent) (empty) BB
+      @git (behind by 1 commits): qpvuntsm/0 1e742089 (divergent) (empty) CC
+      @origin (behind by 1 commits): qpvuntsm/1 d9a9f6a0 (divergent) (empty) BB
     [EOF]
     ");
 }
@@ -368,7 +368,7 @@ fn test_git_push_revert_repo_only() {
     work_dir.run_jj(["describe", "-m", "BB"]).success();
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm d9a9f6a0 (empty) BB
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden 3a44d6c5 (empty) AA
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
     let pre_push_opid = work_dir.current_operation_id();
@@ -389,7 +389,17 @@ fn test_git_push_revert_repo_only() {
     // This currently gives an identical result to `test_git_push_revert_import`.
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     main: qpvuntsm 1e742089 (empty) CC
-      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm hidden d9a9f6a0 (empty) BB
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/1 d9a9f6a0 (hidden) (empty) BB
+    [EOF]
+    ");
+
+    // Revert the remote-tracking, without modifying the repo
+    work_dir
+        .run_jj(["op", "restore", "--what=remote-tracking", &pre_push_opid])
+        .success();
+    insta::assert_snapshot!(get_bookmark_output(&work_dir), @"
+    main: qpvuntsm 1e742089 (empty) CC
+      @origin (ahead by 1 commits, behind by 1 commits): qpvuntsm/2 3a44d6c5 (hidden) (empty) AA
     [EOF]
     ");
 }
@@ -423,7 +433,7 @@ fn test_bookmark_track_untrack_revert() {
 
     // Track/untrack can be reverted so long as states can be trivially merged.
     work_dir
-        .run_jj(["bookmark", "untrack", "feature1@origin", "feature2@origin"])
+        .run_jj(["bookmark", "untrack", "feature1 | feature2"])
         .success();
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     feature1: qpvuntsm bab5b5ef (empty) commit
@@ -449,9 +459,7 @@ fn test_bookmark_track_untrack_revert() {
     [EOF]
     ");
 
-    work_dir
-        .run_jj(["bookmark", "track", "feature1@origin"])
-        .success();
+    work_dir.run_jj(["bookmark", "track", "feature1"]).success();
     insta::assert_snapshot!(get_bookmark_output(&work_dir), @r"
     feature1: qpvuntsm bab5b5ef (empty) commit
       @origin: qpvuntsm bab5b5ef (empty) commit
