@@ -37,9 +37,7 @@ fn test_parallelize_no_descendants() {
     [EOF]
     ");
 
-    work_dir
-        .run_jj(["parallelize", "subject(glob:1)::"])
-        .success();
+    work_dir.run_jj(["parallelize", "subject(1)::"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  22b8a32d1949 6 parents:
     │ ○  436e81ced43f 5 parents:
@@ -80,7 +78,7 @@ fn test_parallelize_with_descendants_simple() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:1)::subject(glob:4)"])
+        .run_jj(["parallelize", "subject(1)::subject(4)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  75ac07d7dedc 6 parents: 5
@@ -110,12 +108,8 @@ fn test_parallelize_where_interior_has_non_target_children() {
     for n in 1..6 {
         work_dir.run_jj(["commit", &format!("-m{n}")]).success();
     }
-    work_dir
-        .run_jj(["new", "subject(glob:2)", "-m=2c"])
-        .success();
-    work_dir
-        .run_jj(["new", "subject(glob:5)", "-m=6"])
-        .success();
+    work_dir.run_jj(["new", "subject(2)", "-m=2c"]).success();
+    work_dir.run_jj(["new", "subject(5)", "-m=6"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  9554e07afe42 6 parents: 5
     ○  44f4686efbe9 5 parents: 4
@@ -130,7 +124,7 @@ fn test_parallelize_where_interior_has_non_target_children() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:1)::subject(glob:4)"])
+        .run_jj(["parallelize", "subject(1)::subject(4)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  8bbff9ba415a 6 parents: 5
@@ -159,12 +153,8 @@ fn test_parallelize_where_root_has_non_target_children() {
     for n in 1..4 {
         work_dir.run_jj(["commit", &format!("-m{n}")]).success();
     }
-    work_dir
-        .run_jj(["new", "subject(glob:1)", "-m=1c"])
-        .success();
-    work_dir
-        .run_jj(["new", "subject(glob:3)", "-m=4"])
-        .success();
+    work_dir.run_jj(["new", "subject(1)", "-m=1c"]).success();
+    work_dir.run_jj(["new", "subject(3)", "-m=4"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  4c392c2965f0 4 parents: 3
     ○  8cfb27e238c8 3 parents: 2
@@ -176,7 +166,7 @@ fn test_parallelize_where_root_has_non_target_children() {
     [EOF]
     ");
     work_dir
-        .run_jj(["parallelize", "subject(glob:1)::subject(glob:3)"])
+        .run_jj(["parallelize", "subject(1)::subject(3)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @      a5d4e90a54bf 4 parents: 1 2 3
@@ -206,11 +196,9 @@ fn test_parallelize_with_merge_commit_child() {
     }
     work_dir.run_jj(["new", "root()", "-m", "a"]).success();
     work_dir
-        .run_jj(["new", "subject(glob:2)", "subject(glob:a)", "-m", "2a-c"])
-        .success();
-    work_dir
-        .run_jj(["new", "subject(glob:3)", "-m", "4"])
+        .run_jj(["new", "subject(2)", "subject(a)", "-m", "2a-c"])
         .success();
+    work_dir.run_jj(["new", "subject(3)", "-m", "4"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  e6a543fcc5d8 4 parents: 3
     ○  8cfb27e238c8 3 parents: 2
@@ -226,7 +214,7 @@ fn test_parallelize_with_merge_commit_child() {
 
     // After this finishes, child-2a will have three parents: "1", "2", and "a".
     work_dir
-        .run_jj(["parallelize", "subject(glob:1)::subject(glob:3)"])
+        .run_jj(["parallelize", "subject(1)::subject(3)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @      431d5005bab0 4 parents: 1 2 3
@@ -263,7 +251,7 @@ fn test_parallelize_disconnected_target_commits() {
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["parallelize", "subject(glob:1)", "subject(glob:3)"]);
+    let output = work_dir.run_jj(["parallelize", "subject(1)", "subject(3)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Nothing changed.
@@ -290,12 +278,7 @@ fn test_parallelize_head_is_a_merge() {
     work_dir.run_jj(["commit", "-m=a"]).success();
     work_dir.run_jj(["commit", "-m=b"]).success();
     work_dir
-        .run_jj([
-            "new",
-            "subject(glob:2)",
-            "subject(glob:b)",
-            "-m=merged-head",
-        ])
+        .run_jj(["new", "subject(2)", "subject(b)", "-m=merged-head"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    c634925e6ac2 merged-head parents: 2 b
@@ -310,9 +293,7 @@ fn test_parallelize_head_is_a_merge() {
     [EOF]
     ");
 
-    work_dir
-        .run_jj(["parallelize", "subject(glob:1)::"])
-        .success();
+    work_dir.run_jj(["parallelize", "subject(1)::"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    f97b547cdca0 merged-head parents: 0 b
     ├─╮
@@ -338,7 +319,7 @@ fn test_parallelize_interior_target_is_a_merge() {
     work_dir.run_jj(["describe", "-m=1"]).success();
     work_dir.run_jj(["new", "root()", "-m=a"]).success();
     work_dir
-        .run_jj(["new", "subject(glob:1)", "subject(glob:a)", "-m=2"])
+        .run_jj(["new", "subject(1)", "subject(a)", "-m=2"])
         .success();
     work_dir.run_jj(["new", "-m=3"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
@@ -353,9 +334,7 @@ fn test_parallelize_interior_target_is_a_merge() {
     [EOF]
     ");
 
-    work_dir
-        .run_jj(["parallelize", "subject(glob:1)::"])
-        .success();
+    work_dir.run_jj(["parallelize", "subject(1)::"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    d0dae190124d 3 parents: 0 a
     ├─╮
@@ -379,7 +358,7 @@ fn test_parallelize_root_is_a_merge() {
     work_dir.run_jj(["describe", "-m=y"]).success();
     work_dir.run_jj(["new", "root()", "-m=x"]).success();
     work_dir
-        .run_jj(["new", "subject(glob:y)", "subject(glob:x)", "-m=1"])
+        .run_jj(["new", "subject(y)", "subject(x)", "-m=1"])
         .success();
     work_dir.run_jj(["new", "-m=2"]).success();
     work_dir.run_jj(["new", "-m=3"]).success();
@@ -396,7 +375,7 @@ fn test_parallelize_root_is_a_merge() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:1)::subject(glob:2)"])
+        .run_jj(["parallelize", "subject(1)::subject(2)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    2949bc60f108 3 parents: 1 2
@@ -420,9 +399,7 @@ fn test_parallelize_multiple_heads() {
     let work_dir = test_env.work_dir("repo");
     work_dir.run_jj(["commit", "-m=0"]).success();
     work_dir.run_jj(["describe", "-m=1"]).success();
-    work_dir
-        .run_jj(["new", "subject(glob:0)", "-m=2"])
-        .success();
+    work_dir.run_jj(["new", "subject(0)", "-m=2"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  96d58e6cf428 2 parents: 0
     │ ○  42fc76489fb1 1 parents: 0
@@ -432,9 +409,7 @@ fn test_parallelize_multiple_heads() {
     [EOF]
     ");
 
-    work_dir
-        .run_jj(["parallelize", "subject(glob:0)::"])
-        .success();
+    work_dir.run_jj(["parallelize", "subject(0)::"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  fefea56b23ab 2 parents:
     │ ○  c4b1ea1106d1 1 parents:
@@ -456,9 +431,7 @@ fn test_parallelize_multiple_heads_with_and_without_children() {
     let work_dir = test_env.work_dir("repo");
     work_dir.run_jj(["commit", "-m=0"]).success();
     work_dir.run_jj(["describe", "-m=1"]).success();
-    work_dir
-        .run_jj(["new", "subject(glob:0)", "-m=2"])
-        .success();
+    work_dir.run_jj(["new", "subject(0)", "-m=2"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  96d58e6cf428 2 parents: 0
     │ ○  42fc76489fb1 1 parents: 0
@@ -469,7 +442,7 @@ fn test_parallelize_multiple_heads_with_and_without_children() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:0)", "subject(glob:1)"])
+        .run_jj(["parallelize", "subject(0)", "subject(1)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  96d58e6cf428 2 parents: 0
@@ -489,7 +462,7 @@ fn test_parallelize_multiple_roots() {
     work_dir.run_jj(["describe", "-m=1"]).success();
     work_dir.run_jj(["new", "root()", "-m=a"]).success();
     work_dir
-        .run_jj(["new", "subject(glob:1)", "subject(glob:a)", "-m=2"])
+        .run_jj(["new", "subject(1)", "subject(a)", "-m=2"])
         .success();
     work_dir.run_jj(["new", "-m=3"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
@@ -546,8 +519,8 @@ fn test_parallelize_multiple_heads_with_different_children() {
     work_dir
         .run_jj([
             "parallelize",
-            "subject(glob:1)::subject(glob:2)",
-            "subject(glob:a)::subject(glob:b)",
+            "subject(1)::subject(2)",
+            "subject(a)::subject(b)",
         ])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
@@ -579,12 +552,7 @@ fn test_parallelize_multiple_roots_with_different_parents() {
     work_dir.run_jj(["commit", "-m=a"]).success();
     work_dir.run_jj(["commit", "-m=b"]).success();
     work_dir
-        .run_jj([
-            "new",
-            "subject(glob:2)",
-            "subject(glob:b)",
-            "-m=merged-head",
-        ])
+        .run_jj(["new", "subject(2)", "subject(b)", "-m=merged-head"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    4e5f16f52b5e merged-head parents: 2 b
@@ -599,7 +567,7 @@ fn test_parallelize_multiple_roots_with_different_parents() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:2)::", "subject(glob:b)::"])
+        .run_jj(["parallelize", "subject(2)::", "subject(b)::"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    180840c2f967 merged-head parents: 1 a
@@ -622,25 +590,13 @@ fn test_parallelize_complex_nonlinear_target() {
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
     let work_dir = test_env.work_dir("repo");
     work_dir.run_jj(["new", "-m=0", "root()"]).success();
-    work_dir
-        .run_jj(["new", "-m=1", "subject(glob:0)"])
-        .success();
-    work_dir
-        .run_jj(["new", "-m=2", "subject(glob:0)"])
-        .success();
-    work_dir
-        .run_jj(["new", "-m=3", "subject(glob:0)"])
-        .success();
+    work_dir.run_jj(["new", "-m=1", "subject(0)"]).success();
+    work_dir.run_jj(["new", "-m=2", "subject(0)"]).success();
+    work_dir.run_jj(["new", "-m=3", "subject(0)"]).success();
     work_dir.run_jj(["new", "-m=4", "heads(..)"]).success();
-    work_dir
-        .run_jj(["new", "-m=1c", "subject(glob:1)"])
-        .success();
-    work_dir
-        .run_jj(["new", "-m=2c", "subject(glob:2)"])
-        .success();
-    work_dir
-        .run_jj(["new", "-m=3c", "subject(glob:3)"])
-        .success();
+    work_dir.run_jj(["new", "-m=1c", "subject(1)"]).success();
+    work_dir.run_jj(["new", "-m=2c", "subject(2)"]).success();
+    work_dir.run_jj(["new", "-m=3c", "subject(3)"]).success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  5cca06f145b2 3c parents: 3
     │ ○    095be6de6f23 4 parents: 3 2 1
@@ -659,7 +615,7 @@ fn test_parallelize_complex_nonlinear_target() {
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["parallelize", "subject(glob:0)::subject(glob:4)"]);
+    let output = work_dir.run_jj(["parallelize", "subject(0)::subject(4)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Working copy  (@) now at: yostqsxw d6bb6520 (empty) 3c
@@ -709,7 +665,7 @@ fn test_parallelize_immutable_base_commits() {
             "set",
             "--repo",
             "revset-aliases.'immutable_heads()'",
-            "subject(glob:x) | subject(glob:y)",
+            "subject(x) | subject(y)",
         ])
         .success();
     work_dir
@@ -729,7 +685,7 @@ fn test_parallelize_immutable_base_commits() {
     ");
 
     work_dir
-        .run_jj(["parallelize", "subject(glob:x*)", "subject(glob:y*)"])
+        .run_jj(["parallelize", "subject(x*)", "subject(y*)"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  264da1b87cf3 y2 parents:
@@ -767,7 +723,7 @@ fn test_parallelize_no_immutable_non_base_commits() {
             "set",
             "--repo",
             "revset-aliases.'immutable_heads()'",
-            "subject(glob:x1)",
+            "subject(x1)",
         ])
         .success();
     work_dir
@@ -782,7 +738,7 @@ fn test_parallelize_no_immutable_non_base_commits() {
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["parallelize", "subject(glob:x*)"]);
+    let output = work_dir.run_jj(["parallelize", "subject(x*)"]);
     insta::assert_snapshot!(output, @r#"
     ------- stderr -------
     Error: Commit 6d01ab1fb731 is immutable
