@@ -27,18 +27,18 @@ fn test_report_conflicts() {
     work_dir.write_file("file", "C\n");
     work_dir.run_jj(["commit", "-m=C"]).success();
 
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:B)", "-d=root()"]);
-    insta::assert_snapshot!(output, @r###"
+    let output = work_dir.run_jj(["rebase", "-s=subject(B)", "-d=root()"]);
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 3 commits to destination
-    Working copy  (@) now at: zsuskuln 1f0443b9 (conflict) (empty) (no description set)
-    Parent commit (@-)      : kkmpptxz 94037e0e (conflict) C
+    Working copy  (@) now at: zsuskuln 0798f940 (conflict) (empty) (no description set)
+    Parent commit (@-)      : kkmpptxz f18bc634 (conflict) C
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in 2 commits:
-      kkmpptxz 94037e0e (conflict) C
-      rlvkpnrz 871ac2e2 (conflict) B
+      kkmpptxz f18bc634 (conflict) C
+      rlvkpnrz 3ec72c59 (conflict) B
     Hint: To resolve the conflicts, start by creating a commit on top of
     the first conflicted commit:
       jj new rlvkpnrz
@@ -46,9 +46,9 @@ fn test_report_conflicts() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
-    let output = work_dir.run_jj(["rebase", "-d=subject(glob:A)"]);
+    let output = work_dir.run_jj(["rebase", "-d=subject(A)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 3 commits to destination
@@ -60,19 +60,19 @@ fn test_report_conflicts() {
     ");
 
     // Can get hint about multiple root commits
-    let output = work_dir.run_jj(["rebase", "-r=subject(glob:B)", "-d=root()"]);
-    insta::assert_snapshot!(output, @r###"
+    let output = work_dir.run_jj(["rebase", "-r=subject(B)", "-d=root()"]);
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 commits to destination
     Rebased 2 descendant commits
-    Working copy  (@) now at: zsuskuln f525f3b5 (conflict) (empty) (no description set)
-    Parent commit (@-)      : kkmpptxz 2aa6a481 (conflict) C
+    Working copy  (@) now at: zsuskuln 33a4249e (conflict) (empty) (no description set)
+    Parent commit (@-)      : kkmpptxz b7d2d9ac (conflict) C
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict
     New conflicts appeared in 2 commits:
-      kkmpptxz 2aa6a481 (conflict) C
-      rlvkpnrz 50a742b3 (conflict) B
+      kkmpptxz b7d2d9ac (conflict) C
+      rlvkpnrz d4d3dc60 (conflict) B
     Hint: To resolve the conflicts, start by creating a commit on top of
     one of the first conflicted commits:
       jj new kkmpptxz
@@ -81,14 +81,14 @@ fn test_report_conflicts() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
     // Resolve one of the conflicts by (mostly) following the instructions
     let output = work_dir.run_jj(["new", "rlvkpnrzqnoo"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Working copy  (@) now at: vruxwmqv 36e37773 (conflict) (empty) (no description set)
-    Parent commit (@-)      : rlvkpnrz 50a742b3 (conflict) B
+    Working copy  (@) now at: vruxwmqv bd3920e6 (conflict) (empty) (no description set)
+    Parent commit (@-)      : rlvkpnrz d4d3dc60 (conflict) B
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
@@ -122,20 +122,20 @@ fn test_report_conflicts_with_divergent_commits() {
         .run_jj(["describe", "-m=C3", "--at-op=@-"])
         .success();
 
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:B)", "-d=root()"]);
-    insta::assert_snapshot!(output, @r###"
+    let output = work_dir.run_jj(["rebase", "-s=subject(B)", "-d=root()"]);
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Concurrent modification detected, resolving automatically.
     Rebased 3 commits to destination
-    Working copy  (@) now at: zsuskuln?? e91a430b (conflict) C2
-    Parent commit (@-)      : kkmpptxz fcd54aca (conflict) B
+    Working copy  (@) now at: zsuskuln/1 8d399a54 (divergent) (conflict) C2
+    Parent commit (@-)      : kkmpptxz 1c19b9e0 (conflict) B
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in 3 commits:
-      zsuskuln?? 33d16252 (conflict) C3
-      zsuskuln?? e91a430b (conflict) C2
-      kkmpptxz fcd54aca (conflict) B
+      zsuskuln/0 b04ca335 (divergent) (conflict) C3
+      zsuskuln/1 8d399a54 (divergent) (conflict) C2
+      kkmpptxz 1c19b9e0 (conflict) B
     Hint: To resolve the conflicts, start by creating a commit on top of
     the first conflicted commit:
       jj new kkmpptxz
@@ -143,13 +143,13 @@ fn test_report_conflicts_with_divergent_commits() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
-    let output = work_dir.run_jj(["rebase", "-d=subject(glob:A)"]);
+    let output = work_dir.run_jj(["rebase", "-d=subject(A)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 3 commits to destination
-    Working copy  (@) now at: zsuskuln?? 27ef05d9 C2
+    Working copy  (@) now at: zsuskuln/1 27ef05d9 (divergent) C2
     Parent commit (@-)      : kkmpptxz 9039ed49 B
     Added 0 files, modified 1 files, removed 0 files
     Existing conflicts were resolved or abandoned from 3 commits.
@@ -157,53 +157,53 @@ fn test_report_conflicts_with_divergent_commits() {
     ");
 
     // Same thing when rebasing the divergent commits one at a time
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:C2)", "-d=root()"]);
-    insta::assert_snapshot!(output, @r###"
+    let output = work_dir.run_jj(["rebase", "-s=subject(C2)", "-d=root()"]);
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 commits to destination
-    Working copy  (@) now at: zsuskuln?? 151c23fc (conflict) C2
+    Working copy  (@) now at: zsuskuln/0 b536e208 (divergent) (conflict) C2
     Parent commit (@-)      : zzzzzzzz 00000000 (empty) (no description set)
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in 1 commits:
-      zsuskuln?? 151c23fc (conflict) C2
+      zsuskuln/0 b536e208 (divergent) (conflict) C2
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
-      jj new zsuskuln
+      jj new zsuskuln/0
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
 
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:C3)", "-d=root()"]);
-    insta::assert_snapshot!(output, @r###"
-    ------- stderr -------
-    Rebased 1 commits to destination
-    New conflicts appeared in 1 commits:
-      zsuskuln?? d59fa233 (conflict) C3
-    Hint: To resolve the conflicts, start by creating a commit on top of
-    the conflicted commit:
-      jj new zsuskuln
-    Then use `jj resolve`, or edit the conflict markers in the file directly.
-    Once the conflicts are resolved, you can inspect the result with `jj diff`.
-    Then run `jj squash` to move the resolution into the conflicted commit.
-    [EOF]
-    "###);
-
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:C2)", "-d=subject(glob:B)"]);
+    let output = work_dir.run_jj(["rebase", "-s=subject(C3)", "-d=root()"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 commits to destination
-    Working copy  (@) now at: zsuskuln?? 3fcf2fd2 C2
+    New conflicts appeared in 1 commits:
+      zsuskuln/0 2015a3ed (divergent) (conflict) C3
+    Hint: To resolve the conflicts, start by creating a commit on top of
+    the conflicted commit:
+      jj new zsuskuln/0
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you can inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    [EOF]
+    ");
+
+    let output = work_dir.run_jj(["rebase", "-s=subject(C2)", "-d=subject(B)"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Rebased 1 commits to destination
+    Working copy  (@) now at: zsuskuln/0 3fcf2fd2 (divergent) C2
     Parent commit (@-)      : kkmpptxz 9039ed49 B
     Added 0 files, modified 1 files, removed 0 files
     Existing conflicts were resolved or abandoned from 1 commits.
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["rebase", "-s=subject(glob:C3)", "-d=subject(glob:B)"]);
+    let output = work_dir.run_jj(["rebase", "-s=subject(C3)", "-d=subject(B)"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 commits to destination
@@ -227,21 +227,21 @@ fn test_report_conflicts_with_resolving_conflicts_hint_disabled() {
 
     let output = work_dir.run_jj([
         "rebase",
-        "-s=subject(glob:B)",
+        "-s=subject(B)",
         "-d=root()",
         "--config=hints.resolving-conflicts=false",
     ]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 3 commits to destination
-    Working copy  (@) now at: zsuskuln 1f0443b9 (conflict) (empty) (no description set)
-    Parent commit (@-)      : kkmpptxz 94037e0e (conflict) C
+    Working copy  (@) now at: zsuskuln 0798f940 (conflict) (empty) (no description set)
+    Parent commit (@-)      : kkmpptxz f18bc634 (conflict) C
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in 2 commits:
-      kkmpptxz 94037e0e (conflict) C
-      rlvkpnrz 871ac2e2 (conflict) B
+      kkmpptxz f18bc634 (conflict) C
+      rlvkpnrz 3ec72c59 (conflict) B
     [EOF]
     ");
 }
