@@ -67,13 +67,13 @@ fn test_restore() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 descendant commits
-    Working copy  (@) now at: kkmpptxz 315c9388 (conflict) (no description set)
+    Working copy  (@) now at: kkmpptxz 7f135b03 (conflict) (no description set)
     Parent commit (@-)      : rlvkpnrz 67841e01 (empty) (no description set)
     Added 0 files, modified 1 files, removed 0 files
     Warning: There are unresolved conflicts at these paths:
     file2    2-sided conflict including 1 deletion
     New conflicts appeared in 1 commits:
-      kkmpptxz 315c9388 (conflict) (no description set)
+      kkmpptxz 7f135b03 (conflict) (no description set)
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
       jj new kkmpptxz
@@ -189,30 +189,32 @@ fn test_restore_conflicted_merge() {
     ◆
     [EOF]
     ");
-    insta::assert_snapshot!(work_dir.read_file("file"), @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    insta::assert_snapshot!(work_dir.read_file("file"), @r#"
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: rlvkpnrz 1792382a "base"
+    \\\\\\\        to: zsuskuln 45537d53 "a"
     -base
     +a
-    +++++++ Contents of side #2
+    +++++++ royxmykx 89d1b299 "b"
     b
-    >>>>>>> Conflict 1 of 1 ends
-    ");
+    >>>>>>> conflict 1 of 1 ends
+    "#);
 
     // Overwrite the file...
     work_dir.write_file("file", "resolution");
-    insta::assert_snapshot!(work_dir.run_jj(["diff"]), @r"
+    insta::assert_snapshot!(work_dir.run_jj(["diff"]), @r#"
     Resolved conflict in file:
-       1     : <<<<<<< Conflict 1 of 1
-       2     : %%%%%%% Changes from base to side #1
-       3     : -base
-       4     : +a
-       5     : +++++++ Contents of side #2
-       6     : b
-       7     : >>>>>>> Conflict 1 of 1 ends
+       1     : <<<<<<< conflict 1 of 1
+       2     : %%%%%%% diff from: rlvkpnrz 1792382a "base"
+       3     : \\\\\\\        to: zsuskuln 45537d53 "a"
+       4     : -base
+       5     : +a
+       6     : +++++++ royxmykx 89d1b299 "b"
+       7     : b
+       8     : >>>>>>> conflict 1 of 1 ends
             1: resolution
     [EOF]
-    ");
+    "#);
 
     // ...and restore it back again.
     let output = work_dir.run_jj(["restore", "file"]);
@@ -227,37 +229,38 @@ fn test_restore_conflicted_merge() {
     [EOF]
     ");
     insta::assert_snapshot!(work_dir.read_file("file"), @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base to side #1
     -base
     +a
-    +++++++ Contents of side #2
+    +++++++ side #2
     b
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     ");
     let output = work_dir.run_jj(["diff"]);
     insta::assert_snapshot!(output, @"");
 
     // The same, but without the `file` argument. Overwrite the file...
     work_dir.write_file("file", "resolution");
-    insta::assert_snapshot!(work_dir.run_jj(["diff"]), @r"
+    insta::assert_snapshot!(work_dir.run_jj(["diff"]), @r#"
     Resolved conflict in file:
-       1     : <<<<<<< Conflict 1 of 1
-       2     : %%%%%%% Changes from base to side #1
-       3     : -base
-       4     : +a
-       5     : +++++++ Contents of side #2
-       6     : b
-       7     : >>>>>>> Conflict 1 of 1 ends
+       1     : <<<<<<< conflict 1 of 1
+       2     : %%%%%%% diff from: rlvkpnrz 1792382a "base"
+       3     : \\\\\\\        to: zsuskuln 45537d53 "a"
+       4     : -base
+       5     : +a
+       6     : +++++++ royxmykx 89d1b299 "b"
+       7     : b
+       8     : >>>>>>> conflict 1 of 1 ends
             1: resolution
     [EOF]
-    ");
+    "#);
 
     // ... and restore it back again.
     let output = work_dir.run_jj(["restore"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Working copy  (@) now at: vruxwmqv e46a78b9 conflict | (conflict) (empty) conflict
+    Working copy  (@) now at: vruxwmqv 60d86a33 conflict | (conflict) (empty) conflict
     Parent commit (@-)      : zsuskuln 45537d53 a | a
     Parent commit (@-)      : royxmykx 89d1b299 b | b
     Added 0 files, modified 1 files, removed 0 files
@@ -265,15 +268,16 @@ fn test_restore_conflicted_merge() {
     file    2-sided conflict
     [EOF]
     ");
-    insta::assert_snapshot!(work_dir.read_file("file"), @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    insta::assert_snapshot!(work_dir.read_file("file"), @r#"
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: rlvkpnrz 1792382a "base"
+    \\\\\\\        to: zsuskuln 45537d53 "a"
     -base
     +a
-    +++++++ Contents of side #2
+    +++++++ royxmykx 89d1b299 "b"
     b
-    >>>>>>> Conflict 1 of 1 ends
-    ");
+    >>>>>>> conflict 1 of 1 ends
+    "#);
 }
 
 #[test]
