@@ -22,6 +22,7 @@ fn test_show() {
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
     let work_dir = test_env.work_dir("repo");
 
+    // Show @ by default
     let output = work_dir.run_jj(["show"]);
     let output = output.normalize_stdout_with(|s| s.split_inclusive('\n').skip(2).collect());
 
@@ -33,6 +34,32 @@ fn test_show() {
 
     [EOF]
     ");
+
+    // Specify revision with -r
+    let output = work_dir.run_jj(["show", "-r@-"]);
+    insta::assert_snapshot!(output, @r"
+    Commit ID: 0000000000000000000000000000000000000000
+    Change ID: zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz
+    Author   : (no name set) <(no email set)> (1970-01-01 11:00:00)
+    Committer: (no name set) <(no email set)> (1970-01-01 11:00:00)
+
+        (no description set)
+
+    [EOF]
+    ");
+
+    // Specify both positional and -r args
+    let output = work_dir.run_jj(["show", "@", "-r@-"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    error: the argument '[REVSET]' cannot be used with '-r <REVSET>'
+
+    Usage: jj show <REVSET>
+
+    For more information, try '--help'.
+    [EOF]
+    [exit status: 2]
+    ");
 }
 
 #[test]
@@ -92,7 +119,7 @@ fn test_show_basic() {
     [38;5;3m<<show commit description placeholder::    (no description set)>>[39m<<show commit::>>
     <<show commit::>>
     [38;5;3m<<diff header::Modified regular file file2:>>[39m
-    [38;5;1m<<diff removed line_number::   1>>[39m<<diff:: >>[38;5;2m<<diff added line_number::   1>>[39m<<diff::: foo>>
+    [2m[38;5;1m<<diff context removed line_number::   1>>[0m<<diff context:: >>[2m[38;5;2m<<diff context added line_number::   1>>[0m<<diff context::: foo>>
     <<diff::     >>[38;5;2m<<diff added line_number::   2>>[39m<<diff::: >>[4m[38;5;2m<<diff added token::bar>>[24m[39m
     [38;5;1m<<diff removed line_number::   2>>[39m<<diff:: >>[38;5;2m<<diff added line_number::   3>>[39m<<diff::: baz >>[4m[38;5;1m<<diff removed token::qux>>[38;5;2m<<diff added token::quux>>[24m[39m<<diff::>>
     [38;5;3m<<diff header::Modified regular file file3 (file1 => file3):>>[39m
