@@ -202,7 +202,7 @@ fn test_split_with_non_empty_description() {
     let mut test_env = TestEnvironment::default();
     let edit_script = test_env.set_up_fake_editor();
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
-    test_env.add_config(r#"ui.default-description = "\n\nTESTED=TODO""#);
+    test_env.add_config(r#"template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'"#);
     let work_dir = test_env.work_dir("repo");
 
     work_dir.write_file("file1", "foo\n");
@@ -221,15 +221,14 @@ fn test_split_with_non_empty_description() {
     )
     .unwrap();
     let output = work_dir.run_jj(["split", "file1"]);
-    insta::assert_snapshot!(output, @r#"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
     Selected changes : qpvuntsm c7f7b14b part 1
     Remaining changes: kkmpptxz ac33a5a9 part 2
     Working copy  (@) now at: kkmpptxz ac33a5a9 part 2
     Parent commit (@-)      : qpvuntsm c7f7b14b part 1
     [EOF]
-    "#);
+    ");
 
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor1")).unwrap(), @r#"
@@ -253,15 +252,12 @@ fn test_split_with_non_empty_description() {
     JJ:
     JJ: Lines starting with "JJ:" (like this one) will be removed.
     "#);
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  kkmpptxzrspx false part 2
     ○  qpvuntsmwlqt false part 1
     ◆  zzzzzzzzzzzz true
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 }
 
 #[test]
@@ -269,7 +265,7 @@ fn test_split_with_default_description() {
     let mut test_env = TestEnvironment::default();
     let edit_script = test_env.set_up_fake_editor();
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
-    test_env.add_config(r#"ui.default-description = "\n\nTESTED=TODO""#);
+    test_env.add_config(r#"template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'"#);
     let work_dir = test_env.work_dir("repo");
 
     work_dir.write_file("file1", "foo\n");
@@ -281,15 +277,14 @@ fn test_split_with_default_description() {
     )
     .unwrap();
     let output = work_dir.run_jj(["split", "file1"]);
-    insta::assert_snapshot!(output, @r#"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
     Selected changes : qpvuntsm ff633dcc TESTED=TODO
     Remaining changes: rlvkpnrz b1d20b7e (no description set)
     Working copy  (@) now at: rlvkpnrz b1d20b7e (no description set)
     Parent commit (@-)      : qpvuntsm ff633dcc TESTED=TODO
     [EOF]
-    "#);
+    ");
 
     // Since the commit being split has no description, the user will only be
     // prompted to add a description to the first commit, which will use the
@@ -309,15 +304,12 @@ fn test_split_with_default_description() {
     JJ: Lines starting with "JJ:" (like this one) will be removed.
     "#);
     assert!(!test_env.env_root().join("editor2").exists());
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  rlvkpnrzqnoo false
     ○  qpvuntsmwlqt false TESTED=TODO
     ◆  zzzzzzzzzzzz true
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 }
 
 #[test]
@@ -340,13 +332,13 @@ fn test_split_with_descendants() {
     // Third commit.
     work_dir.write_file("file4", "foobarbaz\n");
     work_dir.run_jj(["describe", "-m", "Add file4"]).success();
-    insta::assert_snapshot!(get_log_output(&work_dir), @r###"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  kkmpptxzrspx false Add file4
     ○  rlvkpnrzqnoo false Add file3
     ○  qpvuntsmwlqt false Add file1 & file2
     ◆  zzzzzzzzzzzz true
     [EOF]
-    "###);
+    ");
 
     // Set up the editor and do the split.
     std::fs::write(
@@ -415,13 +407,13 @@ fn test_split_with_descendants() {
     ○  qpvuntsm test.user@example.com 2001-02-03 08:05:12 74306e35
     │  Add file1
     │  -- operation 994b490f285d split commit 1d2499e72cefc8a2b87ebb47569140857b96189f
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 1d2499e7
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:08 1d2499e7 (hidden)
     │  Add file1 & file2
     │  -- operation adf4f33386c9 commit f5700f8ef89e290e4e90ae6adc0908707e0d8c85
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 f5700f8e
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:08 f5700f8e (hidden)
     │  (no description set)
     │  -- operation 78ead2155fcc snapshot working copy
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/3 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -434,13 +426,13 @@ fn test_split_with_descendants() {
     ○  royxmykx test.user@example.com 2001-02-03 08:05:12 0a37745e
     │  Add file2
     │  -- operation 994b490f285d split commit 1d2499e72cefc8a2b87ebb47569140857b96189f
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 1d2499e7
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:08 1d2499e7 (hidden)
     │  Add file1 & file2
     │  -- operation adf4f33386c9 commit f5700f8ef89e290e4e90ae6adc0908707e0d8c85
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 f5700f8e
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:08 f5700f8e (hidden)
     │  (no description set)
     │  -- operation 78ead2155fcc snapshot working copy
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/3 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
@@ -460,7 +452,7 @@ fn test_split_with_merge_child() {
     work_dir.write_file("file1", "foo\n");
     work_dir.write_file("file2", "bar\n");
     work_dir
-        .run_jj(["new", "subject(glob:1)", "subject(glob:a)", "-m=2"])
+        .run_jj(["new", "subject(1)", "subject(a)", "-m=2"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    zsuskulnrvyr true 2
@@ -478,7 +470,7 @@ fn test_split_with_merge_child() {
         ["write\nAdd file1", "next invocation\n", "write\nAdd file2"].join("\0"),
     )
     .unwrap();
-    let output = work_dir.run_jj(["split", "-rsubject(glob:a)", "file1"]);
+    let output = work_dir.run_jj(["split", "-rsubject(a)", "file1"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 descendant commits
@@ -508,20 +500,17 @@ fn test_split_parallel_no_descendants() {
     let mut test_env = TestEnvironment::default();
     let edit_script = test_env.set_up_fake_editor();
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
-    test_env.add_config(r#"ui.default-description = "\n\nTESTED=TODO""#);
+    test_env.add_config(r#"template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'"#);
     let work_dir = test_env.work_dir("repo");
 
     work_dir.write_file("file1", "foo\n");
     work_dir.write_file("file2", "bar\n");
 
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  qpvuntsmwlqt false
     ◆  zzzzzzzzzzzz true
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 
     std::fs::write(
         edit_script,
@@ -529,26 +518,22 @@ fn test_split_parallel_no_descendants() {
     )
     .unwrap();
     let output = work_dir.run_jj(["split", "--parallel", "file1"]);
-    insta::assert_snapshot!(output, @r#"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
     Selected changes : qpvuntsm 7bcd474c TESTED=TODO
     Remaining changes: kkmpptxz 431886f6 (no description set)
     Working copy  (@) now at: kkmpptxz 431886f6 (no description set)
     Parent commit (@-)      : zzzzzzzz 00000000 (empty) (no description set)
     Added 0 files, modified 0 files, removed 1 files
     [EOF]
-    "#);
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    ");
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  kkmpptxzrspx false
     │ ○  qpvuntsmwlqt false TESTED=TODO
     ├─╯
     ◆  zzzzzzzzzzzz true
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 
     // Since the commit being split has no description, the user will only be
     // prompted to add a description to the first commit, which will use the
@@ -574,40 +559,34 @@ fn test_split_parallel_no_descendants() {
     // - The rewritten commit from the snapshot after the files were added.
     // - The rewritten commit after the split.
     let evolog_1 = work_dir.run_jj(["evolog", "-r", "qpvun"]);
-    insta::assert_snapshot!(evolog_1, @r#"
+    insta::assert_snapshot!(evolog_1, @r"
     ○  qpvuntsm test.user@example.com 2001-02-03 08:05:09 7bcd474c
     │  TESTED=TODO
     │  -- operation 2b21c33e1596 split commit f5700f8ef89e290e4e90ae6adc0908707e0d8c85
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 f5700f8e
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:08 f5700f8e (hidden)
     │  (no description set)
     │  -- operation 1663cd1cc445 snapshot working copy
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 
     // The evolog for the second commit is the same, except that the change id
     // changes after the split.
     let evolog_2 = work_dir.run_jj(["evolog", "-r", "kkmpp"]);
-    insta::assert_snapshot!(evolog_2, @r#"
+    insta::assert_snapshot!(evolog_2, @r"
     @  kkmpptxz test.user@example.com 2001-02-03 08:05:09 431886f6
     │  (no description set)
     │  -- operation 2b21c33e1596 split commit f5700f8ef89e290e4e90ae6adc0908707e0d8c85
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:08 f5700f8e
+    ○  qpvuntsm/1 test.user@example.com 2001-02-03 08:05:08 f5700f8e (hidden)
     │  (no description set)
     │  -- operation 1663cd1cc445 snapshot working copy
-    ○  qpvuntsm hidden test.user@example.com 2001-02-03 08:05:07 e8849ae1
+    ○  qpvuntsm/2 test.user@example.com 2001-02-03 08:05:07 e8849ae1 (hidden)
        (empty) (no description set)
        -- operation 8f47435a3990 add workspace 'default'
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 }
 
 #[test]
@@ -716,7 +695,7 @@ fn test_split_parallel_with_merge_child() {
     work_dir.write_file("file1", "foo\n");
     work_dir.write_file("file2", "bar\n");
     work_dir
-        .run_jj(["new", "subject(glob:1)", "subject(glob:a)", "-m=2"])
+        .run_jj(["new", "subject(1)", "subject(a)", "-m=2"])
         .success();
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @    zsuskulnrvyr true 2
@@ -734,7 +713,7 @@ fn test_split_parallel_with_merge_child() {
         ["write\nAdd file1", "next invocation\n", "write\nAdd file2"].join("\0"),
     )
     .unwrap();
-    let output = work_dir.run_jj(["split", "-rsubject(glob:a)", "--parallel", "file1"]);
+    let output = work_dir.run_jj(["split", "-rsubject(a)", "--parallel", "file1"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 descendant commits
@@ -759,6 +738,96 @@ fn test_split_parallel_with_merge_child() {
     ");
 }
 
+#[test]
+fn test_split_parallel_with_conflict() {
+    let mut test_env = TestEnvironment::default();
+    let diff_editor = test_env.set_up_fake_diff_editor();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let work_dir = test_env.work_dir("repo");
+
+    work_dir.write_file("file", "line 1\nline 2\nline 3\n");
+    work_dir.run_jj(["new"]).success();
+    work_dir.write_file("file", "line 1\nline 2.1\nline 2.2\nline 3\n");
+    work_dir.run_jj(["new"]).success();
+    work_dir.write_file("file", "line 1\nline 3\n");
+    work_dir.run_jj(["prev", "--edit"]).success();
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
+    ○  kkmpptxzrspx false
+    @  rlvkpnrzqnoo false
+    ○  qpvuntsmwlqt false
+    ◆  zzzzzzzzzzzz true
+    [EOF]
+    ");
+
+    // Create a conflict by splitting two consecutive lines into parallel commits.
+    std::fs::write(
+        diff_editor,
+        ["write file\nline 1\nline 2.1\nline 3\n"].join("\0"),
+    )
+    .unwrap();
+    let output = work_dir.run_jj(["split", "--parallel", "-i", "-m="]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Rebased 1 descendant commits
+    Selected changes : rlvkpnrz abe15fea (no description set)
+    Remaining changes: royxmykx ec55f25f (conflict) (no description set)
+    Working copy  (@) now at: royxmykx ec55f25f (conflict) (no description set)
+    Parent commit (@-)      : qpvuntsm ee8e9376 (no description set)
+    Added 0 files, modified 1 files, removed 0 files
+    Warning: There are unresolved conflicts at these paths:
+    file    2-sided conflict
+    New conflicts appeared in 1 commits:
+      royxmykx ec55f25f (conflict) (no description set)
+    Hint: To resolve the conflicts, start by creating a commit on top of
+    the conflicted commit:
+      jj new royxmykx
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you can inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    [EOF]
+    ");
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
+    ○    kkmpptxzrspx false
+    ├─╮
+    │ @  royxmykxtrkr false
+    ○ │  rlvkpnrzqnoo false
+    ├─╯
+    ○  qpvuntsmwlqt false
+    ◆  zzzzzzzzzzzz true
+    [EOF]
+    ");
+
+    // The new commit should be conflicted.
+    insta::assert_snapshot!(work_dir.read_file("file"), @r"
+    line 1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: selected changes for split (from rlvkpnrz 35382813)
+    \\\\\\\        to: split revision (rlvkpnrz 35382813)
+     line 2.1
+    +line 2.2
+    +++++++ qpvuntsm ee8e9376 (parents of split revision)
+    line 2
+    >>>>>>> conflict 1 of 1 ends
+    line 3
+    ");
+
+    // The old commit shouldn't be conflicted, since it matches the selection from
+    // the editor.
+    insta::assert_snapshot!(work_dir.run_jj(["file", "show", "-r=@+-~@", "file"]), @r"
+    line 1
+    line 2.1
+    line 3
+    [EOF]
+    ");
+
+    // The child merge commit should keep the same contents.
+    insta::assert_snapshot!(work_dir.run_jj(["file", "show", "-r=@+", "file"]), @r"
+    line 1
+    line 3
+    [EOF]
+    ");
+}
+
 // Make sure `jj split` would refuse to split an empty commit.
 #[test]
 fn test_split_empty() {
@@ -954,7 +1023,7 @@ fn test_split_with_multiple_workspaces_same_working_copy() {
         .success();
     // Change the working copy in the second workspace.
     secondary_dir
-        .run_jj(["edit", "-r", "subject(glob:first-commit)"])
+        .run_jj(["edit", "-r", "subject(first-commit)"])
         .success();
     // Check the working-copy commit in each workspace in the log output. The "@"
     // node in the graph indicates the current workspace's working-copy commit.
@@ -1066,7 +1135,7 @@ fn test_split_with_non_empty_description_and_trailers() {
     let mut test_env = TestEnvironment::default();
     let edit_script = test_env.set_up_fake_editor();
     test_env.run_jj_in(".", ["git", "init", "repo"]).success();
-    test_env.add_config(r#"ui.default-description = "\n\nTESTED=TODO""#);
+    test_env.add_config(r#"template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'"#);
     let work_dir = test_env.work_dir("repo");
 
     work_dir.write_file("file1", "foo\n");
@@ -1090,15 +1159,14 @@ fn test_split_with_non_empty_description_and_trailers() {
         commit_trailers = '''"Signed-off-by: " ++ committer.email()'''"#,
     );
     let output = work_dir.run_jj(["split", "file1"]);
-    insta::assert_snapshot!(output, @r#"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
     Selected changes : qpvuntsm c7f7b14b part 1
     Remaining changes: kkmpptxz ac33a5a9 part 2
     Working copy  (@) now at: kkmpptxz ac33a5a9 part 2
     Parent commit (@-)      : qpvuntsm c7f7b14b part 1
     [EOF]
-    "#);
+    ");
 
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor1")).unwrap(), @r#"
@@ -1126,15 +1194,12 @@ fn test_split_with_non_empty_description_and_trailers() {
     JJ:
     JJ: Lines starting with "JJ:" (like this one) will be removed.
     "#);
-    insta::assert_snapshot!(get_log_output(&work_dir), @r#"
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
     @  kkmpptxzrspx false part 2
     ○  qpvuntsmwlqt false part 1
     ◆  zzzzzzzzzzzz true
     [EOF]
-    ------- stderr -------
-    Warning: Deprecated user-level config: ui.default-description is updated to template-aliases.default_commit_description = '"\n\nTESTED=TODO\n"'
-    [EOF]
-    "#);
+    ");
 }
 
 #[test]
