@@ -331,6 +331,16 @@ fn test_squash_partial() {
     [EOF]
     "#);
 
+    // No warning if we pass a positional argument does not parse as a revset
+    work_dir.run_jj(["op", "restore", &start_op_id]).success();
+    let output = work_dir.run_jj(["squash", ".tmp"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Warning: No matching entries for paths: .tmp
+    Nothing changed.
+    [EOF]
+    ");
+
     // we can use --interactive and fileset together
     work_dir.run_jj(["op", "restore", &start_op_id]).success();
     work_dir.write_file("file3", "foo\n");
@@ -339,17 +349,17 @@ fn test_squash_partial() {
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 1 descendant commits
-    Working copy  (@) now at: mzvwutvl 69c58f86 c | (no description set)
-    Parent commit (@-)      : kkmpptxz 0f38c564 b | (no description set)
+    Working copy  (@) now at: mzvwutvl 3615d80e c | (no description set)
+    Parent commit (@-)      : kkmpptxz 037106c4 b | (no description set)
     [EOF]
     ");
     let output = work_dir.run_jj(["log", "-s"]);
     insta::assert_snapshot!(output, @r"
-    @  mzvwutvl test.user@example.com 2001-02-03 08:05:36 c 69c58f86
+    @  mzvwutvl test.user@example.com 2001-02-03 08:05:38 c 3615d80e
     │  (no description set)
     │  M file1
     │  M file2
-    ○  kkmpptxz test.user@example.com 2001-02-03 08:05:36 b 0f38c564
+    ○  kkmpptxz test.user@example.com 2001-02-03 08:05:38 b 037106c4
     │  (no description set)
     │  M file1
     │  M file2
@@ -361,6 +371,24 @@ fn test_squash_partial() {
     ◆  zzzzzzzz root() 00000000
     [EOF]
     ");
+
+    // Error if no changes selected in interactive mode
+    work_dir.run_jj(["op", "restore", &start_op_id]).success();
+    std::fs::write(&edit_script, "reset file1\0reset file2").unwrap();
+    let output = work_dir.run_jj(["squash", "-r", "b", "-i"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Error: No changes selected
+    [EOF]
+    [exit status: 1]
+    ");
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
+    @  87059ac9657b c
+    ○  f2c9709f39e9 b
+    ○  64ea60be8d77 a
+    ◆  000000000000 (empty)
+    [EOF]
+    ");
 }
 
 #[test]
@@ -872,13 +900,13 @@ fn test_squash_from_multiple() {
 
     // Squash a few commits sideways
     let output = work_dir.run_jj(["squash", "--from=b", "--from=c", "--into=d"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 2 descendant commits
-    Working copy  (@) now at: kpqxywon 0b695306 f | (no description set)
-    Parent commit (@-)      : yostqsxw ff064d52 e | (no description set)
+    Working copy  (@) now at: kpqxywon d64492cf f | (no description set)
+    Parent commit (@-)      : yostqsxw 7e58dc67 e | (no description set)
     New conflicts appeared in 1 commits:
-      yqosqzyt 61130da4 d | (conflict) (no description set)
+      yqosqzyt 4198211f d | (conflict) (no description set)
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
       jj new yqosqzyt
@@ -886,12 +914,12 @@ fn test_squash_from_multiple() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
-    @  0b6953066ee0 f
-    ○    ff064d529578 e
+    @  d64492cf8e79 f
+    ○    7e58dc679ec0 e
     ├─╮
-    × │  61130da4e714 d
+    × │  4198211f54c1 d
     ├─╯
     ○  e88768e65e67 a b c
     ◆  000000000000 (empty)
@@ -900,16 +928,18 @@ fn test_squash_from_multiple() {
     // The changes from the sources have been applied
     let output = work_dir.run_jj(["file", "show", "-r=d", "file"]);
     insta::assert_snapshot!(output, @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base #1 to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: qpvuntsm e88768e6 (parents of squashed revision)
+    \\\\\\\        to: yqosqzyt 8acbb715 (squash destination)
     -a
     +d
-    %%%%%%% Changes from base #2 to side #2
+    %%%%%%% diff from: qpvuntsm e88768e6 (parents of squashed revision)
+    \\\\\\\        to: kkmpptxz fed4d1a2 (squashed revision)
     -a
     +b
-    +++++++ Contents of side #3
+    +++++++ mzvwutvl d7e94ec7 (squashed revision)
     c
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     [EOF]
     ");
 
@@ -1016,13 +1046,13 @@ fn test_squash_from_multiple_partial() {
 
     // Partially squash a few commits sideways
     let output = work_dir.run_jj(["squash", "--from=b|c", "--into=d", "file1"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Rebased 2 descendant commits
-    Working copy  (@) now at: kpqxywon a724910c f | (no description set)
-    Parent commit (@-)      : yostqsxw 1bc405e1 e | (no description set)
+    Working copy  (@) now at: kpqxywon 316211c8 f | (no description set)
+    Parent commit (@-)      : yostqsxw 6a7086c8 e | (no description set)
     New conflicts appeared in 1 commits:
-      yqosqzyt 7ddfe685 d | (conflict) (no description set)
+      yqosqzyt 7aca142d d | (conflict) (no description set)
     Hint: To resolve the conflicts, start by creating a commit on top of
     the conflicted commit:
       jj new yqosqzyt
@@ -1030,15 +1060,15 @@ fn test_squash_from_multiple_partial() {
     Once the conflicts are resolved, you can inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
     [EOF]
-    "###);
+    ");
     insta::assert_snapshot!(get_log_output(&work_dir), @r"
-    @  a724910cd361 f
-    ○      1bc405e12b68 e
+    @  316211c82ebb f
+    ○      6a7086c8dda4 e
     ├─┬─╮
     │ │ ○  e9db15b956c4 b
     │ ○ │  83cbe51db94d c
     │ ├─╯
-    × │  7ddfe6857387 d
+    × │  7aca142da791 d
     ├─╯
     ○  64ea60be8d77 a
     ◆  000000000000 (empty)
@@ -1058,16 +1088,18 @@ fn test_squash_from_multiple_partial() {
     // The selected changes from the sources have been applied
     let output = work_dir.run_jj(["file", "show", "-r=d", "file1"]);
     insta::assert_snapshot!(output, @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base #1 to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: qpvuntsm 64ea60be (parents of squashed revision)
+    \\\\\\\        to: yqosqzyt f6812ff8 (squash destination)
     -a
     +d
-    %%%%%%% Changes from base #2 to side #2
+    %%%%%%% diff from: qpvuntsm 64ea60be (parents of squashed revision)
+    \\\\\\\        to: selected changes for squash (from kkmpptxz f2c9709f)
     -a
     +b
-    +++++++ Contents of side #3
+    +++++++ selected changes for squash (from mzvwutvl aa908686)
     c
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     [EOF]
     ");
     // The unselected change from the sources have not been applied to the
@@ -1592,8 +1624,8 @@ fn test_squash_use_destination_message() {
         .run_jj([
             "squash",
             "--use-destination-message",
-            "--from=subject(glob:b)::",
-            "--into=subject(glob:a)",
+            "--from=subject(b)::",
+            "--into=subject(a)",
         ])
         .success();
     insta::assert_snapshot!(get_log_output_with_description(&work_dir), @r"
@@ -1776,7 +1808,7 @@ fn test_squash_to_new_commit() {
     [EOF]
     ");
 
-    // insert the commit before the source commit
+    // insert the commit before a commit
     let output = work_dir.run_jj([
         "squash",
         "-m",
@@ -2030,28 +2062,28 @@ fn test_squash_to_new_commit() {
     ○    pkstwlsy test.user@example.com 2001-02-03 08:05:35 41510a56
     ├─╮  file 3&4
     │ │  -- operation ad1aa66374f6 squash commit 0d254956d33ed5bb11d93eb795c5e514aadc81b5 and 1 more
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:35 a5bc761f
+    │ ○  zsuskuln/0 test.user@example.com 2001-02-03 08:05:35 a5bc761f (hidden)
     │ │  file4
     │ │  -- operation ad1aa66374f6 squash commit 0d254956d33ed5bb11d93eb795c5e514aadc81b5 and 1 more
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:11 38778966
+    │ ○  zsuskuln/4 test.user@example.com 2001-02-03 08:05:11 38778966 (hidden)
     │ │  file4
     │ │  -- operation 83489d186f66 commit 89a30a7539466ed176c1ef122a020fd9cb15848e
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:11 89a30a75
+    │ ○  zsuskuln/5 test.user@example.com 2001-02-03 08:05:11 89a30a75 (hidden)
     │ │  (no description set)
     │ │  -- operation e23fd04aab50 snapshot working copy
-    │ ○  zsuskuln hidden test.user@example.com 2001-02-03 08:05:10 bbf04d26
+    │ ○  zsuskuln/6 test.user@example.com 2001-02-03 08:05:10 bbf04d26 (hidden)
     │    (empty) (no description set)
     │    -- operation 19d57874b952 commit c23c424826221bc4fdee9487926595324e50ee95
-    ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:35 ce3b0a58
+    ○  kkmpptxz/0 test.user@example.com 2001-02-03 08:05:35 ce3b0a58 (hidden)
     │  file3
     │  -- operation ad1aa66374f6 squash commit 0d254956d33ed5bb11d93eb795c5e514aadc81b5 and 1 more
-    ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:10 0d254956
+    ○  kkmpptxz/3 test.user@example.com 2001-02-03 08:05:10 0d254956 (hidden)
     │  file3
     │  -- operation 19d57874b952 commit c23c424826221bc4fdee9487926595324e50ee95
-    ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:10 c23c4248
+    ○  kkmpptxz/4 test.user@example.com 2001-02-03 08:05:10 c23c4248 (hidden)
     │  (no description set)
     │  -- operation d19ad3734aa6 snapshot working copy
-    ○  kkmpptxz hidden test.user@example.com 2001-02-03 08:05:09 c1272e87
+    ○  kkmpptxz/5 test.user@example.com 2001-02-03 08:05:09 c1272e87 (hidden)
        (empty) (no description set)
        -- operation fdee458ae5f2 commit cb58ff1c6f1af92f827661e7275941ceb4d910c5
     [EOF]
@@ -2083,8 +2115,7 @@ fn test_squash_to_new_commit() {
     │  A file2
     ○  qpvuntsmwlqt bm1 file1
     │  A file1
-    ○  soqnvnyzoxuu
-    │  A file3
+    ○  soqnvnyzoxuuA file3
     │  A file4
     ◆  zzzzzzzzzzzz
     [EOF]
@@ -2220,7 +2251,7 @@ fn test_squash_to_new_commit() {
     ○  pyoswmwk test.user@example.com 2001-02-03 08:05:50 991d0644
     │  (empty) (no description set)
     │  -- operation 60d056329b43 squash commit f5e47d019271a392eb7f92a6b2e9f8cf41d97049
-    ○  szrrkvty hidden test.user@example.com 2001-02-03 08:05:50 f5e47d01
+    ○  szrrkvty/0 test.user@example.com 2001-02-03 08:05:50 f5e47d01 (hidden)
        (empty) (no description set)
        -- operation 31e408225067 new empty commit
     [EOF]
@@ -2260,6 +2291,43 @@ fn test_squash_to_new_commit() {
     ◆  zzzzzzzzzzzz
     [EOF]
     ");
+
+    // squash-moves can use the current commit too
+    work_dir.run_jj(["op", "restore", &setup_opid]).success();
+    work_dir.run_jj(["edit", "bm3"]).success();
+    insta::assert_snapshot!(get_log_with_summary(&work_dir), @r"
+    ○  zsuskulnrvyr bm4 file4
+    │  A file4
+    @  kkmpptxzrspx bm3 file3
+    │  A file3
+    ○  rlvkpnrzqnoo bm2 file2
+    │  A file2
+    ○  qpvuntsmwlqt bm1 file1
+    │  A file1
+    ◆  zzzzzzzzzzzz
+    [EOF]
+    ");
+    insta::assert_snapshot!(work_dir.run_jj(["squash", "--before", "rlvkpnrzqnoo"]), @r"
+    ------- stderr -------
+    Created new commit wxzmtyol bc0392dc file3
+    Rebased 2 descendant commits
+    Working copy  (@) now at: musouqkq 1841cc81 (empty) (no description set)
+    Parent commit (@-)      : rlvkpnrz 264a43af bm2 bm3 | file2
+    [EOF]
+    ");
+    insta::assert_snapshot!(get_log_with_summary(&work_dir), @r"
+    @  musouqkqsmll
+    │ ○  zsuskulnrvyr bm4 file4
+    ├─╯  A file4
+    ○  rlvkpnrzqnoo bm2 bm3 file2
+    │  A file2
+    ○  wxzmtyollrwl file3
+    │  A file3
+    ○  qpvuntsmwlqt bm1 file1
+    │  A file1
+    ◆  zzzzzzzzzzzz
+    [EOF]
+    ");
 }
 
 #[test]
@@ -2370,6 +2438,7 @@ fn test_squash_with_editor_and_empty_message() {
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r#"
 
+
     Trailer: value
 
     JJ: Change ID: qpvuntsm
@@ -2379,7 +2448,6 @@ fn test_squash_with_editor_and_empty_message() {
     JJ: Lines starting with "JJ:" (like this one) will be removed.
     "#);
     insta::assert_snapshot!(get_description(&work_dir, "@-"), @r"
-
     Trailer: value
     [EOF]
     ");
