@@ -84,7 +84,22 @@ fn test_tag_set_delete() {
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["tag", "delete", "glob:b*"]);
+    let output = work_dir.run_jj(["tag", "set", "--allow-move", "-r@-", "baz"]);
+    insta::assert_snapshot!(output, @r"
+    ------- stderr -------
+    Warning: Target revision is empty.
+    Nothing changed.
+    [EOF]
+    ");
+    insta::assert_snapshot!(get_log_output(&work_dir), @r"
+    @  13cbd51558a6
+    ◆  bbc749308d7f baz
+    ◆  b876c5f49546 bar
+    ◆  000000000000
+    [EOF]
+    ");
+
+    let output = work_dir.run_jj(["tag", "delete", "b*"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     Deleted 2 tags.
@@ -204,7 +219,7 @@ fn test_tag_unknown() {
     [EOF]
     ");
 
-    let output = work_dir.run_jj(["tag", "delete", "glob:unknown*"]);
+    let output = work_dir.run_jj(["tag", "delete", "unknown*"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
     No tags to delete.
@@ -277,7 +292,7 @@ fn test_tag_list() {
     [EOF]
     ");
 
-    insta::assert_snapshot!(work_dir.run_jj(["tag", "list", "glob:'test_tag?'"]), @r"
+    insta::assert_snapshot!(work_dir.run_jj(["tag", "list", "'test_tag?'"]), @r"
     test_tag2: zsuskuln 76abdd20 (empty) commit2
     [EOF]
     ");
@@ -285,7 +300,7 @@ fn test_tag_list() {
     // Unmatched exact name pattern should be warned. "test_tag2" exists, but
     // isn't included in the match.
     insta::assert_snapshot!(
-        work_dir.run_jj(["tag", "list", "glob:test* & ~glob:*2", "unknown ~ test_tag2"]), @r"
+        work_dir.run_jj(["tag", "list", "test* & ~*2", "unknown ~ test_tag2"]), @r"
     test_tag: rlvkpnrz 893e67dc (empty) commit1
     [EOF]
     ------- stderr -------
@@ -324,6 +339,29 @@ fn test_tag_list() {
     added_targets: commit2
     [EOF]
     ");
+
+    // Sort by command argument
+    insta::assert_snapshot!(work_dir.run_jj(["tag", "list", "--sort=committer-date-,name"]), @"
+    conflicted_tag (conflicted):
+      - rlvkpnrz 893e67dc (empty) commit1
+      + zsuskuln 76abdd20 (empty) commit2
+      + royxmykx 13c4e819 (empty) commit3
+    test_tag2: zsuskuln 76abdd20 (empty) commit2
+    test_tag: rlvkpnrz 893e67dc (empty) commit1
+    [EOF]
+    ");
+
+    // Default sort keys in config
+    let config = "--config=ui.tag-list-sort-keys=['committer-date', 'name-']";
+    insta::assert_snapshot!(work_dir.run_jj(["tag", "list", config]), @"
+    test_tag: rlvkpnrz 893e67dc (empty) commit1
+    test_tag2: zsuskuln 76abdd20 (empty) commit2
+    conflicted_tag (conflicted):
+      - rlvkpnrz 893e67dc (empty) commit1
+      + zsuskuln 76abdd20 (empty) commit2
+      + royxmykx 13c4e819 (empty) commit3
+    [EOF]
+    ");
 }
 
 #[must_use]
