@@ -12,6 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+use std::fs;
+
 use insta::assert_snapshot;
 
 use crate::common::TestEnvironment;
@@ -120,8 +122,10 @@ fn test_shell_completions() {
     }
 
     test("bash");
+    test("elvish");
     test("fish");
     test("nushell");
+    test("power-shell");
     test("zsh");
 }
 
@@ -159,16 +163,18 @@ fn test_util_exec_fail() {
         ],
     );
     // Ensures only stdout contains text
-    insta::assert_snapshot!(output.normalize_stderr_with(|s| s.replace(".exe", "")), @r###"
+    insta::assert_snapshot!(output.normalize_stderr_with(|s| s.replace(".exe", "")), @r"
     ------- stderr -------
     error: unexpected argument '--badopt' found
 
-    Usage: fake-formatter [OPTIONS]
+      tip: a similar argument exists: '--abort'
+
+    Usage: fake-formatter --abort
 
     For more information, try '--help'.
     [EOF]
     [exit status: 2]
-    "###);
+    ");
 }
 
 #[test]
@@ -183,6 +189,38 @@ fn test_util_exec_not_found() {
     ");
 }
 
+#[test]
+fn test_util_exec_crash() {
+    let test_env = TestEnvironment::default();
+    let formatter_path = assert_cmd::cargo::cargo_bin!("fake-formatter");
+    let output = test_env.run_jj_in(
+        ".",
+        [
+            "util",
+            "exec",
+            "--",
+            formatter_path.to_str().unwrap(),
+            "--abort",
+        ],
+    );
+
+    if cfg!(unix) {
+        // abort produces SIGABRT; strip any "(core dumped)" string
+        let output = output.normalize_stderr_with(|s| s.replacen(" (core dumped)", "", 1));
+        insta::assert_snapshot!(output, @r"
+        ------- stderr -------
+        Error: External command was terminated by signal: 6 (SIGABRT)
+        [EOF]
+        [exit status: 1]
+        ");
+    } else if cfg!(windows) {
+        // abort produces STATUS_STACK_BUFFER_OVERRUN (0xc0000409)
+        insta::assert_snapshot!(output, @r"
+        [exit status: -1073740791]
+        ");
+    }
+}
+
 #[cfg(unix)]
 #[test]
 fn test_util_exec_sets_env() {
@@ -201,8 +239,25 @@ fn test_util_exec_sets_env() {
             r#"echo "$JJ_WORKSPACE_ROOT""#,
         ],
     );
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     $TEST_ENV/repo
     [EOF]
-    "###);
+    ");
+}
+
+#[test]
+fn test_install_man_pages() {
+    let test_env = TestEnvironment::default();
+
+    // no man pages present
+    let man_dir = test_env.env_root().join("man1");
+    assert!(!man_dir.exists());
+
+    // install man pages
+    let output = test_env.run_jj_in(".", ["util", "install-man-pages", "."]);
+    insta::assert_snapshot!(output, @"");
+
+    // confirm something is now present
+    assert!(man_dir.is_dir());
+    assert!(fs::read_dir(man_dir).unwrap().next().is_some());
 }
