@@ -19,9 +19,35 @@ use crate::common::CommandOutput;
 use crate::common::TestEnvironment;
 use crate::common::TestWorkDir;
 
-/// Test adding a second workspace
 #[test]
-fn test_workspaces_add_second_workspace() {
+fn test_workspaces_invalid_name() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "repo"]).success();
+    let main_dir = test_env.work_dir("repo");
+
+    // refuse to create, directory not created
+    let output = main_dir.run_jj(["workspace", "add", "--name", "", "../secondary"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Error: New workspace name cannot be empty
+    [EOF]
+    [exit status: 1]
+    ");
+    assert!(!test_env.env_root().join("secondary").exists());
+
+    // refuse to rename
+    let output = main_dir.run_jj(["workspace", "rename", ""]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Error: New workspace name cannot be empty
+    [EOF]
+    [exit status: 1]
+    ");
+}
+
+/// Test adding a second and a third workspace
+#[test]
+fn test_workspaces_add_second_and_third_workspace() {
     let test_env = TestEnvironment::default();
     test_env.run_jj_in(".", ["git", "init", "main"]).success();
     let main_dir = test_env.work_dir("main");
@@ -72,6 +98,28 @@ fn test_workspaces_add_second_workspace() {
     second: rzvqmyuk bcc858e1 (empty) (no description set)
     [EOF]
     ");
+
+    // Check that a workspace can be created in an existing empty directory
+    main_dir.create_dir("../third");
+    let output = main_dir.run_jj(["workspace", "add", "--name", "third", "../third"]);
+    insta::assert_snapshot!(output.normalize_backslash(), @r#"
+    ------- stderr -------
+    Created workspace in "../third"
+    Working copy  (@) now at: nuwvvtmy d55e769c (empty) (no description set)
+    Parent commit (@-)      : qpvuntsm 7b22a8cb initial
+    Added 1 files, modified 0 files, removed 0 files
+    [EOF]
+    "#);
+
+    // Duplicate names are not allowed, directory not created
+    let output = main_dir.run_jj(["workspace", "add", "--name", "third", "../tertiary"]);
+    insta::assert_snapshot!(output.normalize_backslash(), @"
+    ------- stderr -------
+    Error: Workspace named 'third' already exists
+    [EOF]
+    [exit status: 1]
+    ");
+    assert!(!test_env.env_root().join("tertiary").exists());
 }
 
 /// Test how sparse patterns are inherited
@@ -351,9 +399,9 @@ fn test_workspaces_add_workspace_multiple_revisions() {
         "add",
         "--name=merge",
         "../merged",
-        "-r=subject(glob:third)",
-        "-r=subject(glob:second)",
-        "-r=subject(glob:first)",
+        "-r=subject(third)",
+        "-r=subject(second)",
+        "-r=subject(first)",
     ]);
     insta::assert_snapshot!(output.normalize_backslash(), @r#"
     ------- stderr -------
@@ -441,11 +489,11 @@ fn test_workspaces_add_workspace_in_current_workspace() {
 
     // Workspace created despite warning
     let output = main_dir.run_jj(["workspace", "list"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     default: rlvkpnrz 504e3d8c (empty) (no description set)
     secondary: pmmvwywv 058f604d (empty) (no description set)
     [EOF]
-    "###);
+    ");
 
     // Use explicit path instead (no warning)
     let output = main_dir.run_jj(["workspace", "add", "./third"]);
@@ -460,18 +508,18 @@ fn test_workspaces_add_workspace_in_current_workspace() {
 
     // Both workspaces created
     let output = main_dir.run_jj(["workspace", "list"]);
-    insta::assert_snapshot!(output, @r###"
+    insta::assert_snapshot!(output, @r"
     default: rlvkpnrz 504e3d8c (empty) (no description set)
     secondary: pmmvwywv 058f604d (empty) (no description set)
     third: zxsnswpr 1c1effec (empty) (no description set)
     [EOF]
-    "###);
+    ");
 
     let output = main_dir.run_jj(["file", "list"]);
-    insta::assert_snapshot!(output.normalize_backslash(), @r###"
+    insta::assert_snapshot!(output.normalize_backslash(), @r"
     file
     [EOF]
-    "###);
+    ");
 }
 
 /// Test making changes to the working copy in a workspace as it gets rewritten
@@ -549,7 +597,7 @@ fn test_workspaces_conflicting_edits() {
     ------- stderr -------
     Concurrent modification detected, resolving automatically.
     Rebased 1 descendant commits onto commits rewritten by other operation
-    Working copy  (@) now at: pmmvwywv?? 90f3d42e (empty) (no description set)
+    Working copy  (@) now at: pmmvwywv/2 90f3d42e (divergent) (empty) (no description set)
     Parent commit (@-)      : qpvuntsm b853f7c8 (no description set)
     Added 0 files, modified 1 files, removed 0 files
     Updated working copy to fresh commit 90f3d42e0bff
@@ -558,7 +606,7 @@ fn test_workspaces_conflicting_edits() {
     insta::assert_snapshot!(get_log_output(&secondary_dir),
     @r"
     @  90f3d42e0bff secondary@ (divergent)
-    │ ×  3ef90f18334b (divergent)
+    │ ×  5ae7e71904b9 (divergent)
     ├─╯
     │ ○  3a9b690d6e67 default@
     ├─╯
@@ -569,7 +617,7 @@ fn test_workspaces_conflicting_edits() {
     // The stale working copy should have been resolved by the previous command
     insta::assert_snapshot!(get_log_output(&secondary_dir), @r"
     @  90f3d42e0bff secondary@ (divergent)
-    │ ×  3ef90f18334b (divergent)
+    │ ×  5ae7e71904b9 (divergent)
     ├─╯
     │ ○  3a9b690d6e67 default@
     ├─╯
@@ -888,7 +936,7 @@ fn test_workspaces_current_op_discarded_by_other(automatic: bool) {
         @  kmkuslsw test.user@example.com 2001-02-03 08:05:18 secondary@ 18851b39
         │  RECOVERY COMMIT FROM `jj workspace update-stale`
         │  -- operation 0a26da4b0149 snapshot working copy
-        ○  kmkuslsw hidden test.user@example.com 2001-02-03 08:05:18 866928d1
+        ○  kmkuslsw/1 test.user@example.com 2001-02-03 08:05:18 866928d1 (hidden)
            (empty) RECOVERY COMMIT FROM `jj workspace update-stale`
            -- operation 83f707034db1 recovery commit
         [EOF]
@@ -898,7 +946,7 @@ fn test_workspaces_current_op_discarded_by_other(automatic: bool) {
         @  kmkuslsw test.user@example.com 2001-02-03 08:05:18 secondary@ 18851b39
         │  RECOVERY COMMIT FROM `jj workspace update-stale`
         │  -- operation 0f876590219e snapshot working copy
-        ○  kmkuslsw hidden test.user@example.com 2001-02-03 08:05:18 866928d1
+        ○  kmkuslsw/1 test.user@example.com 2001-02-03 08:05:18 866928d1 (hidden)
            (empty) RECOVERY COMMIT FROM `jj workspace update-stale`
            -- operation 83f707034db1 recovery commit
         [EOF]
@@ -1036,7 +1084,7 @@ fn test_colocated_workspace_update_stale() {
         .run_jj(["new", "--no-edit", "root()", "-mold book1"])
         .success();
     main_dir
-        .run_jj(["bookmark", "set", "-rsubject(glob:'old book1')", "book1"])
+        .run_jj(["bookmark", "set", "-rsubject('old book1')", "book1"])
         .success();
 
     main_dir
@@ -1056,7 +1104,7 @@ fn test_colocated_workspace_update_stale() {
         .run_jj([
             "bookmark",
             "set",
-            "-rsubject(glob:'new book1')",
+            "-rsubject('new book1')",
             "--allow-backwards",
             "book1",
         ])
@@ -1084,7 +1132,7 @@ fn test_colocated_workspace_update_stale() {
     let output = main_dir.run_jj(["st"]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Error: The working copy is stale (not updated since operation a3fbf68cb3f8).
+    Error: The working copy is stale (not updated since operation b0dfa4a0da08).
     Hint: Run `jj workspace update-stale` to update it.
     See https://docs.jj-vcs.dev/latest/working-copy/#stale-working-copy for more information.
     [EOF]
@@ -1156,13 +1204,6 @@ fn test_workspaces_forget() {
     [EOF]
     ");
 
-    // `jj status` tells us that there's no working copy here
-    let output = main_dir.run_jj(["st"]);
-    insta::assert_snapshot!(output, @r"
-    No working copy
-    [EOF]
-    ");
-
     // The old working copy doesn't get an "@" in the log output
     // TODO: It seems useful to still have the "secondary@" marker here even though
     // there's only one workspace. We should show it when the command is not run
@@ -1188,21 +1229,40 @@ fn test_workspaces_forget() {
     let output = main_dir.run_jj(["workspace", "add", "."]);
     insta::assert_snapshot!(output, @r"
     ------- stderr -------
-    Error: Workspace already exists
+    Error: Destination path exists and is not an empty directory
     [EOF]
     [exit status: 1]
     ");
 
     // Add a third workspace...
     main_dir.run_jj(["workspace", "add", "../third"]).success();
-    // ... and then forget it, and the secondary workspace too
-    let output = main_dir.run_jj(["workspace", "forget", "secondary", "third"]);
-    insta::assert_snapshot!(output, @"");
+    // ... and then forget it, a non-existent one, and the secondary workspace too
+    let output = main_dir.run_jj(["workspace", "forget", "secondary", "nonexistent", "third"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Warning: No such workspace: nonexistent
+    [EOF]
+    ");
     // No workspaces left
     let output = main_dir.run_jj(["workspace", "list"]);
     insta::assert_snapshot!(output, @"");
 }
 
+#[test]
+fn test_workspaces_forget_nothing_changed() {
+    let test_env = TestEnvironment::default();
+    test_env.run_jj_in(".", ["git", "init", "main"]).success();
+    let main_dir = test_env.work_dir("main");
+    let output = main_dir.run_jj(["workspace", "forget", "second", "third"]);
+    insta::assert_snapshot!(output, @"
+    ------- stderr -------
+    Warning: No such workspace: second
+    Warning: No such workspace: third
+    Nothing changed.
+    [EOF]
+    ");
+}
+
 #[test]
 fn test_workspaces_forget_multi_transaction() {
     let test_env = TestEnvironment::default();
@@ -1226,7 +1286,7 @@ fn test_workspaces_forget_multi_transaction() {
 
     // delete two at once, in a single tx
     main_dir
-        .run_jj(["workspace", "forget", "second", "third"])
+        .run_jj(["workspace", "forget", "second", "third", "fourth"])
         .success();
     let output = main_dir.run_jj(["workspace", "list"]);
     insta::assert_snapshot!(output, @r"
@@ -1234,12 +1294,12 @@ fn test_workspaces_forget_multi_transaction() {
     [EOF]
     ");
 
-    // the op log should have multiple workspaces forgotten in a single tx
+    // the op log should have the multiple valid workspaces forgotten in a single tx
     let output = main_dir.run_jj(["op", "log", "--limit", "1"]);
-    insta::assert_snapshot!(output, @r"
-    @  d3aded9a10b6 test-username@host.example.com 2001-02-03 04:05:12.000 +07:00 - 2001-02-03 04:05:12.000 +07:00
+    insta::assert_snapshot!(output, @"
+    @  86a599409515 test-username@host.example.com 2001-02-03 04:05:12.000 +07:00 - 2001-02-03 04:05:12.000 +07:00
     │  forget workspaces second, third
-    │  args: jj workspace forget second third
+    │  args: jj workspace forget second third fourth
     [EOF]
     ");
 
