@@ -15,7 +15,7 @@ branch. Other remote branches are only available as remote-tracking bookmarks."
 run_command "jj bookmark list --all"
 comment "We can create a local bookmark tracking one of the remote branches we just
 fetched."
-run_command "jj bookmark track octocat-patch-1@origin"
+run_command "jj bookmark track octocat-patch-1 --remote=origin"
 
 comment "By default, \"jj log\" excludes untracked remote branches to focus on
 \"our\" commits."
@@ -33,6 +33,6 @@ comment "We can generate a 'git format-patch' compatible diff"
 run_command "jj show --git --template git_format_patch_email_headers"
 
 comment "The repo is backed by the actual Git repo:"
-run_command "git --git-dir=.jj/repo/store/git log --graph --all --decorate --oneline"
+run_command "git log --graph --all --decorate --oneline"
 
 blank
