@@ -4,14 +4,14 @@ set -euo pipefail
 
 new_tmp_dir
 {
-    jj git clone https://github.com/octocat/Hello-World 
+    jj git clone https://github.com/octocat/Hello-World
     cd Hello-World
     jj abandon --ignore-immutable test@origin
-    jj branch forget test
+    jj bookmark forget test
 } > /dev/null 2>&1
 
-comment "We are on the master branch of the
-octocat/Hello-World repo:"
+comment "We are on the master branch of the octocat/Hello-World repo,
+represented by the \"master\" bookmark on the parent commit."
 run_command "jj log"
 
 comment "Let's make an edit that will conflict
@@ -29,7 +29,7 @@ That commit looks like this:"
 run_command "jj diff -r b1"
 
 comment "Now rebase:"
-run_command "jj rebase -d b1"
+run_command "jj rebase --onto b1"
 
 comment "That seemed to succeed but we are also told there is now a conflict.
 Let's take a look at the repo:"
