@@ -32,6 +32,7 @@ use crate::backend::BackendResult;
 use crate::backend::CommitId;
 use crate::backend::TreeValue;
 use crate::commit::Commit;
+use crate::commit::conflict_label_for_commits;
 use crate::conflicts::MaterializedFileValue;
 use crate::conflicts::MaterializedTreeValue;
 use crate::conflicts::materialized_diff_stream;
@@ -39,6 +40,7 @@ use crate::copies::CopyRecords;
 use crate::diff::ContentDiff;
 use crate::diff::DiffHunkKind;
 use crate::matchers::Matcher;
+use crate::merge::Diff;
 use crate::merge::Merge;
 use crate::merged_tree::MergedTree;
 use crate::merged_tree::MergedTreeBuilder;
@@ -52,15 +54,18 @@ use crate::revset::RevsetEvaluationError;
 #[derive(Clone, Debug)]
 pub struct AbsorbSource {
     commit: Commit,
+    parents: Vec<Commit>,
     parent_tree: MergedTree,
 }
 
 impl AbsorbSource {
     /// Create an absorb source from a single commit.
     pub fn from_commit(repo: &dyn Repo, commit: Commit) -> BackendResult<Self> {
+        let parents = commit.parents().try_collect()?;
         let parent_tree = commit.parent_tree(repo)?;
         Ok(Self {
             commit,
+            parents,
             parent_tree,
         })
     }
@@ -102,7 +107,11 @@ pub async fn split_hunks_to_trees(
     // TODO: enable copy tracking if we add support for annotate and merge
     let copy_records = CopyRecords::default();
     let tree_diff = left_tree.diff_stream_with_copies(&right_tree, matcher, &copy_records);
-    let mut diff_stream = materialized_diff_stream(repo.store(), tree_diff);
+    let mut diff_stream = materialized_diff_stream(
+        repo.store(),
+        tree_diff,
+        Diff::new(left_tree.labels(), right_tree.labels()),
+    );
     while let Some(entry) = diff_stream.next().await {
         let left_path = entry.path.source();
         let right_path = entry.path.target();
@@ -293,6 +302,8 @@ pub fn absorb_hunks(
     let mut rewritten_source = None;
     let mut rewritten_destinations = Vec::new();
     let mut num_rebased = 0;
+    let parents_label = conflict_label_for_commits(&source.parents);
+    let source_commit_label = source.commit.conflict_label();
     // Rewrite commits in topological order so that descendant commits wouldn't
     // be rewritten multiple times.
     repo.transform_descendants(selected_trees.keys().cloned().collect(), async |rewriter| {
@@ -314,11 +325,24 @@ pub fn absorb_hunks(
         };
         // Merge hunks between source parent tree and selected tree
         let selected_tree = tree_builder.write_tree()?;
+        let destination_label = rewriter.old_commit().conflict_label();
         let commit_builder = rewriter.rebase().await?;
         let destination_tree = commit_builder.tree();
-        let new_tree = destination_tree
-            .merge(source.parent_tree.clone(), selected_tree)
-            .block_on()?;
+        let new_tree = MergedTree::merge(Merge::from_vec(vec![
+            (
+                destination_tree,
+                format!("{destination_label} (absorb destination)"),
+            ),
+            (
+                source.parent_tree.clone(),
+                format!("{parents_label} (parents of absorbed revision)"),
+            ),
+            (
+                selected_tree,
+                format!("absorbed changes (from {source_commit_label})"),
+            ),
+        ]))
+        .block_on()?;
         let mut predecessors = commit_builder.predecessors().to_vec();
         predecessors.push(source.commit.id().clone());
         let new_commit = commit_builder
