@@ -33,6 +33,7 @@ use crate::backend::ChangeId;
 use crate::backend::CommitId;
 use crate::backend::Signature;
 use crate::backend::TreeId;
+use crate::conflict_labels::ConflictLabels;
 use crate::index::IndexResult;
 use crate::merge::Merge;
 use crate::merged_tree::MergedTree;
@@ -121,7 +122,11 @@ impl Commit {
     }
 
     pub fn tree(&self) -> MergedTree {
-        MergedTree::new(self.store.clone(), self.data.root_tree.clone())
+        MergedTree::new(
+            self.store.clone(),
+            self.data.root_tree.clone(),
+            ConflictLabels::from_merge(self.data.conflict_labels.clone()),
+        )
     }
 
     pub fn tree_ids(&self) -> &Merge<TreeId> {
@@ -180,8 +185,8 @@ impl Commit {
 
     ///  A commit is hidden if its commit id is not in the change id index.
     pub fn is_hidden(&self, repo: &dyn Repo) -> IndexResult<bool> {
-        let maybe_entries = repo.resolve_change_id(self.change_id())?;
-        Ok(maybe_entries.is_none_or(|entries| !entries.contains(&self.id)))
+        let maybe_targets = repo.resolve_change_id(self.change_id())?;
+        Ok(maybe_targets.is_none_or(|targets| !targets.has_visible(&self.id)))
     }
 
     /// A commit is discardable if it has no change from its parent, and an
@@ -203,6 +208,48 @@ impl Commit {
             .map(|sig| self.store.signer().verify(&self.id, &sig.data, &sig.sig))
             .transpose()
     }
+
+    /// A string describing the commit to be used in conflict markers. If a
+    /// description is set, it will include the first line of the description.
+    pub fn conflict_label(&self) -> String {
+        if let Some(subject) = self.description().lines().next() {
+            // Example: nlqwxzwn 7dd24e73 "first line of description"
+            format!(
+                "{} \"{}\"",
+                self.conflict_label_short(),
+                // Control characters shouldn't be written in conflict markers, and '\0' isn't
+                // supported by the Git backend, so we just remove them. Unicode characters are
+                // supported, so we don't have to remove them.
+                subject.trim().replace(char::is_control, "")
+            )
+        } else {
+            self.conflict_label_short()
+        }
+    }
+
+    /// A short string describing the commit to be used in conflict markers.
+    /// Does not include the commit description.
+    fn conflict_label_short(&self) -> String {
+        // Example: nlqwxzwn 7dd24e73
+        format!("{:.8} {:.8}", self.change_id(), self.id())
+    }
+
+    /// A string describing the commit's parents to be used in conflict markers.
+    pub fn parents_conflict_label(&self) -> BackendResult<String> {
+        let parents: Vec<_> = self.parents().try_collect()?;
+        Ok(conflict_label_for_commits(&parents))
+    }
+}
+
+// If there is a single commit, returns the detailed conflict label for that
+// commit. If there are multiple commits, joins the short conflict labels of
+// each commit.
+pub fn conflict_label_for_commits(commits: &[Commit]) -> String {
+    if commits.len() == 1 {
+        commits[0].conflict_label()
+    } else {
+        commits.iter().map(Commit::conflict_label_short).join(", ")
+    }
 }
 
 pub(crate) fn is_backend_commit_empty(
