@@ -19,6 +19,7 @@ use std::io::Write;
 use std::iter::zip;
 use std::pin::Pin;
 
+use bstr::BStr;
 use bstr::BString;
 use bstr::ByteSlice as _;
 use futures::Stream;
@@ -38,6 +39,7 @@ use crate::backend::FileId;
 use crate::backend::SymlinkId;
 use crate::backend::TreeId;
 use crate::backend::TreeValue;
+use crate::conflict_labels::ConflictLabels;
 use crate::copies::CopiesTreeDiffEntry;
 use crate::copies::CopiesTreeDiffEntryPath;
 use crate::diff::ContentDiff;
@@ -65,12 +67,6 @@ const CONFLICT_MARKER_LEN_INCREMENT: usize = 4;
 /// Comment for missing terminating newline in a term of a conflict.
 const NO_EOL_COMMENT: &str = " (no terminating newline)";
 
-/// Comment for missing terminating newline in the "add" side of a diff.
-const ADD_NO_EOL_COMMENT: &str = " (removes terminating newline)";
-
-/// Comment for missing terminating newline in the "remove" side of a diff.
-const REMOVE_NO_EOL_COMMENT: &str = " (adds terminating newline)";
-
 fn write_diff_hunks(hunks: &[DiffHunk], file: &mut dyn Write) -> io::Result<()> {
     for hunk in hunks {
         match hunk.kind {
@@ -137,9 +133,15 @@ pub enum MaterializedTreeValue {
     Absent,
     AccessDenied(Box<dyn std::error::Error + Send + Sync>),
     File(MaterializedFileValue),
-    Symlink { id: SymlinkId, target: String },
+    Symlink {
+        id: SymlinkId,
+        target: String,
+    },
     FileConflict(MaterializedFileConflictValue),
-    OtherConflict { id: MergedTreeValue },
+    OtherConflict {
+        id: MergedTreeValue,
+        labels: ConflictLabels,
+    },
     GitSubmodule(CommitId),
     Tree(TreeId),
 }
@@ -186,6 +188,8 @@ pub struct MaterializedFileConflictValue {
     pub unsimplified_ids: Merge<Option<FileId>>,
     /// Simplified file ids, in which redundant id pairs are dropped.
     pub ids: Merge<Option<FileId>>,
+    /// Simplified conflict labels, matching `ids`.
+    pub labels: ConflictLabels,
     /// File contents corresponding to the simplified `ids`.
     // TODO: or Vec<(FileId, Box<dyn Read>)> so that caller can stop reading
     // when null bytes found?
@@ -203,8 +207,9 @@ pub async fn materialize_tree_value(
     store: &Store,
     path: &RepoPath,
     value: MergedTreeValue,
+    conflict_labels: &ConflictLabels,
 ) -> BackendResult<MaterializedTreeValue> {
-    match materialize_tree_value_no_access_denied(store, path, value).await {
+    match materialize_tree_value_no_access_denied(store, path, value, conflict_labels).await {
         Err(BackendError::ReadAccessDenied { source, .. }) => {
             Ok(MaterializedTreeValue::AccessDenied(source))
         }
@@ -216,6 +221,7 @@ async fn materialize_tree_value_no_access_denied(
     store: &Store,
     path: &RepoPath,
     value: MergedTreeValue,
+    conflict_labels: &ConflictLabels,
 ) -> BackendResult<MaterializedTreeValue> {
     match value.into_resolved() {
         Ok(None) => Ok(MaterializedTreeValue::Absent),
@@ -238,10 +244,17 @@ async fn materialize_tree_value_no_access_denied(
         }
         Ok(Some(TreeValue::GitSubmodule(id))) => Ok(MaterializedTreeValue::GitSubmodule(id)),
         Ok(Some(TreeValue::Tree(id))) => Ok(MaterializedTreeValue::Tree(id)),
-        Err(conflict) => match try_materialize_file_conflict_value(store, path, &conflict).await? {
-            Some(file) => Ok(MaterializedTreeValue::FileConflict(file)),
-            None => Ok(MaterializedTreeValue::OtherConflict { id: conflict }),
-        },
+        Err(conflict) => {
+            match try_materialize_file_conflict_value(store, path, &conflict, conflict_labels)
+                .await?
+            {
+                Some(file) => Ok(MaterializedTreeValue::FileConflict(file)),
+                None => Ok(MaterializedTreeValue::OtherConflict {
+                    id: conflict,
+                    labels: conflict_labels.clone(),
+                }),
+            }
+        }
     }
 }
 
@@ -251,18 +264,20 @@ pub async fn try_materialize_file_conflict_value(
     store: &Store,
     path: &RepoPath,
     conflict: &MergedTreeValue,
+    conflict_labels: &ConflictLabels,
 ) -> BackendResult<Option<MaterializedFileConflictValue>> {
     let (Some(unsimplified_ids), Some(executable_bits)) =
         (conflict.to_file_merge(), conflict.to_executable_merge())
     else {
         return Ok(None);
     };
-    let ids = unsimplified_ids.simplify();
+    let (labels, ids) = conflict_labels.simplify_with(&unsimplified_ids);
     let contents = extract_as_single_hunk(&ids, store, path).await?;
     let executable = resolve_file_executable(&executable_bits);
     Ok(Some(MaterializedFileConflictValue {
         unsimplified_ids,
         ids,
+        labels,
         contents,
         executable,
         copy_id: Some(CopyId::placeholder()),
@@ -323,6 +338,7 @@ enum ConflictMarkerLineChar {
     Add = b'+',
     Remove = b'-',
     Diff = b'%',
+    Note = b'\\',
     GitAncestor = b'|',
     GitSeparator = b'=',
 }
@@ -341,6 +357,7 @@ impl ConflictMarkerLineChar {
             b'+' => Some(Self::Add),
             b'-' => Some(Self::Remove),
             b'%' => Some(Self::Diff),
+            b'\\' => Some(Self::Note),
             b'|' => Some(Self::GitAncestor),
             b'=' => Some(Self::GitSeparator),
             _ => None,
@@ -414,6 +431,7 @@ pub fn choose_materialized_conflict_marker_len<T: AsRef<[u8]>>(single_hunk: &Mer
 
 pub fn materialize_merge_result<T: AsRef<[u8]>>(
     single_hunk: &Merge<T>,
+    labels: &ConflictLabels,
     output: &mut dyn Write,
     options: &ConflictMaterializeOptions,
 ) -> io::Result<()> {
@@ -424,13 +442,14 @@ pub fn materialize_merge_result<T: AsRef<[u8]>>(
             let marker_len = options
                 .marker_len
                 .unwrap_or_else(|| choose_materialized_conflict_marker_len(single_hunk));
-            materialize_conflict_hunks(hunks, options.marker_style, marker_len, output)
+            materialize_conflict_hunks(hunks, options.marker_style, marker_len, labels, output)
         }
     }
 }
 
 pub fn materialize_merge_result_to_bytes<T: AsRef<[u8]>>(
     single_hunk: &Merge<T>,
+    labels: &ConflictLabels,
     options: &ConflictMaterializeOptions,
 ) -> BString {
     let merge_result = files::merge_hunks(single_hunk, &options.merge);
@@ -441,8 +460,14 @@ pub fn materialize_merge_result_to_bytes<T: AsRef<[u8]>>(
                 .marker_len
                 .unwrap_or_else(|| choose_materialized_conflict_marker_len(single_hunk));
             let mut output = Vec::new();
-            materialize_conflict_hunks(&hunks, options.marker_style, marker_len, &mut output)
-                .expect("writing to an in-memory buffer should never fail");
+            materialize_conflict_hunks(
+                &hunks,
+                options.marker_style,
+                marker_len,
+                labels,
+                &mut output,
+            )
+            .expect("writing to an in-memory buffer should never fail");
             output.into()
         }
     }
@@ -452,6 +477,7 @@ fn materialize_conflict_hunks(
     hunks: &[Merge<BString>],
     conflict_marker_style: ConflictMarkerStyle,
     conflict_marker_len: usize,
+    labels: &ConflictLabels,
     output: &mut dyn Write,
 ) -> io::Result<()> {
     let num_conflicts = hunks
@@ -464,7 +490,7 @@ fn materialize_conflict_hunks(
             output.write_all(content)?;
         } else {
             conflict_index += 1;
-            let conflict_info = format!("Conflict {conflict_index} of {num_conflicts}");
+            let conflict_info = format!("conflict {conflict_index} of {num_conflicts}");
 
             match (conflict_marker_style, hunk.as_slice()) {
                 // 2-sided conflicts can use Git-style conflict markers
@@ -473,8 +499,8 @@ fn materialize_conflict_hunks(
                         left,
                         base,
                         right,
-                        &conflict_info,
                         conflict_marker_len,
+                        labels,
                         output,
                     )?;
                 }
@@ -484,6 +510,7 @@ fn materialize_conflict_hunks(
                         &conflict_info,
                         conflict_marker_style,
                         conflict_marker_len,
+                        labels,
                         output,
                     )?;
                 }
@@ -497,15 +524,15 @@ fn materialize_git_style_conflict(
     left: &[u8],
     base: &[u8],
     right: &[u8],
-    conflict_info: &str,
     conflict_marker_len: usize,
+    labels: &ConflictLabels,
     output: &mut dyn Write,
 ) -> io::Result<()> {
     write_conflict_marker(
         output,
         ConflictMarkerLineChar::ConflictStart,
         conflict_marker_len,
-        &format!("Side #1 ({conflict_info})"),
+        labels.get_add(0).unwrap_or("side #1"),
     )?;
     write_and_ensure_newline(output, left)?;
 
@@ -513,7 +540,7 @@ fn materialize_git_style_conflict(
         output,
         ConflictMarkerLineChar::GitAncestor,
         conflict_marker_len,
-        "Base",
+        labels.get_remove(0).unwrap_or("base"),
     )?;
     write_and_ensure_newline(output, base)?;
 
@@ -530,7 +557,7 @@ fn materialize_git_style_conflict(
         output,
         ConflictMarkerLineChar::ConflictEnd,
         conflict_marker_len,
-        &format!("Side #2 ({conflict_info} ends)"),
+        labels.get_add(1).unwrap_or("side #2"),
     )?;
 
     Ok(())
@@ -541,58 +568,101 @@ fn materialize_jj_style_conflict(
     conflict_info: &str,
     conflict_marker_style: ConflictMarkerStyle,
     conflict_marker_len: usize,
+    labels: &ConflictLabels,
     output: &mut dyn Write,
 ) -> io::Result<()> {
+    let get_side_label = |add_index: usize| -> String {
+        labels.get_add(add_index).map_or_else(
+            || format!("side #{}", add_index + 1),
+            |label| label.to_owned(),
+        )
+    };
+
+    let get_base_label = |base_index: usize| -> String {
+        labels
+            .get_remove(base_index)
+            .map(|label| label.to_owned())
+            .unwrap_or_else(|| {
+                // The vast majority of conflicts one actually tries to resolve manually have 1
+                // base.
+                if hunk.removes().len() == 1 {
+                    "base".to_string()
+                } else {
+                    format!("base #{}", base_index + 1)
+                }
+            })
+    };
+
     // Write a positive snapshot (side) of a conflict
     let write_side = |add_index: usize, data: &[u8], output: &mut dyn Write| {
         write_conflict_marker(
             output,
             ConflictMarkerLineChar::Add,
             conflict_marker_len,
-            &format!(
-                "Contents of side #{}{}",
-                add_index + 1,
-                maybe_no_eol_comment(data)
-            ),
+            &(get_side_label(add_index) + maybe_no_eol_comment(data)),
         )?;
         write_and_ensure_newline(output, data)
     };
 
     // Write a negative snapshot (base) of a conflict
-    let write_base = |base_str: &str, data: &[u8], output: &mut dyn Write| {
+    let write_base = |base_index: usize, data: &[u8], output: &mut dyn Write| {
         write_conflict_marker(
             output,
             ConflictMarkerLineChar::Remove,
             conflict_marker_len,
-            &format!("Contents of {base_str}{}", maybe_no_eol_comment(data)),
+            &(get_base_label(base_index) + maybe_no_eol_comment(data)),
         )?;
         write_and_ensure_newline(output, data)
     };
 
     // Write a diff from a negative term to a positive term
     let write_diff =
-        |base_str: &str, add_index: usize, diff: &[DiffHunk], output: &mut dyn Write| {
-            let no_eol_remove = diff
+        |base_index: usize, add_index: usize, diff: &[DiffHunk], output: &mut dyn Write| {
+            let (remove_last_hunk, add_last_hunk) = diff
                 .last()
-                .is_some_and(|diff_hunk| has_no_eol(diff_hunk.contents[0]));
-            let no_eol_add = diff
-                .last()
-                .is_some_and(|diff_hunk| has_no_eol(diff_hunk.contents[1]));
-            let no_eol_comment = match (no_eol_remove, no_eol_add) {
-                (true, true) => NO_EOL_COMMENT,
-                (true, _) => REMOVE_NO_EOL_COMMENT,
-                (_, true) => ADD_NO_EOL_COMMENT,
-                _ => "",
-            };
-            write_conflict_marker(
-                output,
-                ConflictMarkerLineChar::Diff,
-                conflict_marker_len,
-                &format!(
-                    "Changes from {base_str} to side #{}{no_eol_comment}",
-                    add_index + 1
-                ),
-            )?;
+                .map_or((BStr::new(""), BStr::new("")), |diff_hunk| {
+                    (diff_hunk.contents[0], diff_hunk.contents[1])
+                });
+            if labels.get_add(add_index).is_none()
+                && labels.get_remove(base_index).is_none()
+                && !has_no_eol(remove_last_hunk)
+                && !has_no_eol(add_last_hunk)
+            {
+                // TODO: remove this format when all conflicts have labels
+                // Use simple conflict markers when there are no conflict labels and no comment
+                // for missing terminating newline.
+                write_conflict_marker(
+                    output,
+                    ConflictMarkerLineChar::Diff,
+                    conflict_marker_len,
+                    &format!(
+                        "diff from {} to {}",
+                        get_base_label(base_index),
+                        get_side_label(add_index)
+                    ),
+                )?;
+            } else {
+                write_conflict_marker(
+                    output,
+                    ConflictMarkerLineChar::Diff,
+                    conflict_marker_len,
+                    &format!(
+                        "diff from: {}{}",
+                        get_base_label(base_index),
+                        maybe_no_eol_comment(remove_last_hunk)
+                    ),
+                )?;
+                write_conflict_marker(
+                    output,
+                    ConflictMarkerLineChar::Note,
+                    conflict_marker_len,
+                    &format!(
+                        "       to: {}{}",
+                        get_side_label(add_index),
+                        maybe_no_eol_comment(add_last_hunk)
+                    ),
+                )?;
+            }
             write_diff_hunks(diff, output)
         };
 
@@ -615,20 +685,12 @@ fn materialize_jj_style_conflict(
             base_index
         };
 
-        // The vast majority of conflicts one actually tries to resolve manually have 1
-        // base.
-        let base_str = if hunk.removes().len() == 1 {
-            "base".to_string()
-        } else {
-            format!("base #{}", base_index + 1)
-        };
-
         let right1 = hunk.get_add(add_index).unwrap();
 
         // Write the base and side separately if the conflict marker style doesn't
         // support diffs.
         if !conflict_marker_style.allows_diff() {
-            write_base(&base_str, left, output)?;
+            write_base(base_index, left, output)?;
             write_side(add_index, right1, output)?;
             continue;
         }
@@ -644,13 +706,13 @@ fn materialize_jj_style_conflict(
                 // If the next positive term is a better match, emit the current positive term
                 // as a snapshot and the next positive term as a diff.
                 write_side(add_index, right1, output)?;
-                write_diff(&base_str, add_index + 1, &diff2, output)?;
+                write_diff(base_index, add_index + 1, &diff2, output)?;
                 snapshot_written = true;
                 continue;
             }
         }
 
-        write_diff(&base_str, add_index, &diff1, output)?;
+        write_diff(base_index, add_index, &diff1, output)?;
     }
 
     // If we still didn't emit a snapshot, the last side is the snapshot.
@@ -708,6 +770,7 @@ pub struct MaterializedTreeDiffEntry {
 pub fn materialized_diff_stream(
     store: &Store,
     tree_diff: BoxStream<'_, CopiesTreeDiffEntry>,
+    conflict_labels: Diff<&ConflictLabels>,
 ) -> impl Stream<Item = MaterializedTreeDiffEntry> {
     tree_diff
         .map(async |CopiesTreeDiffEntry { path, values }| match values {
@@ -716,8 +779,18 @@ pub fn materialized_diff_stream(
                 values: Err(err),
             },
             Ok(values) => {
-                let before_future = materialize_tree_value(store, path.source(), values.before);
-                let after_future = materialize_tree_value(store, path.target(), values.after);
+                let before_future = materialize_tree_value(
+                    store,
+                    path.source(),
+                    values.before,
+                    conflict_labels.before,
+                );
+                let after_future = materialize_tree_value(
+                    store,
+                    path.target(),
+                    values.after,
+                    conflict_labels.after,
+                );
                 let values = try_join!(before_future, after_future)
                     .map(|(before, after)| Diff { before, after });
                 MaterializedTreeDiffEntry { path, values }
@@ -842,6 +915,9 @@ fn parse_jj_style_conflict_hunk(input: &[u8], expected_marker_len: usize) -> Mer
                 adds.push(BString::new(vec![]));
                 continue;
             }
+            Some(ConflictMarkerLineChar::Note) => {
+                continue;
+            }
             _ => {}
         }
         match state {
@@ -964,7 +1040,7 @@ pub async fn update_from_content(
         .and_then(|hunks| hunks.last_mut())
         .filter(|hunk| !hunk.is_resolved())
     {
-        for (original_content, term) in old_contents.iter().zip_eq(last_hunk.iter_mut()) {
+        for (original_content, term) in itertools::zip_eq(&old_contents, last_hunk) {
             if term.last() == Some(&b'\n') && has_no_eol(original_content) {
                 term.pop();
             }
@@ -991,40 +1067,28 @@ pub async fn update_from_content(
     let mut contents = simplified_file_ids.map(|_| vec![]);
     for hunk in hunks {
         if let Some(slice) = hunk.as_resolved() {
-            for content in contents.iter_mut() {
+            for content in &mut contents {
                 content.extend_from_slice(slice);
             }
         } else {
-            for (content, slice) in zip(contents.iter_mut(), hunk.into_iter()) {
+            for (content, slice) in zip(&mut contents, hunk) {
                 content.extend(Vec::from(slice));
             }
         }
     }
 
-    // If the user edited the empty placeholder for an absent side, we consider the
-    // conflict resolved.
-    if zip(contents.iter(), simplified_file_ids.iter())
-        .any(|(content, file_id)| file_id.is_none() && !content.is_empty())
-    {
-        let file_id = store.write_file(path, &mut &content[..]).await?;
-        return Ok(Merge::normal(file_id));
-    }
-
     // Now write the new files contents we found by parsing the file with conflict
     // markers.
     // TODO: Write these concurrently
-    let new_file_ids: Vec<Option<FileId>> = zip(contents.iter(), simplified_file_ids.iter())
+    let new_file_ids: Vec<Option<FileId>> = zip(&contents, &simplified_file_ids)
         .map(|(content, file_id)| -> BackendResult<Option<FileId>> {
-            match file_id {
-                Some(_) => {
-                    let file_id = store.write_file(path, &mut content.as_slice()).block_on()?;
-                    Ok(Some(file_id))
-                }
-                None => {
-                    // The missing side of a conflict is still represented by
-                    // the empty string we materialized it as
-                    Ok(None)
-                }
+            if file_id.is_some() || !content.is_empty() {
+                let file_id = store.write_file(path, &mut content.as_slice()).block_on()?;
+                Ok(Some(file_id))
+            } else {
+                // The missing side of a conflict is still represented by
+                // the empty string we materialized it as
+                Ok(None)
             }
         })
         .try_collect()?;
