@@ -44,6 +44,8 @@ use crate::hex_util;
 use crate::index::ChangeIdIndex;
 use crate::index::Index;
 use crate::index::IndexResult;
+use crate::index::ResolvedChangeState;
+use crate::index::ResolvedChangeTargets;
 use crate::object_id::HexPrefix;
 use crate::object_id::ObjectId as _;
 use crate::object_id::PrefixResolution;
@@ -79,6 +81,7 @@ pub(super) trait CommitIndexSegment: Send + Sync {
         change_id: &ChangeId,
     ) -> (Option<ChangeId>, Option<ChangeId>);
 
+    // Returns positions in ascending order.
     fn resolve_change_id_prefix(
         &self,
         prefix: &HexPrefix,
@@ -254,7 +257,7 @@ impl CompositeCommitIndex {
     /// Resolves the given change id `prefix` to the associated entries. The
     /// returned entries may be hidden.
     ///
-    /// The returned index positions are sorted in ascending order.
+    /// The returned index positions are sorted in descending order.
     pub(super) fn resolve_change_id_prefix(
         &self,
         prefix: &HexPrefix,
@@ -272,15 +275,14 @@ impl CompositeCommitIndex {
                 // Similar to PrefixResolution::plus(), but merges matches of the same id.
                 match (acc_match, segment.resolve_change_id_prefix(prefix)) {
                     (NoMatch, local_match) => local_match.map(|(id, positions)| {
-                        (id, positions.into_iter().map(to_global_pos).collect())
+                        (id, positions.into_iter().rev().map(to_global_pos).collect())
                     }),
                     (acc_match, NoMatch) => acc_match,
                     (AmbiguousMatch, _) => AmbiguousMatch,
                     (_, AmbiguousMatch) => AmbiguousMatch,
                     (SingleMatch((id1, _)), SingleMatch((id2, _))) if id1 != id2 => AmbiguousMatch,
                     (SingleMatch((id, mut acc_positions)), SingleMatch((_, local_positions))) => {
-                        acc_positions
-                            .insert_many(0, local_positions.into_iter().map(to_global_pos));
+                        acc_positions.extend(local_positions.into_iter().rev().map(to_global_pos));
                         SingleMatch((id, acc_positions))
                     }
                 }
@@ -648,29 +650,38 @@ impl<I: AsCompositeIndex> ChangeIdIndexImpl<I> {
 }
 
 impl<I: AsCompositeIndex + Send + Sync> ChangeIdIndex for ChangeIdIndexImpl<I> {
-    // Resolves change id prefix among all ids, then filters out hidden
-    // entries.
+    // Resolves change ID prefix among all IDs.
     //
-    // If `SingleMatch` is returned, the commits including in the set are all
-    // visible. `AmbiguousMatch` may be returned even if the prefix is unique
-    // within the visible entries.
-    fn resolve_prefix(&self, prefix: &HexPrefix) -> IndexResult<PrefixResolution<Vec<CommitId>>> {
+    // If `SingleMatch` is returned, there is at least one commit with the given
+    // change ID (either visible or hidden). `AmbiguousMatch` may be returned even
+    // if the prefix is unique within the visible entries.
+    fn resolve_prefix(
+        &self,
+        prefix: &HexPrefix,
+    ) -> IndexResult<PrefixResolution<ResolvedChangeTargets>> {
         let index = self.index.as_composite().commits();
         let prefix = match index.resolve_change_id_prefix(prefix) {
             PrefixResolution::NoMatch => PrefixResolution::NoMatch,
             PrefixResolution::SingleMatch((_change_id, positions)) => {
-                debug_assert!(positions.is_sorted_by(|a, b| a < b));
+                debug_assert!(positions.is_sorted_by(|a, b| a > b));
                 let mut reachable_set = self.reachable_set.lock().unwrap();
-                reachable_set.visit_until(index, *positions.first().unwrap());
-                let reachable_commit_ids = positions
+                reachable_set.visit_until(index, *positions.last().unwrap());
+                let targets = positions
                     .iter()
-                    .filter(|&&pos| reachable_set.contains(pos))
-                    .map(|&pos| index.entry_by_pos(pos).commit_id())
+                    .map(|&pos| {
+                        let commit_id = index.entry_by_pos(pos).commit_id();
+                        let state = if reachable_set.contains(pos) {
+                            ResolvedChangeState::Visible
+                        } else {
+                            ResolvedChangeState::Hidden
+                        };
+                        (commit_id, state)
+                    })
                     .collect_vec();
-                if reachable_commit_ids.is_empty() {
+                if targets.is_empty() {
                     PrefixResolution::NoMatch
                 } else {
-                    PrefixResolution::SingleMatch(reachable_commit_ids)
+                    PrefixResolution::SingleMatch(ResolvedChangeTargets { targets })
                 }
             }
             PrefixResolution::AmbiguousMatch => PrefixResolution::AmbiguousMatch,
