@@ -42,6 +42,7 @@ use crate::backend::ChangeId;
 use crate::backend::CommitId;
 use crate::backend::MillisSinceEpoch;
 use crate::commit::Commit;
+use crate::conflict_labels::ConflictLabels;
 use crate::conflicts::MaterializedTreeValue;
 use crate::conflicts::materialize_tree_value;
 use crate::diff::ContentDiff;
@@ -1382,8 +1383,11 @@ async fn matches_diff_from_parent(
         if !values.is_changed() {
             continue;
         }
-        let left_future = materialize_tree_value(store, &entry.path, values.before);
-        let right_future = materialize_tree_value(store, &entry.path, values.after);
+        let conflict_labels = ConflictLabels::unlabeled();
+        let left_future =
+            materialize_tree_value(store, &entry.path, values.before, &conflict_labels);
+        let right_future =
+            materialize_tree_value(store, &entry.path, values.after, &conflict_labels);
         let (left_value, right_value) = futures::try_join!(left_future, right_future)?;
         let left_contents = to_file_content(&entry.path, left_value).await?;
         let right_contents = to_file_content(&entry.path, right_value).await?;
@@ -1404,30 +1408,21 @@ fn diff_match_lines(
     // Filter lines prior to comparison. This might produce inferior hunks due
     // to lack of contexts, but is way faster than full diff.
     if let (Some(left), Some(right)) = (lefts.as_resolved(), rights.as_resolved()) {
-        let left_lines = match_lines(left, matcher);
-        let right_lines = match_lines(right, matcher);
+        let left_lines = matcher.match_lines(left);
+        let right_lines = matcher.match_lines(right);
         Ok(left_lines.ne(right_lines))
     } else {
-        let lefts: Merge<BString> = lefts.map(|text| match_lines(text, matcher).collect());
-        let rights: Merge<BString> = rights.map(|text| match_lines(text, matcher).collect());
+        let lefts: Merge<BString> = lefts.map(|text| matcher.match_lines(text).collect());
+        let rights: Merge<BString> = rights.map(|text| matcher.match_lines(text).collect());
         let lefts = files::merge(&lefts, merge_options);
         let rights = files::merge(&rights, merge_options);
-        let diff = ContentDiff::by_line(lefts.iter().chain(rights.iter()));
+        let diff = ContentDiff::by_line(itertools::chain(&lefts, &rights));
         let different = files::conflict_diff_hunks(diff.hunks(), lefts.as_slice().len())
             .any(|hunk| hunk.kind == DiffHunkKind::Different);
         Ok(different)
     }
 }
 
-fn match_lines<'a>(text: &'a [u8], matcher: &StringMatcher) -> impl Iterator<Item = &'a [u8]> {
-    // The pattern is matched line by line so that it can be anchored to line
-    // start/end. For example, exact:"" will match blank lines.
-    text.split_inclusive(|b| *b == b'\n').filter(|line| {
-        let line = line.strip_suffix(b"\n").unwrap_or(line);
-        matcher.is_match_bytes(line)
-    })
-}
-
 async fn to_file_content(
     path: &RepoPath,
     value: MaterializedTreeValue,
