@@ -33,7 +33,6 @@ use crate::diff::DiffHunk;
 use crate::diff::DiffHunkKind;
 use crate::diff::find_line_ranges;
 use crate::merge::Diff;
-use crate::merge::Merge;
 use crate::repo_path::RepoPath;
 
 pub mod unified;
@@ -55,12 +54,6 @@ pub struct FileContent<T> {
     pub contents: T,
 }
 
-impl FileContent<Merge<BString>> {
-    pub fn is_empty(&self) -> bool {
-        self.contents.as_resolved().is_some_and(|c| c.is_empty())
-    }
-}
-
 pub fn file_content_for_diff<T>(
     path: &RepoPath,
     file: &mut MaterializedFileValue,
