@@ -19,6 +19,7 @@ use std::ffi::OsString;
 use std::fs;
 use std::fs::File;
 use std::io;
+use std::io::ErrorKind;
 use std::io::Read;
 use std::io::Write;
 use std::path::Component;
@@ -34,8 +35,11 @@ use tokio::io::AsyncRead;
 use tokio::io::AsyncReadExt as _;
 use tokio::io::ReadBuf;
 
+#[cfg(unix)]
+pub use self::platform::check_executable_bit_support;
 pub use self::platform::check_symlink_support;
-pub use self::platform::try_symlink;
+pub use self::platform::symlink_dir;
+pub use self::platform::symlink_file;
 
 #[derive(Debug, Error)]
 #[error("Cannot access {path}")]
@@ -82,6 +86,18 @@ pub fn remove_dir_contents(dirname: &Path) -> Result<(), PathError> {
     Ok(())
 }
 
+/// Checks if path points at an empty directory.
+pub fn is_empty_dir(path: &Path) -> Result<bool, PathError> {
+    match path.read_dir() {
+        Ok(mut entries) => Ok(entries.next().is_none()),
+        Err(error) => match error.kind() {
+            ErrorKind::NotADirectory => Ok(false),
+            ErrorKind::NotFound => Ok(false),
+            _ => Err(error).context(path)?,
+        },
+    }
+}
+
 #[derive(Debug, Error)]
 #[error(transparent)]
 pub struct BadPathEncoding(platform::BadOsStrEncoding);
@@ -242,6 +258,29 @@ pub fn persist_content_addressed_temp_file<P: AsRef<Path>>(
     }
 }
 
+/// Opaque value that can be tested to know whether file or directory paths
+/// point to the same filesystem entity.
+///
+/// The primary use case is to detect file name aliases on case-insensitive
+/// filesystem. On Unix, device and inode numbers are compared.
+#[derive(Debug, Eq, Hash, PartialEq)]
+pub struct FileIdentity(platform::FileIdentity);
+
+impl FileIdentity {
+    /// Queries file identity without following symlinks.
+    ///
+    /// BUG: On Windows, symbolic links would be followed.
+    pub fn from_symlink_path(path: impl AsRef<Path>) -> io::Result<Self> {
+        platform::file_identity_from_symlink_path(path.as_ref()).map(Self)
+    }
+
+    /// Queries file identity of the given `file`.
+    // TODO: do not consume file object
+    pub fn from_file(file: File) -> io::Result<Self> {
+        platform::file_identity_from_file(file).map(Self)
+    }
+}
+
 /// Reads from an async source and writes to a sync destination. Does not spawn
 /// a task, so writes will block.
 pub async fn copy_async_to_sync<R: AsyncRead, W: Write + ?Sized>(
@@ -262,7 +301,7 @@ pub async fn copy_async_to_sync<R: AsyncRead, W: Write + ?Sized>(
     }
 }
 
-/// `AsyncRead`` implementation backed by a `Read`. It is not actually async;
+/// `AsyncRead` implementation backed by a `Read`. It is not actually async;
 /// the goal is simply to avoid reading the full contents from the `Read` into
 /// memory.
 pub struct BlockingAsyncReader<R> {
@@ -292,8 +331,12 @@ impl<R: Read + Unpin> AsyncRead for BlockingAsyncReader<R> {
 mod platform {
     use std::convert::Infallible;
     use std::ffi::OsStr;
+    use std::fs;
+    use std::fs::File;
     use std::io;
     use std::os::unix::ffi::OsStrExt as _;
+    use std::os::unix::fs::MetadataExt as _;
+    use std::os::unix::fs::PermissionsExt;
     use std::os::unix::fs::symlink;
     use std::path::Path;
 
@@ -307,20 +350,76 @@ mod platform {
         Ok(data.as_bytes())
     }
 
-    /// Symlinks are always available on UNIX
+    /// Whether changing executable bits is permitted on the filesystem of this
+    /// directory, and whether attempting to flip one has an observable effect.
+    pub fn check_executable_bit_support(path: impl AsRef<Path>) -> io::Result<bool> {
+        // Get current permissions and try to flip just the user's executable bit.
+        let temp_file = tempfile::tempfile_in(path)?;
+        let old_mode = temp_file.metadata()?.permissions().mode();
+        let new_mode = old_mode ^ 0o100;
+        let result = temp_file.set_permissions(PermissionsExt::from_mode(new_mode));
+        match result {
+            // If permission was denied, we do not have executable bit support.
+            Err(err) if err.kind() == io::ErrorKind::PermissionDenied => Ok(false),
+            Err(err) => Err(err),
+            Ok(()) => {
+                // Verify that the permission change was not silently ignored.
+                let mode = temp_file.metadata()?.permissions().mode();
+                Ok(mode == new_mode)
+            }
+        }
+    }
+
+    /// Symlinks are always available on Unix.
     pub fn check_symlink_support() -> io::Result<bool> {
         Ok(true)
     }
 
-    pub fn try_symlink<P: AsRef<Path>, Q: AsRef<Path>>(original: P, link: Q) -> io::Result<()> {
+    /// Creates a new symlink `link` pointing to the `original` path.
+    ///
+    /// On Unix, the `original` path doesn't have to be a directory.
+    pub fn symlink_dir<P: AsRef<Path>, Q: AsRef<Path>>(original: P, link: Q) -> io::Result<()> {
         symlink(original, link)
     }
+
+    /// Creates a new symlink `link` pointing to the `original` path.
+    ///
+    /// On Unix, the `original` path doesn't have to be a file.
+    pub fn symlink_file<P: AsRef<Path>, Q: AsRef<Path>>(original: P, link: Q) -> io::Result<()> {
+        symlink(original, link)
+    }
+
+    #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
+    pub struct FileIdentity {
+        // https://github.com/BurntSushi/same-file/blob/1.0.6/src/unix.rs#L30
+        dev: u64,
+        ino: u64,
+    }
+
+    impl FileIdentity {
+        fn from_metadata(metadata: fs::Metadata) -> Self {
+            Self {
+                dev: metadata.dev(),
+                ino: metadata.ino(),
+            }
+        }
+    }
+
+    pub fn file_identity_from_symlink_path(path: &Path) -> io::Result<FileIdentity> {
+        path.symlink_metadata().map(FileIdentity::from_metadata)
+    }
+
+    pub fn file_identity_from_file(file: File) -> io::Result<FileIdentity> {
+        file.metadata().map(FileIdentity::from_metadata)
+    }
 }
 
 #[cfg(windows)]
 mod platform {
+    use std::fs::File;
     use std::io;
-    use std::os::windows::fs::symlink_file;
+    pub use std::os::windows::fs::symlink_dir;
+    pub use std::os::windows::fs::symlink_file;
     use std::path::Path;
 
     use winreg::RegKey;
@@ -332,6 +431,9 @@ mod platform {
 
     /// Symlinks may or may not be enabled on Windows. They require the
     /// Developer Mode setting, which is stored in the registry key below.
+    ///
+    /// Note: If developer mode is not enabled, the error code of symlink
+    /// creation will be 1314, `ERROR_PRIVILEGE_NOT_HELD`.
     pub fn check_symlink_support() -> io::Result<bool> {
         let hklm = RegKey::predef(HKEY_LOCAL_MACHINE);
         let sideloading =
@@ -340,14 +442,20 @@ mod platform {
         Ok(developer_mode == 1)
     }
 
-    pub fn try_symlink<P: AsRef<Path>, Q: AsRef<Path>>(original: P, link: Q) -> io::Result<()> {
-        // this will create a nonfunctional link for directories, but at the moment
-        // we don't have enough information in the tree to determine whether the
-        // symlink target is a file or a directory
-        // note: if developer mode is not enabled the error code will be 1314,
-        // ERROR_PRIVILEGE_NOT_HELD
+    pub type FileIdentity = same_file::Handle;
 
-        symlink_file(original, link)
+    // FIXME: This shouldn't follow symlinks when querying file identity.
+    // Perhaps, we need to open file with FILE_FLAG_BACKUP_SEMANTICS and
+    // FILE_FLAG_OPEN_REPARSE_POINT, then pass it to from_file(). Alternatively,
+    // maybe we can use symlink_metadata(), volume_serial_number(), and
+    // file_index() when they get stabilized. See the same-file crate and std
+    // lstat() implementation. https://github.com/rust-lang/rust/issues/63010
+    pub fn file_identity_from_symlink_path(path: &Path) -> io::Result<FileIdentity> {
+        same_file::Handle::from_path(path)
+    }
+
+    pub fn file_identity_from_file(file: File) -> io::Result<FileIdentity> {
+        same_file::Handle::from_file(file)
     }
 }
 
@@ -383,6 +491,17 @@ mod tests {
     use super::*;
     use crate::tests::new_temp_dir;
 
+    #[test]
+    #[cfg(unix)]
+    fn exec_bit_support_in_temp_dir() {
+        // Temporary directories on Unix should always have executable support.
+        // Note that it would be problematic to test in a non-temp directory, as
+        // a developer's filesystem may or may not have executable bit support.
+        let dir = new_temp_dir();
+        let supported = check_executable_bit_support(dir.path()).unwrap();
+        assert!(supported);
+    }
+
     #[test]
     fn test_path_bytes_roundtrip() {
         let bytes = b"ascii";
@@ -466,6 +585,88 @@ mod tests {
         assert!(persist_content_addressed_temp_file(temp_file, &target).is_ok());
     }
 
+    #[test]
+    fn test_file_identity_hard_link() {
+        let temp_dir = new_temp_dir();
+        let file_path = temp_dir.path().join("file");
+        let other_file_path = temp_dir.path().join("other_file");
+        let link_path = temp_dir.path().join("link");
+        fs::write(&file_path, "").unwrap();
+        fs::write(&other_file_path, "").unwrap();
+        fs::hard_link(&file_path, &link_path).unwrap();
+        assert_eq!(
+            FileIdentity::from_symlink_path(&file_path).unwrap(),
+            FileIdentity::from_symlink_path(&link_path).unwrap()
+        );
+        assert_ne!(
+            FileIdentity::from_symlink_path(&other_file_path).unwrap(),
+            FileIdentity::from_symlink_path(&link_path).unwrap()
+        );
+        assert_eq!(
+            FileIdentity::from_symlink_path(&file_path).unwrap(),
+            FileIdentity::from_file(File::open(&link_path).unwrap()).unwrap()
+        );
+    }
+
+    #[cfg(unix)]
+    #[test]
+    fn test_file_identity_unix_symlink_dir() {
+        let temp_dir = new_temp_dir();
+        let dir_path = temp_dir.path().join("dir");
+        let symlink_path = temp_dir.path().join("symlink");
+        fs::create_dir(&dir_path).unwrap();
+        std::os::unix::fs::symlink("dir", &symlink_path).unwrap();
+        // symlink should be identical to itself
+        assert_eq!(
+            FileIdentity::from_symlink_path(&symlink_path).unwrap(),
+            FileIdentity::from_symlink_path(&symlink_path).unwrap()
+        );
+        // symlink should be different from the target directory
+        assert_ne!(
+            FileIdentity::from_symlink_path(&dir_path).unwrap(),
+            FileIdentity::from_symlink_path(&symlink_path).unwrap()
+        );
+        // File::open() follows symlinks
+        assert_eq!(
+            FileIdentity::from_symlink_path(&dir_path).unwrap(),
+            FileIdentity::from_file(File::open(&symlink_path).unwrap()).unwrap()
+        );
+        assert_ne!(
+            FileIdentity::from_symlink_path(&symlink_path).unwrap(),
+            FileIdentity::from_file(File::open(&symlink_path).unwrap()).unwrap()
+        );
+    }
+
+    #[cfg(unix)]
+    #[test]
+    fn test_file_identity_unix_symlink_loop() {
+        let temp_dir = new_temp_dir();
+        let lower_file_path = temp_dir.path().join("file");
+        let upper_file_path = temp_dir.path().join("FILE");
+        let lower_symlink_path = temp_dir.path().join("symlink");
+        let upper_symlink_path = temp_dir.path().join("SYMLINK");
+        fs::write(&lower_file_path, "").unwrap();
+        std::os::unix::fs::symlink("symlink", &lower_symlink_path).unwrap();
+        let is_icase_fs = upper_file_path.try_exists().unwrap();
+        // symlink should be identical to itself
+        assert_eq!(
+            FileIdentity::from_symlink_path(&lower_symlink_path).unwrap(),
+            FileIdentity::from_symlink_path(&lower_symlink_path).unwrap()
+        );
+        assert_ne!(
+            FileIdentity::from_symlink_path(&lower_symlink_path).unwrap(),
+            FileIdentity::from_symlink_path(&lower_file_path).unwrap()
+        );
+        if is_icase_fs {
+            assert_eq!(
+                FileIdentity::from_symlink_path(&lower_symlink_path).unwrap(),
+                FileIdentity::from_symlink_path(&upper_symlink_path).unwrap()
+            );
+        } else {
+            assert!(FileIdentity::from_symlink_path(&upper_symlink_path).is_err());
+        }
+    }
+
     #[test]
     fn test_copy_async_to_sync_small() {
         let input = b"hello";
