@@ -34,7 +34,6 @@ use std::sync::MutexGuard;
 use std::time::SystemTime;
 
 use async_trait::async_trait;
-use bstr::BStr;
 use futures::stream::BoxStream;
 use gix::bstr::BString;
 use gix::objs::CommitRefIter;
@@ -97,6 +96,7 @@ const CHANGE_ID_LENGTH: usize = 16;
 const NO_GC_REF_NAMESPACE: &str = "refs/jj/keep/";
 
 pub const JJ_TREES_COMMIT_HEADER: &str = "jj:trees";
+pub const JJ_CONFLICT_LABELS_COMMIT_HEADER: &str = "jj:conflict-labels";
 pub const CHANGE_ID_COMMIT_HEADER: &str = "change-id";
 
 #[derive(Debug, Error)]
@@ -533,8 +533,31 @@ fn gix_open_opts_from_settings(settings: &UserSettings) -> gix::open::Options {
         .strict_config(true)
 }
 
-/// Parses the `jj:trees` header value.
-fn root_tree_from_git_extra_header(value: &BStr) -> Result<Merge<TreeId>, ()> {
+/// Parses the `jj:conflict-labels` header value if present.
+fn extract_conflict_labels_from_commit(commit: &gix::objs::CommitRef) -> Merge<String> {
+    let Some(value) = commit
+        .extra_headers()
+        .find(JJ_CONFLICT_LABELS_COMMIT_HEADER)
+    else {
+        return Merge::resolved(String::new());
+    };
+
+    str::from_utf8(value)
+        .expect("labels should be valid utf8")
+        .split_terminator('\n')
+        .map(str::to_owned)
+        .collect::<MergeBuilder<_>>()
+        .build()
+}
+
+/// Parses the `jj:trees` header value if present, otherwise returns the
+/// resolved tree ID from Git.
+fn extract_root_tree_from_commit(commit: &gix::objs::CommitRef) -> Result<Merge<TreeId>, ()> {
+    let Some(value) = commit.extra_headers().find(JJ_TREES_COMMIT_HEADER) else {
+        let tree_id = TreeId::from_bytes(commit.tree().as_bytes());
+        return Ok(Merge::resolved(tree_id));
+    };
+
     let mut tree_ids = SmallVec::new();
     for hex in value.split(|b| *b == b' ') {
         let tree_id = TreeId::try_from_hex(hex).ok_or(())?;
@@ -557,6 +580,7 @@ fn commit_from_git_without_root_parent(
     git_object: &gix::Object,
     is_shallow: bool,
 ) -> BackendResult<Commit> {
+    let decode_err = |err: gix::objs::decode::Error| to_read_object_err(err, id);
     let commit = git_object
         .try_to_commit_ref()
         .map_err(|err| to_read_object_err(err, id))?;
@@ -577,26 +601,21 @@ fn commit_from_git_without_root_parent(
             .map(|oid| CommitId::from_bytes(oid.as_bytes()))
             .collect_vec()
     };
+    // If the commit is a conflict, the conflict labels are stored in a commit
+    // header separately from the trees.
+    let conflict_labels = extract_conflict_labels_from_commit(&commit);
     // Conflicted commits written before we started using the `jj:trees` header
     // (~March 2024) may have the root trees stored in the extra metadata table
     // instead. For such commits, we'll update the root tree later when we read the
     // extra metadata.
-    let root_tree = commit
-        .extra_headers()
-        .find(JJ_TREES_COMMIT_HEADER)
-        .map(root_tree_from_git_extra_header)
-        .transpose()
-        .map_err(|()| to_read_object_err("Invalid jj:trees header", id))?
-        .unwrap_or_else(|| {
-            let tree_id = TreeId::from_bytes(commit.tree().as_bytes());
-            Merge::resolved(tree_id)
-        });
+    let root_tree = extract_root_tree_from_commit(&commit)
+        .map_err(|()| to_read_object_err("Invalid jj:trees header", id))?;
     // Use lossy conversion as commit message with "mojibake" is still better than
     // nothing.
     // TODO: what should we do with commit.encoding?
     let description = String::from_utf8_lossy(commit.message).into_owned();
-    let author = signature_from_git(commit.author());
-    let committer = signature_from_git(commit.committer());
+    let author = signature_from_git(commit.author().map_err(decode_err)?);
+    let committer = signature_from_git(commit.committer().map_err(decode_err)?);
 
     // If the commit is signed, extract both the signature and the signed data
     // (which is the commit buffer with the gpgsig header omitted).
@@ -611,7 +630,7 @@ fn commit_from_git_without_root_parent(
         .any(|(k, _)| *k == "gpgsig" || *k == "gpgsig-sha256")
         .then(|| CommitRefIter::signature(&git_object.data))
         .transpose()
-        .map_err(|err| to_read_object_err(err, id))?
+        .map_err(decode_err)?
         .flatten()
         .map(|(sig, data)| SecureSig {
             data: data.to_bstring().into(),
@@ -623,6 +642,7 @@ fn commit_from_git_without_root_parent(
         predecessors: vec![],
         // If this commit has associated extra metadata, we may reset this later.
         root_tree,
+        conflict_labels,
         change_id,
         description,
         author,
@@ -1249,6 +1269,21 @@ impl Backend for GitBackend {
             }
         }
         let mut extra_headers: Vec<(BString, BString)> = vec![];
+        if !contents.conflict_labels.is_resolved() {
+            // Labels cannot contain '\n' since we use it as a separator in the header.
+            assert!(
+                contents
+                    .conflict_labels
+                    .iter()
+                    .all(|label| !label.contains('\n'))
+            );
+            let mut joined_with_newlines = contents.conflict_labels.iter().join("\n");
+            joined_with_newlines.push('\n');
+            extra_headers.push((
+                JJ_CONFLICT_LABELS_COMMIT_HEADER.into(),
+                joined_with_newlines.into(),
+            ));
+        }
         if !tree_ids.is_resolved() {
             let value = tree_ids.iter().map(|id| id.hex()).join(" ");
             extra_headers.push((JJ_TREES_COMMIT_HEADER.into(), value.into()));
@@ -1426,10 +1461,16 @@ impl Backend for GitBackend {
             .map_err(|err| BackendError::Other(err.into()))?
             .filter(|id| *id != self.root_commit_id);
         recreate_no_gc_refs(&git_repo, new_heads, keep_newer)?;
+
+        // No locking is needed since we aren't going to add new "commits".
+        let table = self.cached_extra_metadata_table()?;
         // TODO: remove unreachable entries from extras table if segment file
         // mtime <= keep_newer? (it won't be consistent with no-gc refs
         // preserved by the keep_newer timestamp though)
-        // TODO: remove unreachable extras table segments
+        self.extra_metadata_store
+            .gc(&table, keep_newer)
+            .map_err(|err| BackendError::Other(err.into()))?;
+
         run_git_gc(
             self.git_executable.as_ref(),
             self.git_repo_path(),
@@ -1898,6 +1939,7 @@ mod tests {
             parents: vec![backend.root_commit_id().clone()],
             predecessors: vec![],
             root_tree: Merge::resolved(backend.empty_tree_id().clone()),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: original_change_id.clone(),
             description: "initial".to_string(),
             author: create_signature(),
@@ -1989,6 +2031,7 @@ mod tests {
             parents: vec![],
             predecessors: vec![],
             root_tree: Merge::resolved(backend.empty_tree_id().clone()),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: ChangeId::from_hex("abc123"),
             description: "".to_string(),
             author: create_signature(),
@@ -2075,6 +2118,7 @@ mod tests {
             parents: vec![backend.root_commit_id().clone()],
             predecessors: vec![],
             root_tree: root_tree.clone(),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: ChangeId::from_hex("abc123"),
             description: "".to_string(),
             author: create_signature(),
@@ -2175,6 +2219,7 @@ mod tests {
             parents: vec![backend.root_commit_id().clone()],
             predecessors: vec![],
             root_tree: Merge::resolved(backend.empty_tree_id().clone()),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: ChangeId::new(vec![42; 16]),
             description: "initial".to_string(),
             author: signature.clone(),
@@ -2255,6 +2300,7 @@ mod tests {
             parents: vec![backend.root_commit_id().clone()],
             predecessors: vec![],
             root_tree: Merge::resolved(backend.empty_tree_id().clone()),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: ChangeId::from_hex("7f0a7ce70354b22efcccf7bf144017c4"),
             description: "initial".to_string(),
             author: create_signature(),
@@ -2297,6 +2343,7 @@ mod tests {
             parents: vec![backend.root_commit_id().clone()],
             predecessors: vec![],
             root_tree: Merge::resolved(backend.empty_tree_id().clone()),
+            conflict_labels: Merge::resolved(String::new()),
             change_id: ChangeId::new(vec![42; 16]),
             description: "initial".to_string(),
             author: create_signature(),
