@@ -26,6 +26,7 @@ use crate::backend::ChangeId;
 use crate::backend::CommitId;
 use crate::hex_util;
 use crate::index::IndexResult;
+use crate::index::ResolvedChangeTargets;
 use crate::object_id::HexPrefix;
 use crate::object_id::ObjectId;
 use crate::object_id::PrefixResolution;
@@ -221,7 +222,7 @@ impl IdPrefixIndex<'_> {
         &self,
         repo: &dyn Repo,
         prefix: &HexPrefix,
-    ) -> IndexResult<PrefixResolution<Vec<CommitId>>> {
+    ) -> IndexResult<PrefixResolution<ResolvedChangeTargets>> {
         if let Some(indexes) = self.indexes {
             let resolution = indexes
                 .change_index
