@@ -59,6 +59,7 @@ impl Iterator for BackoffIterator {
 #[cfg_attr(all(unix, not(test)), expect(dead_code))]
 impl FileLock {
     pub fn lock(path: PathBuf) -> Result<Self, FileLockError> {
+        tracing::info!("Attempting to lock {path:?}");
         let mut options = OpenOptions::new();
         options.create_new(true);
         options.write(true);
@@ -66,6 +67,7 @@ impl FileLock {
         loop {
             match options.open(&path) {
                 Ok(file) => {
+                    tracing::info!("Locked {path:?}");
                     return Ok(Self { path, _file: file });
                 }
                 Err(err)
