@@ -29,6 +29,7 @@ pub struct FileLock {
 
 impl FileLock {
     pub fn lock(path: PathBuf) -> Result<Self, FileLockError> {
+        tracing::info!("Attempting to lock {path:?}");
         loop {
             // Create lockfile, or open pre-existing one
             let file = File::create(&path).map_err(|err| FileLockError {
@@ -72,6 +73,7 @@ impl FileLock {
                 }
             }
 
+            tracing::info!("Locked {path:?}");
             return Ok(Self { path, file });
         }
     }
@@ -81,10 +83,10 @@ impl Drop for FileLock {
     #[instrument(skip_all)]
     fn drop(&mut self) {
         // Removing the file isn't strictly necessary, but reduces confusion.
-        _ = std::fs::remove_file(&self.path);
+        std::fs::remove_file(&self.path).ok();
         // Unblock any processes that tried to acquire the lock while we held it.
         // They're responsible for creating and locking a new lockfile, since we
         // just deleted this one.
-        _ = rustix::fs::flock(&self.file, FlockOperation::Unlock);
+        rustix::fs::flock(&self.file, FlockOperation::Unlock).ok();
     }
 }
