@@ -14,11 +14,8 @@
 
 #![expect(missing_docs)]
 
-use std::collections::HashMap;
 use std::collections::HashSet;
-use std::fmt;
 use std::fmt::Debug;
-use std::iter;
 
 use globset::Glob;
 use itertools::Itertools as _;
@@ -26,6 +23,7 @@ use tracing::instrument;
 
 use crate::repo_path::RepoPath;
 use crate::repo_path::RepoPathComponentBuf;
+use crate::repo_path::RepoPathTree;
 
 #[derive(PartialEq, Eq, Debug)]
 pub enum Visit {
@@ -140,7 +138,7 @@ impl FilesMatcher {
     pub fn new(files: impl IntoIterator<Item = impl AsRef<RepoPath>>) -> Self {
         let mut tree = RepoPathTree::default();
         for f in files {
-            tree.add(f.as_ref()).value = FilesNodeKind::File;
+            tree.add(f.as_ref()).set_value(FilesNodeKind::File);
         }
         Self { tree }
     }
@@ -150,7 +148,7 @@ impl Matcher for FilesMatcher {
     fn matches(&self, file: &RepoPath) -> bool {
         self.tree
             .get(file)
-            .is_some_and(|sub| sub.value == FilesNodeKind::File)
+            .is_some_and(|sub| *sub.value() == FilesNodeKind::File)
     }
 
     fn visit(&self, dir: &RepoPath) -> Visit {
@@ -172,13 +170,13 @@ enum FilesNodeKind {
 fn files_tree_to_visit_sets(tree: &RepoPathTree<FilesNodeKind>) -> Visit {
     let mut dirs = HashSet::new();
     let mut files = HashSet::new();
-    for (name, sub) in &tree.entries {
+    for (name, sub) in tree.children() {
         // should visit only intermediate directories
-        if !sub.entries.is_empty() {
-            dirs.insert(name.clone());
+        if sub.has_children() {
+            dirs.insert(name.to_owned());
         }
-        if sub.value == FilesNodeKind::File {
-            files.insert(name.clone());
+        if *sub.value() == FilesNodeKind::File {
+            files.insert(name.to_owned());
         }
     }
     Visit::sets(dirs, files)
@@ -194,7 +192,7 @@ impl PrefixMatcher {
     pub fn new(prefixes: impl IntoIterator<Item = impl AsRef<RepoPath>>) -> Self {
         let mut tree = RepoPathTree::default();
         for prefix in prefixes {
-            tree.add(prefix.as_ref()).value = PrefixNodeKind::Prefix;
+            tree.add(prefix.as_ref()).set_value(PrefixNodeKind::Prefix);
         }
         Self { tree }
     }
@@ -204,13 +202,13 @@ impl Matcher for PrefixMatcher {
     fn matches(&self, file: &RepoPath) -> bool {
         self.tree
             .walk_to(file)
-            .any(|(sub, _)| sub.value == PrefixNodeKind::Prefix)
+            .any(|(sub, _)| *sub.value() == PrefixNodeKind::Prefix)
     }
 
     fn visit(&self, dir: &RepoPath) -> Visit {
         for (sub, tail_path) in self.tree.walk_to(dir) {
             // ancestor of 'dir' matches prefix paths
-            if sub.value == PrefixNodeKind::Prefix {
+            if *sub.value() == PrefixNodeKind::Prefix {
                 return Visit::AllRecursively;
             }
             // 'dir' found, and is an ancestor of prefix paths
@@ -234,11 +232,11 @@ enum PrefixNodeKind {
 fn prefix_tree_to_visit_sets(tree: &RepoPathTree<PrefixNodeKind>) -> Visit {
     let mut dirs = HashSet::new();
     let mut files = HashSet::new();
-    for (name, sub) in &tree.entries {
+    for (name, sub) in tree.children() {
         // should visit both intermediate and prefix directories
-        dirs.insert(name.clone());
-        if sub.value == PrefixNodeKind::Prefix {
-            files.insert(name.clone());
+        dirs.insert(name.to_owned());
+        if *sub.value() == PrefixNodeKind::Prefix {
+            files.insert(name.to_owned());
         }
     }
     Visit::sets(dirs, files)
@@ -269,7 +267,7 @@ impl Matcher for GlobsMatcher {
             .take_while(|(_, tail_path)| !tail_path.is_root()) // only dirs
             .any(|(sub, tail_path)| {
                 let tail = tail_path.as_internal_file_string().as_bytes();
-                sub.value.as_ref().is_some_and(|pat| pat.is_match(tail))
+                sub.value().as_ref().is_some_and(|pat| pat.is_match(tail))
             })
     }
 
@@ -277,7 +275,7 @@ impl Matcher for GlobsMatcher {
         let mut max_visit = Visit::Nothing;
         for (sub, tail_path) in self.tree.walk_to(dir) {
             // ancestor of 'dir' has patterns
-            if let Some(pat) = &sub.value {
+            if let Some(pat) = &sub.value() {
                 let tail = tail_path.as_internal_file_string().as_bytes();
                 if self.matches_prefix_paths && pat.is_match(tail) {
                     // 'dir' matches prefix patterns
@@ -291,7 +289,7 @@ impl Matcher for GlobsMatcher {
             }
             // 'dir' found, and is an ancestor of pattern paths
             if tail_path.is_root() && max_visit == Visit::Nothing {
-                let sub_dirs = sub.entries.keys().cloned().collect();
+                let sub_dirs = sub.children().map(|(name, _)| name.to_owned()).collect();
                 return Visit::sets(sub_dirs, HashSet::new());
             }
         }
@@ -349,8 +347,8 @@ impl<'a> GlobsMatcherBuilder<'a> {
                 .build()
                 .expect("glob regex should be valid");
             let sub = tree.add(dir);
-            assert!(sub.value.is_none());
-            sub.value = Some(regex);
+            assert!(sub.value().is_none());
+            sub.set_value(Some(regex));
         }
 
         GlobsMatcher {
@@ -523,60 +521,6 @@ impl<M1: Matcher, M2: Matcher> Matcher for IntersectionMatcher<M1, M2> {
     }
 }
 
-/// Tree that maps `RepoPath` to value of type `V`.
-#[derive(Clone, Default, Eq, PartialEq)]
-struct RepoPathTree<V> {
-    entries: HashMap<RepoPathComponentBuf, Self>,
-    value: V,
-}
-
-impl<V> RepoPathTree<V> {
-    fn add(&mut self, dir: &RepoPath) -> &mut Self
-    where
-        V: Default,
-    {
-        dir.components().fold(self, |sub, name| {
-            // Avoid name.clone() if entry already exists.
-            if !sub.entries.contains_key(name) {
-                sub.entries.insert(name.to_owned(), Self::default());
-            }
-            sub.entries.get_mut(name).unwrap()
-        })
-    }
-
-    fn get(&self, dir: &RepoPath) -> Option<&Self> {
-        dir.components()
-            .try_fold(self, |sub, name| sub.entries.get(name))
-    }
-
-    /// Walks the tree from the root to the given `dir`, yielding each sub tree
-    /// and remaining path.
-    fn walk_to<'a, 'b>(
-        &'a self,
-        dir: &'b RepoPath,
-    ) -> impl Iterator<Item = (&'a Self, &'b RepoPath)> {
-        iter::successors(Some((self, dir)), |(sub, dir)| {
-            let mut components = dir.components();
-            let name = components.next()?;
-            Some((sub.entries.get(name)?, components.as_path()))
-        })
-    }
-}
-
-impl<V: Debug> Debug for RepoPathTree<V> {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        self.value.fmt(f)?;
-        f.write_str(" ")?;
-        f.debug_map()
-            .entries(
-                self.entries
-                    .iter()
-                    .sorted_unstable_by_key(|&(name, _)| name),
-            )
-            .finish()
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use maplit::hashset;
