@@ -20,21 +20,24 @@ use std::collections::HashMap;
 use std::fmt::Debug;
 use std::fmt::Formatter;
 use std::fmt::Write as _;
-use std::future::Future;
 use std::hash::Hash;
+use std::iter;
 use std::iter::zip;
+use std::ops::Deref;
 use std::slice;
 use std::sync::Arc;
 
 use futures::future::try_join_all;
 use itertools::Itertools as _;
 use smallvec::SmallVec;
+use smallvec::smallvec;
 use smallvec::smallvec_inline;
 
 use crate::backend::BackendResult;
 use crate::backend::CopyId;
 use crate::backend::FileId;
 use crate::backend::TreeValue;
+use crate::conflict_labels::ConflictLabels;
 use crate::content_hash::ContentHash;
 use crate::content_hash::DigestUpdate;
 use crate::repo_path::RepoPath;
@@ -68,6 +71,22 @@ impl<T> Diff<T> {
         }
     }
 
+    /// Combine a `Diff<T>` and a `Diff<U>` into a `Diff<(T, U)>`.
+    pub fn zip<U>(self, other: Diff<U>) -> Diff<(T, U)> {
+        Diff {
+            before: (self.before, other.before),
+            after: (self.after, other.after),
+        }
+    }
+
+    /// Inverts a diff, swapping the before and after terms.
+    pub fn invert(self) -> Self {
+        Self {
+            before: self.after,
+            after: self.before,
+        }
+    }
+
     /// Convert a `&Diff<T>` into a `Diff<&T>`.
     pub fn as_ref(&self) -> Diff<&T> {
         Diff {
@@ -76,6 +95,15 @@ impl<T> Diff<T> {
         }
     }
 
+    /// Converts a `Diff<T>` or `&Diff<T>` to `Diff<&T::Target>`. (e.g.
+    /// `Diff<String>` to `Diff<&str>`)
+    pub fn as_deref(&self) -> Diff<&T::Target>
+    where
+        T: Deref,
+    {
+        self.as_ref().map(Deref::deref)
+    }
+
     /// Convert a diff into an array `[before, after]`.
     pub fn into_array(self) -> [T; 2] {
         [self.before, self.after]
@@ -209,6 +237,15 @@ impl<T> Merge<T> {
         Self { values }
     }
 
+    /// Creates a `Merge` from a first side and a series of diffs to apply to
+    /// that side.
+    pub fn from_diffs(first_side: T, diffs: impl IntoIterator<Item = Diff<T>>) -> Self {
+        let values = iter::once(first_side)
+            .chain(diffs.into_iter().flat_map(Diff::into_array))
+            .collect();
+        Self { values }
+    }
+
     /// Creates a `Merge` with a single resolved value.
     pub const fn resolved(value: T) -> Self {
         Self {
@@ -216,6 +253,16 @@ impl<T> Merge<T> {
         }
     }
 
+    /// Creates a `Merge` by repeating a single value.
+    pub fn repeated(value: T, num_sides: usize) -> Self
+    where
+        T: Clone,
+    {
+        Self {
+            values: smallvec![value; num_sides * 2 - 1],
+        }
+    }
+
     /// Create a `Merge` from a `removes` and `adds`, padding with `None` to
     /// make sure that there is exactly one more `adds` than `removes`.
     pub fn from_legacy_form(
@@ -334,6 +381,20 @@ impl<T> Merge<T> {
         simplified_to_original_indices
     }
 
+    /// Apply the mapping returned by [`Self::get_simplified_mapping`].
+    #[must_use]
+    fn apply_simplified_mapping(&self, mapping: &[usize]) -> Self
+    where
+        T: Clone,
+    {
+        // Reorder values based on their new indices in the simplified merge.
+        let values = mapping
+            .iter()
+            .map(|index| self.values[*index].clone())
+            .collect();
+        Self { values }
+    }
+
     /// Simplify the merge by joining diffs like A->B and B->C into A->C.
     /// Also drops trivial diffs like A->A.
     #[must_use]
@@ -342,12 +403,18 @@ impl<T> Merge<T> {
         T: PartialEq + Clone,
     {
         let mapping = self.get_simplified_mapping();
-        // Reorder values based on their new indices in the simplified merge.
-        let values = mapping
-            .iter()
-            .map(|index| self.values[*index].clone())
-            .collect();
-        Self { values }
+        self.apply_simplified_mapping(&mapping)
+    }
+
+    /// Simplify the merge, using a function to choose which values to compare.
+    #[must_use]
+    pub fn simplify_by<'a, U>(&'a self, f: impl FnMut(&'a T) -> U) -> Self
+    where
+        T: Clone,
+        U: PartialEq,
+    {
+        let mapping = self.map(f).get_simplified_mapping();
+        self.apply_simplified_mapping(&mapping)
     }
 
     /// Updates the merge based on the given simplified merge.
@@ -410,7 +477,7 @@ impl<T> Merge<T> {
     }
 
     /// Creates a new merge by applying `f` to each remove and add, returning
-    /// `Err if `f` returns `Err` for any of them.
+    /// `Err` if `f` returns `Err` for any of them.
     pub fn try_map<'a, U, E>(
         &'a self,
         f: impl FnMut(&'a T) -> Result<U, E>,
@@ -420,7 +487,7 @@ impl<T> Merge<T> {
     }
 
     /// Creates a new merge by applying the async function `f` to each remove
-    /// and add, running them concurrently, and returning `Err if `f`
+    /// and add, running them concurrently, and returning `Err` if `f`
     /// returns `Err` for any of them.
     pub async fn try_map_async<'a, F, U, E>(
         &'a self,
@@ -434,6 +501,38 @@ impl<T> Merge<T> {
             values: values.into(),
         })
     }
+
+    /// Converts a `&Merge<T>` into a `Merge<&T>`.
+    pub fn as_ref(&self) -> Merge<&T> {
+        let values = self.values.iter().collect();
+        Merge { values }
+    }
+
+    /// Zip two merges which have the same number of terms. Panics if the merges
+    /// don't have the same number of terms.
+    pub fn zip<U>(self, other: Merge<U>) -> Merge<(T, U)> {
+        assert_eq!(self.values.len(), other.values.len());
+        let values = self.values.into_iter().zip(other.values).collect();
+        Merge { values }
+    }
+}
+
+impl<T, U> Merge<(T, U)> {
+    /// Unzips a merge of pairs into a pair of merges.
+    pub fn unzip(self) -> (Merge<T>, Merge<U>) {
+        let (left, right) = self.values.into_iter().unzip();
+        (Merge { values: left }, Merge { values: right })
+    }
+}
+
+impl<T> Merge<&'_ T> {
+    /// Convert a `Merge<&T>` into a `Merge<T>` by cloning each term.
+    pub fn cloned(&self) -> Merge<T>
+    where
+        T: Clone,
+    {
+        self.map(|&term| term.clone())
+    }
 }
 
 /// Helper for consuming items from an iterator and then creating a `Merge`.
@@ -474,6 +573,24 @@ impl<T> IntoIterator for Merge<T> {
     }
 }
 
+impl<'a, T> IntoIterator for &'a Merge<T> {
+    type Item = &'a T;
+    type IntoIter = slice::Iter<'a, T>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.iter()
+    }
+}
+
+impl<'a, T> IntoIterator for &'a mut Merge<T> {
+    type Item = &'a mut T;
+    type IntoIter = slice::IterMut<'a, T>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.iter_mut()
+    }
+}
+
 impl<T> FromIterator<T> for MergeBuilder<T> {
     fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
         let mut builder = Self::default();
@@ -699,7 +816,7 @@ where
     /// `FileId` values may differ.
     pub fn with_new_file_ids(&self, file_ids: &Merge<Option<FileId>>) -> Merge<Option<TreeValue>> {
         assert_eq!(self.values.len(), file_ids.values.len());
-        let values = zip(self.iter(), file_ids.iter().cloned())
+        let values = zip(self, file_ids.iter().cloned())
             .map(
                 |(tree_value, file_id)| match (borrow_tree_value(tree_value.as_ref()), file_id) {
                     (
@@ -715,6 +832,14 @@ where
                         copy_id: copy_id.clone(),
                     }),
                     (None, None) => None,
+                    // New files are populated to preserve the materialized conflict. The file won't
+                    // be checked out to the disk. So the metadata is not important, and we will
+                    // just use the default values.
+                    (None, Some(id)) => Some(TreeValue::File {
+                        id,
+                        executable: false,
+                        copy_id: CopyId::placeholder(),
+                    }),
                     (old, new) => panic!("incompatible update: {old:?} to {new:?}"),
                 },
             )
@@ -723,14 +848,30 @@ where
     }
 
     /// Give a summary description of the conflict's "removes" and "adds"
-    pub fn describe(&self) -> String {
+    pub fn describe(&self, labels: &ConflictLabels) -> String {
         let mut buf = String::new();
         writeln!(buf, "Conflict:").unwrap();
-        for term in self.removes().flatten() {
-            writeln!(buf, "  Removing {}", describe_conflict_term(term.borrow())).unwrap();
+        for (term, label) in self
+            .removes()
+            .enumerate()
+            .filter_map(|(i, term)| term.as_ref().map(|term| (term, labels.get_remove(i))))
+        {
+            write!(buf, "  Removing {}", describe_conflict_term(term.borrow())).unwrap();
+            if let Some(label) = label {
+                write!(buf, " ({label})").unwrap();
+            }
+            buf.push('\n');
         }
-        for term in self.adds().flatten() {
-            writeln!(buf, "  Adding {}", describe_conflict_term(term.borrow())).unwrap();
+        for (term, label) in self
+            .adds()
+            .enumerate()
+            .filter_map(|(i, term)| term.as_ref().map(|term| (term, labels.get_add(i))))
+        {
+            write!(buf, "  Adding {}", describe_conflict_term(term.borrow())).unwrap();
+            if let Some(label) = label {
+                write!(buf, " ({label})").unwrap();
+            }
+            buf.push('\n');
         }
         buf
     }
@@ -851,6 +992,50 @@ mod tests {
 
     use super::*;
 
+    #[test]
+    fn test_diff_map() {
+        let diff = Diff::new(1, 2);
+        assert_eq!(diff.map(|x| x + 2), Diff::new(3, 4));
+    }
+
+    #[test]
+    fn test_diff_zip() {
+        let diff1 = Diff::new(1, 2);
+        let diff2 = Diff::new(3, 4);
+        assert_eq!(diff1.zip(diff2), Diff::new((1, 3), (2, 4)));
+    }
+
+    #[test]
+    fn test_diff_invert() {
+        let diff = Diff::new(1, 2);
+        assert_eq!(diff.invert(), Diff::new(2, 1));
+    }
+
+    #[test]
+    fn test_diff_as_ref() {
+        let diff = Diff::new(1, 2);
+        assert_eq!(diff.as_ref(), Diff::new(&1, &2));
+    }
+
+    #[test]
+    fn test_diff_into_array() {
+        let diff = Diff::new(1, 2);
+        assert_eq!(diff.into_array(), [1, 2]);
+    }
+
+    #[test]
+    fn test_merge_from_diffs() {
+        assert_eq!(Merge::from_diffs(1, []), Merge::resolved(1));
+        assert_eq!(
+            Merge::from_diffs(1, [Diff::new(2, 3)]),
+            Merge::from_vec(vec![1, 2, 3])
+        );
+        assert_eq!(
+            Merge::from_diffs(1, [Diff::new(2, 3), Diff::new(4, 5)]),
+            Merge::from_vec(vec![1, 2, 3, 4, 5])
+        );
+    }
+
     fn c<T: Clone>(terms: &[T]) -> Merge<T> {
         Merge::from_vec(terms.to_vec())
     }
@@ -1139,6 +1324,46 @@ mod tests {
         assert_eq!(c(&[0, 1, 2, 3, 4, 5, 1]).simplify(), c(&[0, 3, 4, 5, 2]));
     }
 
+    #[test]
+    fn test_simplify_by() {
+        fn enumerate_and_simplify_by(merge: Merge<i32>) -> Merge<(usize, i32)> {
+            let enumerated = Merge::from_vec(merge.iter().copied().enumerate().collect_vec());
+            enumerated.simplify_by(|&(_index, value)| value)
+        }
+
+        // 1-way merge
+        assert_eq!(enumerate_and_simplify_by(c(&[0])), c(&[(0, 0)]));
+        // 3-way merge
+        assert_eq!(enumerate_and_simplify_by(c(&[1, 0, 0])), c(&[(0, 1)]));
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[1, 0, 2])),
+            c(&[(0, 1), (1, 0), (2, 2)])
+        );
+        // 5-way merge
+        assert_eq!(enumerate_and_simplify_by(c(&[0, 0, 0, 0, 0])), c(&[(4, 0)]));
+        assert_eq!(enumerate_and_simplify_by(c(&[0, 0, 0, 0, 1])), c(&[(4, 1)]));
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[0, 0, 0, 1, 2])),
+            c(&[(2, 0), (3, 1), (4, 2)])
+        );
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[0, 1, 2, 2, 0])),
+            c(&[(0, 0), (1, 1), (4, 0)])
+        );
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[0, 1, 2, 2, 2])),
+            c(&[(0, 0), (1, 1), (4, 2)])
+        );
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[0, 1, 2, 2, 3])),
+            c(&[(0, 0), (1, 1), (4, 3)])
+        );
+        assert_eq!(
+            enumerate_and_simplify_by(c(&[0, 1, 2, 3, 4])),
+            c(&[(0, 0), (1, 1), (2, 2), (3, 3), (4, 4)])
+        );
+    }
+
     #[test]
     fn test_update_from_simplified() {
         // 1-way merge
@@ -1293,7 +1518,7 @@ mod tests {
     fn test_try_map() {
         fn sqrt(i: &i32) -> Result<i32, ()> {
             if *i >= 0 {
-                Ok((*i as f64).sqrt() as i32)
+                Ok(f64::from(*i).sqrt() as i32)
             } else {
                 Err(())
             }
@@ -1321,4 +1546,26 @@ mod tests {
             c(&[0, 1, 2, 5, 4, 3, 6, 7, 8])
         );
     }
+
+    #[test]
+    fn test_zip() {
+        // Zip of 1-way merges
+        assert_eq!(c(&[1]).zip(c(&[2])), c(&[(1, 2)]));
+        // Zip of 3-way merges
+        assert_eq!(
+            c(&[1, 2, 3]).zip(c(&[4, 5, 6])),
+            c(&[(1, 4), (2, 5), (3, 6)])
+        );
+    }
+
+    #[test]
+    fn test_unzip() {
+        // 1-way merge
+        assert_eq!(c(&[(1, 2)]).unzip(), (c(&[1]), c(&[2])));
+        // 3-way merge
+        assert_eq!(
+            c(&[(1, 4), (2, 5), (3, 6)]).unzip(),
+            (c(&[1, 2, 3]), c(&[4, 5, 6]))
+        );
+    }
 }
