@@ -38,6 +38,7 @@ use pollster::FutureExt as _;
 use crate::backend::BackendResult;
 use crate::backend::TreeId;
 use crate::backend::TreeValue;
+use crate::conflict_labels::ConflictLabels;
 use crate::copies::CopiesTreeDiffEntry;
 use crate::copies::CopiesTreeDiffStream;
 use crate::copies::CopyRecords;
@@ -56,19 +57,20 @@ use crate::tree::Tree;
 use crate::tree_builder::TreeBuilder;
 use crate::tree_merge::merge_trees;
 
-/// Presents a view of a merged set of trees at the root directory. In the
-/// future, this may store additional metadata like conflict labels, so tree IDs
-/// should be compared instead when checking for file changes.
+/// Presents a view of a merged set of trees at the root directory, as well as
+/// conflict labels.
 #[derive(Clone)]
 pub struct MergedTree {
     store: Arc<Store>,
     tree_ids: Merge<TreeId>,
+    labels: ConflictLabels,
 }
 
 impl fmt::Debug for MergedTree {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_struct("MergedTree")
             .field("tree_ids", &self.tree_ids)
+            .field("labels", &self.labels)
             .finish_non_exhaustive()
     }
 }
@@ -76,12 +78,23 @@ impl fmt::Debug for MergedTree {
 impl MergedTree {
     /// Creates a `MergedTree` with the given resolved tree ID.
     pub fn resolved(store: Arc<Store>, tree_id: TreeId) -> Self {
-        Self::new(store, Merge::resolved(tree_id))
+        Self {
+            store,
+            tree_ids: Merge::resolved(tree_id),
+            labels: ConflictLabels::unlabeled(),
+        }
     }
 
     /// Creates a `MergedTree` with the given tree IDs.
-    pub fn new(store: Arc<Store>, tree_ids: Merge<TreeId>) -> Self {
-        Self { store, tree_ids }
+    pub fn new(store: Arc<Store>, tree_ids: Merge<TreeId>, labels: ConflictLabels) -> Self {
+        if let Some(num_sides) = labels.num_sides() {
+            assert_eq!(tree_ids.num_sides(), num_sides);
+        }
+        Self {
+            store,
+            tree_ids,
+            labels,
+        }
     }
 
     /// The `Store` associated with this tree.
@@ -95,23 +108,59 @@ impl MergedTree {
         &self.tree_ids
     }
 
-    /// Extracts the underlying tree IDs for this `MergedTree`.
+    /// Extracts the underlying tree IDs for this `MergedTree`, discarding any
+    /// conflict labels.
     pub fn into_tree_ids(self) -> Merge<TreeId> {
         self.tree_ids
     }
 
-    /// Reads the merge of tree objects represented by this `MergedTree`.
-    pub fn trees(&self) -> BackendResult<Merge<Tree>> {
-        self.trees_async().block_on()
+    /// Returns this merge's conflict labels, if any.
+    pub fn labels(&self) -> &ConflictLabels {
+        &self.labels
     }
 
-    /// Async version of `trees()`.
-    pub async fn trees_async(&self) -> BackendResult<Merge<Tree>> {
+    /// Returns both the underlying tree IDs and any conflict labels. This can
+    /// be used to check whether there are changes in files to be materialized
+    /// in the working copy.
+    pub fn tree_ids_and_labels(&self) -> (&Merge<TreeId>, &ConflictLabels) {
+        (&self.tree_ids, &self.labels)
+    }
+
+    /// Extracts the underlying tree IDs and conflict labels.
+    pub fn into_tree_ids_and_labels(self) -> (Merge<TreeId>, ConflictLabels) {
+        (self.tree_ids, self.labels)
+    }
+
+    /// Reads the merge of tree objects represented by this `MergedTree`.
+    pub async fn trees(&self) -> BackendResult<Merge<Tree>> {
         self.tree_ids
             .try_map_async(|id| self.store.get_tree_async(RepoPathBuf::root(), id))
             .await
     }
 
+    /// Returns a label for each term in a merge. Resolved merges use the
+    /// provided label, while conflicted merges keep their original labels.
+    /// Missing labels are indicated by empty strings.
+    pub fn labels_by_term<'a>(&'a self, label: &'a str) -> Merge<&'a str> {
+        if self.tree_ids.is_resolved() {
+            assert!(!self.labels.has_labels());
+            Merge::resolved(label)
+        } else if self.labels.has_labels() {
+            // If the merge is conflicted and it already has labels, then we want to use
+            // those labels instead of the provided label. This ensures that rebasing
+            // conflicted commits keeps meaningful labels.
+            let labels = self.labels.as_merge();
+            assert_eq!(labels.num_sides(), self.tree_ids.num_sides());
+            labels.map(|label| label.as_str())
+        } else {
+            // If the merge is conflicted but it doesn't have labels (e.g. conflicts created
+            // before labels were added), then we use empty strings to indicate missing
+            // labels. We could consider using `label` for all the sides instead, but it
+            // might be confusing.
+            Merge::repeated("", self.tree_ids.num_sides())
+        }
+    }
+
     /// Tries to resolve any conflicts, resolving any conflicts that can be
     /// automatically resolved and leaving the rest unresolved.
     pub async fn resolve(self) -> BackendResult<Self> {
@@ -120,26 +169,41 @@ impl MergedTree {
         // a resolved merge. However, that function will always preserve the arity of
         // conflicts it cannot resolve. So we simplify the conflict again
         // here to possibly reduce a complex conflict to a simpler one.
-        let simplified = merged.simplify();
+        let (simplified_labels, simplified) = if merged.is_resolved() {
+            (ConflictLabels::unlabeled(), merged)
+        } else {
+            self.labels.simplify_with(&merged)
+        };
         // If debug assertions are enabled, check that the merge was idempotent. In
-        // particular,  that this last simplification doesn't enable further automatic
+        // particular, that this last simplification doesn't enable further automatic
         // resolutions
         if cfg!(debug_assertions) {
             let re_merged = merge_trees(&self.store, simplified.clone()).await.unwrap();
             debug_assert_eq!(re_merged, simplified);
         }
-        Ok(Self::new(self.store, simplified))
+        Ok(Self {
+            store: self.store,
+            tree_ids: simplified,
+            labels: simplified_labels,
+        })
     }
 
     /// An iterator over the conflicts in this tree, including subtrees.
     /// Recurses into subtrees and yields conflicts in those, but only if
     /// all sides are trees, so tree/file conflicts will be reported as a single
     /// conflict, not one for each path in the tree.
-    // TODO: Restrict this by a matcher (or add a separate method for that).
     pub fn conflicts(
         &self,
     ) -> impl Iterator<Item = (RepoPathBuf, BackendResult<MergedTreeValue>)> + use<> {
-        ConflictIterator::new(self)
+        self.conflicts_matching(&EverythingMatcher)
+    }
+
+    /// Like `conflicts()` but restricted by a matcher.
+    pub fn conflicts_matching<'matcher>(
+        &self,
+        matcher: &'matcher dyn Matcher,
+    ) -> impl Iterator<Item = (RepoPathBuf, BackendResult<MergedTreeValue>)> + use<'matcher> {
+        ConflictIterator::new(self, matcher)
     }
 
     /// Whether this tree has conflicts.
@@ -158,7 +222,7 @@ impl MergedTree {
     pub async fn path_value_async(&self, path: &RepoPath) -> BackendResult<MergedTreeValue> {
         match path.split() {
             Some((dir, basename)) => {
-                let trees = self.trees_async().await?;
+                let trees = self.trees().await?;
                 match trees.sub_tree_recursive(dir).await? {
                     None => Ok(Merge::absent()),
                     Some(tree) => Ok(tree.value(basename).cloned()),
@@ -250,19 +314,40 @@ impl MergedTree {
         ))
     }
 
-    /// Merges this tree with `other`, using `base` as base. Any conflicts will
-    /// be resolved recursively if possible.
-    pub async fn merge(self, base: Self, other: Self) -> BackendResult<Self> {
-        self.merge_no_resolve(base, other).resolve().await
+    /// Merges the provided trees into a single `MergedTree`. Any conflicts will
+    /// be resolved recursively if possible. The provided labels are used if a
+    /// conflict arises. However, if one of the input trees is already
+    /// conflicted, the corresponding label will be ignored, and its existing
+    /// labels will be used instead.
+    pub async fn merge(merge: Merge<(Self, String)>) -> BackendResult<Self> {
+        Self::merge_no_resolve(merge).resolve().await
     }
 
-    /// Merges this tree with `other`, using `base` as base, without attempting
+    /// Merges the provided trees into a single `MergedTree`, without attempting
     /// to resolve file conflicts.
-    pub fn merge_no_resolve(self, base: Self, other: Self) -> Self {
-        debug_assert!(Arc::ptr_eq(&base.store, &self.store));
-        debug_assert!(Arc::ptr_eq(&other.store, &self.store));
-        let nested = Merge::from_vec(vec![self.tree_ids, base.tree_ids, other.tree_ids]);
-        Self::new(self.store, nested.flatten().simplify())
+    pub fn merge_no_resolve(merge: Merge<(Self, String)>) -> Self {
+        debug_assert!(
+            merge
+                .iter()
+                .map(|(tree, _)| Arc::as_ptr(tree.store()))
+                .all_equal()
+        );
+        let store = merge.first().0.store().clone();
+        let flattened_labels = ConflictLabels::from_merge(
+            merge
+                .map(|(tree, label)| tree.labels_by_term(label))
+                .flatten()
+                .map(|&label| label.to_owned()),
+        );
+        let flattened_tree_ids: Merge<TreeId> = merge
+            .into_iter()
+            .map(|(tree, _label)| tree.into_tree_ids())
+            .collect::<MergeBuilder<_>>()
+            .build()
+            .flatten();
+
+        let (labels, tree_ids) = flattened_labels.simplify_with(&flattened_tree_ids);
+        Self::new(store, tree_ids, labels)
     }
 }
 
@@ -420,41 +505,52 @@ struct ConflictsDirItem {
     entries: Vec<(RepoPathBuf, MergedTreeValue)>,
 }
 
-impl From<&Merge<Tree>> for ConflictsDirItem {
-    fn from(trees: &Merge<Tree>) -> Self {
-        let dir = trees.first().dir();
+impl ConflictsDirItem {
+    fn new(trees: &Merge<Tree>, matcher: &dyn Matcher) -> Self {
         if trees.is_resolved() {
             return Self { entries: vec![] };
         }
 
+        let dir = trees.first().dir();
         let mut entries = vec![];
         for (basename, value) in all_tree_entries(trees) {
-            if !value.is_resolved() {
-                entries.push((dir.join(basename), value.cloned()));
+            if value.is_resolved() {
+                continue;
             }
+            let path = dir.join(basename);
+            if value.is_tree() {
+                if matcher.visit(&path).is_nothing() {
+                    continue;
+                }
+            } else if !matcher.matches(&path) {
+                continue;
+            }
+            entries.push((path, value.cloned()));
         }
         entries.reverse();
         Self { entries }
     }
 }
 
-struct ConflictIterator {
+struct ConflictIterator<'matcher> {
     store: Arc<Store>,
     stack: Vec<ConflictsDirItem>,
+    matcher: &'matcher dyn Matcher,
 }
 
-impl ConflictIterator {
-    fn new(tree: &MergedTree) -> Self {
+impl<'matcher> ConflictIterator<'matcher> {
+    fn new(tree: &MergedTree, matcher: &'matcher dyn Matcher) -> Self {
         Self {
             store: tree.store().clone(),
             stack: vec![ConflictsDirItem {
                 entries: vec![(RepoPathBuf::root(), tree.to_merged_tree_value())],
             }],
+            matcher,
         }
     }
 }
 
-impl Iterator for ConflictIterator {
+impl Iterator for ConflictIterator<'_> {
     type Item = (RepoPathBuf, BackendResult<MergedTreeValue>);
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -463,7 +559,7 @@ impl Iterator for ConflictIterator {
                 match tree_values.to_tree_merge(&self.store, &path).block_on() {
                     Ok(Some(trees)) => {
                         // If all sides are trees or missing, descend into the merged tree
-                        self.stack.push(ConflictsDirItem::from(&trees));
+                        self.stack.push(ConflictsDirItem::new(&trees, self.matcher));
                     }
                     Ok(None) => {
                         // Otherwise this is a conflict between files, trees, etc. If they could
@@ -763,7 +859,7 @@ impl<'matcher> TreeDiffStreamImpl<'matcher> {
             }
 
             for (dir, tree_diff) in tree_diffs {
-                let _ = self.pending_trees.remove_entry(&dir).unwrap();
+                drop(self.pending_trees.remove_entry(&dir).unwrap());
                 match tree_diff {
                     Ok((trees1, trees2)) => {
                         self.add_dir_diff_items(&dir, &trees1, &trees2);
@@ -918,11 +1014,21 @@ impl MergedTreeBuilder {
     /// Create new tree(s) from the base tree(s) and overrides.
     pub fn write_tree(self) -> BackendResult<MergedTree> {
         let store = self.base_tree.store.clone();
+        let labels = self.base_tree.labels().clone();
         let new_tree_ids = self.write_merged_trees()?;
         match new_tree_ids.simplify().into_resolved() {
             Ok(single_tree_id) => Ok(MergedTree::resolved(store, single_tree_id)),
             Err(tree_ids) => {
-                let tree = MergedTree::new(store, tree_ids);
+                let labels = if labels.num_sides() == Some(tree_ids.num_sides()) {
+                    labels
+                } else {
+                    // If the number of sides changed, we need to discard the conflict labels,
+                    // otherwise `MergedTree::new` would panic.
+                    // TODO: we should preserve conflict labels when setting conflicted tree values
+                    // originating from a different tree than the base tree.
+                    ConflictLabels::unlabeled()
+                };
+                let tree = MergedTree::new(store, tree_ids, labels);
                 tree.resolve().block_on()
             }
         }
@@ -946,7 +1052,7 @@ impl MergedTreeBuilder {
                 Ok(value) => {
                     // This path was overridden with a resolved value. Apply that to all
                     // builders.
-                    for builder in tree_builders.iter_mut() {
+                    for builder in &mut tree_builders {
                         builder.set_or_remove(path.clone(), value.clone());
                     }
                 }
@@ -954,7 +1060,7 @@ impl MergedTreeBuilder {
                     values.pad_to(num_sides, &None);
                     // This path was overridden with a conflicted value. Apply each term to
                     // its corresponding builder.
-                    for (builder, value) in zip(tree_builders.iter_mut(), values) {
+                    for (builder, value) in zip(&mut tree_builders, values) {
                         builder.set_or_remove(path.clone(), value);
                     }
                 }
