@@ -57,6 +57,7 @@ use crate::index::IndexStore;
 use crate::index::IndexStoreError;
 use crate::index::MutableIndex;
 use crate::index::ReadonlyIndex;
+use crate::index::ResolvedChangeTargets;
 use crate::merge::MergeBuilder;
 use crate::merge::SameChange;
 use crate::merge::trivial_merge;
@@ -127,7 +128,10 @@ pub trait Repo {
 
     fn submodule_store(&self) -> &Arc<dyn SubmoduleStore>;
 
-    fn resolve_change_id(&self, change_id: &ChangeId) -> IndexResult<Option<Vec<CommitId>>> {
+    fn resolve_change_id(
+        &self,
+        change_id: &ChangeId,
+    ) -> IndexResult<Option<ResolvedChangeTargets>> {
         // Replace this if we added more efficient lookup method.
         let prefix = HexPrefix::from_id(change_id);
         match self.resolve_change_id_prefix(&prefix)? {
@@ -140,7 +144,7 @@ pub trait Repo {
     fn resolve_change_id_prefix(
         &self,
         prefix: &HexPrefix,
-    ) -> IndexResult<PrefixResolution<Vec<CommitId>>>;
+    ) -> IndexResult<PrefixResolution<ResolvedChangeTargets>>;
 
     fn shortest_unique_change_id_prefix_len(
         &self,
@@ -362,7 +366,7 @@ impl Repo for ReadonlyRepo {
     fn resolve_change_id_prefix(
         &self,
         prefix: &HexPrefix,
-    ) -> IndexResult<PrefixResolution<Vec<CommitId>>> {
+    ) -> IndexResult<PrefixResolution<ResolvedChangeTargets>> {
         self.change_id_index().resolve_prefix(prefix)
     }
 
@@ -976,7 +980,7 @@ impl MutableRepo {
     /// A later call to `rebase_descendants()` will update bookmarks pointing to
     /// `old_id` be conflicted and pointing to all pf `new_ids`. Working copies
     /// pointing to `old_id` will be updated to point to the first commit in
-    /// `new_ids``. Descendants of `old_id` will be left alone.
+    /// `new_ids`. Descendants of `old_id` will be left alone.
     pub fn set_divergent_rewrite(
         &mut self,
         old_id: CommitId,
@@ -2007,7 +2011,7 @@ impl Repo for MutableRepo {
     fn resolve_change_id_prefix(
         &self,
         prefix: &HexPrefix,
-    ) -> IndexResult<PrefixResolution<Vec<CommitId>>> {
+    ) -> IndexResult<PrefixResolution<ResolvedChangeTargets>> {
         let change_id_index = self.index.change_id_index(&mut self.view().heads().iter());
         change_id_index.resolve_prefix(prefix)
     }
