@@ -33,12 +33,15 @@ use crate::backend::BackendResult;
 use crate::backend::CommitId;
 use crate::commit::Commit;
 use crate::commit::CommitIteratorExt as _;
+use crate::commit::conflict_label_for_commits;
 use crate::commit_builder::CommitBuilder;
 use crate::index::Index;
 use crate::index::IndexResult;
+use crate::index::ResolvedChangeTargets;
 use crate::iter_util::fallible_any;
 use crate::matchers::Matcher;
 use crate::matchers::Visit;
+use crate::merge::Diff;
 use crate::merge::Merge;
 use crate::merged_tree::MergedTree;
 use crate::merged_tree::MergedTreeBuilder;
@@ -75,16 +78,13 @@ pub async fn merge_commit_trees_no_resolve_without_repo(
         .map(|commit| commit.id().clone())
         .collect_vec();
     let commit_id_merge = find_recursive_merge_commits(store, index, commit_ids)?;
-    let tree_id_merge = commit_id_merge
+    let tree_merge: Merge<(MergedTree, String)> = commit_id_merge
         .try_map_async(async |commit_id| {
             let commit = store.get_commit_async(commit_id).await?;
-            Ok::<_, BackendError>(commit.tree_ids().clone())
+            Ok::<_, BackendError>((commit.tree(), commit.conflict_label()))
         })
         .await?;
-    Ok(MergedTree::new(
-        store.clone(),
-        tree_id_merge.flatten().simplify(),
-    ))
+    Ok(MergedTree::merge_no_resolve(tree_merge))
 }
 
 /// Find the commits to use as input to the recursive merge algorithm.
@@ -284,7 +284,27 @@ impl<'repo> CommitRewriter<'repo> {
             let (old_base_tree, new_base_tree) = try_join!(old_base_tree_fut, new_base_tree_fut)?;
             (
                 old_base_tree.tree_ids() == self.old_commit.tree_ids(),
-                new_base_tree.merge(old_base_tree, old_tree).await?,
+                MergedTree::merge(Merge::from_vec(vec![
+                    (
+                        new_base_tree,
+                        format!(
+                            "{} (rebase destination)",
+                            conflict_label_for_commits(&new_parents)
+                        ),
+                    ),
+                    (
+                        old_base_tree,
+                        format!(
+                            "{} (parents of rebased revision)",
+                            conflict_label_for_commits(&old_parents)
+                        ),
+                    ),
+                    (
+                        old_tree,
+                        format!("{} (rebased revision)", self.old_commit.conflict_label()),
+                    ),
+                ]))
+                .await?,
             )
         };
         // Ensure we don't abandon commits with multiple parents (merge commits), even
@@ -365,6 +385,7 @@ pub fn rebase_commit_with_options(
 }
 
 /// Moves changes from `sources` to the `destination` parent, returns new tree.
+// TODO: pass conflict labels as argument to provide more specific information
 pub fn rebase_to_dest_parent(
     repo: &dyn Repo,
     sources: &[Commit],
@@ -375,16 +396,30 @@ pub fn rebase_to_dest_parent(
     {
         return Ok(source.tree());
     }
-    sources.iter().try_fold(
-        destination.parent_tree(repo)?,
-        |destination_tree, source| {
-            let source_parent_tree = source.parent_tree(repo)?;
-            let source_tree = source.tree();
-            destination_tree
-                .merge(source_parent_tree, source_tree)
-                .block_on()
-        },
-    )
+
+    let diffs: Vec<_> = sources
+        .iter()
+        .map(|source| -> BackendResult<_> {
+            Ok(Diff::new(
+                (
+                    source.parent_tree(repo)?,
+                    format!("{} (original parents)", source.parents_conflict_label()?),
+                ),
+                (
+                    source.tree(),
+                    format!("{} (original revision)", source.conflict_label()),
+                ),
+            ))
+        })
+        .try_collect()?;
+    MergedTree::merge(Merge::from_diffs(
+        (
+            destination.parent_tree(repo)?,
+            format!("{} (new parents)", destination.parents_conflict_label()?),
+        ),
+        diffs,
+    ))
+    .block_on()
 }
 
 #[derive(Clone, Copy, Default, PartialEq, Eq, Debug)]
@@ -1146,6 +1181,33 @@ impl CommitWithSelection {
     pub fn is_empty_selection(&self) -> bool {
         self.selected_tree.tree_ids() == self.parent_tree.tree_ids()
     }
+
+    /// Returns a diff of labeled trees which represents the selected changes.
+    /// This can be used with `MergedTree::merge` and `Merge::from_diffs` to
+    /// apply the selected changes to a tree.
+    pub fn diff_with_labels(
+        &self,
+        parent_tree_label: &str,
+        selected_tree_label: &str,
+        full_selection_label: &str,
+    ) -> BackendResult<Diff<(MergedTree, String)>> {
+        let parent_tree_label = format!(
+            "{} ({parent_tree_label})",
+            self.commit.parents_conflict_label()?
+        );
+
+        let commit_label = self.commit.conflict_label();
+        let selected_tree_label = if self.is_full_selection() {
+            format!("{commit_label} ({full_selection_label})")
+        } else {
+            format!("{selected_tree_label} (from {commit_label})")
+        };
+
+        Ok(Diff::new(
+            (self.parent_tree.clone(), parent_tree_label),
+            (self.selected_tree.clone(), selected_tree_label),
+        ))
+    }
 }
 
 /// Resulting commit builder and stats to be returned by [`squash_commits()`].
@@ -1168,6 +1230,7 @@ pub fn squash_commits<'repo>(
 ) -> BackendResult<Option<SquashedCommit<'repo>>> {
     struct SourceCommit<'a> {
         commit: &'a CommitWithSelection,
+        diff: Diff<(MergedTree, String)>,
         abandon: bool,
     }
     let mut source_commits = vec![];
@@ -1184,6 +1247,11 @@ pub fn squash_commits<'repo>(
         // squash -r`)? The source tree will be unchanged in that case.
         source_commits.push(SourceCommit {
             commit: source,
+            diff: source.diff_with_labels(
+                "parents of squashed revision",
+                "selected changes for squash",
+                "squashed revision",
+            )?,
             abandon,
         });
     }
@@ -1200,12 +1268,11 @@ pub fn squash_commits<'repo>(
         } else {
             let source_tree = source.commit.commit.tree();
             // Apply the reverse of the selected changes onto the source
-            let new_source_tree = source_tree
-                .merge(
-                    source.commit.selected_tree.clone(),
-                    source.commit.parent_tree.clone(),
-                )
-                .block_on()?;
+            let new_source_tree = MergedTree::merge(Merge::from_diffs(
+                (source_tree, source.commit.commit.conflict_label()),
+                [source.diff.clone().invert()],
+            ))
+            .block_on()?;
             repo.rewrite_commit(&source.commit.commit)
                 .set_tree(new_source_tree)
                 .write()?;
@@ -1235,22 +1302,21 @@ pub fn squash_commits<'repo>(
             };
         })?;
     }
-    // Apply the selected changes onto the destination
-    let mut destination_tree = rewritten_destination.tree();
-    for source in &source_commits {
-        destination_tree = destination_tree
-            .merge(
-                source.commit.parent_tree.clone(),
-                source.commit.selected_tree.clone(),
-            )
-            .block_on()?;
-    }
     let mut predecessors = vec![destination.id().clone()];
     predecessors.extend(
         source_commits
             .iter()
             .map(|source| source.commit.commit.id().clone()),
     );
+    // Apply the selected changes onto the destination
+    let destination_tree = MergedTree::merge(Merge::from_diffs(
+        (
+            rewritten_destination.tree(),
+            format!("{} (squash destination)", destination.conflict_label()),
+        ),
+        source_commits.into_iter().map(|source| source.diff),
+    ))
+    .block_on()?;
 
     let commit_builder = repo
         .rewrite_commit(&rewritten_destination)
@@ -1295,6 +1361,7 @@ pub fn find_duplicate_divergent_commits(
                 .resolve_change_id(target_commit.change_id())
                 // TODO: indexing error shouldn't be a "BackendError"
                 .map_err(|err| BackendError::Other(err.into()))?
+                .and_then(ResolvedChangeTargets::into_visible)
                 .unwrap_or_default();
             ancestor_candidates.retain(|commit_id| !target_commit_ids.contains(commit_id));
             Ok((target_commit, ancestor_candidates))
