@@ -33,12 +33,12 @@ use crate::backend::ChangeId;
 use crate::backend::CommitId;
 use crate::backend::CopyRecord;
 use crate::backend::FileId;
-use crate::backend::MergedTreeId;
 use crate::backend::SigningFn;
 use crate::backend::SymlinkId;
 use crate::backend::TreeId;
 use crate::commit::Commit;
 use crate::index::Index;
+use crate::merge::Merge;
 use crate::merged_tree::MergedTree;
 use crate::repo_path::RepoPath;
 use crate::repo_path::RepoPathBuf;
@@ -135,8 +135,13 @@ impl Store {
         self.backend.concurrency()
     }
 
-    pub fn empty_merged_tree_id(&self) -> MergedTreeId {
-        MergedTreeId::resolved(self.backend.empty_tree_id().clone())
+    pub fn empty_merged_tree(self: &Arc<Self>) -> MergedTree {
+        let empty_tree_id = self.backend.empty_tree_id().clone();
+        MergedTree::resolved(self.clone(), empty_tree_id)
+    }
+
+    pub fn empty_merged_tree_id(&self) -> Merge<TreeId> {
+        Merge::resolved(self.backend.empty_tree_id().clone())
     }
 
     pub fn root_commit(self: &Arc<Self>) -> Commit {
@@ -215,21 +220,6 @@ impl Store {
         Ok(data)
     }
 
-    pub fn get_root_tree(self: &Arc<Self>, id: &MergedTreeId) -> BackendResult<MergedTree> {
-        self.get_root_tree_async(id).block_on()
-    }
-
-    pub async fn get_root_tree_async(
-        self: &Arc<Self>,
-        id: &MergedTreeId,
-    ) -> BackendResult<MergedTree> {
-        let trees = id
-            .as_merge()
-            .try_map_async(|id| self.get_tree_async(RepoPathBuf::root(), id))
-            .await?;
-        Ok(MergedTree::new(trees))
-    }
-
     pub async fn write_tree(
         self: &Arc<Self>,
         path: &RepoPath,
