@@ -42,21 +42,13 @@ pub enum StringPatternParseError {
     Regex(regex::Error),
 }
 
-/// A wrapper for [`Glob`] and its matcher with a more concise `Debug` impl.
+/// A wrapper for [`Glob`] with a more concise `Debug` impl.
 #[derive(Clone)]
 pub struct GlobPattern {
     glob: Glob,
-    // TODO: Maybe better to add StringPattern::to_matcher(), and move regex
-    // compilation there.
-    regex: regex::bytes::Regex,
 }
 
 impl GlobPattern {
-    /// Returns true if this pattern matches `haystack`.
-    pub fn is_match(&self, haystack: &[u8]) -> bool {
-        self.regex.is_match(haystack)
-    }
-
     /// Returns the original glob pattern.
     pub fn as_str(&self) -> &str {
         self.glob.glob()
@@ -64,7 +56,12 @@ impl GlobPattern {
 
     /// Converts this glob pattern to a bytes regex.
     pub fn to_regex(&self) -> regex::bytes::Regex {
-        self.regex.clone()
+        // Based on new_regex() in globset. We don't use GlobMatcher::is_match(path)
+        // because the input string shouldn't be normalized as path.
+        regex::bytes::RegexBuilder::new(self.glob.regex())
+            .dot_matches_new_line(true)
+            .build()
+            .expect("glob regex should be valid")
     }
 }
 
@@ -83,13 +80,7 @@ fn parse_glob(src: &str, icase: bool) -> Result<GlobPattern, StringPatternParseE
         .backslash_escape(true)
         .build()
         .map_err(StringPatternParseError::GlobPattern)?;
-    // Based on new_regex() in globset. We don't use GlobMatcher::is_match(path)
-    // because the input string shouldn't be normalized as path.
-    let regex = regex::bytes::RegexBuilder::new(glob.regex())
-        .dot_matches_new_line(true)
-        .build()
-        .expect("glob regex should be valid");
-    Ok(GlobPattern { glob, regex })
+    Ok(GlobPattern { glob })
 }
 
 fn is_glob_char(c: char) -> bool {
@@ -126,20 +117,6 @@ impl StringPattern {
         Self::Substring(String::new())
     }
 
-    /// Parses the given string as a [`StringPattern`]. Everything before the
-    /// first ":" is considered the string's prefix. If the prefix is
-    /// "exact[-i]:", "glob[-i]:", or "substring[-i]:", a pattern of the
-    /// specified kind is returned. Returns an error if the string has an
-    /// unrecognized prefix. Otherwise, a `StringPattern::Exact` is
-    /// returned.
-    pub fn parse(src: &str) -> Result<Self, StringPatternParseError> {
-        if let Some((kind, pat)) = src.split_once(':') {
-            Self::from_str_kind(pat, kind)
-        } else {
-            Ok(Self::exact(src))
-        }
-    }
-
     /// Constructs a pattern that matches exactly.
     pub fn exact(src: impl Into<String>) -> Self {
         Self::Exact(src.into())
@@ -272,16 +249,7 @@ impl StringPattern {
         }
     }
 
-    /// Returns true if this pattern matches the `haystack` string.
-    ///
-    /// When matching against a case‐insensitive pattern, only ASCII case
-    /// differences are currently folded. This may change in the future.
-    pub fn is_match(&self, haystack: &str) -> bool {
-        self.is_match_bytes(haystack.as_bytes())
-    }
-
-    /// Returns true if this pattern matches the `haystack` bytes.
-    pub fn is_match_bytes(&self, haystack: &[u8]) -> bool {
+    fn to_match_fn(&self) -> Box<DynMatchFn> {
         // TODO: Unicode case folding is complicated and can be
         // locale‐specific. The `globset` crate and Gitoxide only deal with
         // ASCII case folding, so we do the same here; a more elaborate case
@@ -300,19 +268,33 @@ impl StringPattern {
         // For some discussion of this topic, see:
         // <https://github.com/unicode-org/icu4x/issues/3151>
         match self {
-            Self::Exact(literal) => haystack == literal.as_bytes(),
-            Self::ExactI(literal) => haystack.eq_ignore_ascii_case(literal.as_bytes()),
-            Self::Substring(needle) => haystack.contains_str(needle),
-            Self::SubstringI(needle) => haystack
-                .to_ascii_lowercase()
-                .contains_str(needle.to_ascii_lowercase()),
+            Self::Exact(literal) => {
+                let literal = literal.clone();
+                Box::new(move |haystack| haystack == literal.as_bytes())
+            }
+            Self::ExactI(literal) => {
+                let literal = literal.clone();
+                Box::new(move |haystack| haystack.eq_ignore_ascii_case(literal.as_bytes()))
+            }
+            Self::Substring(needle) => {
+                let needle = needle.clone();
+                Box::new(move |haystack| haystack.contains_str(&needle))
+            }
+            Self::SubstringI(needle) => {
+                let needle = needle.to_ascii_lowercase();
+                Box::new(move |haystack| haystack.to_ascii_lowercase().contains_str(&needle))
+            }
             // (Glob, GlobI) and (Regex, RegexI) pairs are identical here, but
             // callers might want to translate these to backend-specific query
             // differently.
-            Self::Glob(pattern) => pattern.is_match(haystack),
-            Self::GlobI(pattern) => pattern.is_match(haystack),
-            Self::Regex(pattern) => pattern.is_match(haystack),
-            Self::RegexI(pattern) => pattern.is_match(haystack),
+            Self::Glob(pattern) | Self::GlobI(pattern) => {
+                let pattern = pattern.to_regex();
+                Box::new(move |haystack| pattern.is_match(haystack))
+            }
+            Self::Regex(pattern) | Self::RegexI(pattern) => {
+                let pattern = pattern.clone();
+                Box::new(move |haystack| pattern.is_match(haystack))
+            }
         }
     }
 
@@ -323,10 +305,7 @@ impl StringPattern {
         } else if let Some(literal) = self.as_exact() {
             StringMatcher::Exact(literal.to_owned())
         } else {
-            // TODO: fully migrate is_match*() to StringMatcher, and add
-            // pattern.to_match_fn()?
-            let pattern = self.clone();
-            StringMatcher::Fn(Box::new(move |haystack| pattern.is_match_bytes(haystack)))
+            StringMatcher::Fn(self.to_match_fn())
         }
     }
 
@@ -537,6 +516,16 @@ impl StringMatcher {
         }
     }
 
+    /// Iterates over matching lines in `text`.
+    pub fn match_lines<'a>(&self, text: &'a [u8]) -> impl Iterator<Item = &'a [u8]> {
+        // The pattern is matched line by line so that it can be anchored to line
+        // start/end. For example, exact:"" will match blank lines.
+        text.split_inclusive(|b| *b == b'\n').filter(|line| {
+            let line = line.strip_suffix(b"\n").unwrap_or(line);
+            self.is_match_bytes(line)
+        })
+    }
+
     fn into_match_fn(self) -> Box<DynMatchFn> {
         match self {
             Self::All => Box::new(|_haystack| true),
@@ -649,116 +638,70 @@ mod tests {
     #[test]
     fn test_parse() {
         // Parse specific pattern kinds.
-        assert_matches!(
-            StringPattern::parse("exact:foo"),
-            Ok(StringPattern::Exact(s)) if s == "foo"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo", "exact"),
             Ok(StringPattern::Exact(s)) if s == "foo"
         );
-        assert_matches!(
-            StringPattern::parse("glob:foo*"),
-            Ok(StringPattern::Glob(p)) if p.as_str() == "foo*"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo*", "glob"),
             Ok(StringPattern::Glob(p)) if p.as_str() == "foo*"
         );
-        assert_matches!(
-            StringPattern::parse("substring:foo"),
-            Ok(StringPattern::Substring(s)) if s == "foo"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo", "substring"),
             Ok(StringPattern::Substring(s)) if s == "foo"
         );
-        assert_matches!(
-            StringPattern::parse("substring-i:foo"),
-            Ok(StringPattern::SubstringI(s)) if s == "foo"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo", "substring-i"),
             Ok(StringPattern::SubstringI(s)) if s == "foo"
         );
-        assert_matches!(
-            StringPattern::parse("regex:foo"),
-            Ok(StringPattern::Regex(p)) if p.as_str() == "foo"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo", "regex"),
             Ok(StringPattern::Regex(p)) if p.as_str() == "foo"
         );
-        assert_matches!(
-            StringPattern::parse("regex-i:foo"),
-            Ok(StringPattern::RegexI(p)) if p.as_str() == "foo"
-        );
         assert_matches!(
             StringPattern::from_str_kind("foo", "regex-i"),
             Ok(StringPattern::RegexI(p)) if p.as_str() == "foo"
         );
-
-        // Parse a pattern that contains a : itself.
-        assert_matches!(
-            StringPattern::parse("exact:foo:bar"),
-            Ok(StringPattern::Exact(s)) if s == "foo:bar"
-        );
-
-        // If no kind is specified, the input is treated as an exact pattern.
-        assert_matches!(
-            StringPattern::parse("foo"),
-            Ok(StringPattern::Exact(s)) if s == "foo"
-        );
-
-        // Parsing an unknown prefix results in an error.
-        assert_matches!(
-            StringPattern::parse("unknown-prefix:foo"),
-            Err(StringPatternParseError::InvalidKind(_))
-        );
     }
 
     #[test]
     fn test_glob_is_match() {
-        assert!(StringPattern::glob("foo").unwrap().is_match("foo"));
-        assert!(!StringPattern::glob("foo").unwrap().is_match("foobar"));
+        let glob = |src: &str| StringPattern::glob(src).unwrap().to_matcher();
+        let glob_i = |src: &str| StringPattern::glob_i(src).unwrap().to_matcher();
+
+        assert!(glob("foo").is_match("foo"));
+        assert!(!glob("foo").is_match("foobar"));
 
         // "." in string isn't any special
-        assert!(StringPattern::glob("*").unwrap().is_match(".foo"));
+        assert!(glob("*").is_match(".foo"));
 
         // "/" in string isn't any special
-        assert!(StringPattern::glob("*").unwrap().is_match("foo/bar"));
-        assert!(StringPattern::glob(r"*/*").unwrap().is_match("foo/bar"));
-        assert!(!StringPattern::glob(r"*/*").unwrap().is_match(r"foo\bar"));
+        assert!(glob("*").is_match("foo/bar"));
+        assert!(glob(r"*/*").is_match("foo/bar"));
+        assert!(!glob(r"*/*").is_match(r"foo\bar"));
 
         // "\" is an escape character
-        assert!(!StringPattern::glob(r"*\*").unwrap().is_match("foo/bar"));
-        assert!(StringPattern::glob(r"*\*").unwrap().is_match("foo*"));
-        assert!(StringPattern::glob(r"\\").unwrap().is_match(r"\"));
+        assert!(!glob(r"*\*").is_match("foo/bar"));
+        assert!(glob(r"*\*").is_match("foo*"));
+        assert!(glob(r"\\").is_match(r"\"));
 
         // "*" matches newline
-        assert!(StringPattern::glob(r"*").unwrap().is_match("foo\nbar"));
+        assert!(glob(r"*").is_match("foo\nbar"));
 
-        assert!(!StringPattern::glob("f?O").unwrap().is_match("Foo"));
-        assert!(StringPattern::glob_i("f?O").unwrap().is_match("Foo"));
+        assert!(!glob("f?O").is_match("Foo"));
+        assert!(glob_i("f?O").is_match("Foo"));
     }
 
     #[test]
     fn test_regex_is_match() {
+        let regex = |src: &str| StringPattern::regex(src).unwrap().to_matcher();
         // Unicode mode is enabled by default
-        assert!(StringPattern::regex(r"^\w$").unwrap().is_match("\u{c0}"));
-        assert!(StringPattern::regex(r"^.$").unwrap().is_match("\u{c0}"));
+        assert!(regex(r"^\w$").is_match("\u{c0}"));
+        assert!(regex(r"^.$").is_match("\u{c0}"));
         // ASCII-compatible mode should also work
-        assert!(StringPattern::regex(r"^(?-u)\w$").unwrap().is_match("a"));
-        assert!(
-            !StringPattern::regex(r"^(?-u)\w$")
-                .unwrap()
-                .is_match("\u{c0}")
-        );
-        assert!(
-            StringPattern::regex(r"^(?-u).{2}$")
-                .unwrap()
-                .is_match("\u{c0}")
-        );
+        assert!(regex(r"^(?-u)\w$").is_match("a"));
+        assert!(!regex(r"^(?-u)\w$").is_match("\u{c0}"));
+        assert!(regex(r"^(?-u).{2}$").is_match("\u{c0}"));
     }
 
     #[test]
@@ -1017,6 +960,39 @@ mod tests {
         assert!(StringPattern::substring("o").to_matcher().is_match("foo"));
     }
 
+    #[test]
+    fn test_matcher_match_lines() {
+        // TODO: Yield a match for the empty line?
+        assert_eq!(
+            StringMatcher::all().match_lines(b"").collect_vec(),
+            Vec::<&[u8]>::new()
+        );
+        assert_eq!(
+            StringMatcher::all().match_lines(b"\n").collect_vec(),
+            vec![b"\n"]
+        );
+        assert_eq!(
+            StringMatcher::all().match_lines(b"foo").collect_vec(),
+            vec![b"foo"]
+        );
+        assert_eq!(
+            StringMatcher::all().match_lines(b"foo\n").collect_vec(),
+            vec![b"foo\n"]
+        );
+        assert_eq!(
+            StringMatcher::exact("foo")
+                .match_lines(b"foo\nbar\n")
+                .collect_vec(),
+            vec![b"foo\n"]
+        );
+        assert_eq!(
+            StringMatcher::exact("foo\n")
+                .match_lines(b"foo\nbar\n")
+                .collect_vec(),
+            Vec::<&[u8]>::new()
+        );
+    }
+
     #[test]
     fn test_matcher_filter_btree_map() {
         let data = btreemap! {
