@@ -57,7 +57,7 @@ fn diff_paths(from_tree: &MergedTree, to_tree: &MergedTree) -> Vec<RepoPathBuf>
     from_tree
         .diff_stream(to_tree, &EverythingMatcher)
         .map(|diff| {
-            let _ = diff.values.unwrap();
+            diff.values.unwrap();
             diff.path
         })
         .collect()
@@ -186,7 +186,8 @@ fn test_rewrite(backend: TestRepoBackend) {
     let store = repo.store();
     // We have a new store instance, so we need to associate the old tree with the
     // new store instance.
-    let rewritten_tree = MergedTree::new(store.clone(), rewritten_tree.into_tree_ids());
+    let (tree_ids, labels) = rewritten_tree.into_tree_ids_and_labels();
+    let rewritten_tree = MergedTree::new(store.clone(), tree_ids, labels);
     let initial_commit = store.get_commit(initial_commit.id()).unwrap();
     let mut tx = repo.start_transaction();
     let rewritten_commit = tx
