@@ -15,6 +15,7 @@
 use indoc::indoc;
 use itertools::Itertools as _;
 use jj_lib::backend::FileId;
+use jj_lib::conflict_labels::ConflictLabels;
 use jj_lib::conflicts::ConflictMarkerStyle;
 use jj_lib::conflicts::ConflictMaterializeOptions;
 use jj_lib::conflicts::MIN_CONFLICT_MARKER_LEN;
@@ -89,15 +90,15 @@ fn test_materialize_conflict_basic() {
         @r"
     line 1
     line 2
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     left 3.1
     left 3.2
     left 3.3
-    %%%%%%% Changes from base to side #2
+    %%%%%%% diff from base to side #2
     -line 3
     +right 3.1
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 4
     line 5
     "
@@ -113,15 +114,15 @@ fn test_materialize_conflict_basic() {
         @r"
     line 1
     line 2
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base to side #1
     -line 3
     +right 3.1
-    +++++++ Contents of side #2
+    +++++++ side #2
     left 3.1
     left 3.2
     left 3.3
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 4
     line 5
     "
@@ -136,16 +137,16 @@ fn test_materialize_conflict_basic() {
         @r"
     line 1
     line 2
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     left 3.1
     left 3.2
     left 3.3
-    ------- Contents of base
+    ------- base
     line 3
-    +++++++ Contents of side #2
+    +++++++ side #2
     right 3.1
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 4
     line 5
     "
@@ -160,15 +161,15 @@ fn test_materialize_conflict_basic() {
         @r"
     line 1
     line 2
-    <<<<<<< Side #1 (Conflict 1 of 1)
+    <<<<<<< side #1
     left 3.1
     left 3.2
     left 3.3
-    ||||||| Base
+    ||||||| base
     line 3
     =======
     right 3.1
-    >>>>>>> Side #2 (Conflict 1 of 1 ends)
+    >>>>>>> side #2
     line 4
     line 5
     "
@@ -243,21 +244,21 @@ fn test_materialize_conflict_three_sides() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base #1 to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base #1 to side #1
     -line 2 base
     -line 3 base
     +line 2 a.1
     +line 3 a.2
      line 4 base
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 b.1
     line 3 base
     line 4 b.2
-    %%%%%%% Changes from base #2 to side #3
+    %%%%%%% diff from base #2 to side #3
      line 2 base
     +line 3 c.2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 5
     "
     );
@@ -266,21 +267,21 @@ fn test_materialize_conflict_three_sides() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::DiffExperimental),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     line 2 a.1
     line 3 a.2
     line 4 base
-    %%%%%%% Changes from base #1 to side #2
+    %%%%%%% diff from base #1 to side #2
     -line 2 base
     +line 2 b.1
      line 3 base
     -line 4 base
     +line 4 b.2
-    %%%%%%% Changes from base #2 to side #3
+    %%%%%%% diff from base #2 to side #3
      line 2 base
     +line 3 c.2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 5
     "
     );
@@ -289,25 +290,25 @@ fn test_materialize_conflict_three_sides() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Snapshot),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     line 2 a.1
     line 3 a.2
     line 4 base
-    ------- Contents of base #1
+    ------- base #1
     line 2 base
     line 3 base
     line 4 base
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 b.1
     line 3 base
     line 4 b.2
-    ------- Contents of base #2
+    ------- base #2
     line 2 base
-    +++++++ Contents of side #3
+    +++++++ side #3
     line 2 base
     line 3 c.2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 5
     "
     );
@@ -317,25 +318,25 @@ fn test_materialize_conflict_three_sides() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Git),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     line 2 a.1
     line 3 a.2
     line 4 base
-    ------- Contents of base #1
+    ------- base #1
     line 2 base
     line 3 base
     line 4 base
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 b.1
     line 3 base
     line 4 b.2
-    ------- Contents of base #2
+    ------- base #2
     line 2 base
-    +++++++ Contents of side #3
+    +++++++ side #3
     line 2 base
     line 3 c.2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 5
     "
     );
@@ -398,19 +399,19 @@ fn test_materialize_conflict_multi_rebase_conflicts() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     line 2 a.1
     line 2 a.2
     line 2 a.3
-    %%%%%%% Changes from base #1 to side #2
+    %%%%%%% diff from base #1 to side #2
     -line 2 base
     +line 2 b.1
     +line 2 b.2
-    %%%%%%% Changes from base #2 to side #3
+    %%%%%%% diff from base #2 to side #3
     -line 2 base
     +line 2 c.1
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 3
     "
     );
@@ -422,19 +423,19 @@ fn test_materialize_conflict_multi_rebase_conflicts() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base #1 to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base #1 to side #1
     -line 2 base
     +line 2 c.1
-    %%%%%%% Changes from base #2 to side #2
+    %%%%%%% diff from base #2 to side #2
     -line 2 base
     +line 2 b.1
     +line 2 b.2
-    +++++++ Contents of side #3
+    +++++++ side #3
     line 2 a.1
     line 2 a.2
     line 2 a.3
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 3
     "
     );
@@ -446,19 +447,19 @@ fn test_materialize_conflict_multi_rebase_conflicts() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff),
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base #1 to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base #1 to side #1
     -line 2 base
     +line 2 c.1
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 a.1
     line 2 a.2
     line 2 a.3
-    %%%%%%% Changes from base #2 to side #3
+    %%%%%%% diff from base #2 to side #3
     -line 2 base
     +line 2 b.1
     +line 2 b.2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 3
     "
     );
@@ -514,25 +515,25 @@ fn test_materialize_parse_roundtrip() {
     insta::assert_snapshot!(
         materialized,
         @r"
-    <<<<<<< Conflict 1 of 2
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 2
+    +++++++ side #1
     line 1 left
     line 2 left
-    %%%%%%% Changes from base to side #2
+    %%%%%%% diff from base to side #2
     -line 1
     +line 1 right
      line 2
-    >>>>>>> Conflict 1 of 2 ends
+    >>>>>>> conflict 1 of 2 ends
     line 3
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
      line 4
     -line 5
     +line 5 left
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 4 right
     line 5 right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     "
     );
 
@@ -643,12 +644,13 @@ fn test_materialize_conflict_no_newlines_at_eof() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff);
     insta::assert_snapshot!(materialized,
         @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1 (adds terminating newline)
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: base (no terminating newline)
+    \\\\\\\        to: side #1
     -base
-    +++++++ Contents of side #2 (no terminating newline)
+    +++++++ side #2 (no terminating newline)
     right
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     "
     );
     // The conflict markers are parsed with the trailing newline, but it is removed
@@ -721,12 +723,12 @@ fn test_materialize_conflict_modify_delete() {
     insta::assert_snapshot!(&materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff), @r"
     line 1
     line 2
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     modified
-    %%%%%%% Changes from base to side #2
+    %%%%%%% diff from base to side #2
     -line 3
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 4
     line 5
     "
@@ -740,12 +742,12 @@ fn test_materialize_conflict_modify_delete() {
     insta::assert_snapshot!(&materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff), @r"
     line 1
     line 2
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base to side #1
     -line 3
-    +++++++ Contents of side #2
+    +++++++ side #2
     modified
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     line 4
     line 5
     "
@@ -757,16 +759,16 @@ fn test_materialize_conflict_modify_delete() {
         vec![Some(modified_id.clone()), None],
     );
     insta::assert_snapshot!(&materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff), @r"
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from base to side #1
      line 1
      line 2
     -line 3
     +modified
      line 4
      line 5
-    +++++++ Contents of side #2
-    >>>>>>> Conflict 1 of 1 ends
+    +++++++ side #2
+    >>>>>>> conflict 1 of 1 ends
     "
     );
 }
@@ -811,18 +813,94 @@ fn test_materialize_conflict_two_forward_diffs() {
     insta::assert_snapshot!(
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff),
         @r"
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     A
-    %%%%%%% Changes from base #1 to side #2
+    %%%%%%% diff from base #1 to side #2
      B
-    %%%%%%% Changes from base #2 to side #3
+    %%%%%%% diff from base #2 to side #3
     -C
     +D
-    %%%%%%% Changes from base #3 to side #4
+    %%%%%%% diff from base #3 to side #4
     -E
     +C
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
+    "
+    );
+}
+
+#[test]
+fn test_materialize_conflict_with_labels() {
+    let test_repo = TestRepo::init();
+    let store = test_repo.repo.store();
+
+    let path = repo_path("file");
+    let side1 = testutils::write_file(store, path, "side 1\n");
+    let base1 = testutils::write_file(store, path, "base 1\n");
+    let side2 = testutils::write_file(store, path, "side 2\n");
+
+    let conflict = Merge::from_vec(vec![Some(side1), Some(base1), Some(side2)]);
+    let conflict_labels = ConflictLabels::from_vec(vec![
+        "side 1 conflict label".into(),
+        "base conflict label".into(),
+        "side 2 conflict label".into(),
+    ]);
+    insta::assert_snapshot!(
+        &materialize_conflict_string_with_labels(
+            store,
+            path,
+            &conflict,
+            &conflict_labels,
+            ConflictMarkerStyle::Diff,
+        ),
+        @r"
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: base conflict label
+    \\\\\\\        to: side 1 conflict label
+    -base 1
+    +side 1
+    +++++++ side 2 conflict label
+    side 2
+    >>>>>>> conflict 1 of 1 ends
+    "
+    );
+
+    insta::assert_snapshot!(
+        &materialize_conflict_string_with_labels(
+            store,
+            path,
+            &conflict,
+            &conflict_labels,
+            ConflictMarkerStyle::Snapshot,
+        ),
+        @r"
+    <<<<<<< conflict 1 of 1
+    +++++++ side 1 conflict label
+    side 1
+    ------- base conflict label
+    base 1
+    +++++++ side 2 conflict label
+    side 2
+    >>>>>>> conflict 1 of 1 ends
+    "
+    );
+
+    insta::assert_snapshot!(
+        &materialize_conflict_string_with_labels(
+            store,
+            path,
+            &conflict,
+            &conflict_labels,
+            ConflictMarkerStyle::Git,
+        ),
+        @r"
+    <<<<<<< side 1 conflict label
+    side 1
+    ||||||| base conflict label
+    base 1
+    =======
+    side 2
+    >>>>>>> side 2 conflict label
     "
     );
 }
@@ -1581,13 +1659,13 @@ fn test_parse_conflict_mixed_header_styles() {
     insta::assert_debug_snapshot!(
         parse_conflict(indoc! {b"
             line 1
-            <<<<<<< Conflict 1 of 1
-            +++++++ Contents of side #1
+            <<<<<<< conflict 1 of 1
+            +++++++ side #1
             ======= ignored
-            ------- Contents of base
+            ------- base
             ||||||| ignored
-            +++++++ Contents of side #2
-            >>>>>>> Conflict 1 of 1 ends
+            +++++++ side #2
+            >>>>>>> conflict 1 of 1 ends
             line 5
             "},
             2,
@@ -1617,13 +1695,13 @@ fn test_parse_conflict_mixed_header_styles() {
     insta::assert_debug_snapshot!(
         parse_conflict(indoc! {b"
             line 1
-            <<<<<<< Side #1 (Conflict 1 of 1)
-            ||||||| Base
+            <<<<<<< side #1
+            ||||||| base
             ------- ignored
             %%%%%%% ignored
             =======
             +++++++ ignored
-            >>>>>>> Side #2 (Conflict 1 of 1 ends)
+            >>>>>>> side #2
             line 5
             "},
             2,
@@ -1780,21 +1858,21 @@ fn test_update_conflict_from_content_simplified_conflict() {
     insta::assert_snapshot!(
         materialized,
         @r"
-    <<<<<<< Conflict 1 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 2
+    %%%%%%% diff from base to side #1
     -line 1
     +left 1
-    +++++++ Contents of side #2
+    +++++++ side #2
     right 1
-    >>>>>>> Conflict 1 of 2 ends
+    >>>>>>> conflict 1 of 2 ends
     line 2
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
     -line 3
     +left 3
-    +++++++ Contents of side #2
+    +++++++ side #2
     right 3
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     "
     );
     assert_eq!(parse(materialized.as_bytes()), conflict);
@@ -1810,13 +1888,13 @@ fn test_update_conflict_from_content_simplified_conflict() {
     let new_conflict = parse(indoc! {b"
         resolved 1
         line 2
-        <<<<<<< Conflict 2 of 2
-        %%%%%%% Changes from base to side #1
+        <<<<<<< conflict 2 of 2
+        %%%%%%% diff from base to side #1
         -edited line 3
         +edited left 3
-        +++++++ Contents of side #2
+        +++++++ side #2
         edited right 3
-        >>>>>>> Conflict 2 of 2 ends
+        >>>>>>> conflict 2 of 2 ends
     "});
     assert_ne!(new_conflict, conflict);
     // Calculate expected new FileIds
@@ -1888,23 +1966,23 @@ fn test_update_conflict_from_content_with_long_markers() {
     let materialized =
         materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Snapshot);
     insta::assert_snapshot!(materialized, @r"
-    <<<<<<<<<<<<<<<< Conflict 1 of 2
-    ++++++++++++++++ Contents of side #1
+    <<<<<<<<<<<<<<<< conflict 1 of 2
+    ++++++++++++++++ side #1
     <<<< left 1
-    ---------------- Contents of base
+    ---------------- base
     line 1
-    ++++++++++++++++ Contents of side #2
+    ++++++++++++++++ side #2
     >>>>>>> right 1
-    >>>>>>>>>>>>>>>> Conflict 1 of 2 ends
+    >>>>>>>>>>>>>>>> conflict 1 of 2 ends
     line 2
-    <<<<<<<<<<<<<<<< Conflict 2 of 2
-    ++++++++++++++++ Contents of side #1
+    <<<<<<<<<<<<<<<< conflict 2 of 2
+    ++++++++++++++++ side #1
     <<<<<<<<<<<< left 3
-    ---------------- Contents of base
+    ---------------- base
     line 3
-    ++++++++++++++++ Contents of side #2
+    ++++++++++++++++ side #2
     >>>>>>>>>>>> right 3
-    >>>>>>>>>>>>>>>> Conflict 2 of 2 ends
+    >>>>>>>>>>>>>>>> conflict 2 of 2 ends
     "
     );
 
@@ -1935,14 +2013,14 @@ fn test_update_conflict_from_content_with_long_markers() {
 
     // Resolve one of the conflicts, decreasing the minimum conflict marker length
     let new_conflict_contents = indoc! {"
-        <<<<<<<<<<<<<<<< Conflict 1 of 2
-        ++++++++++++++++ Contents of side #1
+        <<<<<<<<<<<<<<<< conflict 1 of 2
+        ++++++++++++++++ side #1
         <<<< left 1
-        ---------------- Contents of base
+        ---------------- base
         line 1
-        ++++++++++++++++ Contents of side #2
+        ++++++++++++++++ side #2
         >>>>>>> right 1
-        >>>>>>>>>>>>>>>> Conflict 1 of 2 ends
+        >>>>>>>>>>>>>>>> conflict 1 of 2 ends
         line 2
         line 3
     "};
@@ -1990,14 +2068,14 @@ fn test_update_conflict_from_content_with_long_markers() {
     insta::assert_snapshot!(
         materialize_conflict_string(store, path, &new_conflict, ConflictMarkerStyle::Snapshot),
         @r"
-    <<<<<<<<<<< Conflict 1 of 1
-    +++++++++++ Contents of side #1
+    <<<<<<<<<<< conflict 1 of 1
+    +++++++++++ side #1
     <<<< left 1
-    ----------- Contents of base
+    ----------- base
     line 1
-    +++++++++++ Contents of side #2
+    +++++++++++ side #2
     >>>>>>> right 1
-    >>>>>>>>>>> Conflict 1 of 1 ends
+    >>>>>>>>>>> conflict 1 of 1 ends
     line 2
     line 3
     "
@@ -2025,22 +2103,23 @@ fn test_update_conflict_from_content_no_eol() {
     insta::assert_snapshot!(materialized,
         @r"
     line 1
-    <<<<<<< Conflict 1 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 2
+    %%%%%%% diff from base to side #1
     -line 2
     +line 2 left
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 right
-    >>>>>>> Conflict 1 of 2 ends
+    >>>>>>> conflict 1 of 2 ends
     line 3
-    <<<<<<< Conflict 2 of 2
-    +++++++ Contents of side #1
+    <<<<<<< conflict 2 of 2
+    +++++++ side #1
     base
     left
-    %%%%%%% Changes from base to side #2 (no terminating newline)
+    %%%%%%% diff from: base (no terminating newline)
+    \\\\\\\        to: side #2 (no terminating newline)
     -base
     +right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     "
     );
     assert_eq!(
@@ -2061,24 +2140,24 @@ fn test_update_conflict_from_content_no_eol() {
     insta::assert_snapshot!(materialized,
         @r"
     line 1
-    <<<<<<< Conflict 1 of 2
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 2
+    +++++++ side #1
     line 2 left
-    ------- Contents of base
+    ------- base
     line 2
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 right
-    >>>>>>> Conflict 1 of 2 ends
+    >>>>>>> conflict 1 of 2 ends
     line 3
-    <<<<<<< Conflict 2 of 2
-    +++++++ Contents of side #1
+    <<<<<<< conflict 2 of 2
+    +++++++ side #1
     base
     left
-    ------- Contents of base (no terminating newline)
+    ------- base (no terminating newline)
     base
-    +++++++ Contents of side #2 (no terminating newline)
+    +++++++ side #2 (no terminating newline)
     right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     "
     );
     assert_eq!(
@@ -2099,22 +2178,22 @@ fn test_update_conflict_from_content_no_eol() {
     insta::assert_snapshot!(materialized,
         @r"
     line 1
-    <<<<<<< Side #1 (Conflict 1 of 2)
+    <<<<<<< side #1
     line 2 left
-    ||||||| Base
+    ||||||| base
     line 2
     =======
     line 2 right
-    >>>>>>> Side #2 (Conflict 1 of 2 ends)
+    >>>>>>> side #2
     line 3
-    <<<<<<< Side #1 (Conflict 2 of 2)
+    <<<<<<< side #1
     base
     left
-    ||||||| Base
+    ||||||| base
     base
     =======
     right
-    >>>>>>> Side #2 (Conflict 2 of 2 ends)
+    >>>>>>> side #2
     "
     );
     assert_eq!(
@@ -2168,26 +2247,29 @@ fn test_update_conflict_from_content_no_eol_in_diff_hunk() {
         &materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff);
     insta::assert_snapshot!(materialized,
         @r"
-    <<<<<<< Conflict 1 of 1
-    +++++++ Contents of side #1
+    <<<<<<< conflict 1 of 1
+    +++++++ side #1
     side
-    %%%%%%% Changes from base #1 to side #2 (adds terminating newline)
+    %%%%%%% diff from: base #1 (no terminating newline)
+    \\\\\\\        to: side #2
      add newline
     -line
     +line
-    %%%%%%% Changes from base #2 to side #3 (removes terminating newline)
+    %%%%%%% diff from: base #2
+    \\\\\\\        to: side #3 (no terminating newline)
      remove newline
     -line
     +line
-    %%%%%%% Changes from base #3 to side #4 (no terminating newline)
+    %%%%%%% diff from: base #3 (no terminating newline)
+    \\\\\\\        to: side #4 (no terminating newline)
      no newline
     -line 1
     +line 2
-    %%%%%%% Changes from base #4 to side #5
+    %%%%%%% diff from base #4 to side #5
      with newline
     -line 1
     +line 2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     "
     );
     assert_eq!(
@@ -2224,12 +2306,13 @@ fn test_update_conflict_from_content_only_no_eol_change() {
     insta::assert_snapshot!(materialized,
         @r"
     line 1
-    <<<<<<< Conflict 1 of 1
-    %%%%%%% Changes from base to side #1 (removes terminating newline)
+    <<<<<<< conflict 1 of 1
+    %%%%%%% diff from: base
+    \\\\\\\        to: side #1 (no terminating newline)
     +line 2
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2
-    >>>>>>> Conflict 1 of 1 ends
+    >>>>>>> conflict 1 of 1 ends
     "
     );
     assert_eq!(
@@ -2302,21 +2385,21 @@ fn test_update_from_content_malformed_conflict() {
         materialize_conflict_string(store, path, &conflict, ConflictMarkerStyle::Diff);
     insta::assert_snapshot!(materialized, @r"
     line 1
-    <<<<<<< Conflict 1 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 1 of 2
+    %%%%%%% diff from base to side #1
     -line 2
     +line 2 left
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 2 right
-    >>>>>>> Conflict 1 of 2 ends
+    >>>>>>> conflict 1 of 2 ends
     line 3
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
     -line 4
     +line 4 left
-    +++++++ Contents of side #2
+    +++++++ side #2
     line 4 right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     line 5
     "
     );
@@ -2331,20 +2414,20 @@ fn test_update_from_content_malformed_conflict() {
     // Make a change to the second conflict that causes it to become invalid
     let new_conflict_contents = indoc! {"
         line 1
-        <<<<<<< Conflict 1 of 2
-        %%%%%%% Changes from base to side #1
+        <<<<<<< conflict 1 of 2
+        %%%%%%% diff from base to side #1
         -line 2
         +line 2 left
-        +++++++ Contents of side #2
+        +++++++ side #2
         line 2 right
-        >>>>>>> Conflict 1 of 2 ends
+        >>>>>>> conflict 1 of 2 ends
         line 3
-        <<<<<<< Conflict 2 of 2
-        %%%%%%% Changes from base to side #1
+        <<<<<<< conflict 2 of 2
+        %%%%%%% diff from base to side #1
         -line 4
         +line 4 left
         line 4 right
-        >>>>>>> Conflict 2 of 2 ends
+        >>>>>>> conflict 2 of 2 ends
         line 5
     "};
     // On the first snapshot, it will parse as a conflict containing conflict
@@ -2362,36 +2445,36 @@ fn test_update_from_content_malformed_conflict() {
     line 1
     line 2 left
     line 3
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
     -line 4
     +line 4 left
     line 4 right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     line 5
     ");
     insta::assert_snapshot!(new_base, @r"
     line 1
     line 2
     line 3
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
     -line 4
     +line 4 left
     line 4 right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     line 5
     ");
     insta::assert_snapshot!(new_right_side, @r"
     line 1
     line 2 right
     line 3
-    <<<<<<< Conflict 2 of 2
-    %%%%%%% Changes from base to side #1
+    <<<<<<< conflict 2 of 2
+    %%%%%%% diff from base to side #1
     -line 4
     +line 4 left
     line 4 right
-    >>>>>>> Conflict 2 of 2 ends
+    >>>>>>> conflict 2 of 2 ends
     line 5
     ");
 
@@ -2406,6 +2489,22 @@ fn materialize_conflict_string(
     path: &RepoPath,
     conflict: &Merge<Option<FileId>>,
     marker_style: ConflictMarkerStyle,
+) -> String {
+    materialize_conflict_string_with_labels(
+        store,
+        path,
+        conflict,
+        &ConflictLabels::unlabeled(),
+        marker_style,
+    )
+}
+
+fn materialize_conflict_string_with_labels(
+    store: &Store,
+    path: &RepoPath,
+    conflict: &Merge<Option<FileId>>,
+    conflict_labels: &ConflictLabels,
+    marker_style: ConflictMarkerStyle,
 ) -> String {
     let contents = extract_as_single_hunk(conflict, store, path)
         .block_on()
@@ -2418,5 +2517,8 @@ fn materialize_conflict_string(
             same_change: SameChange::Accept,
         },
     };
-    String::from_utf8(materialize_merge_result_to_bytes(&contents, &options).into()).unwrap()
+    String::from_utf8(
+        materialize_merge_result_to_bytes(&contents, conflict_labels, &options).into(),
+    )
+    .unwrap()
 }
