@@ -20,23 +20,29 @@ use std::time::Duration;
 use std::time::SystemTime;
 
 use futures::executor::block_on_stream;
+use itertools::Itertools as _;
 use jj_lib::backend::CommitId;
 use jj_lib::backend::CopyRecord;
 use jj_lib::commit::Commit;
+use jj_lib::conflict_labels::ConflictLabels;
 use jj_lib::git_backend::GitBackend;
 use jj_lib::git_backend::JJ_TREES_COMMIT_HEADER;
+use jj_lib::merge::Merge;
 use jj_lib::merged_tree::MergedTree;
 use jj_lib::object_id::ObjectId as _;
 use jj_lib::repo::ReadonlyRepo;
 use jj_lib::repo::Repo as _;
 use jj_lib::repo_path::RepoPath;
 use jj_lib::repo_path::RepoPathBuf;
+use jj_lib::stacked_table::TableSegment as _;
+use jj_lib::stacked_table::TableStore;
 use jj_lib::store::Store;
 use jj_lib::transaction::Transaction;
 use maplit::hashmap;
 use maplit::hashset;
 use testutils::TestRepo;
 use testutils::TestRepoBackend;
+use testutils::assert_tree_eq;
 use testutils::commit_with_tree;
 use testutils::create_random_commit;
 use testutils::create_single_tree;
@@ -89,6 +95,14 @@ fn make_commit(
     tx.repo_mut().new_commit(parents, tree).write().unwrap()
 }
 
+fn list_dir(dir: &Path) -> Vec<String> {
+    std::fs::read_dir(dir)
+        .unwrap()
+        .map(|entry| entry.unwrap().file_name().to_str().unwrap().to_owned())
+        .sorted()
+        .collect()
+}
+
 #[test]
 fn test_gc() {
     // TODO: Better way to disable the test if git command couldn't be executed
@@ -236,6 +250,68 @@ fn test_gc() {
     assert_eq!(collect_no_gc_refs(git_repo_path), hashset! {});
 }
 
+#[test]
+fn test_gc_extra_table() {
+    if !is_external_tool_installed("git") {
+        eprintln!("Skipping because git command might fail to run");
+        return;
+    }
+
+    let test_repo = TestRepo::init_with_backend(TestRepoBackend::Git);
+    let extra_path = test_repo.repo_path().join("store").join("extra");
+    let extra_key_size = test_repo.repo.store().root_commit_id().as_bytes().len();
+    let load_repo = || {
+        test_repo
+            .env
+            .load_repo_at_head(test_repo.repo.settings(), test_repo.repo_path())
+    };
+    let load_extra_table = || {
+        TableStore::load(extra_path.clone(), extra_key_size)
+            .get_head()
+            .unwrap()
+    };
+    let collect_extra_segment_num_entries = || {
+        let mut num_entries = load_extra_table()
+            .ancestor_segments()
+            .map(|table| table.segment_num_entries())
+            .collect_vec();
+        num_entries.reverse();
+        num_entries
+    };
+
+    // Sanity check for the initial state
+    assert_eq!(collect_extra_segment_num_entries(), [0]);
+    assert_eq!(list_dir(&extra_path).len(), 1 + 1); // empty segment + "heads"
+
+    // Write 4 commits
+    let mut tx = test_repo.repo.start_transaction();
+    for _ in 0..4 {
+        write_random_commit(tx.repo_mut());
+    }
+    tx.commit("test").unwrap();
+    // The first 3 will be squashed into one table segment
+    assert_eq!(collect_extra_segment_num_entries(), [3, 1]);
+    assert_eq!(list_dir(&extra_path).len(), 5 + 1);
+
+    // Reload repo to invalidate cache in TableStore
+    let repo = load_repo();
+    let index = repo.readonly_index().as_index();
+
+    // All segments should be kept by modification time
+    repo.store().gc(index, SystemTime::UNIX_EPOCH).unwrap();
+    assert_eq!(collect_extra_segment_num_entries(), [3, 1]);
+    assert_eq!(list_dir(&extra_path).len(), 5 + 1);
+
+    // All unreachable segments should be removed
+    let now = SystemTime::now() + Duration::from_secs(1);
+    repo.store().gc(index, now).unwrap();
+    assert_eq!(collect_extra_segment_num_entries(), [3, 1]);
+    assert_eq!(list_dir(&extra_path).len(), 2 + 1);
+
+    // Ensure that repo is still loadable
+    load_repo();
+}
+
 #[test]
 fn test_copy_detection() {
     let test_repo = TestRepo::init_with_backend(TestRepoBackend::Git);
@@ -348,7 +424,7 @@ fn test_jj_trees_header_with_one_tree() {
     let git_commit = git_repo.find_commit(git_commit_id).unwrap();
 
     // Add `jj:trees` with a single tree which is different from the Git commit tree
-    let mut new_commit: gix::objs::Commit = git_commit.decode().unwrap().into();
+    let mut new_commit: gix::objs::Commit = git_commit.decode().unwrap().try_into().unwrap();
     new_commit.extra_headers = vec![(
         JJ_TREES_COMMIT_HEADER.into(),
         tree_2.id().to_string().into(),
@@ -369,3 +445,55 @@ fn test_jj_trees_header_with_one_tree() {
     )
     "#);
 }
+
+#[test]
+fn test_conflict_headers_roundtrip() {
+    let test_repo = TestRepo::init_with_backend(TestRepoBackend::Git);
+    let repo = test_repo.repo;
+
+    let tree_1 = create_single_tree(&repo, &[(repo_path("file"), "aaa")]);
+    let tree_2 = create_single_tree(&repo, &[(repo_path("file"), "bbb")]);
+    let tree_3 = create_single_tree(&repo, &[(repo_path("file"), "ccc")]);
+    let tree_4 = create_single_tree(&repo, &[(repo_path("file"), "ddd")]);
+    let tree_5 = create_single_tree(&repo, &[(repo_path("file"), "eee")]);
+    let tree_6 = create_single_tree(&repo, &[(repo_path("file"), "fff")]);
+    let tree_7 = create_single_tree(&repo, &[(repo_path("file"), "ggg")]);
+
+    // This creates a Git commit header with leading and trailing newlines to ensure
+    // that it can still be parsed correctly. The resulting `jj:conflict-labels`
+    // header value will look like `\nbase 1\nside 2\n\nside 3\n\n\n`.
+    let merged_tree = MergedTree::new(
+        repo.store().clone(),
+        Merge::from_vec(vec![
+            tree_1.id().clone(),
+            tree_2.id().clone(),
+            tree_3.id().clone(),
+            tree_4.id().clone(),
+            tree_5.id().clone(),
+            tree_6.id().clone(),
+            tree_7.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "".into(),
+            // Test that various UTF-8 characters can be encoded and decoded. Git doesn't allow
+            // storing arbitrary binary data in headers, but it does allow storing UTF-8 encoded
+            // strings as long as they don't contain U+0000 codepoints.
+            "base 1 \"utf8 \u{67d4}\u{8853} \u{ba4}\u{bc1}\u{bb0}\u{bc1} \u{2699}\u{fe0f}\"".into(),
+            "side 2".into(),
+            "".into(),
+            "side 3".into(),
+            "".into(),
+            "".into(),
+        ]),
+    );
+
+    // Create a commit with the conflicted tree.
+    let commit = commit_with_tree(repo.store(), merged_tree.clone());
+    // Clear cached commit to ensure it is re-read.
+    repo.store().clear_caches();
+    // Conflict trees and labels should be preserved on read.
+    assert_tree_eq!(
+        repo.store().get_commit(commit.id()).unwrap().tree(),
+        merged_tree
+    );
+}
