@@ -18,6 +18,7 @@ use jj_lib::backend::CommitId;
 use jj_lib::backend::CopyRecord;
 use jj_lib::backend::FileId;
 use jj_lib::backend::TreeValue;
+use jj_lib::conflict_labels::ConflictLabels;
 use jj_lib::copies::CopiesTreeDiffEntryPath;
 use jj_lib::copies::CopyOperation;
 use jj_lib::copies::CopyRecords;
@@ -80,10 +81,12 @@ fn test_merged_tree_builder_resolves_conflict() {
 
     let base_tree = MergedTree::new(
         store.clone(),
-        Merge::from_removes_adds(
-            [tree1.id().clone()],
-            [tree2.id().clone(), tree3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            tree2.id().clone(),
+            tree1.id().clone(),
+            tree3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["tree 2".into(), "tree 1".into(), "tree 3".into()]),
     );
     let tree_builder = MergedTreeBuilder::new(base_tree);
     let tree = tree_builder.write_tree().unwrap();
@@ -132,10 +135,12 @@ fn test_path_value_and_entries() {
     );
     let merged_tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![tree1.id().clone()],
-            vec![tree2.id().clone(), tree3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            tree2.id().clone(),
+            tree1.id().clone(),
+            tree3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["tree 2".into(), "tree 1".into(), "tree 3".into()]),
     );
 
     // Get the root tree
@@ -284,10 +289,12 @@ fn test_resolve_success() {
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone()],
-            vec![side1.id().clone(), side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["left".into(), "base".into(), "right".into()]),
     );
     let resolved_tree = tree.resolve().block_on().unwrap();
     assert!(resolved_tree.tree_ids().is_resolved());
@@ -308,10 +315,12 @@ fn test_resolve_root_becomes_empty() {
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone()],
-            vec![side1.id().clone(), side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["side 1".into(), "base 1".into(), "side 2".into()]),
     );
     let resolved = tree.resolve().block_on().unwrap();
     assert_tree_eq!(resolved, store.empty_merged_tree());
@@ -326,29 +335,50 @@ fn test_resolve_with_conflict() {
     // cannot)
     let trivial_path = repo_path("dir1/trivial");
     let conflict_path = repo_path("dir2/file_conflict");
-    let base1 = create_single_tree(repo, &[(trivial_path, "base1"), (conflict_path, "base1")]);
-    let side1 = create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "side1")]);
-    let side2 = create_single_tree(repo, &[(trivial_path, "base1"), (conflict_path, "side2")]);
-    let expected_base1 =
-        create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "base1")]);
+
+    // We start with a 3-sided conflict:
+    let side1 = create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "base")]);
+    let base1 = create_single_tree(repo, &[(trivial_path, "base"), (conflict_path, "base")]);
+    let side2 = create_single_tree(repo, &[(trivial_path, "base"), (conflict_path, "side2")]);
+    let base2 = create_single_tree(repo, &[(trivial_path, "base"), (conflict_path, "base")]);
+    let side3 = create_single_tree(repo, &[(trivial_path, "base"), (conflict_path, "side3")]);
+
+    // This should be reduced to a 2-sided conflict after "trivial" is resolved:
     let expected_side1 =
-        create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "side1")]);
-    let expected_side2 =
         create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "side2")]);
+    let expected_base1 =
+        create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "base")]);
+    let expected_side2 =
+        create_single_tree(repo, &[(trivial_path, "side1"), (conflict_path, "side3")]);
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone()],
-            vec![side1.id().clone(), side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+            base2.id().clone(),
+            side3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "side 1".into(),
+            "base 1".into(),
+            "side 2".into(),
+            "base 2".into(),
+            "side 3".into(),
+        ]),
     );
     let resolved_tree = tree.resolve().block_on().unwrap();
-    assert_eq!(
-        resolved_tree.tree_ids(),
-        &Merge::from_removes_adds(
-            vec![expected_base1.id().clone()],
-            vec![expected_side1.id().clone(), expected_side2.id().clone()]
+    assert_tree_eq!(
+        resolved_tree,
+        MergedTree::new(
+            repo.store().clone(),
+            Merge::from_vec(vec![
+                expected_side1.id().clone(),
+                expected_base1.id().clone(),
+                expected_side2.id().clone()
+            ]),
+            ConflictLabels::from_vec(vec!["side 2".into(), "base 2".into(), "side 3".into()]),
         )
     );
 }
@@ -367,10 +397,12 @@ fn test_resolve_with_conflict_containing_empty_subtree() {
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone()],
-            vec![side1.id().clone(), side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["left".into(), "base".into(), "right".into()]),
     );
     let resolved_tree = tree.clone().resolve().block_on().unwrap();
     assert_tree_eq!(resolved_tree, tree);
@@ -445,10 +477,12 @@ fn test_conflict_iterator() {
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone()],
-            vec![side1.id().clone(), side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["side 1".into(), "base 1".into(), "side 2".into()]),
     );
     let conflicts = tree
         .conflicts()
@@ -485,6 +519,22 @@ fn test_conflict_iterator() {
         ]
     );
 
+    // We can filter conflicts using a matcher
+    let conflicts = tree
+        .conflicts_matching(&PrefixMatcher::new([file_conflict_path, dir_file_path]))
+        .map(|(path, conflict)| (path, conflict.unwrap()))
+        .collect_vec();
+    assert_eq!(
+        conflicts,
+        vec![
+            (dir_file_path.to_owned(), conflict_at(dir_file_path)),
+            (
+                file_conflict_path.to_owned(),
+                conflict_at(file_conflict_path)
+            ),
+        ]
+    );
+
     // After we resolve conflicts, there are only non-trivial conflicts left
     let tree = tree.resolve().block_on().unwrap();
     let conflicts = tree
@@ -541,10 +591,20 @@ fn test_conflict_iterator_higher_arity() {
 
     let tree = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![base1.id().clone(), base2.id().clone()],
-            vec![side1.id().clone(), side2.id().clone(), side3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1.id().clone(),
+            base1.id().clone(),
+            side2.id().clone(),
+            base2.id().clone(),
+            side3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "side 1".into(),
+            "base 1".into(),
+            "side 2".into(),
+            "base 2".into(),
+            "side 3".into(),
+        ]),
     );
     let conflicts = tree
         .conflicts()
@@ -879,17 +939,29 @@ fn test_diff_conflicted() {
     );
     let left_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![left_base.id().clone()],
-            vec![left_side1.id().clone(), left_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            left_side1.id().clone(),
+            left_base.id().clone(),
+            left_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "left side 1".into(),
+            "left base".into(),
+            "left side 2".into(),
+        ]),
     );
     let right_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![right_base.id().clone()],
-            vec![right_side1.id().clone(), right_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            right_side1.id().clone(),
+            right_base.id().clone(),
+            right_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "right side 1".into(),
+            "right base".into(),
+            "right side 2".into(),
+        ]),
     );
 
     // Test the forwards diff
@@ -1020,17 +1092,29 @@ fn test_diff_dir_file() {
     );
     let left_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![left_base.id().clone()],
-            vec![left_side1.id().clone(), left_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            left_side1.id().clone(),
+            left_base.id().clone(),
+            left_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "left side 1".into(),
+            "left base".into(),
+            "left side 2".into(),
+        ]),
     );
     let right_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![right_base.id().clone()],
-            vec![right_side1.id().clone(), right_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            right_side1.id().clone(),
+            right_base.id().clone(),
+            right_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "right side 1".into(),
+            "right base".into(),
+            "right side 2".into(),
+        ]),
     );
     let left_value = |path: &RepoPath| left_merged.path_value(path).unwrap();
     let right_value = |path: &RepoPath| right_merged.path_value(path).unwrap();
@@ -1213,10 +1297,13 @@ fn test_merge_simple() {
     let side2_merged = MergedTree::resolved(repo.store().clone(), side2.id().clone());
     let expected_merged = MergedTree::resolved(repo.store().clone(), expected.id().clone());
 
-    let merged = side1_merged
-        .merge(base1_merged, side2_merged)
-        .block_on()
-        .unwrap();
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (side1_merged, "side 1".into()),
+        (base1_merged, "base 1".into()),
+        (side2_merged, "side 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 }
 
@@ -1240,16 +1327,21 @@ fn test_merge_partial_resolution() {
     let side2_merged = MergedTree::resolved(repo.store().clone(), side2.id().clone());
     let expected_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![expected_base1.id().clone()],
-            vec![expected_side1.id().clone(), expected_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            expected_side1.id().clone(),
+            expected_base1.id().clone(),
+            expected_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["side 1".into(), "base 1".into(), "side 2".into()]),
     );
 
-    let merged = side1_merged
-        .merge(base1_merged, side2_merged)
-        .block_on()
-        .unwrap();
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (side1_merged, "side 1".into()),
+        (base1_merged, "base 1".into()),
+        (side2_merged, "side 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 }
 
@@ -1269,31 +1361,40 @@ fn test_merge_simplify_only() {
     let expected = tree5.clone();
     let base1_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![tree1.id().clone()],
-            vec![tree2.id().clone(), tree3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            tree2.id().clone(),
+            tree1.id().clone(),
+            tree3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["tree 2".into(), "tree 1".into(), "tree 3".into()]),
     );
     let side1_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![tree1.id().clone()],
-            vec![tree4.id().clone(), tree2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            tree4.id().clone(),
+            tree1.id().clone(),
+            tree2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["tree 4".into(), "tree 1".into(), "tree 2".into()]),
     );
     let side2_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![tree4.id().clone()],
-            vec![tree5.id().clone(), tree3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            tree5.id().clone(),
+            tree4.id().clone(),
+            tree3.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["tree 5".into(), "tree 4".into(), "tree 3".into()]),
     );
     let expected_merged = MergedTree::resolved(repo.store().clone(), expected.id().clone());
 
-    let merged = side1_merged
-        .merge(base1_merged, side2_merged)
-        .block_on()
-        .unwrap();
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (side1_merged, "side 1".into()),
+        (base1_merged, "base 1".into()),
+        (side2_merged, "side 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 }
 
@@ -1308,35 +1409,110 @@ fn test_merge_simplify_result() {
     // The conflict in path1 cannot be resolved, but the conflict in path2 can.
     let path1 = repo_path("dir1/file");
     let path2 = repo_path("dir2/file");
-    let tree1 = create_single_tree(repo, &[(path1, "1"), (path2, "1")]);
-    let tree2 = create_single_tree(repo, &[(path1, "2"), (path2, "2")]);
-    let tree3 = create_single_tree(repo, &[(path1, "3"), (path2, "3")]);
-    let tree4 = create_single_tree(repo, &[(path1, "4"), (path2, "2")]);
-    let tree5 = create_single_tree(repo, &[(path1, "4"), (path2, "1")]);
-    let expected_base1 = create_single_tree(repo, &[(path1, "1"), (path2, "3")]);
+    let side1_left = create_single_tree(repo, &[(path1, "2"), (path2, "2")]);
+    let side1_base = create_single_tree(repo, &[(path1, "1"), (path2, "1")]);
+    let side1_right = create_single_tree(repo, &[(path1, "3"), (path2, "3")]);
+    let base1 = create_single_tree(repo, &[(path1, "4"), (path2, "2")]);
+    let side2 = create_single_tree(repo, &[(path1, "4"), (path2, "1")]);
     let expected_side1 = create_single_tree(repo, &[(path1, "2"), (path2, "3")]);
+    let expected_base1 = create_single_tree(repo, &[(path1, "1"), (path2, "3")]);
     let expected_side2 = create_single_tree(repo, &[(path1, "3"), (path2, "3")]);
     let side1_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![tree1.id().clone()],
-            vec![tree2.id().clone(), tree3.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            side1_left.id().clone(),
+            side1_base.id().clone(),
+            side1_right.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "side 1 left".into(),
+            "side 1 base".into(),
+            "side 1 right".into(),
+        ]),
     );
-    let base1_merged = MergedTree::resolved(repo.store().clone(), tree4.id().clone());
-    let side2_merged = MergedTree::resolved(repo.store().clone(), tree5.id().clone());
+    let base1_merged = MergedTree::resolved(repo.store().clone(), base1.id().clone());
+    let side2_merged = MergedTree::resolved(repo.store().clone(), side2.id().clone());
     let expected_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![expected_base1.id().clone()],
-            vec![expected_side1.id().clone(), expected_side2.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            expected_side1.id().clone(),
+            expected_base1.id().clone(),
+            expected_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "side 1 left".into(),
+            "side 1 base".into(),
+            "side 1 right".into(),
+        ]),
     );
 
-    let merged = side1_merged
-        .merge(base1_merged, side2_merged)
-        .block_on()
-        .unwrap();
+    // Although we pass labels here, they don't appear in the final result. The
+    // "side 1" label is ignored because that side is already conflicted. The "base
+    // 1" and "side 2" labels are used, but then those sides are removed after
+    // resolving and simplifying.
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (side1_merged, "side 1".into()),
+        (base1_merged, "base 1".into()),
+        (side2_merged, "side 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
+    assert_tree_eq!(merged, expected_merged);
+}
+
+/// Test that resolved trees take their labels from `MergeLabels`.
+#[test]
+fn test_merge_simplify_result_with_resolved_labels() {
+    let test_repo = TestRepo::init();
+    let repo = &test_repo.repo;
+
+    // The conflict in path1 cannot be resolved, but the conflict in path2 can.
+    let path1 = repo_path("dir1/file");
+    let path2 = repo_path("dir2/file");
+    let side1 = create_single_tree(repo, &[(path1, "2"), (path2, "2")]);
+    let base1 = create_single_tree(repo, &[(path1, "1"), (path2, "1")]);
+    let side2_left = create_single_tree(repo, &[(path1, "3"), (path2, "3")]);
+    let side2_base = create_single_tree(repo, &[(path1, "4"), (path2, "2")]);
+    let side2_right = create_single_tree(repo, &[(path1, "4"), (path2, "1")]);
+    let expected_side1 = create_single_tree(repo, &[(path1, "2"), (path2, "3")]);
+    let expected_base1 = create_single_tree(repo, &[(path1, "1"), (path2, "3")]);
+    let expected_side2 = create_single_tree(repo, &[(path1, "3"), (path2, "3")]);
+    let side1_merged = MergedTree::resolved(repo.store().clone(), side1.id().clone());
+    let base1_merged = MergedTree::resolved(repo.store().clone(), base1.id().clone());
+    let side2_merged = MergedTree::new(
+        repo.store().clone(),
+        Merge::from_vec(vec![
+            side2_left.id().clone(),
+            side2_base.id().clone(),
+            side2_right.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "side 2 left".into(),
+            "side 2 base".into(),
+            "side 2 right".into(),
+        ]),
+    );
+    let expected_merged = MergedTree::new(
+        repo.store().clone(),
+        Merge::from_vec(vec![
+            expected_side1.id().clone(),
+            expected_base1.id().clone(),
+            expected_side2.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec!["side 1".into(), "".into(), "side 2 left".into()]),
+    );
+
+    // Since side 1 is resolved, it will use the provided "side 1" label. Since side
+    // 2 is conflicted, its existing labels are used instead of the provided "side
+    // 2" label. Two of the terms from side 2 will be removed after resolving and
+    // simplifying. One of the terms has an empty label, which should be preserved.
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (side1_merged, "side 1".into()),
+        (base1_merged, "".into()),
+        (side2_merged, "side 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 }
 
@@ -1412,10 +1588,16 @@ fn test_merge_simplify_file_conflict() {
     let parent_right = create_single_tree(repo, &[(conflict_path, &parent_right_text)]);
     let parent_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![parent_base.id().clone()],
-            vec![parent_left.id().clone(), parent_right.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            parent_left.id().clone(),
+            parent_base.id().clone(),
+            parent_right.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "parent left".into(),
+            "parent base".into(),
+            "parent right".into(),
+        ]),
     );
 
     // different conflict in child
@@ -1433,10 +1615,16 @@ fn test_merge_simplify_file_conflict() {
     );
     let child1_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![child1_base.id().clone()],
-            vec![child1_left.id().clone(), child1_right.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            child1_left.id().clone(),
+            child1_base.id().clone(),
+            child1_right.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "child 1 left".into(),
+            "child 1 base".into(),
+            "child 1 right".into(),
+        ]),
     );
 
     // resolved state
@@ -1450,14 +1638,17 @@ fn test_merge_simplify_file_conflict() {
     );
     let expected_merged = MergedTree::resolved(repo.store().clone(), expected.id().clone());
 
-    let merged = child1_merged
-        .merge(parent_merged, child2_merged)
-        .block_on()
-        .unwrap();
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (child1_merged, "child 1".into()),
+        (parent_merged, "parent".into()),
+        (child2_merged, "child 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 
     // Also test the setup by checking that the unsimplified content conflict cannot
-    // be resolved. If we later change files::merge() so this no longer fails,  it
+    // be resolved. If we later change files::merge() so this no longer fails, it
     // probably means that we can delete this whole test (the Merge::simplify() call
     // in try_resolve_file_conflict() is just an optimization then).
     let text_merge = Merge::from_removes_adds(
@@ -1497,18 +1688,27 @@ fn test_merge_simplify_file_conflict_with_absent() {
     let parent_merged = MergedTree::resolved(repo.store().clone(), parent.id().clone());
     let child2_merged = MergedTree::new(
         repo.store().clone(),
-        Merge::from_removes_adds(
-            vec![child2_base.id().clone()],
-            vec![child2_left.id().clone(), child2_right.id().clone()],
-        ),
+        Merge::from_vec(vec![
+            child2_left.id().clone(),
+            child2_base.id().clone(),
+            child2_right.id().clone(),
+        ]),
+        ConflictLabels::from_vec(vec![
+            "child 2 left".into(),
+            "child 2 base".into(),
+            "child 2 right".into(),
+        ]),
     );
 
     let expected = create_single_tree(repo, &[(child2_path, ""), (conflict_path, "1\n0\n2\n")]);
     let expected_merged = MergedTree::resolved(repo.store().clone(), expected.id().clone());
 
-    let merged = child1_merged
-        .merge(parent_merged, child2_merged)
-        .block_on()
-        .unwrap();
+    let merged = MergedTree::merge(Merge::from_vec(vec![
+        (child1_merged, "child 1".into()),
+        (parent_merged, "parent".into()),
+        (child2_merged, "child 2".into()),
+    ]))
+    .block_on()
+    .unwrap();
     assert_tree_eq!(merged, expected_merged);
 }
