@@ -23,6 +23,7 @@ use jj_lib::backend::CommitId;
 use jj_lib::config::ConfigLayer;
 use jj_lib::config::ConfigSource;
 use jj_lib::evolution::walk_predecessors;
+use jj_lib::index::Index;
 use jj_lib::object_id::ObjectId as _;
 use jj_lib::op_store::OperationId;
 use jj_lib::op_walk;
@@ -32,6 +33,7 @@ use jj_lib::operation::Operation;
 use jj_lib::repo::ReadonlyRepo;
 use jj_lib::repo::Repo;
 use jj_lib::settings::UserSettings;
+use pollster::FutureExt as _;
 use test_case::test_case;
 use testutils::TestRepo;
 use testutils::write_random_commit;
@@ -55,6 +57,10 @@ fn list_dir(dir: &Path) -> Vec<String> {
         .collect()
 }
 
+fn index_has_id(index: &dyn Index, commit_id: &CommitId) -> bool {
+    index.has_id(commit_id).unwrap()
+}
+
 #[test]
 fn test_unpublished_operation() {
     // Test that the operation doesn't get published until that's requested.
@@ -247,7 +253,7 @@ fn test_stored_commit_predecessors() {
     // Save operation without the predecessors as old jj would do.
     let mut data = op.store_operation().clone();
     data.commit_predecessors = None;
-    let op_id = loader.op_store().write_operation(&data).unwrap();
+    let op_id = loader.op_store().write_operation(&data).block_on().unwrap();
     assert_ne!(&op_id, op.id());
     let op = loader.load_operation(&op_id).unwrap();
     assert!(!op.stores_commit_predecessors());
@@ -526,7 +532,7 @@ fn test_reparent_discarding_predecessors(op_stores_commit_predecessors: bool) {
         // fall back to the legacy code path immediately.
         let mut data = repo_4.operation().store_operation().clone();
         data.commit_predecessors = None;
-        let op_id = op_store.write_operation(&data).unwrap();
+        let op_id = op_store.write_operation(&data).block_on().unwrap();
         repo_at(&op_id)
     };
 
@@ -566,8 +572,8 @@ fn test_reparent_discarding_predecessors(op_stores_commit_predecessors: bool) {
     assert_eq!(stats.unreachable_count, 1);
     let repo = repo_at(&stats.new_head_ids[0]);
     // A0 - B0 are still reachable
-    assert!(repo.index().has_id(commit_a0.id()));
-    assert!(repo.index().has_id(commit_b0.id()));
+    assert!(index_has_id(repo.index(), commit_a0.id()));
+    assert!(index_has_id(repo.index(), commit_b0.id()));
     assert_eq!(
         get_predecessors(&repo, commit_a1.id()),
         [commit_a0.id().clone()]
@@ -592,17 +598,17 @@ fn test_reparent_discarding_predecessors(op_stores_commit_predecessors: bool) {
     assert_eq!(stats.unreachable_count, 2);
     let repo = repo_at(&stats.new_head_ids[0]);
     // A0 is still reachable
-    assert!(repo.index().has_id(commit_a0.id()));
+    assert!(index_has_id(repo.index(), commit_a0.id()));
     if op_stores_commit_predecessors {
         // B0 is no longer reachable
-        assert!(!repo.index().has_id(commit_b0.id()));
+        assert!(!index_has_id(repo.index(), commit_b0.id()));
         // the predecessor record `A1: A0` no longer exists
         assert_eq!(get_predecessors(&repo, commit_a1.id()), []);
         // Unreachable predecessors should be excluded
         assert_eq!(get_predecessors(&repo, commit_b1.id()), []);
     } else {
         // B0 is retained because it is immediate predecessor of B1
-        assert!(repo.index().has_id(commit_b0.id()));
+        assert!(index_has_id(repo.index(), commit_b0.id()));
         assert_eq!(
             get_predecessors(&repo, commit_a1.id()),
             [commit_a0.id().clone()]
@@ -626,9 +632,9 @@ fn test_reparent_discarding_predecessors(op_stores_commit_predecessors: bool) {
     assert_eq!(stats.unreachable_count, 3);
     let repo = repo_at(&stats.new_head_ids[0]);
     // A0 is no longer reachable
-    assert!(!repo.index().has_id(commit_a0.id()));
+    assert!(!index_has_id(repo.index(), commit_a0.id()));
     // A1 is still reachable through A2
-    assert!(repo.index().has_id(commit_a1.id()));
+    assert!(index_has_id(repo.index(), commit_a1.id()));
     assert_eq!(
         get_predecessors(&repo, commit_a2.id()),
         [commit_a1.id().clone()]
