@@ -80,21 +80,37 @@ pub mod git;
 pub mod proptest;
 pub mod test_backend;
 
+pub const HERMETIC_GIT_CONFIGS: &[(&str, &str)] = &[
+    // gitoxide uses "main" as the default branch name, whereas git uses "master". This also
+    // prevents git CLI from issuing the initial branch name advice.
+    ("init.defaultBranch", "master"),
+];
+
 // TODO: Consider figuring out a way to make `GitBackend` and `git(1)` calls in
 // tests ignore external configuration and removing this function. This is
 // somewhat tricky because `gix` looks at system and user configuration, and
 // `GitBackend` also calls into `git(1)` for things like garbage collection.
 pub fn hermetic_git() {
-    unsafe {
+    let mut envs = [
         // Prevent GitBackend from loading user and system configurations. For
         // gitoxide API use in tests, Config::isolated() is probably better.
-        env::set_var("GIT_CONFIG_SYSTEM", "/dev/null");
-        env::set_var("GIT_CONFIG_GLOBAL", "/dev/null");
-        // gitoxide uses "main" as the default branch name, whereas git
-        // uses "master".
-        env::set_var("GIT_CONFIG_KEY_0", "init.defaultBranch");
-        env::set_var("GIT_CONFIG_VALUE_0", "master");
-        env::set_var("GIT_CONFIG_COUNT", "1");
+        ("GIT_CONFIG_SYSTEM", "/dev/null"),
+        ("GIT_CONFIG_GLOBAL", "/dev/null"),
+    ]
+    .map(|(key, value)| (key.to_string(), value.to_string()))
+    .to_vec();
+    for (i, (key, value)) in HERMETIC_GIT_CONFIGS.iter().enumerate() {
+        envs.push((format!("GIT_CONFIG_KEY_{i}"), key.to_string()));
+        envs.push((format!("GIT_CONFIG_VALUE_{i}"), value.to_string()));
+    }
+    envs.push((
+        "GIT_CONFIG_COUNT".to_string(),
+        HERMETIC_GIT_CONFIGS.len().to_string(),
+    ));
+    for (key, value) in envs {
+        // SAFETY: This is actually not safe. `getenv` and `setenv` are not thread safe,
+        // and we can't guarantee that the following call won't have race conditions.
+        unsafe { env::set_var(key, value) };
     }
 }
 
@@ -543,10 +559,12 @@ pub fn commit_with_tree(store: &Arc<Store>, tree: MergedTree) -> Commit {
             tz_offset: 0,
         },
     };
+    let (root_tree, conflict_labels) = tree.into_tree_ids_and_labels();
     let commit = backend::Commit {
         parents: vec![store.root_commit_id().clone()],
         predecessors: vec![],
-        root_tree: tree.into_tree_ids(),
+        root_tree,
+        conflict_labels: conflict_labels.into_merge(),
         change_id: ChangeId::from_hex("abcd"),
         description: "description".to_string(),
         author: signature.clone(),
@@ -560,9 +578,9 @@ pub fn dump_tree(merged_tree: &MergedTree) -> String {
     use std::fmt::Write as _;
     let store = merged_tree.store();
     let mut buf = String::new();
-    let trees = merged_tree.trees().unwrap();
+    let trees = merged_tree.trees().block_on().unwrap();
     writeln!(&mut buf, "merged tree (sides: {})", trees.num_sides()).unwrap();
-    for tree in trees.iter() {
+    for tree in &trees {
         writeln!(&mut buf, "  tree {}", tree.id()).unwrap();
         for (path, entry) in tree.entries_matching(&EverythingMatcher) {
             match entry {
@@ -599,8 +617,8 @@ macro_rules! assert_tree_eq {
         let left_tree: &::jj_lib::merged_tree::MergedTree = &$left_tree;
         let right_tree: &::jj_lib::merged_tree::MergedTree = &$right_tree;
         assert_eq!(
-            left_tree.tree_ids(),
-            right_tree.tree_ids(),
+            left_tree.tree_ids_and_labels(),
+            right_tree.tree_ids_and_labels(),
             "{}:\n left: {}\nright: {}",
             format_args!($($args)*),
             $crate::dump_tree(left_tree),
@@ -773,7 +791,6 @@ pub fn assert_no_forgotten_test_files(test_dir: &Path) {
 /// UTF-8 validation, as on ZFS with the `utf8only=on` property set.
 #[cfg(unix)]
 pub fn check_strict_utf8_fs(dir: &Path) -> bool {
-    use std::ffi::OsStr;
     use std::os::unix::ffi::OsStrExt as _;
 
     let test_file_normal = tempfile::Builder::new()
